Class: CyberSource::AddAgentKeyResponse201
- Inherits:
-
Object
- Object
- CyberSource::AddAgentKeyResponse201
- Defined in:
- lib/cybersource_rest_client/models/add_agent_key_response201.rb
Overview
Response object for a single agent public key, including agent context.
Instance Attribute Summary collapse
-
#agent_id ⇒ Object
Agent identifier.
-
#agent_name ⇒ Object
Agent name.
-
#agent_type ⇒ Object
Agent classification Possible values: - trusted - known.
-
#algorithm ⇒ Object
Signing algorithm Possible values: - RSA-SHA256 - RSA-SHA512 - ECDSA-SHA256 - ECDSA-SHA512 - EdDSA.
-
#created_at ⇒ Object
Creation timestamp.
-
#expiration_date ⇒ Object
Key expiration date in UTC.
-
#id ⇒ Object
Unique key identifier.
-
#key_name ⇒ Object
Unique identifier for the key.
-
#public_key ⇒ Object
Base64-encoded public key.
-
#status ⇒ Object
Key lifecycle status Possible values: - active - deactivated - expired.
-
#updated_at ⇒ Object
Last update timestamp.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddAgentKeyResponse201
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AddAgentKeyResponse201
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 103 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'agentId') self.agent_id = attributes[:'agentId'] end if attributes.has_key?(:'agentName') self.agent_name = attributes[:'agentName'] end if attributes.has_key?(:'agentType') self.agent_type = attributes[:'agentType'] end if attributes.has_key?(:'keyName') self.key_name = attributes[:'keyName'] end if attributes.has_key?(:'publicKey') self.public_key = attributes[:'publicKey'] end if attributes.has_key?(:'algorithm') self.algorithm = attributes[:'algorithm'] end if attributes.has_key?(:'expirationDate') self.expiration_date = attributes[:'expirationDate'] end if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'createdAt') self.created_at = attributes[:'createdAt'] end if attributes.has_key?(:'updatedAt') self.updated_at = attributes[:'updatedAt'] end end |
Instance Attribute Details
#agent_id ⇒ Object
Agent identifier
21 22 23 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 21 def agent_id @agent_id end |
#agent_name ⇒ Object
Agent name
24 25 26 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 24 def agent_name @agent_name end |
#agent_type ⇒ Object
Agent classification Possible values: - trusted - known
27 28 29 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 27 def agent_type @agent_type end |
#algorithm ⇒ Object
Signing algorithm Possible values: - RSA-SHA256 - RSA-SHA512 - ECDSA-SHA256 - ECDSA-SHA512 - EdDSA
36 37 38 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 36 def algorithm @algorithm end |
#created_at ⇒ Object
Creation timestamp
45 46 47 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 45 def created_at @created_at end |
#expiration_date ⇒ Object
Key expiration date in UTC
39 40 41 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 39 def expiration_date @expiration_date end |
#id ⇒ Object
Unique key identifier. Generated from VARS.
18 19 20 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 18 def id @id end |
#key_name ⇒ Object
Unique identifier for the key
30 31 32 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 30 def key_name @key_name end |
#public_key ⇒ Object
Base64-encoded public key
33 34 35 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 33 def public_key @public_key end |
#status ⇒ Object
Key lifecycle status Possible values: - active - deactivated - expired
42 43 44 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 42 def status @status end |
#updated_at ⇒ Object
Last update timestamp
48 49 50 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 48 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 51 def self.attribute_map { :'id' => :'id', :'agent_id' => :'agentId', :'agent_name' => :'agentName', :'agent_type' => :'agentType', :'key_name' => :'keyName', :'public_key' => :'publicKey', :'algorithm' => :'algorithm', :'expiration_date' => :'expirationDate', :'status' => :'status', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 68 def self.json_map { :'id' => :'id', :'agent_id' => :'agent_id', :'agent_name' => :'agent_name', :'agent_type' => :'agent_type', :'key_name' => :'key_name', :'public_key' => :'public_key', :'algorithm' => :'algorithm', :'expiration_date' => :'expiration_date', :'status' => :'status', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.swagger_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 85 def self.swagger_types { :'id' => :'String', :'agent_id' => :'String', :'agent_name' => :'String', :'agent_type' => :'String', :'key_name' => :'String', :'public_key' => :'String', :'algorithm' => :'String', :'expiration_date' => :'DateTime', :'status' => :'String', :'created_at' => :'DateTime', :'updated_at' => :'DateTime' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && agent_id == o.agent_id && agent_name == o.agent_name && agent_type == o.agent_type && key_name == o.key_name && public_key == o.public_key && algorithm == o.algorithm && expiration_date == o.expiration_date && status == o.status && created_at == o.created_at && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 276 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 342 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 255 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 248 def hash [id, agent_id, agent_name, agent_type, key_name, public_key, algorithm, expiration_date, status, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 156 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @agent_id.nil? invalid_properties.push('invalid value for "agent_id", agent_id cannot be nil.') end if @agent_name.nil? invalid_properties.push('invalid value for "agent_name", agent_name cannot be nil.') end if @agent_type.nil? invalid_properties.push('invalid value for "agent_type", agent_type cannot be nil.') end if @key_name.nil? invalid_properties.push('invalid value for "key_name", key_name cannot be nil.') end if @public_key.nil? invalid_properties.push('invalid value for "public_key", public_key cannot be nil.') end if @algorithm.nil? invalid_properties.push('invalid value for "algorithm", algorithm cannot be nil.') end if @expiration_date.nil? invalid_properties.push('invalid value for "expiration_date", expiration_date cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
322 323 324 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 322 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
316 317 318 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 316 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/cybersource_rest_client/models/add_agent_key_response201.rb', line 207 def valid? return false if @id.nil? return false if @agent_id.nil? return false if @agent_name.nil? return false if @agent_type.nil? return false if @key_name.nil? return false if @public_key.nil? return false if @algorithm.nil? return false if @expiration_date.nil? return false if @status.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |