Class: CyberSource::AgentRegistrationResponse201
- Inherits:
-
Object
- Object
- CyberSource::AgentRegistrationResponse201
- Defined in:
- lib/cybersource_rest_client/models/agent_registration_response201.rb
Overview
Response object for a registered agent, including its associated public keys.
Instance Attribute Summary collapse
-
#agent_metadata ⇒ Object
Additional agent metadata.
-
#agent_type ⇒ Object
Agent classification: 'trusted' (commercially onboarded) or 'known' (open-source/unverified) Possible values: - trusted - known.
-
#contact_email ⇒ Object
Contact email.
-
#created_at ⇒ Object
Creation timestamp.
-
#description ⇒ Object
Agent description.
-
#domain ⇒ Object
Agent domain URL.
-
#id ⇒ Object
Unique agent identifier (64-char SHA-256 hash of domain + email + tokenRequestorId).
-
#is_active ⇒ Object
Whether the agent is active.
-
#keys ⇒ Object
List of keys associated with the agent.
-
#name ⇒ Object
Agent name.
-
#token_requestor_id ⇒ Object
Unique token requestor identifier.
-
#updated_at ⇒ Object
Last update timestamp.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AgentRegistrationResponse201
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AgentRegistrationResponse201
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 109 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'domain') self.domain = attributes[:'domain'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'contactEmail') self.contact_email = attributes[:'contactEmail'] end if attributes.has_key?(:'tokenRequestorId') self.token_requestor_id = attributes[:'tokenRequestorId'] end if attributes.has_key?(:'agentType') self.agent_type = attributes[:'agentType'] end if attributes.has_key?(:'agentMetadata') if (value = attributes[:'agentMetadata']).is_a?(Hash) self. = value end end if attributes.has_key?(:'isActive') self.is_active = attributes[:'isActive'] end if attributes.has_key?(:'createdAt') self.created_at = attributes[:'createdAt'] end if attributes.has_key?(:'updatedAt') self.updated_at = attributes[:'updatedAt'] end if attributes.has_key?(:'keys') if (value = attributes[:'keys']).is_a?(Array) self.keys = value end end end |
Instance Attribute Details
#agent_metadata ⇒ Object
Additional agent metadata
39 40 41 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 39 def @agent_metadata end |
#agent_type ⇒ Object
Agent classification: 'trusted' (commercially onboarded) or 'known' (open-source/unverified) Possible values: - trusted - known
36 37 38 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 36 def agent_type @agent_type end |
#contact_email ⇒ Object
Contact email
30 31 32 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 30 def contact_email @contact_email end |
#created_at ⇒ Object
Creation timestamp
45 46 47 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 45 def created_at @created_at end |
#description ⇒ Object
Agent description
27 28 29 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 27 def description @description end |
#domain ⇒ Object
Agent domain URL
24 25 26 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 24 def domain @domain end |
#id ⇒ Object
Unique agent identifier (64-char SHA-256 hash of domain + email + tokenRequestorId)
18 19 20 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 18 def id @id end |
#is_active ⇒ Object
Whether the agent is active
42 43 44 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 42 def is_active @is_active end |
#keys ⇒ Object
List of keys associated with the agent
51 52 53 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 51 def keys @keys end |
#name ⇒ Object
Agent name
21 22 23 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 21 def name @name end |
#token_requestor_id ⇒ Object
Unique token requestor identifier
33 34 35 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 33 def token_requestor_id @token_requestor_id end |
#updated_at ⇒ Object
Last update timestamp
48 49 50 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 48 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 54 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'domain' => :'domain', :'description' => :'description', :'contact_email' => :'contactEmail', :'token_requestor_id' => :'tokenRequestorId', :'agent_type' => :'agentType', :'agent_metadata' => :'agentMetadata', :'is_active' => :'isActive', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'keys' => :'keys' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 72 def self.json_map { :'id' => :'id', :'name' => :'name', :'domain' => :'domain', :'description' => :'description', :'contact_email' => :'contact_email', :'token_requestor_id' => :'token_requestor_id', :'agent_type' => :'agent_type', :'agent_metadata' => :'agent_metadata', :'is_active' => :'is_active', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'keys' => :'keys' } end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 90 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'domain' => :'String', :'description' => :'String', :'contact_email' => :'String', :'token_requestor_id' => :'String', :'agent_type' => :'String', :'agent_metadata' => :'Hash<String, String>', :'is_active' => :'BOOLEAN', :'created_at' => :'DateTime', :'updated_at' => :'DateTime', :'keys' => :'Array<AgentRegistrationResponse201Keys>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 223 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && domain == o.domain && description == o.description && contact_email == o.contact_email && token_requestor_id == o.token_requestor_id && agent_type == o.agent_type && == o. && is_active == o.is_active && created_at == o.created_at && updated_at == o.updated_at && keys == o.keys end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 276 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 342 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 255 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 248 def hash [id, name, domain, description, contact_email, token_requestor_id, agent_type, , is_active, created_at, updated_at, keys].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 170 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @domain.nil? invalid_properties.push('invalid value for "domain", domain cannot be nil.') end if @token_requestor_id.nil? invalid_properties.push('invalid value for "token_requestor_id", token_requestor_id cannot be nil.') end if @agent_type.nil? invalid_properties.push('invalid value for "agent_type", agent_type cannot be nil.') end if @is_active.nil? invalid_properties.push('invalid value for "is_active", is_active cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
322 323 324 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 322 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
316 317 318 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 316 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/cybersource_rest_client/models/agent_registration_response201.rb', line 209 def valid? return false if @id.nil? return false if @name.nil? return false if @domain.nil? return false if @token_requestor_id.nil? return false if @agent_type.nil? return false if @is_active.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |