Class: CyberSource::AgentRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/agent_request.rb

Overview

Request object for registering a new AI agent in the VARS.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AgentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 79

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'domain')
    self.domain = attributes[:'domain']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'contactEmail')
    self.contact_email = attributes[:'contactEmail']
  end

  if attributes.has_key?(:'tokenRequestorId')
    self.token_requestor_id = attributes[:'tokenRequestorId']
  end

  if attributes.has_key?(:'agentMetadata')
    if (value = attributes[:'agentMetadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.has_key?(:'keys')
    if (value = attributes[:'keys']).is_a?(Array)
      self.keys = value
    end
  end
end

Instance Attribute Details

#agent_metadataObject

Optional metadata (e.g., framework, version)



33
34
35
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 33

def 
  @agent_metadata
end

#contact_emailObject

Contact email



27
28
29
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 27

def contact_email
  @contact_email
end

#descriptionObject

Agent description



24
25
26
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 24

def description
  @description
end

#domainObject

Agent domain URL



21
22
23
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 21

def domain
  @domain
end

#keysObject

Optional list of keys to create with the agent



36
37
38
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 36

def keys
  @keys
end

#nameObject

Agent name



18
19
20
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 18

def name
  @name
end

#token_requestor_idObject

Unique token requestor identifier



30
31
32
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 30

def token_requestor_id
  @token_requestor_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 39

def self.attribute_map
  {
    :'name' => :'name',
    :'domain' => :'domain',
    :'description' => :'description',
    :'contact_email' => :'contactEmail',
    :'token_requestor_id' => :'tokenRequestorId',
    :'agent_metadata' => :'agentMetadata',
    :'keys' => :'keys'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 52

def self.json_map
  {
    :'name' => :'name',
    :'domain' => :'domain',
    :'description' => :'description',
    :'contact_email' => :'contact_email',
    :'token_requestor_id' => :'token_requestor_id',
    :'agent_metadata' => :'agent_metadata',
    :'keys' => :'keys'
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 65

def self.swagger_types
  {
    :'name' => :'String',
    :'domain' => :'String',
    :'description' => :'String',
    :'contact_email' => :'String',
    :'token_requestor_id' => :'String',
    :'agent_metadata' => :'Hash<String, String>',
    :'keys' => :'Array<Iccv1agentsKeys>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



158
159
160
161
162
163
164
165
166
167
168
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      domain == o.domain &&
      description == o.description &&
      contact_email == o.contact_email &&
      token_requestor_id == o.token_requestor_id &&
       == o. &&
      keys == o.keys
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 206

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 272

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 185

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


172
173
174
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 172

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



178
179
180
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 178

def hash
  [name, domain, description, contact_email, token_requestor_id, , keys].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 120

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @domain.nil?
    invalid_properties.push('invalid value for "domain", domain cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @contact_email.nil?
    invalid_properties.push('invalid value for "contact_email", contact_email cannot be nil.')
  end

  if @token_requestor_id.nil?
    invalid_properties.push('invalid value for "token_requestor_id", token_requestor_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



252
253
254
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 252

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



246
247
248
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 246

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
# File 'lib/cybersource_rest_client/models/agent_request.rb', line 147

def valid?
  return false if @name.nil?
  return false if @domain.nil?
  return false if @description.nil?
  return false if @contact_email.nil?
  return false if @token_requestor_id.nil?
  true
end