Class: CyberSource::Boardingv1registrationsOrganizationInformationBusinessInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Boardingv1registrationsOrganizationInformationBusinessInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 120

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'locale')
    self.locale = attributes[:'locale']
  end

  if attributes.has_key?(:'localizedNames')
    self.localized_names = attributes[:'localizedNames']
  end

  if attributes.has_key?(:'doingBusinessAs')
    self.doing_business_as = attributes[:'doingBusinessAs']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'startDate')
    self.start_date = attributes[:'startDate']
  end

  if attributes.has_key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.has_key?(:'timeZone')
    self.time_zone = attributes[:'timeZone']
  end

  if attributes.has_key?(:'websiteUrl')
    self.website_url = attributes[:'websiteUrl']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'taxId')
    self.tax_id = attributes[:'taxId']
  end

  if attributes.has_key?(:'phoneNumber')
    self.phone_number = attributes[:'phoneNumber']
  end

  if attributes.has_key?(:'businessContact')
    self.business_contact = attributes[:'businessContact']
  end

  if attributes.has_key?(:'technicalContact')
    self.technical_contact = attributes[:'technicalContact']
  end

  if attributes.has_key?(:'emergencyContact')
    self.emergency_contact = attributes[:'emergencyContact']
  end

  if attributes.has_key?(:'merchantCategoryCode')
    self.merchant_category_code = attributes[:'merchantCategoryCode']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



29
30
31
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 29

def address
  @address
end

#business_contactObject

Returns the value of attribute business_contact.



43
44
45
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 43

def business_contact
  @business_contact
end

#descriptionObject

Returns the value of attribute description.



24
25
26
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 24

def description
  @description
end

#doing_business_asObject

Returns the value of attribute doing_business_as.



22
23
24
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 22

def doing_business_as
  @doing_business_as
end

#emergency_contactObject

Returns the value of attribute emergency_contact.



47
48
49
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 47

def emergency_contact
  @emergency_contact
end

#localeObject

Returns the value of attribute locale.



18
19
20
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 18

def locale
  @locale
end

#localized_namesObject

Returns the value of attribute localized_names.



20
21
22
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 20

def localized_names
  @localized_names
end

#merchant_category_codeObject

Industry standard Merchant Category Code (MCC)



50
51
52
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 50

def merchant_category_code
  @merchant_category_code
end

#nameObject

Returns the value of attribute name.



16
17
18
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 16

def name
  @name
end

#phone_numberObject

Returns the value of attribute phone_number.



41
42
43
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 41

def phone_number
  @phone_number
end

#start_dateObject

‘Format: YYYY-MM-DD` Example 2016-08-11 equals August 11, 2016



27
28
29
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 27

def start_date
  @start_date
end

#tax_idObject

Returns the value of attribute tax_id.



39
40
41
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 39

def tax_id
  @tax_id
end

#technical_contactObject

Returns the value of attribute technical_contact.



45
46
47
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 45

def technical_contact
  @technical_contact
end

#time_zoneObject

Merchant perferred time zone Possible Values: - ‘Pacific/Pago_Pago’ - ‘Pacific/Honolulu’ - ‘America/Anchorage’ - ‘America/Vancouver’ - ‘America/Los_Angeles’ - ‘America/Phoenix’ - ‘America/Edmonton’ - ‘America/Denver’ - ‘America/Winnipeg’ - ‘America/Mexico_City’ - ‘America/Chicago’ - ‘America/Bogota’ - ‘America/Indianapolis’ - ‘America/New_York’ - ‘America/La_Paz’ - ‘America/Halifax’ - ‘America/St_Johns’ - ‘America/Buenos_Aires’ - ‘America/Godthab’ - ‘America/Sao_Paulo’ - ‘America/Noronha’ - ‘Atlantic/Cape_Verde’ - ‘GMT’ - ‘Europe/Dublin’ - ‘Europe/Lisbon’ - ‘Europe/London’ - ‘Africa/Tunis’ - ‘Europe/Vienna’ - ‘Europe/Brussels’ - ‘Europe/Zurich’ - ‘Europe/Prague’ - ‘Europe/Berlin’ - ‘Europe/Copenhagen’ - ‘Europe/Madrid’ - ‘Europe/Budapest’ - ‘Europe/Rome’ - ‘Africa/Tripoli’ - ‘Europe/Monaco’ - ‘Europe/Malta’ - ‘Europe/Amsterdam’ - ‘Europe/Oslo’ - ‘Europe/Warsaw’ - ‘Europe/Stockholm’ - ‘Europe/Belgrade’ - ‘Europe/Paris’ - ‘Africa/Johannesburg’ - ‘Europe/Minsk’ - ‘Africa/Cairo’ - ‘Europe/Helsinki’ - ‘Europe/Athens’ - ‘Asia/Jerusalem’ - ‘Europe/Riga’ - ‘Europe/Bucharest’ - ‘Europe/Istanbul’ - ‘Asia/Riyadh’ - ‘Europe/Moscow’ - ‘Asia/Dubai’ - ‘Asia/Baku’ - ‘Asia/Tbilisi’ - ‘Asia/Calcutta’ - ‘Asia/Katmandu’ - ‘Asia/Dacca’ - ‘Asia/Rangoon’ - ‘Asia/Jakarta’ - ‘Asia/Saigon’ - ‘Asia/Bangkok’ - ‘Australia/Perth’ - ‘Asia/Hong_Kong’ - ‘Asia/Macao’ - ‘Asia/Kuala_Lumpur’ - ‘Asia/Manila’ - ‘Asia/Singapore’ - ‘Asia/Taipei’ - ‘Asia/Shanghai’ - ‘Asia/Seoul’ - ‘Asia/Tokyo’ - ‘Asia/Yakutsk’ - ‘Australia/Adelaide’ - ‘Australia/Brisbane’ - ‘Australia/Broken_Hill’ - ‘Australia/Darwin’ - ‘Australia/Eucla’ - ‘Australia/Hobart’ - ‘Australia/Lindeman’ - ‘Australia/Sydney’ - ‘Australia/Lord_Howe’ - ‘Australia/Melbourne’ - ‘Asia/Magadan’ - ‘Pacific/Norfolk’ - ‘Pacific/Auckland’



32
33
34
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 32

def time_zone
  @time_zone
end

#typeObject

Business type Possible Values: - ‘PARTNERSHIP’ - ‘SOLE_PROPRIETORSHIP’ - ‘CORPORATION’ - ‘LLC’ - ‘NON_PROFIT’ - ‘TRUST’



37
38
39
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 37

def type
  @type
end

#website_urlObject

Returns the value of attribute website_url.



34
35
36
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 34

def website_url
  @website_url
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 53

def self.attribute_map
  {
    :'name' => :'name',
    :'locale' => :'locale',
    :'localized_names' => :'localizedNames',
    :'doing_business_as' => :'doingBusinessAs',
    :'description' => :'description',
    :'start_date' => :'startDate',
    :'address' => :'address',
    :'time_zone' => :'timeZone',
    :'website_url' => :'websiteUrl',
    :'type' => :'type',
    :'tax_id' => :'taxId',
    :'phone_number' => :'phoneNumber',
    :'business_contact' => :'businessContact',
    :'technical_contact' => :'technicalContact',
    :'emergency_contact' => :'emergencyContact',
    :'merchant_category_code' => :'merchantCategoryCode'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 75

def self.json_map
  {
    :'name' => :'name',
    :'locale' => :'locale',
    :'localized_names' => :'localized_names',
    :'doing_business_as' => :'doing_business_as',
    :'description' => :'description',
    :'start_date' => :'start_date',
    :'address' => :'address',
    :'time_zone' => :'time_zone',
    :'website_url' => :'website_url',
    :'type' => :'type',
    :'tax_id' => :'tax_id',
    :'phone_number' => :'phone_number',
    :'business_contact' => :'business_contact',
    :'technical_contact' => :'technical_contact',
    :'emergency_contact' => :'emergency_contact',
    :'merchant_category_code' => :'merchant_category_code'
  }
end

.swagger_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 97

def self.swagger_types
  {
    :'name' => :'String',
    :'locale' => :'String',
    :'localized_names' => :'Boardingv1registrationsOrganizationInformationBusinessInformationLocalizedNames',
    :'doing_business_as' => :'String',
    :'description' => :'String',
    :'start_date' => :'Date',
    :'address' => :'Boardingv1registrationsOrganizationInformationBusinessInformationAddress',
    :'time_zone' => :'String',
    :'website_url' => :'String',
    :'type' => :'String',
    :'tax_id' => :'String',
    :'phone_number' => :'String',
    :'business_contact' => :'Boardingv1registrationsOrganizationInformationBusinessInformationBusinessContact',
    :'technical_contact' => :'Boardingv1registrationsOrganizationInformationBusinessInformationBusinessContact',
    :'emergency_contact' => :'Boardingv1registrationsOrganizationInformationBusinessInformationBusinessContact',
    :'merchant_category_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 335

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      locale == o.locale &&
      localized_names == o.localized_names &&
      doing_business_as == o.doing_business_as &&
      description == o.description &&
      start_date == o.start_date &&
      address == o.address &&
      time_zone == o.time_zone &&
      website_url == o.website_url &&
      type == o.type &&
      tax_id == o.tax_id &&
      phone_number == o.phone_number &&
      business_contact == o.business_contact &&
      technical_contact == o.technical_contact &&
      emergency_contact == o.emergency_contact &&
      merchant_category_code == o.merchant_category_code
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 392

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 458

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 371

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


358
359
360
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 358

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



364
365
366
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 364

def hash
  [name, locale, localized_names, doing_business_as, description, start_date, address, time_zone, website_url, type, tax_id, phone_number, business_contact, technical_contact, emergency_contact, merchant_category_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 193

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  #if @name !~ Regexp.new(/^[0-9a-zA-Z _\\-\\+\\.\\*\\\"\/'&\\,\\(\\)!$;:?@\\#¡-￿]+$/)
    #invalid_properties.push('invalid value for "name", must conform to the pattern /^[0-9a-zA-Z _\\-\\+\\.\\*\\\"\/'&\\,\\(\\)!$;:?@\\#¡-￿]+$/.')
  #end

  #if !@locale.nil? && @locale !~ Regexp.new(/^(de-de|en-gb|en-us|es-es|es-us|fr-ca|fr-fr|it-it|ja-jp|pt-br|zh-cn|zh-tw)$/)
    #invalid_properties.push('invalid value for "locale", must conform to the pattern /^(de-de|en-gb|en-us|es-es|es-us|fr-ca|fr-fr|it-it|ja-jp|pt-br|zh-cn|zh-tw)$/.')
  #end

  #if !@doing_business_as.nil? && @doing_business_as !~ Regexp.new(/^[0-9a-zA-Z _\\-\\+\\.\\*\\\"\/'&\\,\\(\\)!$;:?@\\#¡-￿]+$/)
    #invalid_properties.push('invalid value for "doing_business_as", must conform to the pattern /^[0-9a-zA-Z _\\-\\+\\.\\*\\\"\/'&\\,\\(\\)!$;:?@\\#¡-￿]+$/.')
  #end

  #if !@description.nil? && @description !~ Regexp.new(/[À-ÖØ-öø-ǿÀ-ÖØ-öø-ǿ\\n\\ra-zA-Z0-9().\\-_#,;\/\\\\@$:&amp;!?%«»€₣«»€₣ ]{1,}$/)
    #invalid_properties.push('invalid value for "description", must conform to the pattern /[À-ÖØ-öø-ǿÀ-ÖØ-öø-ǿ\\n\\ra-zA-Z0-9().\\-_#,;\/\\\\@$:&amp;!?%«»€₣«»€₣ ]{1,}$/.')
  #end

  #if !@website_url.nil? && @website_url !~ Regexp.new(/\\b((?:https?:\/\/|www\\d{0,3}[.]|[a-z0-9.\\-]+[.][a-z]{2,4}\/)(?:[^\\s()<>]+|\\(([^\\s()<>]+|(\\([^\\s()<>]+\\)))*\\))+(?:\\(([^\\s()<>]+|(\\([^\\s()<>]+\\)))*\\)|[^\\s`!()\\[\\]{};:'\".,<>?«»“”‘’]))/)
    #invalid_properties.push('invalid value for "website_url", must conform to the pattern /\\b((?:https?:\/\/|www\\d{0,3}[.]|[a-z0-9.\\-]+[.][a-z]{2,4}\/)(?:[^\\s()<>]+|\\(([^\\s()<>]+|(\\([^\\s()<>]+\\)))*\\))+(?:\\(([^\\s()<>]+|(\\([^\\s()<>]+\\)))*\\)|[^\\s`!()\\[\\]{};:'\".,<>?«»“”‘’]))/.')
  #end

  #if !@tax_id.nil? && @tax_id !~ Regexp.new(/\\d{9}/)
    #invalid_properties.push('invalid value for "tax_id", must conform to the pattern /\\d{9}/.')
  #end

  #if !@phone_number.nil? && @phone_number !~ Regexp.new(/^[0-9a-zA-Z\\\\+\\\\-]+$/)
    #invalid_properties.push('invalid value for "phone_number", must conform to the pattern /^[0-9a-zA-Z\\\\+\\\\-]+$/.')
  #end

  #if !@merchant_category_code.nil? && @merchant_category_code !~ Regexp.new(/^\\d{3,4}$/)
    #invalid_properties.push('invalid value for "merchant_category_code", must conform to the pattern /^\\d{3,4}$/.')
  #end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



438
439
440
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 438

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



444
445
446
447
448
449
450
451
452
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 444

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



432
433
434
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 432

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/cybersource_rest_client/models/boardingv1registrations_organization_information_business_information.rb', line 236

def valid?
  return false if @name.nil?
  #return false if @name !~ Regexp.new(/^[0-9a-zA-Z _\\-\\+\\.\\*\\\"\/'&\\,\\(\\)!$;:?@\\#¡-￿]+$/)
  #return false if !@locale.nil? && @locale !~ Regexp.new(/^(de-de|en-gb|en-us|es-es|es-us|fr-ca|fr-fr|it-it|ja-jp|pt-br|zh-cn|zh-tw)$/)
  #return false if !@doing_business_as.nil? && @doing_business_as !~ Regexp.new(/^[0-9a-zA-Z _\\-\\+\\.\\*\\\"\/'&\\,\\(\\)!$;:?@\\#¡-￿]+$/)
  #return false if !@description.nil? && @description !~ Regexp.new(/[À-ÖØ-öø-ǿÀ-ÖØ-öø-ǿ\\n\\ra-zA-Z0-9().\\-_#,;\/\\\\@$:&amp;!?%«»€₣«»€₣ ]{1,}$/)
  #return false if !@website_url.nil? && @website_url !~ Regexp.new(/\\b((?:https?:\/\/|www\\d{0,3}[.]|[a-z0-9.\\-]+[.][a-z]{2,4}\/)(?:[^\\s()<>]+|\\(([^\\s()<>]+|(\\([^\\s()<>]+\\)))*\\))+(?:\\(([^\\s()<>]+|(\\([^\\s()<>]+\\)))*\\)|[^\\s`!()\\[\\]{};:'\".,<>?«»“”‘’]))/)
  #return false if !@tax_id.nil? && @tax_id !~ Regexp.new(/\\d{9}/)
  #return false if !@phone_number.nil? && @phone_number !~ Regexp.new(/^[0-9a-zA-Z\\\\+\\\\-]+$/)
  #return false if !@merchant_category_code.nil? && @merchant_category_code !~ Regexp.new(/^\\d{3,4}$/)
  true
end