Class: CyberSource::EnrollmentApi
- Inherits:
-
Object
- Object
- CyberSource::EnrollmentApi
- Defined in:
- lib/cybersource_rest_client/api/enrollment_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#enroll_card(agentic_card_enrollment_request, opts = {}) ⇒ AgenticCardEnrollmentResponse200
Enroll a card Enroll a payment card for agentic or e-commerce transactions.
-
#enroll_card_with_http_info(agentic_card_enrollment_request, opts = {}) ⇒ Array<(AgenticCardEnrollmentResponse200, Fixnum, Hash)>
Enroll a card Enroll a payment card for agentic or e-commerce transactions.
-
#initialize(api_client = ApiClient.default, config) ⇒ EnrollmentApi
constructor
A new instance of EnrollmentApi.
Constructor Details
#initialize(api_client = ApiClient.default, config) ⇒ EnrollmentApi
Returns a new instance of EnrollmentApi.
18 19 20 21 |
# File 'lib/cybersource_rest_client/api/enrollment_api.rb', line 18 def initialize(api_client = ApiClient.default, config) @api_client = api_client @api_client.set_configuration(config) end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
16 17 18 |
# File 'lib/cybersource_rest_client/api/enrollment_api.rb', line 16 def api_client @api_client end |
Instance Method Details
#enroll_card(agentic_card_enrollment_request, opts = {}) ⇒ AgenticCardEnrollmentResponse200
Enroll a card Enroll a payment card for agentic or e-commerce transactions. This is typically the first step in the Intelligent Commerce payment lifecycle — the agent calls this endpoint to register a consumer’s card, creating a tokenized reference that can be used in subsequent purchase instructions and payment credential retrieval. Requires device information, consumer identity, billing details, and payment instrument references. Returns a status of ACTIVE (HTTP 200) if enrollment completes immediately, or PENDING (HTTP 202) with pendingEvents if cardholder authentication is required. Call this endpoint when a consumer wants to add a new payment card or when setting up a card for agentic payment flows.
29 30 31 32 |
# File 'lib/cybersource_rest_client/api/enrollment_api.rb', line 29 def enroll_card(agentic_card_enrollment_request, opts = {}) data, status_code, headers = enroll_card_with_http_info(agentic_card_enrollment_request, opts) return data, status_code, headers end |
#enroll_card_with_http_info(agentic_card_enrollment_request, opts = {}) ⇒ Array<(AgenticCardEnrollmentResponse200, Fixnum, Hash)>
Enroll a card Enroll a payment card for agentic or e-commerce transactions. This is typically the first step in the Intelligent Commerce payment lifecycle — the agent calls this endpoint to register a consumer's card, creating a tokenized reference that can be used in subsequent purchase instructions and payment credential retrieval. Requires device information, consumer identity, billing details, and payment instrument references. Returns a status of ACTIVE (HTTP 200) if enrollment completes immediately, or PENDING (HTTP 202) with pendingEvents if cardholder authentication is required. Call this endpoint when a consumer wants to add a new payment card or when setting up a card for agentic payment flows.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cybersource_rest_client/api/enrollment_api.rb', line 39 def enroll_card_with_http_info(agentic_card_enrollment_request, opts = {}) if @api_client.config.debugging begin raise @api_client.config.logger.debug 'Calling API: EnrollmentApi.enroll_card ...' rescue puts 'Cannot write to log' end end # verify the required parameter 'agentic_card_enrollment_request' is set if @api_client.config.client_side_validation && agentic_card_enrollment_request.nil? fail ArgumentError, "Missing the required parameter 'agentic_card_enrollment_request' when calling EnrollmentApi.enroll_card" end # resource path local_var_path = 'acp/v1/tokens' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/hal+json;charset=utf-8']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(agentic_card_enrollment_request) sdk_tracker = SdkTracker.new post_body = sdk_tracker.insert_developer_id_tracker(post_body, 'AgenticCardEnrollmentRequest', @api_client.config.host, @api_client.merchantconfig.defaultDeveloperId) inbound_mle_status = "mandatory" if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["enroll_card","enroll_card_with_http_info"]) begin post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body) rescue raise end end is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["enroll_card","enroll_card_with_http_info"]) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AgenticCardEnrollmentResponse200', :isResponseMLEForApi => is_response_mle_for_api) if @api_client.config.debugging begin raise @api_client.config.logger.debug "API called: EnrollmentApi#enroll_card\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" rescue puts 'Cannot write to log' end end return data, status_code, headers end |