Class: CyberSource::InlineResponse20017

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/inline_response_200_17.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InlineResponse20017

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 104

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'buyer')
    self.buyer = attributes[:'buyer']
  end

  if attributes.has_key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.has_key?(:'fulfillment_address')
    self.fulfillment_address = attributes[:'fulfillment_address']
  end

  if attributes.has_key?(:'fulfillment_options')
    if (value = attributes[:'fulfillment_options']).is_a?(Array)
      self.fulfillment_options = value
    end
  end

  if attributes.has_key?(:'fulfillment_option_id')
    self.fulfillment_option_id = attributes[:'fulfillment_option_id']
  end

  if attributes.has_key?(:'totals')
    if (value = attributes[:'totals']).is_a?(Array)
      self.totals = value
    end
  end

  if attributes.has_key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.has_key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  end

  if attributes.has_key?(:'links')
    if (value = attributes[:'links']).is_a?(Array)
      self.links = value
    end
  end
end

Instance Attribute Details

#buyerObject

Returns the value of attribute buyer.



25
26
27
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 25

def buyer
  @buyer
end

#currencyObject

ISO 4217 lowercase currency code.



23
24
25
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 23

def currency
  @currency
end

#fulfillment_addressObject

Returns the value of attribute fulfillment_address.



30
31
32
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 30

def fulfillment_address
  @fulfillment_address
end

#fulfillment_option_idObject

ID of the selected fulfillment option.



35
36
37
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 35

def fulfillment_option_id
  @fulfillment_option_id
end

#fulfillment_optionsObject

Returns the value of attribute fulfillment_options.



32
33
34
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 32

def fulfillment_options
  @fulfillment_options
end

#idObject

The checkout session identifier.



17
18
19
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 17

def id
  @id
end

#line_itemsObject

Final line items with confirmed pricing.



28
29
30
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 28

def line_items
  @line_items
end

Related resource links from the merchant (e.g. terms of use, privacy policy).



46
47
48
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 46

def links
  @links
end

#messagesObject

Informational or error messages from the merchant backend.



43
44
45
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 43

def messages
  @messages
end

#orderObject

Returns the value of attribute order.



40
41
42
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 40

def order
  @order
end

#statusObject

Will always be completed on a successful response. Possible values: - completed



20
21
22
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 20

def status
  @status
end

#totalsObject

Final order totals as typed total lines. All amounts in minor units (cents).



38
39
40
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 38

def totals
  @totals
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 49

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'currency' => :'currency',
    :'buyer' => :'buyer',
    :'line_items' => :'line_items',
    :'fulfillment_address' => :'fulfillment_address',
    :'fulfillment_options' => :'fulfillment_options',
    :'fulfillment_option_id' => :'fulfillment_option_id',
    :'totals' => :'totals',
    :'order' => :'order',
    :'messages' => :'messages',
    :'links' => :'links'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 67

def self.json_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'currency' => :'currency',
    :'buyer' => :'buyer',
    :'line_items' => :'line_items',
    :'fulfillment_address' => :'fulfillment_address',
    :'fulfillment_options' => :'fulfillment_options',
    :'fulfillment_option_id' => :'fulfillment_option_id',
    :'totals' => :'totals',
    :'order' => :'order',
    :'messages' => :'messages',
    :'links' => :'links'
  }
end

.swagger_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 85

def self.swagger_types
  {
    :'id' => :'String',
    :'status' => :'String',
    :'currency' => :'String',
    :'buyer' => :'AcpCompleteCheckoutResponseBuyer',
    :'line_items' => :'Array<InlineResponse20113LineItems>',
    :'fulfillment_address' => :'InlineResponse20017FulfillmentAddress',
    :'fulfillment_options' => :'Array<InlineResponse20113FulfillmentOptions>',
    :'fulfillment_option_id' => :'String',
    :'totals' => :'Array<InlineResponse20113Totals>',
    :'order' => :'InlineResponse20017Order',
    :'messages' => :'Array<InlineResponse20113Messages>',
    :'links' => :'Array<InlineResponse20113Links>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      currency == o.currency &&
      buyer == o.buyer &&
      line_items == o.line_items &&
      fulfillment_address == o.fulfillment_address &&
      fulfillment_options == o.fulfillment_options &&
      fulfillment_option_id == o.fulfillment_option_id &&
      totals == o.totals &&
      order == o.order &&
      messages == o.messages &&
      links == o.links
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 237

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 303

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 216

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 203

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



209
210
211
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 209

def hash
  [id, status, currency, buyer, line_items, fulfillment_address, fulfillment_options, fulfillment_option_id, totals, order, messages, links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 171

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



283
284
285
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 283

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
292
293
294
295
296
297
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 289

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



277
278
279
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 277

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
# File 'lib/cybersource_rest_client/models/inline_response_200_17.rb', line 178

def valid?
  true
end