Class: CyberSource::InlineResponse20020Products

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/inline_response_200_20_products.rb

Overview

Full product record as stored in the ACG catalog. Contains all ingest fields plus server-assigned metadata timestamps.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InlineResponse20020Products

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 503

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'item_id')
    self.item_id = attributes[:'item_id']
  end

  if attributes.has_key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.has_key?(:'image_url')
    self.image_url = attributes[:'image_url']
  end

  if attributes.has_key?(:'additional_image_urls')
    self.additional_image_urls = attributes[:'additional_image_urls']
  end

  if attributes.has_key?(:'video_url')
    self.video_url = attributes[:'video_url']
  end

  if attributes.has_key?(:'model_3d_url')
    self.model_3d_url = attributes[:'model_3d_url']
  end

  if attributes.has_key?(:'product_category')
    self.product_category = attributes[:'product_category']
  end

  if attributes.has_key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.has_key?(:'gtin')
    self.gtin = attributes[:'gtin']
  end

  if attributes.has_key?(:'mpn')
    self.mpn = attributes[:'mpn']
  end

  if attributes.has_key?(:'condition')
    self.condition = attributes[:'condition']
  end

  if attributes.has_key?(:'material')
    self.material = attributes[:'material']
  end

  if attributes.has_key?(:'weight')
    self.weight = attributes[:'weight']
  end

  if attributes.has_key?(:'dimensions')
    self.dimensions = attributes[:'dimensions']
  end

  if attributes.has_key?(:'length')
    self.length = attributes[:'length']
  end

  if attributes.has_key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.has_key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.has_key?(:'dimensions_unit')
    self.dimensions_unit = attributes[:'dimensions_unit']
  end

  if attributes.has_key?(:'item_weight_unit')
    self.item_weight_unit = attributes[:'item_weight_unit']
  end

  if attributes.has_key?(:'age_group')
    self.age_group = attributes[:'age_group']
  end

  if attributes.has_key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.has_key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.has_key?(:'size_system')
    self.size_system = attributes[:'size_system']
  end

  if attributes.has_key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.has_key?(:'group_id')
    self.group_id = attributes[:'group_id']
  end

  if attributes.has_key?(:'listing_has_variations')
    self.listing_has_variations = attributes[:'listing_has_variations']
  end

  if attributes.has_key?(:'item_group_title')
    self.item_group_title = attributes[:'item_group_title']
  end

  if attributes.has_key?(:'offer_id')
    self.offer_id = attributes[:'offer_id']
  end

  if attributes.has_key?(:'variant_dict')
    if (value = attributes[:'variant_dict']).is_a?(Hash)
      self.variant_dict = value
    end
  end

  if attributes.has_key?(:'custom_variant1_category')
    self.custom_variant1_category = attributes[:'custom_variant1_category']
  end

  if attributes.has_key?(:'custom_variant1_option')
    self.custom_variant1_option = attributes[:'custom_variant1_option']
  end

  if attributes.has_key?(:'custom_variant2_category')
    self.custom_variant2_category = attributes[:'custom_variant2_category']
  end

  if attributes.has_key?(:'custom_variant2_option')
    self.custom_variant2_option = attributes[:'custom_variant2_option']
  end

  if attributes.has_key?(:'custom_variant3_category')
    self.custom_variant3_category = attributes[:'custom_variant3_category']
  end

  if attributes.has_key?(:'custom_variant3_option')
    self.custom_variant3_option = attributes[:'custom_variant3_option']
  end

  if attributes.has_key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'sale_price')
    self.sale_price = attributes[:'sale_price']
  end

  if attributes.has_key?(:'sale_price_start_date')
    self.sale_price_start_date = attributes[:'sale_price_start_date']
  end

  if attributes.has_key?(:'sale_price_end_date')
    self.sale_price_end_date = attributes[:'sale_price_end_date']
  end

  if attributes.has_key?(:'unit_pricing_measure')
    self.unit_pricing_measure = attributes[:'unit_pricing_measure']
  end

  if attributes.has_key?(:'base_measure')
    self.base_measure = attributes[:'base_measure']
  end

  if attributes.has_key?(:'pricing_trend')
    self.pricing_trend = attributes[:'pricing_trend']
  end

  if attributes.has_key?(:'geo_price')
    self.geo_price = attributes[:'geo_price']
  end

  if attributes.has_key?(:'geo_availability')
    self.geo_availability = attributes[:'geo_availability']
  end

  if attributes.has_key?(:'availability')
    self.availability = attributes[:'availability']
  end

  if attributes.has_key?(:'availability_date')
    self.availability_date = attributes[:'availability_date']
  end

  if attributes.has_key?(:'expiration_date')
    self.expiration_date = attributes[:'expiration_date']
  end

  if attributes.has_key?(:'seller_name')
    self.seller_name = attributes[:'seller_name']
  end

  if attributes.has_key?(:'seller_url')
    self.seller_url = attributes[:'seller_url']
  end

  if attributes.has_key?(:'marketplace_seller')
    self.marketplace_seller = attributes[:'marketplace_seller']
  end

  if attributes.has_key?(:'seller_privacy_policy')
    self.seller_privacy_policy = attributes[:'seller_privacy_policy']
  end

  if attributes.has_key?(:'seller_tos')
    self.seller_tos = attributes[:'seller_tos']
  end

  if attributes.has_key?(:'shipping_price')
    self.shipping_price = attributes[:'shipping_price']
  end

  if attributes.has_key?(:'delivery_estimate')
    self.delivery_estimate = attributes[:'delivery_estimate']
  end

  if attributes.has_key?(:'pickup_method')
    self.pickup_method = attributes[:'pickup_method']
  end

  if attributes.has_key?(:'pickup_sla')
    self.pickup_sla = attributes[:'pickup_sla']
  end

  if attributes.has_key?(:'is_digital')
    self.is_digital = attributes[:'is_digital']
  end

  if attributes.has_key?(:'return_policy')
    self.return_policy = attributes[:'return_policy']
  end

  if attributes.has_key?(:'accepts_returns')
    self.accepts_returns = attributes[:'accepts_returns']
  end

  if attributes.has_key?(:'return_deadline_in_days')
    self.return_deadline_in_days = attributes[:'return_deadline_in_days']
  end

  if attributes.has_key?(:'accepts_exchanges')
    self.accepts_exchanges = attributes[:'accepts_exchanges']
  end

  if attributes.has_key?(:'is_eligible_search')
    self.is_eligible_search = attributes[:'is_eligible_search']
  end

  if attributes.has_key?(:'is_eligible_checkout')
    self.is_eligible_checkout = attributes[:'is_eligible_checkout']
  end

  if attributes.has_key?(:'popularity_score')
    self.popularity_score = attributes[:'popularity_score']
  end

  if attributes.has_key?(:'return_rate')
    self.return_rate = attributes[:'return_rate']
  end

  if attributes.has_key?(:'warning')
    self.warning = attributes[:'warning']
  end

  if attributes.has_key?(:'warning_url')
    self.warning_url = attributes[:'warning_url']
  end

  if attributes.has_key?(:'age_restriction')
    self.age_restriction = attributes[:'age_restriction']
  end

  if attributes.has_key?(:'review_count')
    self.review_count = attributes[:'review_count']
  end

  if attributes.has_key?(:'star_rating')
    self.star_rating = attributes[:'star_rating']
  end

  if attributes.has_key?(:'store_review_count')
    self.store_review_count = attributes[:'store_review_count']
  end

  if attributes.has_key?(:'store_star_rating')
    self.store_star_rating = attributes[:'store_star_rating']
  end

  if attributes.has_key?(:'related_product_id')
    self.related_product_id = attributes[:'related_product_id']
  end

  if attributes.has_key?(:'relationship_type')
    self.relationship_type = attributes[:'relationship_type']
  end

  if attributes.has_key?(:'target_countries')
    if (value = attributes[:'target_countries']).is_a?(Array)
      self.target_countries = value
    end
  end

  if attributes.has_key?(:'store_country')
    self.store_country = attributes[:'store_country']
  end

  if attributes.has_key?(:'q_and_a')
    if (value = attributes[:'q_and_a']).is_a?(Array)
      self.q_and_a = value
    end
  end

  if attributes.has_key?(:'qandA')
    if (value = attributes[:'qandA']).is_a?(Array)
      self.qand_a = value
    end
  end

  if attributes.has_key?(:'reviews')
    if (value = attributes[:'reviews']).is_a?(Array)
      self.reviews = value
    end
  end

  if attributes.has_key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.has_key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#accepts_exchangesObject

Returns the value of attribute accepts_exchanges.



180
181
182
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 180

def accepts_exchanges
  @accepts_exchanges
end

#accepts_returnsObject

Returns the value of attribute accepts_returns.



176
177
178
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 176

def accepts_returns
  @accepts_returns
end

#additional_image_urlsObject

Additional product image URLs.



36
37
38
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 36

def additional_image_urls
  @additional_image_urls
end

#age_groupObject

Target age group (e.g. "adult", "kids", "infant").



84
85
86
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 84

def age_group
  @age_group
end

#age_restrictionObject

Returns the value of attribute age_restriction.



196
197
198
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 196

def age_restriction
  @age_restriction
end

#availabilityObject

Current stock status. Possible values: - in_stock - out_of_stock - preorder - backorder



147
148
149
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 147

def availability
  @availability
end

#availability_dateObject

Returns the value of attribute availability_date.



149
150
151
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 149

def availability_date
  @availability_date
end

#base_measureObject

Returns the value of attribute base_measure.



138
139
140
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 138

def base_measure
  @base_measure
end

#brandObject

Product brand or manufacturer.



48
49
50
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 48

def brand
  @brand
end

#colorObject

Primary product color. Used for variant filtering.



87
88
89
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 87

def color
  @color
end

#conditionObject

Product condition (e.g. new, used, refurbished).



57
58
59
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 57

def condition
  @condition
end

#created_atObject

ISO 8601 timestamp when this product was first ingested.



223
224
225
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 223

def created_at
  @created_at
end

#currencyObject

ISO 4217 currency code.



128
129
130
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 128

def currency
  @currency
end

#custom_variant1_categoryObject

Returns the value of attribute custom_variant1_category.



112
113
114
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 112

def custom_variant1_category
  @custom_variant1_category
end

#custom_variant1_optionObject

Returns the value of attribute custom_variant1_option.



114
115
116
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 114

def custom_variant1_option
  @custom_variant1_option
end

#custom_variant2_categoryObject

Returns the value of attribute custom_variant2_category.



116
117
118
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 116

def custom_variant2_category
  @custom_variant2_category
end

#custom_variant2_optionObject

Returns the value of attribute custom_variant2_option.



118
119
120
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 118

def custom_variant2_option
  @custom_variant2_option
end

#custom_variant3_categoryObject

Returns the value of attribute custom_variant3_category.



120
121
122
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 120

def custom_variant3_category
  @custom_variant3_category
end

#custom_variant3_optionObject

Returns the value of attribute custom_variant3_option.



122
123
124
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 122

def custom_variant3_option
  @custom_variant3_option
end

#delivery_estimateObject

Returns the value of attribute delivery_estimate.



166
167
168
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 166

def delivery_estimate
  @delivery_estimate
end

#descriptionObject

Product description.



27
28
29
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 27

def description
  @description
end

#dimensionsObject

Combined dimension string (e.g. "10x5x3 cm").



66
67
68
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 66

def dimensions
  @dimensions
end

#dimensions_unitObject

Unit for dimension values (e.g. "cm", "in", "mm").



78
79
80
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 78

def dimensions_unit
  @dimensions_unit
end

#expiration_dateObject

Returns the value of attribute expiration_date.



151
152
153
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 151

def expiration_date
  @expiration_date
end

#genderObject

Target gender (e.g. "male", "female", "unisex").



96
97
98
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 96

def gender
  @gender
end

#geo_availabilityObject

Returns the value of attribute geo_availability.



144
145
146
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 144

def geo_availability
  @geo_availability
end

#geo_priceObject

Returns the value of attribute geo_price.



142
143
144
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 142

def geo_price
  @geo_price
end

#group_idObject

Product variant group identifier.



99
100
101
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 99

def group_id
  @group_id
end

#gtinObject

Global Trade Item Number.



51
52
53
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 51

def gtin
  @gtin
end

#heightObject

Product height. Pair with dimensions_unit for unit context.



75
76
77
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 75

def height
  @height
end

#idObject

The merchant SKU / item_id as stored in the ACG catalog. Equivalent to the item_id field submitted during feed ingestion.



18
19
20
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 18

def id
  @id
end

#image_urlObject

URL to the primary product image.



33
34
35
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 33

def image_url
  @image_url
end

#is_digitalObject

Returns the value of attribute is_digital.



172
173
174
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 172

def is_digital
  @is_digital
end

#is_eligible_checkoutObject

When true, product can be added to a checkout session.



186
187
188
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 186

def is_eligible_checkout
  @is_eligible_checkout
end

#is_eligible_searchObject

When true, product appears in AI agent discovery results.



183
184
185
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 183

def is_eligible_search
  @is_eligible_search
end

#item_group_titleObject

Display title for the variant group.



105
106
107
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 105

def item_group_title
  @item_group_title
end

#item_idObject

Unique product identifier / SKU.



21
22
23
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 21

def item_id
  @item_id
end

#item_weight_unitObject

Unit for weight value (e.g. "kg", "lb", "oz").



81
82
83
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 81

def item_weight_unit
  @item_weight_unit
end

#lengthObject

Product length. Pair with dimensions_unit for unit context.



69
70
71
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 69

def length
  @length
end

#listing_has_variationsObject

Whether this listing has product variations (e.g. different sizes or colors).



102
103
104
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 102

def listing_has_variations
  @listing_has_variations
end

#marketplace_sellerObject

Returns the value of attribute marketplace_seller.



158
159
160
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 158

def marketplace_seller
  @marketplace_seller
end

#materialObject

Primary material (relevant for apparel, furniture, etc.).



60
61
62
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 60

def material
  @material
end

#model_3d_urlObject

URL to a 3D model asset.



42
43
44
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 42

def model_3d_url
  @model_3d_url
end

#mpnObject

Manufacturer Part Number.



54
55
56
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 54

def mpn
  @mpn
end

#offer_idObject

Merchant-assigned offer identifier.



108
109
110
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 108

def offer_id
  @offer_id
end

#pickup_methodObject

Returns the value of attribute pickup_method.



168
169
170
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 168

def pickup_method
  @pickup_method
end

#pickup_slaObject

Returns the value of attribute pickup_sla.



170
171
172
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 170

def pickup_sla
  @pickup_sla
end

#popularity_scoreObject

Returns the value of attribute popularity_score.



188
189
190
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 188

def popularity_score
  @popularity_score
end

#priceObject

Product price as a decimal number.



125
126
127
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 125

def price
  @price
end

#pricing_trendObject

Returns the value of attribute pricing_trend.



140
141
142
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 140

def pricing_trend
  @pricing_trend
end

#product_categoryObject

Product category hierarchy (e.g. Electronics > Audio > Headphones).



45
46
47
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 45

def product_category
  @product_category
end

#q_and_aObject

Returns the value of attribute q_and_a.



216
217
218
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 216

def q_and_a
  @q_and_a
end

#qand_aObject

Returns the value of attribute qand_a.



218
219
220
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 218

def qand_a
  @qand_a
end

Returns the value of attribute related_product_id.



206
207
208
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 206

def related_product_id
  @related_product_id
end

#relationship_typeObject

Returns the value of attribute relationship_type.



208
209
210
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 208

def relationship_type
  @relationship_type
end

#return_deadline_in_daysObject

Returns the value of attribute return_deadline_in_days.



178
179
180
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 178

def return_deadline_in_days
  @return_deadline_in_days
end

#return_policyObject

Returns the value of attribute return_policy.



174
175
176
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 174

def return_policy
  @return_policy
end

#return_rateObject

Returns the value of attribute return_rate.



190
191
192
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 190

def return_rate
  @return_rate
end

#review_countObject

Returns the value of attribute review_count.



198
199
200
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 198

def review_count
  @review_count
end

#reviewsObject

Returns the value of attribute reviews.



220
221
222
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 220

def reviews
  @reviews
end

#sale_priceObject

Returns the value of attribute sale_price.



130
131
132
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 130

def sale_price
  @sale_price
end

#sale_price_end_dateObject

Returns the value of attribute sale_price_end_date.



134
135
136
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 134

def sale_price_end_date
  @sale_price_end_date
end

#sale_price_start_dateObject

Returns the value of attribute sale_price_start_date.



132
133
134
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 132

def sale_price_start_date
  @sale_price_start_date
end

#seller_nameObject

Merchant or seller display name. Max 70 characters.



154
155
156
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 154

def seller_name
  @seller_name
end

#seller_privacy_policyObject

Returns the value of attribute seller_privacy_policy.



160
161
162
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 160

def seller_privacy_policy
  @seller_privacy_policy
end

#seller_tosObject

Returns the value of attribute seller_tos.



162
163
164
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 162

def seller_tos
  @seller_tos
end

#seller_urlObject

Returns the value of attribute seller_url.



156
157
158
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 156

def seller_url
  @seller_url
end

#shipping_priceObject

Returns the value of attribute shipping_price.



164
165
166
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 164

def shipping_price
  @shipping_price
end

#sizeObject

Product size (e.g. "M", "42", "XL"). Used for variant filtering.



90
91
92
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 90

def size
  @size
end

#size_systemObject

Size standard used (e.g. "US", "EU", "UK").



93
94
95
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 93

def size_system
  @size_system
end

#star_ratingObject

Returns the value of attribute star_rating.



200
201
202
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 200

def star_rating
  @star_rating
end

#store_countryObject

ISO 3166-1 alpha-2 country code of the merchant's store.



214
215
216
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 214

def store_country
  @store_country
end

#store_review_countObject

Returns the value of attribute store_review_count.



202
203
204
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 202

def store_review_count
  @store_review_count
end

#store_star_ratingObject

Returns the value of attribute store_star_rating.



204
205
206
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 204

def store_star_rating
  @store_star_rating
end

#target_countriesObject

Country codes where this product is available.



211
212
213
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 211

def target_countries
  @target_countries
end

#titleObject

Product display name.



24
25
26
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 24

def title
  @title
end

#unit_pricing_measureObject

Returns the value of attribute unit_pricing_measure.



136
137
138
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 136

def unit_pricing_measure
  @unit_pricing_measure
end

#updated_atObject

ISO 8601 timestamp of the most recent update.



226
227
228
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 226

def updated_at
  @updated_at
end

#urlObject

URL to the product page on the merchant's storefront.



30
31
32
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 30

def url
  @url
end

#variant_dictObject

Returns the value of attribute variant_dict.



110
111
112
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 110

def variant_dict
  @variant_dict
end

#video_urlObject

URL to a product video.



39
40
41
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 39

def video_url
  @video_url
end

#warningObject

Returns the value of attribute warning.



192
193
194
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 192

def warning
  @warning
end

#warning_urlObject

Returns the value of attribute warning_url.



194
195
196
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 194

def warning_url
  @warning_url
end

#weightObject

Product weight including unit.



63
64
65
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 63

def weight
  @weight
end

#widthObject

Product width. Pair with dimensions_unit for unit context.



72
73
74
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 72

def width
  @width
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 229

def self.attribute_map
  {
    :'id' => :'id',
    :'item_id' => :'item_id',
    :'title' => :'title',
    :'description' => :'description',
    :'url' => :'url',
    :'image_url' => :'image_url',
    :'additional_image_urls' => :'additional_image_urls',
    :'video_url' => :'video_url',
    :'model_3d_url' => :'model_3d_url',
    :'product_category' => :'product_category',
    :'brand' => :'brand',
    :'gtin' => :'gtin',
    :'mpn' => :'mpn',
    :'condition' => :'condition',
    :'material' => :'material',
    :'weight' => :'weight',
    :'dimensions' => :'dimensions',
    :'length' => :'length',
    :'width' => :'width',
    :'height' => :'height',
    :'dimensions_unit' => :'dimensions_unit',
    :'item_weight_unit' => :'item_weight_unit',
    :'age_group' => :'age_group',
    :'color' => :'color',
    :'size' => :'size',
    :'size_system' => :'size_system',
    :'gender' => :'gender',
    :'group_id' => :'group_id',
    :'listing_has_variations' => :'listing_has_variations',
    :'item_group_title' => :'item_group_title',
    :'offer_id' => :'offer_id',
    :'variant_dict' => :'variant_dict',
    :'custom_variant1_category' => :'custom_variant1_category',
    :'custom_variant1_option' => :'custom_variant1_option',
    :'custom_variant2_category' => :'custom_variant2_category',
    :'custom_variant2_option' => :'custom_variant2_option',
    :'custom_variant3_category' => :'custom_variant3_category',
    :'custom_variant3_option' => :'custom_variant3_option',
    :'price' => :'price',
    :'currency' => :'currency',
    :'sale_price' => :'sale_price',
    :'sale_price_start_date' => :'sale_price_start_date',
    :'sale_price_end_date' => :'sale_price_end_date',
    :'unit_pricing_measure' => :'unit_pricing_measure',
    :'base_measure' => :'base_measure',
    :'pricing_trend' => :'pricing_trend',
    :'geo_price' => :'geo_price',
    :'geo_availability' => :'geo_availability',
    :'availability' => :'availability',
    :'availability_date' => :'availability_date',
    :'expiration_date' => :'expiration_date',
    :'seller_name' => :'seller_name',
    :'seller_url' => :'seller_url',
    :'marketplace_seller' => :'marketplace_seller',
    :'seller_privacy_policy' => :'seller_privacy_policy',
    :'seller_tos' => :'seller_tos',
    :'shipping_price' => :'shipping_price',
    :'delivery_estimate' => :'delivery_estimate',
    :'pickup_method' => :'pickup_method',
    :'pickup_sla' => :'pickup_sla',
    :'is_digital' => :'is_digital',
    :'return_policy' => :'return_policy',
    :'accepts_returns' => :'accepts_returns',
    :'return_deadline_in_days' => :'return_deadline_in_days',
    :'accepts_exchanges' => :'accepts_exchanges',
    :'is_eligible_search' => :'is_eligible_search',
    :'is_eligible_checkout' => :'is_eligible_checkout',
    :'popularity_score' => :'popularity_score',
    :'return_rate' => :'return_rate',
    :'warning' => :'warning',
    :'warning_url' => :'warning_url',
    :'age_restriction' => :'age_restriction',
    :'review_count' => :'review_count',
    :'star_rating' => :'star_rating',
    :'store_review_count' => :'store_review_count',
    :'store_star_rating' => :'store_star_rating',
    :'related_product_id' => :'related_product_id',
    :'relationship_type' => :'relationship_type',
    :'target_countries' => :'target_countries',
    :'store_country' => :'store_country',
    :'q_and_a' => :'q_and_a',
    :'qand_a' => :'qandA',
    :'reviews' => :'reviews',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 320

def self.json_map
  {
    :'id' => :'id',
    :'item_id' => :'item_id',
    :'title' => :'title',
    :'description' => :'description',
    :'url' => :'url',
    :'image_url' => :'image_url',
    :'additional_image_urls' => :'additional_image_urls',
    :'video_url' => :'video_url',
    :'model_3d_url' => :'model_3d_url',
    :'product_category' => :'product_category',
    :'brand' => :'brand',
    :'gtin' => :'gtin',
    :'mpn' => :'mpn',
    :'condition' => :'condition',
    :'material' => :'material',
    :'weight' => :'weight',
    :'dimensions' => :'dimensions',
    :'length' => :'length',
    :'width' => :'width',
    :'height' => :'height',
    :'dimensions_unit' => :'dimensions_unit',
    :'item_weight_unit' => :'item_weight_unit',
    :'age_group' => :'age_group',
    :'color' => :'color',
    :'size' => :'size',
    :'size_system' => :'size_system',
    :'gender' => :'gender',
    :'group_id' => :'group_id',
    :'listing_has_variations' => :'listing_has_variations',
    :'item_group_title' => :'item_group_title',
    :'offer_id' => :'offer_id',
    :'variant_dict' => :'variant_dict',
    :'custom_variant1_category' => :'custom_variant1_category',
    :'custom_variant1_option' => :'custom_variant1_option',
    :'custom_variant2_category' => :'custom_variant2_category',
    :'custom_variant2_option' => :'custom_variant2_option',
    :'custom_variant3_category' => :'custom_variant3_category',
    :'custom_variant3_option' => :'custom_variant3_option',
    :'price' => :'price',
    :'currency' => :'currency',
    :'sale_price' => :'sale_price',
    :'sale_price_start_date' => :'sale_price_start_date',
    :'sale_price_end_date' => :'sale_price_end_date',
    :'unit_pricing_measure' => :'unit_pricing_measure',
    :'base_measure' => :'base_measure',
    :'pricing_trend' => :'pricing_trend',
    :'geo_price' => :'geo_price',
    :'geo_availability' => :'geo_availability',
    :'availability' => :'availability',
    :'availability_date' => :'availability_date',
    :'expiration_date' => :'expiration_date',
    :'seller_name' => :'seller_name',
    :'seller_url' => :'seller_url',
    :'marketplace_seller' => :'marketplace_seller',
    :'seller_privacy_policy' => :'seller_privacy_policy',
    :'seller_tos' => :'seller_tos',
    :'shipping_price' => :'shipping_price',
    :'delivery_estimate' => :'delivery_estimate',
    :'pickup_method' => :'pickup_method',
    :'pickup_sla' => :'pickup_sla',
    :'is_digital' => :'is_digital',
    :'return_policy' => :'return_policy',
    :'accepts_returns' => :'accepts_returns',
    :'return_deadline_in_days' => :'return_deadline_in_days',
    :'accepts_exchanges' => :'accepts_exchanges',
    :'is_eligible_search' => :'is_eligible_search',
    :'is_eligible_checkout' => :'is_eligible_checkout',
    :'popularity_score' => :'popularity_score',
    :'return_rate' => :'return_rate',
    :'warning' => :'warning',
    :'warning_url' => :'warning_url',
    :'age_restriction' => :'age_restriction',
    :'review_count' => :'review_count',
    :'star_rating' => :'star_rating',
    :'store_review_count' => :'store_review_count',
    :'store_star_rating' => :'store_star_rating',
    :'related_product_id' => :'related_product_id',
    :'relationship_type' => :'relationship_type',
    :'target_countries' => :'target_countries',
    :'store_country' => :'store_country',
    :'q_and_a' => :'q_and_a',
    :'qand_a' => :'qand_a',
    :'reviews' => :'reviews',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.swagger_typesObject

Attribute type mapping.



411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 411

def self.swagger_types
  {
    :'id' => :'String',
    :'item_id' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'url' => :'String',
    :'image_url' => :'String',
    :'additional_image_urls' => :'String',
    :'video_url' => :'String',
    :'model_3d_url' => :'String',
    :'product_category' => :'String',
    :'brand' => :'String',
    :'gtin' => :'String',
    :'mpn' => :'String',
    :'condition' => :'String',
    :'material' => :'String',
    :'weight' => :'String',
    :'dimensions' => :'String',
    :'length' => :'String',
    :'width' => :'String',
    :'height' => :'String',
    :'dimensions_unit' => :'String',
    :'item_weight_unit' => :'String',
    :'age_group' => :'String',
    :'color' => :'String',
    :'size' => :'String',
    :'size_system' => :'String',
    :'gender' => :'String',
    :'group_id' => :'String',
    :'listing_has_variations' => :'BOOLEAN',
    :'item_group_title' => :'String',
    :'offer_id' => :'String',
    :'variant_dict' => :'Hash<String, String>',
    :'custom_variant1_category' => :'String',
    :'custom_variant1_option' => :'String',
    :'custom_variant2_category' => :'String',
    :'custom_variant2_option' => :'String',
    :'custom_variant3_category' => :'String',
    :'custom_variant3_option' => :'String',
    :'price' => :'Float',
    :'currency' => :'String',
    :'sale_price' => :'Float',
    :'sale_price_start_date' => :'Date',
    :'sale_price_end_date' => :'Date',
    :'unit_pricing_measure' => :'String',
    :'base_measure' => :'String',
    :'pricing_trend' => :'String',
    :'geo_price' => :'String',
    :'geo_availability' => :'String',
    :'availability' => :'String',
    :'availability_date' => :'Date',
    :'expiration_date' => :'Date',
    :'seller_name' => :'String',
    :'seller_url' => :'String',
    :'marketplace_seller' => :'String',
    :'seller_privacy_policy' => :'String',
    :'seller_tos' => :'String',
    :'shipping_price' => :'String',
    :'delivery_estimate' => :'Date',
    :'pickup_method' => :'String',
    :'pickup_sla' => :'String',
    :'is_digital' => :'BOOLEAN',
    :'return_policy' => :'String',
    :'accepts_returns' => :'BOOLEAN',
    :'return_deadline_in_days' => :'Integer',
    :'accepts_exchanges' => :'BOOLEAN',
    :'is_eligible_search' => :'BOOLEAN',
    :'is_eligible_checkout' => :'BOOLEAN',
    :'popularity_score' => :'Float',
    :'return_rate' => :'String',
    :'warning' => :'String',
    :'warning_url' => :'String',
    :'age_restriction' => :'Integer',
    :'review_count' => :'Integer',
    :'star_rating' => :'String',
    :'store_review_count' => :'Integer',
    :'store_star_rating' => :'String',
    :'related_product_id' => :'String',
    :'relationship_type' => :'String',
    :'target_countries' => :'Array<String>',
    :'store_country' => :'String',
    :'q_and_a' => :'Array<Hash<String, Object>>',
    :'qand_a' => :'Array<Hash<String, Object>>',
    :'reviews' => :'Array<Hash<String, Object>>',
    :'created_at' => :'DateTime',
    :'updated_at' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 875

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      item_id == o.item_id &&
      title == o.title &&
      description == o.description &&
      url == o.url &&
      image_url == o.image_url &&
      additional_image_urls == o.additional_image_urls &&
      video_url == o.video_url &&
      model_3d_url == o.model_3d_url &&
      product_category == o.product_category &&
      brand == o.brand &&
      gtin == o.gtin &&
      mpn == o.mpn &&
      condition == o.condition &&
      material == o.material &&
      weight == o.weight &&
      dimensions == o.dimensions &&
      length == o.length &&
      width == o.width &&
      height == o.height &&
      dimensions_unit == o.dimensions_unit &&
      item_weight_unit == o.item_weight_unit &&
      age_group == o.age_group &&
      color == o.color &&
      size == o.size &&
      size_system == o.size_system &&
      gender == o.gender &&
      group_id == o.group_id &&
      listing_has_variations == o.listing_has_variations &&
      item_group_title == o.item_group_title &&
      offer_id == o.offer_id &&
      variant_dict == o.variant_dict &&
      custom_variant1_category == o.custom_variant1_category &&
      custom_variant1_option == o.custom_variant1_option &&
      custom_variant2_category == o.custom_variant2_category &&
      custom_variant2_option == o.custom_variant2_option &&
      custom_variant3_category == o.custom_variant3_category &&
      custom_variant3_option == o.custom_variant3_option &&
      price == o.price &&
      currency == o.currency &&
      sale_price == o.sale_price &&
      sale_price_start_date == o.sale_price_start_date &&
      sale_price_end_date == o.sale_price_end_date &&
      unit_pricing_measure == o.unit_pricing_measure &&
      base_measure == o.base_measure &&
      pricing_trend == o.pricing_trend &&
      geo_price == o.geo_price &&
      geo_availability == o.geo_availability &&
      availability == o.availability &&
      availability_date == o.availability_date &&
      expiration_date == o.expiration_date &&
      seller_name == o.seller_name &&
      seller_url == o.seller_url &&
      marketplace_seller == o.marketplace_seller &&
      seller_privacy_policy == o.seller_privacy_policy &&
      seller_tos == o.seller_tos &&
      shipping_price == o.shipping_price &&
      delivery_estimate == o.delivery_estimate &&
      pickup_method == o.pickup_method &&
      pickup_sla == o.pickup_sla &&
      is_digital == o.is_digital &&
      return_policy == o.return_policy &&
      accepts_returns == o.accepts_returns &&
      return_deadline_in_days == o.return_deadline_in_days &&
      accepts_exchanges == o.accepts_exchanges &&
      is_eligible_search == o.is_eligible_search &&
      is_eligible_checkout == o.is_eligible_checkout &&
      popularity_score == o.popularity_score &&
      return_rate == o.return_rate &&
      warning == o.warning &&
      warning_url == o.warning_url &&
      age_restriction == o.age_restriction &&
      review_count == o.review_count &&
      star_rating == o.star_rating &&
      store_review_count == o.store_review_count &&
      store_star_rating == o.store_star_rating &&
      related_product_id == o.related_product_id &&
      relationship_type == o.relationship_type &&
      target_countries == o.target_countries &&
      store_country == o.store_country &&
      q_and_a == o.q_and_a &&
      qand_a == o.qand_a &&
      reviews == o.reviews &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 1001

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 1067

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 980

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


967
968
969
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 967

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



973
974
975
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 973

def hash
  [id, item_id, title, description, url, image_url, additional_image_urls, video_url, model_3d_url, product_category, brand, gtin, mpn, condition, material, weight, dimensions, length, width, height, dimensions_unit, item_weight_unit, age_group, color, size, size_system, gender, group_id, listing_has_variations, item_group_title, offer_id, variant_dict, custom_variant1_category, custom_variant1_option, custom_variant2_category, custom_variant2_option, custom_variant3_category, custom_variant3_option, price, currency, sale_price, sale_price_start_date, sale_price_end_date, unit_pricing_measure, base_measure, pricing_trend, geo_price, geo_availability, availability, availability_date, expiration_date, seller_name, seller_url, marketplace_seller, seller_privacy_policy, seller_tos, shipping_price, delivery_estimate, pickup_method, pickup_sla, is_digital, return_policy, accepts_returns, return_deadline_in_days, accepts_exchanges, is_eligible_search, is_eligible_checkout, popularity_score, return_rate, warning, warning_url, age_restriction, review_count, star_rating, store_review_count, store_star_rating, related_product_id, relationship_type, target_countries, store_country, q_and_a, qand_a, reviews, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



862
863
864
865
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 862

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



1047
1048
1049
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 1047

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



1053
1054
1055
1056
1057
1058
1059
1060
1061
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 1053

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



1041
1042
1043
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 1041

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



869
870
871
# File 'lib/cybersource_rest_client/models/inline_response_200_20_products.rb', line 869

def valid?
  true
end