Class: CyberSource::InlineResponse2014OrderInformationAmountDetails
- Inherits:
-
Object
- Object
- CyberSource::InlineResponse2014OrderInformationAmountDetails
- Defined in:
- lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb
Instance Attribute Summary collapse
-
#destination_amount ⇒ Object
Amount in your destination's local pricing currency.
-
#exchange_rate ⇒ Object
Exchange rate returned by the card network.
-
#markup_rate ⇒ Object
The markup between the offer exchange rate and wholesale rates, i.e.
-
#original_amount ⇒ Object
Amount in your original local pricing currency.
-
#original_amount_without_markup ⇒ Object
Original Transaction Amount excluding markup in source currency.
-
#settlement_amount ⇒ Object
The transaction amount in settlement currency.
-
#settlement_currency ⇒ Object
The currency in which Visa or Mastercard settles with the acquirer/acquirer.
-
#settlement_exchange_rate ⇒ Object
Exchange rate returned by the card network for settlement.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InlineResponse2014OrderInformationAmountDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ InlineResponse2014OrderInformationAmountDetails
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'markupRate') self.markup_rate = attributes[:'markupRate'] end if attributes.has_key?(:'exchangeRate') self.exchange_rate = attributes[:'exchangeRate'] end if attributes.has_key?(:'originalAmount') self.original_amount = attributes[:'originalAmount'] end if attributes.has_key?(:'destinationAmount') self.destination_amount = attributes[:'destinationAmount'] end if attributes.has_key?(:'originalAmountWithoutMarkup') self.original_amount_without_markup = attributes[:'originalAmountWithoutMarkup'] end if attributes.has_key?(:'settlementAmount') self.settlement_amount = attributes[:'settlementAmount'] end if attributes.has_key?(:'settlementCurrency') self.settlement_currency = attributes[:'settlementCurrency'] end if attributes.has_key?(:'settlementExchangeRate') self.settlement_exchange_rate = attributes[:'settlementExchangeRate'] end end |
Instance Attribute Details
#destination_amount ⇒ Object
Amount in your destination's local pricing currency. This value cannot be negative. You can include a decimal point (.) in this field to denote the currency exponent, but you cannot include any other special characters. If needed, CyberSource truncates the amount to the correct number of decimal places.
26 27 28 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 26 def destination_amount @destination_amount end |
#exchange_rate ⇒ Object
Exchange rate returned by the card network.
20 21 22 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 20 def exchange_rate @exchange_rate end |
#markup_rate ⇒ Object
The markup between the offer exchange rate and wholesale rates, i.e. the mark up. Expressed as a percentage of 100, e.g. 3.75. If the markup value is not supplied in the API, and the Acquiring BIN is provided, the markup configured during onboarding will be picked up and applied to the transaction. To override any markup defaults set up on the account, always send a markup value of 0.00 to indicate 0% markup. Supported by Visa Direct.
17 18 19 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 17 def markup_rate @markup_rate end |
#original_amount ⇒ Object
Amount in your original local pricing currency. This value cannot be negative. You can include a decimal point (.) in this field to denote the currency exponent, but you cannot include any other special characters. If needed, CyberSource truncates the amount to the correct number of decimal places.
23 24 25 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 23 def original_amount @original_amount end |
#original_amount_without_markup ⇒ Object
Original Transaction Amount excluding markup in source currency. This field will be returned in a source-to-destination inquiry response when markup is applicable. Supported by Visa Direct
29 30 31 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 29 def original_amount_without_markup @original_amount_without_markup end |
#settlement_amount ⇒ Object
The transaction amount in settlement currency.
32 33 34 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 32 def settlement_amount @settlement_amount end |
#settlement_currency ⇒ Object
The currency in which Visa or Mastercard settles with the acquirer/acquirer. Use ISO 4217 3-Alpha Currency Codes.
35 36 37 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 35 def settlement_currency @settlement_currency end |
#settlement_exchange_rate ⇒ Object
Exchange rate returned by the card network for settlement.
38 39 40 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 38 def settlement_exchange_rate @settlement_exchange_rate end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 41 def self.attribute_map { :'markup_rate' => :'markupRate', :'exchange_rate' => :'exchangeRate', :'original_amount' => :'originalAmount', :'destination_amount' => :'destinationAmount', :'original_amount_without_markup' => :'originalAmountWithoutMarkup', :'settlement_amount' => :'settlementAmount', :'settlement_currency' => :'settlementCurrency', :'settlement_exchange_rate' => :'settlementExchangeRate' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 55 def self.json_map { :'markup_rate' => :'markup_rate', :'exchange_rate' => :'exchange_rate', :'original_amount' => :'original_amount', :'destination_amount' => :'destination_amount', :'original_amount_without_markup' => :'original_amount_without_markup', :'settlement_amount' => :'settlement_amount', :'settlement_currency' => :'settlement_currency', :'settlement_exchange_rate' => :'settlement_exchange_rate' } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 69 def self.swagger_types { :'markup_rate' => :'String', :'exchange_rate' => :'String', :'original_amount' => :'String', :'destination_amount' => :'String', :'original_amount_without_markup' => :'String', :'settlement_amount' => :'String', :'settlement_currency' => :'String', :'settlement_exchange_rate' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && markup_rate == o.markup_rate && exchange_rate == o.exchange_rate && original_amount == o.original_amount && destination_amount == o.destination_amount && original_amount_without_markup == o.original_amount_without_markup && settlement_amount == o.settlement_amount && settlement_currency == o.settlement_currency && settlement_exchange_rate == o.settlement_exchange_rate end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 235 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 301 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 214 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 207 def hash [markup_rate, exchange_rate, original_amount, destination_amount, original_amount_without_markup, settlement_amount, settlement_currency, settlement_exchange_rate].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 125 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
281 282 283 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 281 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
275 276 277 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 275 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 |
# File 'lib/cybersource_rest_client/models/inline_response_201_4_order_information_amount_details.rb', line 132 def valid? true end |