Class: CyberSource::InvoicingV2InvoicesPost201ResponseInvoiceInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb

Overview

Contains all of the invoice-specific fields, such as the invoice number and due date.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InvoicingV2InvoicesPost201ResponseInvoiceInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 91

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'invoiceNumber')
    self.invoice_number = attributes[:'invoiceNumber']
  end

  if attributes.has_key?(:'transactionReferenceNumber')
    self.transaction_reference_number = attributes[:'transactionReferenceNumber']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'dueDate')
    self.due_date = attributes[:'dueDate']
  end

  if attributes.has_key?(:'expirationDate')
    self.expiration_date = attributes[:'expirationDate']
  end

  if attributes.has_key?(:'allowPartialPayments')
    self.allow_partial_payments = attributes[:'allowPartialPayments']
  else
    self.allow_partial_payments = false
  end

  if attributes.has_key?(:'paymentLink')
    self.payment_link = attributes[:'paymentLink']
  end

  if attributes.has_key?(:'deliveryMode')
    self.delivery_mode = attributes[:'deliveryMode']
  end

  if attributes.has_key?(:'customLabels')
    if (value = attributes[:'customLabels']).is_a?(Array)
      self.custom_labels = value
    end
  end
end

Instance Attribute Details

#allow_partial_paymentsObject

If set to true, the payer can make a partial invoice payment.



33
34
35
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 33

def allow_partial_payments
  @allow_partial_payments
end

#custom_labelsObject

A list of custom labels that allows you to override (rename) default field names and control the visibility of specific fields on invoices and items. If the list is empty, the labels will not be overwritten.



42
43
44
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 42

def custom_labels
  @custom_labels
end

#delivery_modeObject

If this field is set to 'None', an invoice will be generated with the status 'CREATED', but no email will be dispatched. Possible values: - None - Email



39
40
41
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 39

def delivery_mode
  @delivery_mode
end

#descriptionObject

The description included in the invoice.



24
25
26
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 24

def description
  @description
end

#due_dateObject

The invoice due date. This field is required for creating an invoice. Format: YYYY-MM-DD, where YYYY = year, MM = month, and DD = day. The invoice link automatically expires 12 months after the due date.



27
28
29
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 27

def due_date
  @due_date
end

#expiration_dateObject

Define an expiration date for the link. The date must be today or in the future. Format: YYYY-MM-DD, where YYYY = year, MM = month, and DD = day. The invoice link automatically expires 12 months after the due date.



30
31
32
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 30

def expiration_date
  @expiration_date
end

#invoice_numberObject

Invoice Number.



18
19
20
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 18

def invoice_number
  @invoice_number
end

Returns the payment link to an invoice when the invoice status is SENT, CREATED, PARTIAL, or PAID.



36
37
38
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 36

def payment_link
  @payment_link
end

#transaction_reference_numberObject

The transaction reference number (TRN) is a identifier assigned to each payment transaction that allows merchants, customers, and payment processors to track and reference specific transactions throughout their lifecycle. When provided, this value is passed to the payment processor as the reconciliation ID for the payment. For invoices this is typically the invoice number, and for purchase or donation links it is typically the link identifier. Only letters and numbers are allowed; spaces and other special characters are not permitted.



21
22
23
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 21

def transaction_reference_number
  @transaction_reference_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 45

def self.attribute_map
  {
    :'invoice_number' => :'invoiceNumber',
    :'transaction_reference_number' => :'transactionReferenceNumber',
    :'description' => :'description',
    :'due_date' => :'dueDate',
    :'expiration_date' => :'expirationDate',
    :'allow_partial_payments' => :'allowPartialPayments',
    :'payment_link' => :'paymentLink',
    :'delivery_mode' => :'deliveryMode',
    :'custom_labels' => :'customLabels'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 60

def self.json_map
  {
    :'invoice_number' => :'invoice_number',
    :'transaction_reference_number' => :'transaction_reference_number',
    :'description' => :'description',
    :'due_date' => :'due_date',
    :'expiration_date' => :'expiration_date',
    :'allow_partial_payments' => :'allow_partial_payments',
    :'payment_link' => :'payment_link',
    :'delivery_mode' => :'delivery_mode',
    :'custom_labels' => :'custom_labels'
  }
end

.swagger_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 75

def self.swagger_types
  {
    :'invoice_number' => :'String',
    :'transaction_reference_number' => :'String',
    :'description' => :'String',
    :'due_date' => :'Date',
    :'expiration_date' => :'Date',
    :'allow_partial_payments' => :'BOOLEAN',
    :'payment_link' => :'String',
    :'delivery_mode' => :'String',
    :'custom_labels' => :'Array<InvoicingV2InvoicesPost201ResponseInvoiceInformationCustomLabels>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      invoice_number == o.invoice_number &&
      transaction_reference_number == o.transaction_reference_number &&
      description == o.description &&
      due_date == o.due_date &&
      expiration_date == o.expiration_date &&
      allow_partial_payments == o.allow_partial_payments &&
      payment_link == o.payment_link &&
      delivery_mode == o.delivery_mode &&
      custom_labels == o.custom_labels
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 215

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 281

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 194

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


181
182
183
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 181

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



187
188
189
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 187

def hash
  [invoice_number, transaction_reference_number, description, due_date, expiration_date, allow_partial_payments, payment_link, delivery_mode, custom_labels].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 261

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



255
256
257
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 255

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
# File 'lib/cybersource_rest_client/models/invoicing_v2_invoices_post201_response_invoice_information.rb', line 147

def valid?
  true
end