Class: CyberSource::Invoicingv2invoiceSettingsInvoiceSettingsInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Invoicingv2invoiceSettingsInvoiceSettingsInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 136

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'merchantLogo')
    self. = attributes[:'merchantLogo']
  end

  if attributes.has_key?(:'merchantDisplayName')
    self.merchant_display_name = attributes[:'merchantDisplayName']
  end

  if attributes.has_key?(:'customEmailMessage')
    self.custom_email_message = attributes[:'customEmailMessage']
  end

  if attributes.has_key?(:'enableReminders')
    self.enable_reminders = attributes[:'enableReminders']
  end

  if attributes.has_key?(:'headerStyle')
    self.header_style = attributes[:'headerStyle']
  end

  if attributes.has_key?(:'deliveryLanguage')
    self.delivery_language = attributes[:'deliveryLanguage']
  end

  if attributes.has_key?(:'defaultCurrencyCode')
    self.default_currency_code = attributes[:'defaultCurrencyCode']
  end

  if attributes.has_key?(:'payerAuthenticationInInvoicing')
    self.payer_authentication_in_invoicing = attributes[:'payerAuthenticationInInvoicing']
  end

  if attributes.has_key?(:'showVatNumber')
    self.show_vat_number = attributes[:'showVatNumber']
  else
    self.show_vat_number = false
  end

  if attributes.has_key?(:'vatRegistrationNumber')
    self.vat_registration_number = attributes[:'vatRegistrationNumber']
  end

  if attributes.has_key?(:'shipTo')
    self.ship_to = attributes[:'shipTo']
  else
    self.ship_to = false
  end

  if attributes.has_key?(:'phoneNumber')
    self.phone_number = attributes[:'phoneNumber']
  else
    self.phone_number = false
  end

  if attributes.has_key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = false
  end

  if attributes.has_key?(:'enableMerchantEmailNotifications')
    self.enable_merchant_email_notifications = attributes[:'enableMerchantEmailNotifications']
  else
    self.enable_merchant_email_notifications = false
  end

  if attributes.has_key?(:'merchantEmail')
    self.merchant_email = attributes[:'merchantEmail']
  end

  if attributes.has_key?(:'customLabels')
    if (value = attributes[:'customLabels']).is_a?(Array)
      self.custom_labels = value
    end
  end

  if attributes.has_key?(:'customRedirectUrls')
    self.custom_redirect_urls = attributes[:'customRedirectUrls']
  end
end

Instance Attribute Details

#custom_email_messageObject

The content of the email message that we send to your customers.



23
24
25
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 23

def custom_email_message
  @custom_email_message
end

#custom_labelsObject

A list of custom labels that allows you to override (rename) default field names and control the visibility of specific fields on invoices and items. If the list is empty, the labels will not be overwritten.



61
62
63
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 61

def custom_labels
  @custom_labels
end

#custom_redirect_urlsObject

Returns the value of attribute custom_redirect_urls.



63
64
65
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 63

def custom_redirect_urls
  @custom_redirect_urls
end

#default_currency_codeObject

Currency used for the order. Use the three-character ISO Standard Currency Codes. #### Used by Authorization Required field. Authorization Reversal For an authorization reversal (reversalInformation) or a capture (processingOptions.capture is set to true), you must use the same currency that you used in your payment authorization request. #### PIN Debit Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the ISO Standard Currency Codes. Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the ISO Standard Currency Codes. Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests. #### GPX This field is optional for reversing an authorization or credit. #### DCC for First Data Your local currency. #### Tax Calculation Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.



34
35
36
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 34

def default_currency_code
  @default_currency_code
end

#delivery_languageObject

The language of the email that we send to your customers. Possible values are zh-CN, zh-TW, en-US, fr-FR, de-DE, ja-JP, pt-BR, ru-RU and es-419.



31
32
33
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 31

def delivery_language
  @delivery_language
end

#emailObject

Collect the payers email address when the email address is not known or confirm it if it is known at the time of invoice creation.



52
53
54
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 52

def email
  @email
end

#enable_merchant_email_notificationsObject

Whether you would like to receive payment notification for successful transaction



55
56
57
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 55

def enable_merchant_email_notifications
  @enable_merchant_email_notifications
end

#enable_remindersObject

Whether you would like us to send an auto-generated reminder email to your invoice recipients. Currently, this reminder email is sent five days before the invoice is due and one day after it is past due.



26
27
28
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 26

def enable_reminders
  @enable_reminders
end

#header_styleObject

Returns the value of attribute header_style.



28
29
30
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 28

def header_style
  @header_style
end

#merchant_display_nameObject

The merchant's display name shown on the invoice.



20
21
22
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 20

def merchant_display_name
  @merchant_display_name
end

#merchant_emailObject

The merchant's email address for receiving payment notifications.



58
59
60
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 58

def merchant_email
  @merchant_email
end

#merchant_logoObject

The image file, which must be encoded in Base64 format. Supported file formats are png, jpg, and gif. The image file size restriction is 1 MB.



17
18
19
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 17

def 
  @merchant_logo
end

#payer_authentication_in_invoicingObject

For a merchant's invoice payments, enable 3D Secure payer authentication version 1, update to 3D Secure version 2, or disable 3D Secure. Possible values are: - enable - update - disable



37
38
39
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 37

def payer_authentication_in_invoicing
  @payer_authentication_in_invoicing
end

#phone_numberObject

Collect the payers phone number.



49
50
51
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 49

def phone_number
  @phone_number
end

#ship_toObject

Collect the payers shipping address.



46
47
48
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 46

def ship_to
  @ship_to
end

#show_vat_numberObject

Display VAT number on Invoice.



40
41
42
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 40

def show_vat_number
  @show_vat_number
end

#vat_registration_numberObject

Your government-assigned tax identification number. #### Tax Calculation Required field for value added tax only. Not applicable to U.S. and Canadian taxes.



43
44
45
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 43

def vat_registration_number
  @vat_registration_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 66

def self.attribute_map
  {
    :'merchant_logo' => :'merchantLogo',
    :'merchant_display_name' => :'merchantDisplayName',
    :'custom_email_message' => :'customEmailMessage',
    :'enable_reminders' => :'enableReminders',
    :'header_style' => :'headerStyle',
    :'delivery_language' => :'deliveryLanguage',
    :'default_currency_code' => :'defaultCurrencyCode',
    :'payer_authentication_in_invoicing' => :'payerAuthenticationInInvoicing',
    :'show_vat_number' => :'showVatNumber',
    :'vat_registration_number' => :'vatRegistrationNumber',
    :'ship_to' => :'shipTo',
    :'phone_number' => :'phoneNumber',
    :'email' => :'email',
    :'enable_merchant_email_notifications' => :'enableMerchantEmailNotifications',
    :'merchant_email' => :'merchantEmail',
    :'custom_labels' => :'customLabels',
    :'custom_redirect_urls' => :'customRedirectUrls'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 89

def self.json_map
  {
    :'merchant_logo' => :'merchant_logo',
    :'merchant_display_name' => :'merchant_display_name',
    :'custom_email_message' => :'custom_email_message',
    :'enable_reminders' => :'enable_reminders',
    :'header_style' => :'header_style',
    :'delivery_language' => :'delivery_language',
    :'default_currency_code' => :'default_currency_code',
    :'payer_authentication_in_invoicing' => :'payer_authentication_in_invoicing',
    :'show_vat_number' => :'show_vat_number',
    :'vat_registration_number' => :'vat_registration_number',
    :'ship_to' => :'ship_to',
    :'phone_number' => :'phone_number',
    :'email' => :'email',
    :'enable_merchant_email_notifications' => :'enable_merchant_email_notifications',
    :'merchant_email' => :'merchant_email',
    :'custom_labels' => :'custom_labels',
    :'custom_redirect_urls' => :'custom_redirect_urls'
  }
end

.swagger_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 112

def self.swagger_types
  {
    :'merchant_logo' => :'String',
    :'merchant_display_name' => :'String',
    :'custom_email_message' => :'String',
    :'enable_reminders' => :'BOOLEAN',
    :'header_style' => :'InvoicingV2InvoiceSettingsGet200ResponseInvoiceSettingsInformationHeaderStyle',
    :'delivery_language' => :'String',
    :'default_currency_code' => :'String',
    :'payer_authentication_in_invoicing' => :'String',
    :'show_vat_number' => :'BOOLEAN',
    :'vat_registration_number' => :'String',
    :'ship_to' => :'BOOLEAN',
    :'phone_number' => :'BOOLEAN',
    :'email' => :'BOOLEAN',
    :'enable_merchant_email_notifications' => :'BOOLEAN',
    :'merchant_email' => :'String',
    :'custom_labels' => :'Array<InvoicingV2InvoicesPost201ResponseInvoiceInformationCustomLabels>',
    :'custom_redirect_urls' => :'InvoicingV2InvoiceSettingsGet200ResponseInvoiceSettingsInformationCustomRedirectUrls'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 286

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      merchant_display_name == o.merchant_display_name &&
      custom_email_message == o.custom_email_message &&
      enable_reminders == o.enable_reminders &&
      header_style == o.header_style &&
      delivery_language == o.delivery_language &&
      default_currency_code == o.default_currency_code &&
      payer_authentication_in_invoicing == o.payer_authentication_in_invoicing &&
      show_vat_number == o.show_vat_number &&
      vat_registration_number == o.vat_registration_number &&
      ship_to == o.ship_to &&
      phone_number == o.phone_number &&
      email == o.email &&
      enable_merchant_email_notifications == o.enable_merchant_email_notifications &&
      merchant_email == o.merchant_email &&
      custom_labels == o.custom_labels &&
      custom_redirect_urls == o.custom_redirect_urls
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 344

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 410

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 323

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 310

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



316
317
318
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 316

def hash
  [, merchant_display_name, custom_email_message, enable_reminders, header_style, delivery_language, default_currency_code, payer_authentication_in_invoicing, show_vat_number, vat_registration_number, ship_to, phone_number, email, enable_merchant_email_notifications, merchant_email, custom_labels, custom_redirect_urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



225
226
227
228
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 225

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



390
391
392
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 390

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



396
397
398
399
400
401
402
403
404
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 396

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



384
385
386
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 384

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
# File 'lib/cybersource_rest_client/models/invoicingv2invoice_settings_invoice_settings_information.rb', line 232

def valid?
  true
end