Class: CyberSource::LabelRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/label_request.rb

Overview

Label submission request for providing ground truth feedback on previously assessed transactions

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LabelRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/cybersource_rest_client/models/label_request.rb', line 71

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.has_key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  end

  if attributes.has_key?(:'requestId')
    self.request_id = attributes[:'requestId']
  end

  if attributes.has_key?(:'eventTime')
    self.event_time = attributes[:'eventTime']
  end

  if attributes.has_key?(:'transaction')
    self.transaction = attributes[:'transaction']
  end

  if attributes.has_key?(:'labels')
    self.labels = attributes[:'labels']
  end
end

Instance Attribute Details

#actionsObject

Actions to perform. For label submission, specify VISA_PROTECT_RISK_INSIGHTS.



18
19
20
# File 'lib/cybersource_rest_client/models/label_request.rb', line 18

def actions
  @actions
end

#event_timeObject

The time that the real-world event occurred.



27
28
29
# File 'lib/cybersource_rest_client/models/label_request.rb', line 27

def event_time
  @event_time
end

#eventsObject

Must be LABELS for label submission requests.



21
22
23
# File 'lib/cybersource_rest_client/models/label_request.rb', line 21

def events
  @events
end

#labelsObject

Returns the value of attribute labels.



31
32
33
# File 'lib/cybersource_rest_client/models/label_request.rb', line 31

def labels
  @labels
end

#request_idObject

Unique identifier for the label submission request



24
25
26
# File 'lib/cybersource_rest_client/models/label_request.rb', line 24

def request_id
  @request_id
end

#transactionObject

Returns the value of attribute transaction.



29
30
31
# File 'lib/cybersource_rest_client/models/label_request.rb', line 29

def transaction
  @transaction
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/cybersource_rest_client/models/label_request.rb', line 34

def self.attribute_map
  {
    :'actions' => :'actions',
    :'events' => :'events',
    :'request_id' => :'requestId',
    :'event_time' => :'eventTime',
    :'transaction' => :'transaction',
    :'labels' => :'labels'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



46
47
48
49
50
51
52
53
54
55
# File 'lib/cybersource_rest_client/models/label_request.rb', line 46

def self.json_map
  {
    :'actions' => :'actions',
    :'events' => :'events',
    :'request_id' => :'request_id',
    :'event_time' => :'event_time',
    :'transaction' => :'transaction',
    :'labels' => :'labels'
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/cybersource_rest_client/models/label_request.rb', line 58

def self.swagger_types
  {
    :'actions' => :'Array<String>',
    :'events' => :'Array<String>',
    :'request_id' => :'String',
    :'event_time' => :'DateTime',
    :'transaction' => :'UnifiedriskTransaction',
    :'labels' => :'UnifiedriskLabels'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
149
150
# File 'lib/cybersource_rest_client/models/label_request.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      actions == o.actions &&
      events == o.events &&
      request_id == o.request_id &&
      event_time == o.event_time &&
      transaction == o.transaction &&
      labels == o.labels
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/cybersource_rest_client/models/label_request.rb', line 188

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/cybersource_rest_client/models/label_request.rb', line 254

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/cybersource_rest_client/models/label_request.rb', line 167

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/cybersource_rest_client/models/label_request.rb', line 154

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



160
161
162
# File 'lib/cybersource_rest_client/models/label_request.rb', line 160

def hash
  [actions, events, request_id, event_time, transaction, labels].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/cybersource_rest_client/models/label_request.rb', line 108

def list_invalid_properties
  invalid_properties = Array.new
  if @actions.nil?
    invalid_properties.push('invalid value for "actions", actions cannot be nil.')
  end

  if @events.nil?
    invalid_properties.push('invalid value for "events", events cannot be nil.')
  end

  if @transaction.nil?
    invalid_properties.push('invalid value for "transaction", transaction cannot be nil.')
  end

  if @labels.nil?
    invalid_properties.push('invalid value for "labels", labels cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
# File 'lib/cybersource_rest_client/models/label_request.rb', line 234

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
# File 'lib/cybersource_rest_client/models/label_request.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



228
229
230
# File 'lib/cybersource_rest_client/models/label_request.rb', line 228

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
137
# File 'lib/cybersource_rest_client/models/label_request.rb', line 131

def valid?
  return false if @actions.nil?
  return false if @events.nil?
  return false if @transaction.nil?
  return false if @labels.nil?
  true
end