Class: CyberSource::ListMerchantKeysResponse200
- Inherits:
-
Object
- Object
- CyberSource::ListMerchantKeysResponse200
- Defined in:
- lib/cybersource_rest_client/models/list_merchant_keys_response200.rb
Overview
Response object for listing all encryption keys associated with a merchant.
Instance Attribute Summary collapse
-
#keys ⇒ Object
List of keys.
-
#merchant_id ⇒ Object
Unique merchant identifier (UUID).
-
#merchant_name ⇒ Object
Merchant name.
-
#merchant_url ⇒ Object
Base merchant URL.
-
#total_keys ⇒ Object
Total number of keys.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListMerchantKeysResponse200
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ListMerchantKeysResponse200
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'merchantId') self.merchant_id = attributes[:'merchantId'] end if attributes.has_key?(:'merchantName') self.merchant_name = attributes[:'merchantName'] end if attributes.has_key?(:'merchantUrl') self.merchant_url = attributes[:'merchantUrl'] end if attributes.has_key?(:'keys') if (value = attributes[:'keys']).is_a?(Array) self.keys = value end end if attributes.has_key?(:'totalKeys') self.total_keys = attributes[:'totalKeys'] end end |
Instance Attribute Details
#keys ⇒ Object
List of keys
27 28 29 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 27 def keys @keys end |
#merchant_id ⇒ Object
Unique merchant identifier (UUID)
18 19 20 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 18 def merchant_id @merchant_id end |
#merchant_name ⇒ Object
Merchant name
21 22 23 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 21 def merchant_name @merchant_name end |
#merchant_url ⇒ Object
Base merchant URL
24 25 26 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 24 def merchant_url @merchant_url end |
#total_keys ⇒ Object
Total number of keys
30 31 32 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 30 def total_keys @total_keys end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 33 def self.attribute_map { :'merchant_id' => :'merchantId', :'merchant_name' => :'merchantName', :'merchant_url' => :'merchantUrl', :'keys' => :'keys', :'total_keys' => :'totalKeys' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
44 45 46 47 48 49 50 51 52 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 44 def self.json_map { :'merchant_id' => :'merchant_id', :'merchant_name' => :'merchant_name', :'merchant_url' => :'merchant_url', :'keys' => :'keys', :'total_keys' => :'total_keys' } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 55 def self.swagger_types { :'merchant_id' => :'String', :'merchant_name' => :'String', :'merchant_url' => :'String', :'keys' => :'Array<MerchantRegistrationResponse201Keys>', :'total_keys' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 136 def ==(o) return true if self.equal?(o) self.class == o.class && merchant_id == o.merchant_id && merchant_name == o.merchant_name && merchant_url == o.merchant_url && keys == o.keys && total_keys == o.total_keys end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 182 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 248 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 161 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
148 149 150 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 148 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 154 def hash [merchant_id, merchant_name, merchant_url, keys, total_keys].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 98 def list_invalid_properties invalid_properties = Array.new if @merchant_id.nil? invalid_properties.push('invalid value for "merchant_id", merchant_id cannot be nil.') end if @merchant_name.nil? invalid_properties.push('invalid value for "merchant_name", merchant_name cannot be nil.') end if @merchant_url.nil? invalid_properties.push('invalid value for "merchant_url", merchant_url cannot be nil.') end if @keys.nil? invalid_properties.push('invalid value for "keys", keys cannot be nil.') end if @total_keys.nil? invalid_properties.push('invalid value for "total_keys", total_keys cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
228 229 230 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 228 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
222 223 224 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 222 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 129 130 131 132 |
# File 'lib/cybersource_rest_client/models/list_merchant_keys_response200.rb', line 125 def valid? return false if @merchant_id.nil? return false if @merchant_name.nil? return false if @merchant_url.nil? return false if @keys.nil? return false if @total_keys.nil? true end |