Class: CyberSource::MerchantRegistrationResponse201Keys
- Inherits:
-
Object
- Object
- CyberSource::MerchantRegistrationResponse201Keys
- Defined in:
- lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb
Overview
Key response without merchant fields (used in merchant-level responses)
Instance Attribute Summary collapse
-
#algorithm ⇒ Object
JWE key wrap algorithm Possible values: - RSA-OAEP - RSA-OAEP-256 - RSA-OAEP-384 - RSA-OAEP-512.
-
#created_at ⇒ Object
Creation timestamp.
-
#encryption_key ⇒ Object
Base64-encoded public key.
-
#encryption_type ⇒ Object
JWE content encryption algorithm Possible values: - A256GCM - A128GCM - C20P - A256CBC-HS512 - A128CBC-HS256 - A256CCM - A128CCM.
-
#expiration_date ⇒ Object
Key expiration date in UTC.
-
#id ⇒ Object
Unique key identifier (UUID).
-
#key_name ⇒ Object
Unique name for the key.
-
#status ⇒ Object
Key lifecycle status Possible values: - active - deactivated - expired.
-
#updated_at ⇒ Object
Last update timestamp.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MerchantRegistrationResponse201Keys
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MerchantRegistrationResponse201Keys
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'keyName') self.key_name = attributes[:'keyName'] end if attributes.has_key?(:'encryptionKey') self.encryption_key = attributes[:'encryptionKey'] end if attributes.has_key?(:'algorithm') self.algorithm = attributes[:'algorithm'] end if attributes.has_key?(:'encryptionType') self.encryption_type = attributes[:'encryptionType'] end if attributes.has_key?(:'expirationDate') self.expiration_date = attributes[:'expirationDate'] end if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'createdAt') self.created_at = attributes[:'createdAt'] end if attributes.has_key?(:'updatedAt') self.updated_at = attributes[:'updatedAt'] end end |
Instance Attribute Details
#algorithm ⇒ Object
JWE key wrap algorithm Possible values: - RSA-OAEP - RSA-OAEP-256 - RSA-OAEP-384 - RSA-OAEP-512
27 28 29 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 27 def algorithm @algorithm end |
#created_at ⇒ Object
Creation timestamp
39 40 41 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 39 def created_at @created_at end |
#encryption_key ⇒ Object
Base64-encoded public key
24 25 26 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 24 def encryption_key @encryption_key end |
#encryption_type ⇒ Object
JWE content encryption algorithm Possible values: - A256GCM - A128GCM - C20P - A256CBC-HS512 - A128CBC-HS256 - A256CCM - A128CCM
30 31 32 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 30 def encryption_type @encryption_type end |
#expiration_date ⇒ Object
Key expiration date in UTC
33 34 35 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 33 def expiration_date @expiration_date end |
#id ⇒ Object
Unique key identifier (UUID). Generated from VMRS.
18 19 20 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 18 def id @id end |
#key_name ⇒ Object
Unique name for the key
21 22 23 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 21 def key_name @key_name end |
#status ⇒ Object
Key lifecycle status Possible values: - active - deactivated - expired
36 37 38 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 36 def status @status end |
#updated_at ⇒ Object
Last update timestamp
42 43 44 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 42 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 45 def self.attribute_map { :'id' => :'id', :'key_name' => :'keyName', :'encryption_key' => :'encryptionKey', :'algorithm' => :'algorithm', :'encryption_type' => :'encryptionType', :'expiration_date' => :'expirationDate', :'status' => :'status', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 60 def self.json_map { :'id' => :'id', :'key_name' => :'key_name', :'encryption_key' => :'encryption_key', :'algorithm' => :'algorithm', :'encryption_type' => :'encryption_type', :'expiration_date' => :'expiration_date', :'status' => :'status', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 75 def self.swagger_types { :'id' => :'String', :'key_name' => :'String', :'encryption_key' => :'String', :'algorithm' => :'String', :'encryption_type' => :'String', :'expiration_date' => :'DateTime', :'status' => :'String', :'created_at' => :'DateTime', :'updated_at' => :'DateTime' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && key_name == o.key_name && encryption_key == o.encryption_key && algorithm == o.algorithm && encryption_type == o.encryption_type && expiration_date == o.expiration_date && status == o.status && created_at == o.created_at && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 244 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 310 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 216 def hash [id, key_name, encryption_key, algorithm, encryption_type, expiration_date, status, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 136 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @key_name.nil? invalid_properties.push('invalid value for "key_name", key_name cannot be nil.') end if @encryption_key.nil? invalid_properties.push('invalid value for "encryption_key", encryption_key cannot be nil.') end if @algorithm.nil? invalid_properties.push('invalid value for "algorithm", algorithm cannot be nil.') end if @encryption_type.nil? invalid_properties.push('invalid value for "encryption_type", encryption_type cannot be nil.') end if @expiration_date.nil? invalid_properties.push('invalid value for "expiration_date", expiration_date cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
290 291 292 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 290 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
296 297 298 299 300 301 302 303 304 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 296 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
284 285 286 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 284 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/cybersource_rest_client/models/merchant_registration_response201_keys.rb', line 179 def valid? return false if @id.nil? return false if @key_name.nil? return false if @encryption_key.nil? return false if @algorithm.nil? return false if @encryption_type.nil? return false if @expiration_date.nil? return false if @status.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |