Class: CyberSource::MerchantUpdate

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/merchant_update.rb

Overview

All fields are optional; only provided fields are updated.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MerchantUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 83

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'merchantName')
    self.merchant_name = attributes[:'merchantName']
  end

  if attributes.has_key?(:'merchantUrl')
    self.merchant_url = attributes[:'merchantUrl']
  end

  if attributes.has_key?(:'cryptogramType')
    self.cryptogram_type = attributes[:'cryptogramType']
  end

  if attributes.has_key?(:'paymentPayloadType')
    self.payment_payload_type = attributes[:'paymentPayloadType']
  end

  if attributes.has_key?(:'acceptanceRelationships')
    if (value = attributes[:'acceptanceRelationships']).is_a?(Array)
      self.acceptance_relationships = value
    end
  end

  if attributes.has_key?(:'protocolInteractions')
    if (value = attributes[:'protocolInteractions']).is_a?(Array)
      self.protocol_interactions = value
    end
  end

  if attributes.has_key?(:'webIntegrations')
    self.web_integrations = attributes[:'webIntegrations']
  end

  if attributes.has_key?(:'apiIntegrations')
    self.api_integrations = attributes[:'apiIntegrations']
  end
end

Instance Attribute Details

#acceptance_relationshipsObject

List of acceptance network relationships



30
31
32
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 30

def acceptance_relationships
  @acceptance_relationships
end

#api_integrationsObject

Returns the value of attribute api_integrations.



37
38
39
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 37

def api_integrations
  @api_integrations
end

#cryptogram_typeObject

Authentication cryptogram type Possible values: - TAVV - DAVV



24
25
26
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 24

def cryptogram_type
  @cryptogram_type
end

#merchant_nameObject

Doing business as (DBA) name



18
19
20
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 18

def merchant_name
  @merchant_name
end

#merchant_urlObject

Base merchant URL (must use HTTPS)



21
22
23
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 21

def merchant_url
  @merchant_url
end

#payment_payload_typeObject

Credential delivery format Possible values: - ENCRYPTED - UNENCRYPTED



27
28
29
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 27

def payment_payload_type
  @payment_payload_type
end

#protocol_interactionsObject

List of protocol configurations



33
34
35
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 33

def protocol_interactions
  @protocol_interactions
end

#web_integrationsObject

Returns the value of attribute web_integrations.



35
36
37
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 35

def web_integrations
  @web_integrations
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 40

def self.attribute_map
  {
    :'merchant_name' => :'merchantName',
    :'merchant_url' => :'merchantUrl',
    :'cryptogram_type' => :'cryptogramType',
    :'payment_payload_type' => :'paymentPayloadType',
    :'acceptance_relationships' => :'acceptanceRelationships',
    :'protocol_interactions' => :'protocolInteractions',
    :'web_integrations' => :'webIntegrations',
    :'api_integrations' => :'apiIntegrations'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 54

def self.json_map
  {
    :'merchant_name' => :'merchant_name',
    :'merchant_url' => :'merchant_url',
    :'cryptogram_type' => :'cryptogram_type',
    :'payment_payload_type' => :'payment_payload_type',
    :'acceptance_relationships' => :'acceptance_relationships',
    :'protocol_interactions' => :'protocol_interactions',
    :'web_integrations' => :'web_integrations',
    :'api_integrations' => :'api_integrations'
  }
end

.swagger_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 68

def self.swagger_types
  {
    :'merchant_name' => :'String',
    :'merchant_url' => :'String',
    :'cryptogram_type' => :'String',
    :'payment_payload_type' => :'String',
    :'acceptance_relationships' => :'Array<String>',
    :'protocol_interactions' => :'Array<Iccv1merchantsProtocolInteractions>',
    :'web_integrations' => :'Iccv1merchantsWebIntegrations',
    :'api_integrations' => :'Iccv1merchantsApiIntegrations'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      merchant_name == o.merchant_name &&
      merchant_url == o.merchant_url &&
      cryptogram_type == o.cryptogram_type &&
      payment_payload_type == o.payment_payload_type &&
      acceptance_relationships == o.acceptance_relationships &&
      protocol_interactions == o.protocol_interactions &&
      web_integrations == o.web_integrations &&
      api_integrations == o.api_integrations
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 190

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 256

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 169

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 156

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



162
163
164
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 162

def hash
  [merchant_name, merchant_url, cryptogram_type, payment_payload_type, acceptance_relationships, protocol_interactions, web_integrations, api_integrations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 128

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 236

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



242
243
244
245
246
247
248
249
250
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 242

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



230
231
232
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 230

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
# File 'lib/cybersource_rest_client/models/merchant_update.rb', line 135

def valid?
  true
end