Class: CyberSource::NetFundingsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/api/net_fundings_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default, config) ⇒ NetFundingsApi



18
19
20
21
# File 'lib/cybersource_rest_client/api/net_fundings_api.rb', line 18

def initialize(api_client = ApiClient.default, config)
  @api_client = api_client
  @api_client.set_configuration(config)
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



16
17
18
# File 'lib/cybersource_rest_client/api/net_fundings_api.rb', line 16

def api_client
  @api_client
end

Instance Method Details

#get_net_funding_details(start_time, end_time, opts = {}) ⇒ ReportingV3NetFundingsGet200Response

Get Netfunding Information for an Account or a Merchant Get Netfunding information for an account or a merchant.

Options Hash (opts):

  • :organization_id (String)

    Valid Organization Id

  • :group_name (String)

    Valid CyberSource Group Name.



32
33
34
35
# File 'lib/cybersource_rest_client/api/net_fundings_api.rb', line 32

def get_net_funding_details(start_time, end_time, opts = {})
  data, status_code, headers = get_net_funding_details_with_http_info(start_time, end_time, opts)
  return data, status_code, headers
end

#get_net_funding_details_with_http_info(start_time, end_time, opts = {}) ⇒ Array<(ReportingV3NetFundingsGet200Response, Fixnum, Hash)>

Get Netfunding Information for an Account or a Merchant Get Netfunding information for an account or a merchant.

Options Hash (opts):

  • :organization_id (String)

    Valid Organization Id

  • :group_name (String)

    Valid CyberSource Group Name.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/cybersource_rest_client/api/net_fundings_api.rb', line 45

def get_net_funding_details_with_http_info(start_time, end_time, opts = {})

  if @api_client.config.debugging
      begin
        raise
            @api_client.config.logger.debug 'Calling API: NetFundingsApi.get_net_funding_details ...'
        rescue
            puts 'Cannot write to log'
        end
  end
  # verify the required parameter 'start_time' is set

  if @api_client.config.client_side_validation && start_time.nil?
    fail ArgumentError, "Missing the required parameter 'start_time' when calling NetFundingsApi.get_net_funding_details"
  end
  # verify the required parameter 'end_time' is set

  if @api_client.config.client_side_validation && end_time.nil?
    fail ArgumentError, "Missing the required parameter 'end_time' when calling NetFundingsApi.get_net_funding_details"
  end
  #if @api_client.config.client_side_validation && !opts[:'organization_id'].nil? && opts[:'organization_id'] !~ Regexp.new(/[a-zA-Z0-9-_]+/)

    #fail ArgumentError, "invalid value for 'opts[:\"organization_id\"]' when calling NetFundingsApi.get_net_funding_details, must conform to the pattern /[a-zA-Z0-9-_]+/."

  #end


  # resource path

  local_var_path = 'reporting/v3/net-fundings'

  # query parameters

  query_params = {}
  query_params[:'startTime'] = start_time
  query_params[:'endTime'] = end_time
  query_params[:'organizationId'] = opts[:'organization_id'] if !opts[:'organization_id'].nil?
  query_params[:'groupName'] = opts[:'group_name'] if !opts[:'group_name'].nil?

  # header parameters

  header_params = {}
  # HTTP header 'Accept' (if needed)

  header_params['Accept'] = @api_client.select_header_accept(['application/hal+json', 'application/xml'])
  # HTTP header 'Content-Type'

  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8'])

  # form parameters

  form_params = {}

  # http body (model)

  if 'GET' == 'POST'
    post_body = '{}'
  else
    post_body = nil
  end
  inbound_mle_status = "false"
  if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["get_net_funding_details","get_net_funding_details_with_http_info"])
    begin
      post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body)
    rescue
      raise
    end
  end

  is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["get_net_funding_details","get_net_funding_details_with_http_info"])

  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'ReportingV3NetFundingsGet200Response',
    :isResponseMLEForApi => is_response_mle_for_api)
  if @api_client.config.debugging
    begin
    raise
        @api_client.config.logger.debug "API called: NetFundingsApi#get_net_funding_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
    rescue
        puts 'Cannot write to log'
    end
  end
  return data, status_code, headers
end