Class: CyberSource::NotificationOfChangesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/api/notification_of_changes_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default, config) ⇒ NotificationOfChangesApi



18
19
20
21
# File 'lib/cybersource_rest_client/api/notification_of_changes_api.rb', line 18

def initialize(api_client = ApiClient.default, config)
  @api_client = api_client
  @api_client.set_configuration(config)
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



16
17
18
# File 'lib/cybersource_rest_client/api/notification_of_changes_api.rb', line 16

def api_client
  @api_client
end

Instance Method Details

#get_notification_of_change_report(start_time, end_time, opts = {}) ⇒ ReportingV3NotificationofChangesGet200Response

Get Notification of Changes Download the Notification of Change report. This report shows eCheck-related fields updated as a result of a response to an eCheck settlement transaction.



30
31
32
33
# File 'lib/cybersource_rest_client/api/notification_of_changes_api.rb', line 30

def get_notification_of_change_report(start_time, end_time, opts = {})
  data, status_code, headers = get_notification_of_change_report_with_http_info(start_time, end_time, opts)
  return data, status_code, headers
end

#get_notification_of_change_report_with_http_info(start_time, end_time, opts = {}) ⇒ Array<(ReportingV3NotificationofChangesGet200Response, Fixnum, Hash)>

Get Notification of Changes Download the Notification of Change report. This report shows eCheck-related fields updated as a result of a response to an eCheck settlement transaction.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/cybersource_rest_client/api/notification_of_changes_api.rb', line 41

def get_notification_of_change_report_with_http_info(start_time, end_time, opts = {})

  if @api_client.config.debugging
      begin
        raise
            @api_client.config.logger.debug 'Calling API: NotificationOfChangesApi.get_notification_of_change_report ...'
        rescue
            puts 'Cannot write to log'
        end
  end
  # verify the required parameter 'start_time' is set

  if @api_client.config.client_side_validation && start_time.nil?
    fail ArgumentError, "Missing the required parameter 'start_time' when calling NotificationOfChangesApi.get_notification_of_change_report"
  end
  # verify the required parameter 'end_time' is set

  if @api_client.config.client_side_validation && end_time.nil?
    fail ArgumentError, "Missing the required parameter 'end_time' when calling NotificationOfChangesApi.get_notification_of_change_report"
  end
  # resource path

  local_var_path = 'reporting/v3/notification-of-changes'

  # query parameters

  query_params = {}
  query_params[:'startTime'] = start_time
  query_params[:'endTime'] = end_time

  # header parameters

  header_params = {}
  # HTTP header 'Accept' (if needed)

  header_params['Accept'] = @api_client.select_header_accept(['application/hal+json', 'text/csv', 'application/xml'])
  # HTTP header 'Content-Type'

  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8'])

  # form parameters

  form_params = {}

  # http body (model)

  if 'GET' == 'POST'
    post_body = '{}'
  else
    post_body = nil
  end
  is_mle_supported_by_cybs_for_api = false
  if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, is_mle_supported_by_cybs_for_api, ["get_notification_of_change_report","get_notification_of_change_report_with_http_info"])
    post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body)
  end
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'ReportingV3NotificationofChangesGet200Response')
  if @api_client.config.debugging
    begin
    raise
        @api_client.config.logger.debug "API called: NotificationOfChangesApi#get_notification_of_change_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
    rescue
        puts 'Cannot write to log'
    end
  end
  return data, status_code, headers
end