Class: CyberSource::PayoutsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/api/payouts_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default, config) ⇒ PayoutsApi



18
19
20
21
# File 'lib/cybersource_rest_client/api/payouts_api.rb', line 18

def initialize(api_client = ApiClient.default, config)
  @api_client = api_client
  @api_client.set_configuration(config)
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



16
17
18
# File 'lib/cybersource_rest_client/api/payouts_api.rb', line 16

def api_client
  @api_client
end

Instance Method Details

#oct_create_payment(oct_create_payment_request, opts = {}) ⇒ PtsV2PayoutsPost201Response

Process a Payout Send funds from a selected funding source to a designated credit/debit card account or a prepaid card using an Original Credit Transaction (OCT). The availability of API features for a merchant can depend on the portfolio configuration and may need to be enabled at the portfolio level before they can be added to merchant accounts.



29
30
31
32
# File 'lib/cybersource_rest_client/api/payouts_api.rb', line 29

def oct_create_payment(oct_create_payment_request, opts = {})
  data, status_code, headers = oct_create_payment_with_http_info(oct_create_payment_request, opts)
  return data, status_code, headers
end

#oct_create_payment_with_http_info(oct_create_payment_request, opts = {}) ⇒ Array<(PtsV2PayoutsPost201Response, Fixnum, Hash)>

Process a Payout Send funds from a selected funding source to a designated credit/debit card account or a prepaid card using an Original Credit Transaction (OCT). The availability of API features for a merchant can depend on the portfolio configuration and may need to be enabled at the portfolio level before they can be added to merchant accounts.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cybersource_rest_client/api/payouts_api.rb', line 39

def oct_create_payment_with_http_info(oct_create_payment_request, opts = {})

  if @api_client.config.debugging
      begin
        raise
            @api_client.config.logger.debug 'Calling API: PayoutsApi.oct_create_payment ...'
        rescue
            puts 'Cannot write to log'
        end
  end
  # verify the required parameter 'oct_create_payment_request' is set

  if @api_client.config.client_side_validation && oct_create_payment_request.nil?
    fail ArgumentError, "Missing the required parameter 'oct_create_payment_request' when calling PayoutsApi.oct_create_payment"
  end
  # resource path

  local_var_path = 'pts/v2/payouts'

  # query parameters

  query_params = {}

  # header parameters

  header_params = {}
  # HTTP header 'Accept' (if needed)

  header_params['Accept'] = @api_client.select_header_accept(['application/hal+json;charset=utf-8'])
  # HTTP header 'Content-Type'

  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8'])

  # form parameters

  form_params = {}

  # http body (model)

  post_body = @api_client.object_to_http_body(oct_create_payment_request)
  sdk_tracker = SdkTracker.new
  post_body = sdk_tracker.insert_developer_id_tracker(post_body, 'OctCreatePaymentRequest', @api_client.config.host, @api_client.merchantconfig.defaultDeveloperId)
  inbound_mle_status = "optional"
  if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["oct_create_payment","oct_create_payment_with_http_info"])
    begin
      post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body)
    rescue
      raise
    end
  end

  is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["oct_create_payment","oct_create_payment_with_http_info"])

  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PtsV2PayoutsPost201Response',
    :isResponseMLEForApi => is_response_mle_for_api)
  if @api_client.config.debugging
    begin
    raise
        @api_client.config.logger.debug "API called: PayoutsApi#oct_create_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
    rescue
        puts 'Cannot write to log'
    end
  end
  return data, status_code, headers
end