Class: CyberSource::PtsV2CreditsPost201Response
- Inherits:
-
Object
- Object
- CyberSource::PtsV2CreditsPost201Response
- Defined in:
- lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb
Instance Attribute Summary collapse
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#clearing_information ⇒ Object
Returns the value of attribute clearing_information.
-
#client_reference_information ⇒ Object
Returns the value of attribute client_reference_information.
-
#credit_amount_details ⇒ Object
Returns the value of attribute credit_amount_details.
-
#error_information ⇒ Object
Returns the value of attribute error_information.
-
#id ⇒ Object
An unique identification number generated by Cybersource to identify the submitted request.
-
#merchant_information ⇒ Object
Returns the value of attribute merchant_information.
-
#order_information ⇒ Object
Returns the value of attribute order_information.
-
#payment_account_information ⇒ Object
Returns the value of attribute payment_account_information.
-
#payment_information ⇒ Object
Returns the value of attribute payment_information.
-
#point_of_sale_information ⇒ Object
Returns the value of attribute point_of_sale_information.
-
#processing_information ⇒ Object
Returns the value of attribute processing_information.
-
#processor_information ⇒ Object
Returns the value of attribute processor_information.
-
#reconciliation_id ⇒ Object
Reference number for the transaction.
-
#status ⇒ Object
The status of the submitted transaction.
-
#submit_time_utc ⇒ Object
Time of request in UTC.
-
#token_information ⇒ Object
Returns the value of attribute token_information.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PtsV2CreditsPost201Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PtsV2CreditsPost201Response
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'_links') self._links = attributes[:'_links'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'submitTimeUtc') self.submit_time_utc = attributes[:'submitTimeUtc'] end if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'reconciliationId') self.reconciliation_id = attributes[:'reconciliationId'] end if attributes.has_key?(:'clientReferenceInformation') self.client_reference_information = attributes[:'clientReferenceInformation'] end if attributes.has_key?(:'creditAmountDetails') self.credit_amount_details = attributes[:'creditAmountDetails'] end if attributes.has_key?(:'processingInformation') self.processing_information = attributes[:'processingInformation'] end if attributes.has_key?(:'processorInformation') self.processor_information = attributes[:'processorInformation'] end if attributes.has_key?(:'paymentInformation') self.payment_information = attributes[:'paymentInformation'] end if attributes.has_key?(:'orderInformation') self.order_information = attributes[:'orderInformation'] end if attributes.has_key?(:'merchantInformation') self.merchant_information = attributes[:'merchantInformation'] end if attributes.has_key?(:'clearingInformation') self.clearing_information = attributes[:'clearingInformation'] end if attributes.has_key?(:'pointOfSaleInformation') self.point_of_sale_information = attributes[:'pointOfSaleInformation'] end if attributes.has_key?(:'tokenInformation') self.token_information = attributes[:'tokenInformation'] end if attributes.has_key?(:'paymentAccountInformation') self.payment_account_information = attributes[:'paymentAccountInformation'] end if attributes.has_key?(:'errorInformation') self.error_information = attributes[:'errorInformation'] end end |
Instance Attribute Details
#_links ⇒ Object
Returns the value of attribute _links.
16 17 18 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 16 def _links @_links end |
#clearing_information ⇒ Object
Returns the value of attribute clearing_information.
44 45 46 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 44 def clearing_information @clearing_information end |
#client_reference_information ⇒ Object
Returns the value of attribute client_reference_information.
30 31 32 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 30 def client_reference_information @client_reference_information end |
#credit_amount_details ⇒ Object
Returns the value of attribute credit_amount_details.
32 33 34 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 32 def credit_amount_details @credit_amount_details end |
#error_information ⇒ Object
Returns the value of attribute error_information.
52 53 54 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 52 def error_information @error_information end |
#id ⇒ Object
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
19 20 21 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 19 def id @id end |
#merchant_information ⇒ Object
Returns the value of attribute merchant_information.
42 43 44 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 42 def merchant_information @merchant_information end |
#order_information ⇒ Object
Returns the value of attribute order_information.
40 41 42 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 40 def order_information @order_information end |
#payment_account_information ⇒ Object
Returns the value of attribute payment_account_information.
50 51 52 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 50 def payment_account_information @payment_account_information end |
#payment_information ⇒ Object
Returns the value of attribute payment_information.
38 39 40 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 38 def payment_information @payment_information end |
#point_of_sale_information ⇒ Object
Returns the value of attribute point_of_sale_information.
46 47 48 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 46 def point_of_sale_information @point_of_sale_information end |
#processing_information ⇒ Object
Returns the value of attribute processing_information.
34 35 36 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 34 def processing_information @processing_information end |
#processor_information ⇒ Object
Returns the value of attribute processor_information.
36 37 38 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 36 def processor_information @processor_information end |
#reconciliation_id ⇒ Object
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
28 29 30 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 28 def reconciliation_id @reconciliation_id end |
#status ⇒ Object
The status of the submitted transaction. Possible values: - PENDING - COMPLETED (as in the case of PIN Debit Full Financial Credit)
25 26 27 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 25 def status @status end |
#submit_time_utc ⇒ Object
Time of request in UTC. Format: ‘YYYY-MM-DDThh:mm:ssZ` Example `2016-08-11T22:47:57Z` equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The `T` separates the date and the time. The `Z` indicates UTC. Returned by Cybersource for all services.
22 23 24 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 22 def submit_time_utc @submit_time_utc end |
#token_information ⇒ Object
Returns the value of attribute token_information.
48 49 50 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 48 def token_information @token_information end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 55 def self.attribute_map { :'_links' => :'_links', :'id' => :'id', :'submit_time_utc' => :'submitTimeUtc', :'status' => :'status', :'reconciliation_id' => :'reconciliationId', :'client_reference_information' => :'clientReferenceInformation', :'credit_amount_details' => :'creditAmountDetails', :'processing_information' => :'processingInformation', :'processor_information' => :'processorInformation', :'payment_information' => :'paymentInformation', :'order_information' => :'orderInformation', :'merchant_information' => :'merchantInformation', :'clearing_information' => :'clearingInformation', :'point_of_sale_information' => :'pointOfSaleInformation', :'token_information' => :'tokenInformation', :'payment_account_information' => :'paymentAccountInformation', :'error_information' => :'errorInformation' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 78 def self.json_map { :'_links' => :'_links', :'id' => :'id', :'submit_time_utc' => :'submit_time_utc', :'status' => :'status', :'reconciliation_id' => :'reconciliation_id', :'client_reference_information' => :'client_reference_information', :'credit_amount_details' => :'credit_amount_details', :'processing_information' => :'processing_information', :'processor_information' => :'processor_information', :'payment_information' => :'payment_information', :'order_information' => :'order_information', :'merchant_information' => :'merchant_information', :'clearing_information' => :'clearing_information', :'point_of_sale_information' => :'point_of_sale_information', :'token_information' => :'token_information', :'payment_account_information' => :'payment_account_information', :'error_information' => :'error_information' } end |
.swagger_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 101 def self.swagger_types { :'_links' => :'PtsV2PaymentsRefundPost201ResponseLinks', :'id' => :'String', :'submit_time_utc' => :'String', :'status' => :'String', :'reconciliation_id' => :'String', :'client_reference_information' => :'PtsV2PaymentsPost201ResponseClientReferenceInformation', :'credit_amount_details' => :'PtsV2CreditsPost201ResponseCreditAmountDetails', :'processing_information' => :'PtsV2CreditsPost201ResponseProcessingInformation', :'processor_information' => :'PtsV2PaymentsRefundPost201ResponseProcessorInformation', :'payment_information' => :'PtsV2CreditsPost201ResponsePaymentInformation', :'order_information' => :'PtsV2PaymentsRefundPost201ResponseOrderInformation', :'merchant_information' => :'PtsV2CreditsPost201ResponseMerchantInformation', :'clearing_information' => :'PtsV2PaymentsPost201ResponseClearingInformation', :'point_of_sale_information' => :'PtsV2PaymentsCapturesPost201ResponsePointOfSaleInformation', :'token_information' => :'PtsV2CreditsPost201ResponseTokenInformation', :'payment_account_information' => :'PtsV2CreditsPost201ResponsePaymentAccountInformation', :'error_information' => :'PtsV2PaymentsRefundPost201ResponseErrorInformation' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && id == o.id && submit_time_utc == o.submit_time_utc && status == o.status && reconciliation_id == o.reconciliation_id && client_reference_information == o.client_reference_information && credit_amount_details == o.credit_amount_details && processing_information == o.processing_information && processor_information == o.processor_information && payment_information == o.payment_information && order_information == o.order_information && merchant_information == o.merchant_information && clearing_information == o.clearing_information && point_of_sale_information == o.point_of_sale_information && token_information == o.token_information && payment_account_information == o.payment_account_information && error_information == o.error_information end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 285 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 351 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 264 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 257 def hash [_links, id, submit_time_utc, status, reconciliation_id, client_reference_information, credit_amount_details, processing_information, processor_information, payment_information, order_information, merchant_information, clearing_information, point_of_sale_information, token_information, payment_account_information, error_information].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 202 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
331 332 333 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 331 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 325 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 |
# File 'lib/cybersource_rest_client/models/pts_v2_credits_post201_response.rb', line 209 def valid? true end |