Class: CyberSource::PtsV2ModifyBillingAgreementPost201ResponseAgreementInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PtsV2ModifyBillingAgreementPost201ResponseAgreementInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 96

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'dateSigned')
    self.date_signed = attributes[:'dateSigned']
  end

  if attributes.has_key?(:'dateCreated')
    self.date_created = attributes[:'dateCreated']
  end

  if attributes.has_key?(:'dateRevoked')
    self.date_revoked = attributes[:'dateRevoked']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'frequency')
    self.frequency = attributes[:'frequency']
  end

  if attributes.has_key?(:'encodedHtml')
    self.encoded_html = attributes[:'encodedHtml']
  end

  if attributes.has_key?(:'encodedHtmlPopup')
    self.encoded_html_popup = attributes[:'encodedHtmlPopup']
  end

  if attributes.has_key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.has_key?(:'transactionId')
    self.transaction_id = attributes[:'transactionId']
  end
end

Instance Attribute Details

#date_createdObject

Date the mandate has been created. Format YYYYMMdd



23
24
25
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 23

def date_created
  @date_created
end

#date_revokedObject

Date the mandate has been revoked. Format YYYYMMdd



26
27
28
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 26

def date_revoked
  @date_revoked
end

#date_signedObject

Date the mandate has been signed. Format YYYYMMdd



20
21
22
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 20

def date_signed
  @date_signed
end

#encoded_htmlObject

Base64 encoded html string



35
36
37
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 35

def encoded_html
  @encoded_html
end

#encoded_html_popupObject

Base64 encoded popup html string



38
39
40
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 38

def encoded_html_popup
  @encoded_html_popup
end

#frequencyObject

Regularity with which the event occurs. Possible values: - annual - monthly - quarterly - semiannual - weekly - daily - adhoc - intraday - fortnightly



32
33
34
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 32

def frequency
  @frequency
end

#idObject

Identifier for the mandate.



17
18
19
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 17

def id
  @id
end

#transaction_idObject

The Billing Agreement ID returned by processor (PayPal).



44
45
46
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 44

def transaction_id
  @transaction_id
end

#typeObject

Identifies the type of schedule as either recurring, one-off, split or usage. Possible values: - recurring - oneoff - split - usage



29
30
31
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 29

def type
  @type
end

#urlObject

URL for redirecting the customer for creating the mandate.



41
42
43
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 41

def url
  @url
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 47

def self.attribute_map
  {
    :'id' => :'id',
    :'date_signed' => :'dateSigned',
    :'date_created' => :'dateCreated',
    :'date_revoked' => :'dateRevoked',
    :'type' => :'type',
    :'frequency' => :'frequency',
    :'encoded_html' => :'encodedHtml',
    :'encoded_html_popup' => :'encodedHtmlPopup',
    :'url' => :'url',
    :'transaction_id' => :'transactionId'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 63

def self.json_map
  {
    :'id' => :'id',
    :'date_signed' => :'date_signed',
    :'date_created' => :'date_created',
    :'date_revoked' => :'date_revoked',
    :'type' => :'type',
    :'frequency' => :'frequency',
    :'encoded_html' => :'encoded_html',
    :'encoded_html_popup' => :'encoded_html_popup',
    :'url' => :'url',
    :'transaction_id' => :'transaction_id'
  }
end

.swagger_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 79

def self.swagger_types
  {
    :'id' => :'String',
    :'date_signed' => :'String',
    :'date_created' => :'String',
    :'date_revoked' => :'String',
    :'type' => :'String',
    :'frequency' => :'String',
    :'encoded_html' => :'String',
    :'encoded_html_popup' => :'String',
    :'url' => :'String',
    :'transaction_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      date_signed == o.date_signed &&
      date_created == o.date_created &&
      date_revoked == o.date_revoked &&
      type == o.type &&
      frequency == o.frequency &&
      encoded_html == o.encoded_html &&
      encoded_html_popup == o.encoded_html_popup &&
      url == o.url &&
      transaction_id == o.transaction_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 257

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 323

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 236

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 223

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



229
230
231
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 229

def hash
  [id, date_signed, date_created, date_revoked, type, frequency, encoded_html, encoded_html_popup, url, transaction_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 145

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



303
304
305
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 303

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
312
313
314
315
316
317
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 309

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



297
298
299
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 297

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
# File 'lib/cybersource_rest_client/models/pts_v2_modify_billing_agreement_post201_response_agreement_information.rb', line 152

def valid?
  true
end