Class: CyberSource::PtsV2PaymentsPost201ResponseConsumerAuthenticationInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PtsV2PaymentsPost201ResponseConsumerAuthenticationInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 334

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'accessToken')
    self.access_token = attributes[:'accessToken']
  end

  if attributes.has_key?(:'acsRenderingType')
    self.acs_rendering_type = attributes[:'acsRenderingType']
  end

  if attributes.has_key?(:'acsTransactionId')
    self.acs_transaction_id = attributes[:'acsTransactionId']
  end

  if attributes.has_key?(:'acsUrl')
    self.acs_url = attributes[:'acsUrl']
  end

  if attributes.has_key?(:'authenticationPath')
    self.authentication_path = attributes[:'authenticationPath']
  end

  if attributes.has_key?(:'authorizationPayload')
    self.authorization_payload = attributes[:'authorizationPayload']
  end

  if attributes.has_key?(:'authenticationTransactionId')
    self.authentication_transaction_id = attributes[:'authenticationTransactionId']
  end

  if attributes.has_key?(:'cardholderMessage')
    self.cardholder_message = attributes[:'cardholderMessage']
  end

  if attributes.has_key?(:'cavv')
    self.cavv = attributes[:'cavv']
  end

  if attributes.has_key?(:'cavvAlgorithm')
    self.cavv_algorithm = attributes[:'cavvAlgorithm']
  end

  if attributes.has_key?(:'challengeCancelCode')
    self.challenge_cancel_code = attributes[:'challengeCancelCode']
  end

  if attributes.has_key?(:'challengeRequired')
    self.challenge_required = attributes[:'challengeRequired']
  end

  if attributes.has_key?(:'decoupledAuthenticationIndicator')
    self.decoupled_authentication_indicator = attributes[:'decoupledAuthenticationIndicator']
  end

  if attributes.has_key?(:'directoryServerErrorCode')
    self.directory_server_error_code = attributes[:'directoryServerErrorCode']
  end

  if attributes.has_key?(:'directoryServerErrorDescription')
    self.directory_server_error_description = attributes[:'directoryServerErrorDescription']
  end

  if attributes.has_key?(:'ecommerceIndicator')
    self.ecommerce_indicator = attributes[:'ecommerceIndicator']
  end

  if attributes.has_key?(:'eci')
    self.eci = attributes[:'eci']
  end

  if attributes.has_key?(:'eciRaw')
    self.eci_raw = attributes[:'eciRaw']
  end

  if attributes.has_key?(:'effectiveAuthenticationType')
    self.effective_authentication_type = attributes[:'effectiveAuthenticationType']
  end

  if attributes.has_key?(:'ivr')
    self.ivr = attributes[:'ivr']
  end

  if attributes.has_key?(:'strongAuthentication')
    self.strong_authentication = attributes[:'strongAuthentication']
  end

  if attributes.has_key?(:'networkScore')
    self.network_score = attributes[:'networkScore']
  end

  if attributes.has_key?(:'pareq')
    self.pareq = attributes[:'pareq']
  end

  if attributes.has_key?(:'paresStatus')
    self.pares_status = attributes[:'paresStatus']
  end

  if attributes.has_key?(:'proofXml')
    self.proof_xml = attributes[:'proofXml']
  end

  if attributes.has_key?(:'proxyPan')
    self.proxy_pan = attributes[:'proxyPan']
  end

  if attributes.has_key?(:'sdkTransactionId')
    self.sdk_transaction_id = attributes[:'sdkTransactionId']
  end

  if attributes.has_key?(:'signedParesStatusReason')
    self.signed_pares_status_reason = attributes[:'signedParesStatusReason']
  end

  if attributes.has_key?(:'specificationVersion')
    self.specification_version = attributes[:'specificationVersion']
  end

  if attributes.has_key?(:'stepUpUrl')
    self.step_up_url = attributes[:'stepUpUrl']
  end

  if attributes.has_key?(:'threeDSServerTransactionId')
    self.three_ds_server_transaction_id = attributes[:'threeDSServerTransactionId']
  end

  if attributes.has_key?(:'ucafAuthenticationData')
    self.ucaf_authentication_data = attributes[:'ucafAuthenticationData']
  end

  if attributes.has_key?(:'ucafCollectionIndicator')
    self.ucaf_collection_indicator = attributes[:'ucafCollectionIndicator']
  end

  if attributes.has_key?(:'veresEnrolled')
    self.veres_enrolled = attributes[:'veresEnrolled']
  end

  if attributes.has_key?(:'whiteListStatusSource')
    self.white_list_status_source = attributes[:'whiteListStatusSource']
  end

  if attributes.has_key?(:'xid')
    self.xid = attributes[:'xid']
  end

  if attributes.has_key?(:'directoryServerTransactionId')
    self.directory_server_transaction_id = attributes[:'directoryServerTransactionId']
  end

  if attributes.has_key?(:'dataQualityIndicator')
    self.data_quality_indicator = attributes[:'dataQualityIndicator']
  end

  if attributes.has_key?(:'authenticationResult')
    self.authentication_result = attributes[:'authenticationResult']
  end

  if attributes.has_key?(:'authenticationStatusMsg')
    self.authentication_status_msg = attributes[:'authenticationStatusMsg']
  end

  if attributes.has_key?(:'indicator')
    self.indicator = attributes[:'indicator']
  end

  if attributes.has_key?(:'interactionCounter')
    self.interaction_counter = attributes[:'interactionCounter']
  end

  if attributes.has_key?(:'whiteListStatus')
    self.white_list_status = attributes[:'whiteListStatus']
  end

  if attributes.has_key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.has_key?(:'acsReferenceNumber')
    self.acs_reference_number = attributes[:'acsReferenceNumber']
  end

  if attributes.has_key?(:'acsOperatorID')
    self.acs_operator_id = attributes[:'acsOperatorID']
  end

  if attributes.has_key?(:'idciScore')
    self.idci_score = attributes[:'idciScore']
  end

  if attributes.has_key?(:'idciDecision')
    self.idci_decision = attributes[:'idciDecision']
  end

  if attributes.has_key?(:'idciReasonCode1')
    self.idci_reason_code1 = attributes[:'idciReasonCode1']
  end

  if attributes.has_key?(:'idciReasonCode2')
    self.idci_reason_code2 = attributes[:'idciReasonCode2']
  end
end

Instance Attribute Details

#access_tokenObject

JSON Web Token (JWT) used to authenticate the consumer with the authentication provider, such as, CardinalCommerce or Rupay. Note - Max Length of this field is 2048 characters.



17
18
19
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 17

def access_token
  @access_token
end

#acs_operator_idObject

Directory Server assigned ACS identifier.



150
151
152
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 150

def acs_operator_id
  @acs_operator_id
end

#acs_reference_numberObject

Unique identifier assigned by the EMVCo Secretariat upon Testing and Approval.



147
148
149
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 147

def acs_reference_number
  @acs_reference_number
end

#acs_rendering_typeObject

Identifies the UI Type the ACS will use to complete the challenge. NOTE: Only available for App transactions using the Cardinal Mobile SDK.



20
21
22
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 20

def acs_rendering_type
  @acs_rendering_type
end

#acs_transaction_idObject

Unique transaction identifier assigned by the ACS to identify a single transaction.



23
24
25
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 23

def acs_transaction_id
  @acs_transaction_id
end

#acs_urlObject

URL for the card-issuing bank’s authentication form that you receive when the card is enrolled. The value can be very large.



26
27
28
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 26

def acs_url
  @acs_url
end

#authentication_pathObject

Indicates what displays to the customer during the authentication process. This field can contain one of these values: - ‘ADS`: (Card not enrolled) customer prompted to activate the card during the checkout process. - `ATTEMPTS`: (Attempts processing) Processing briefly displays before the checkout process is completed. - `ENROLLED`: (Card enrolled) the card issuer’s authentication window displays. - ‘UNKNOWN`: Card enrollment status cannot be determined. - `NOREDIRECT`: (Card not enrolled, authentication unavailable, or error occurred) nothing displays to the customer. The following values can be returned if you are using rules-based payer authentication. - `RIBA`: The card-issuing bank supports risk-based authentication, but whether the cardholder is likely to be challenged cannot be determined. - `RIBA_PASS`: The card-issuing bank supports risk-based authentication and it is likely that the cardholder will not be challenged to provide credentials, also known as _silent authentication_.



29
30
31
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 29

def authentication_path
  @authentication_path
end

#authentication_resultObject

Raw authentication data that comes from the cardissuing bank. Primary authentication field that indicates if authentication was successful and if liability shift occurred. You should examine first the result of this field. This field contains one of these values: - ‘-1`: Invalid PARes. - `0`: Successful validation. - `1`: Cardholder is not participating, but the attempt to authenticate was recorded. - `6`: Issuer unable to perform authentication. - `9`: Cardholder did not complete authentication.



129
130
131
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 129

def authentication_result
  @authentication_result
end

#authentication_status_msgObject

Message that explains the authenticationResult reply field.



132
133
134
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 132

def authentication_status_msg
  @authentication_status_msg
end

#authentication_transaction_idObject

Payer authentication transaction identifier is used to link the check enrollment and validate authentication messages. For Rupay, this field should be passed as request only for Resend OTP use case.



35
36
37
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 35

def authentication_transaction_id
  @authentication_transaction_id
end

#authorization_payloadObject

The Base64 encoded JSON Payload of CB specific Authorization Values returned in the challenge Flow



32
33
34
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 32

def authorization_payload
  @authorization_payload
end

#cardholder_messageObject

Text provided by the ACS/Issuer to Cardholder during a Frictionless or Decoupled transaction.The Issuer can provide information to Cardholder. For example, "Additional authentication is needed for this transaction, please contact (Issuer Name) at xxx-xxx-xxxx.". The Issuing Bank can optionally support this value.



38
39
40
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 38

def cardholder_message
  @cardholder_message
end

#cavvObject

Unique identifier generated by the card-issuing bank for Visa, American Express, JCB, Diners Club, and Discover transactions after the customer is authenticated. The value is in base64. When you request the card authorization service, CyberSource automatically converts the value, not the field name, to the format required by your payment processor.



41
42
43
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 41

def cavv
  @cavv
end

#cavv_algorithmObject

Field that is returned only when the CAVV is generated, which occurs when paresStatus contains the values Y (successful authentication) or A (attempted authentication). If you use the ATOS processor, send the value of this field in the ‘cavv_algorithm` request field of the authorization service. This field contains one of these values: - `2`: Visa, American Express, JCB, Diners Club, and Discover - `3`: Mastercard



44
45
46
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 44

def cavv_algorithm
  @cavv_algorithm
end

#challenge_cancel_codeObject

An indicator as to why the transaction was canceled. Possible Values: - ‘01`: Cardholder selected Cancel. - `02`: Reserved for future EMVCo use (values invalid until defined by EMVCo). - `03`: Transaction Timed Out—Decoupled Authentication - `04`: Transaction timed out at ACS—other timeouts - `05`: Transaction Timed out at ACS - First CReq not received by ACS - `06`: Transaction Error - `07`: Unknown - `08`: Transaction Timed Out at SDK



47
48
49
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 47

def challenge_cancel_code
  @challenge_cancel_code
end

#challenge_requiredObject

Indicates whether a challenge is required in order to complete authentication. Note Regional mandates might determine that a challenge is required. Possible values: - ‘Y`: Challenge required - `N`: Challenge not required Note Used by the Hybrid integration.



50
51
52
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 50

def challenge_required
  @challenge_required
end

#data_quality_indicatorObject

The field is used to indicate that a transaction does not meet the Visa Secure authentication data quality requirements.



126
127
128
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 126

def data_quality_indicator
  @data_quality_indicator
end

#decoupled_authentication_indicatorObject

Indicates whether the 3DS Requestor requests the ACS to utilize Decoupled Authentication and agrees to utilize Decoupled Authentication if the ACS confirms its use. Possible Values: Y - Decoupled Authentication is supported and preferred if challenge is necessary N - Do not use Decoupled Authentication **Default Value**: N



53
54
55
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 53

def decoupled_authentication_indicator
  @decoupled_authentication_indicator
end

#directory_server_error_codeObject

The directory server error code indicating a problem with this transaction. Note - Max Length of this field is typically 3 characters.



56
57
58
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 56

def directory_server_error_code
  @directory_server_error_code
end

#directory_server_error_descriptionObject

Directory server text and additional detail about the error for this transaction.



59
60
61
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 59

def directory_server_error_description
  @directory_server_error_description
end

#directory_server_transaction_idObject

The Directory Server Transaction ID is generated by the Mastercard Directory Server during the authentication transaction and passed back to the merchant with the authentication results. For Cybersource Through Visanet Gateway: The value for this field corresponds to the following data in the TC 33 capture file3: Record: CP01 TCR7, Position: 114-149, Field: MC AVV Verification—Directory Server Transaction ID



123
124
125
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 123

def directory_server_transaction_id
  @directory_server_transaction_id
end

#eciObject

Note This field applies only to non-U.S-issued cards. For enroll, Numeric electronic commerce indicator (ECI) returned only for Visa, American Express, JCB, Diners Club, and Discover transactions when the card is not enrolled. For more information, see "Interpreting the Reply," page 22. If you are not using the CyberSource payment services, you must send this value to your payment processor in the subsequent request for card authorization. This field contains one of these values: - ‘06`: The card can be enrolled. Liability shift. - `07`: The card cannot be enrolled. No liability shift. For validate, Numeric electronic commerce indicator (ECI) returned only for Visa, American Express, JCB, Diners Club, and Discover transactions. The field is absent when authentication fails. You must send this value to your payment processor in the subsequent request for card authorization. This field contains one of these values: - `05`: Successful authentication - `06`: Authentication attempted - `07`: Failed authentication (No response from the merchant because of a problem.)



65
66
67
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 65

def eci
  @eci
end

#eci_rawObject

ECI value that can be returned for Visa, Mastercard, American Express, JCB, Diners Club, and Discover. The field is absent when authentication fails. If your payment processor is Streamline, you must pass the value of this field instead of the value of ‘eci` or `ucafCollectionIndicator`. This field can contain one of these values: - `01`: Authentication attempted (Mastercard) - `02`: Successful authentication (Mastercard) - `05`: Successful authentication (Visa, American Express, JCB, Diners Club, and Discover) - `06`: Authentication attempted (Visa, American Express, JCB, Diners Club, and Discover)



68
69
70
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 68

def eci_raw
  @eci_raw
end

#ecommerce_indicatorObject

Commerce indicator for cards not enrolled. This field contains one of these values: - ‘internet`: Card not enrolled, or card type not supported by payer authentication. No liability shift. - `js_attempted`: Card not enrolled, but attempt to authenticate is recorded. Liability shift. - `js_failure`: J/Secure directory service is not available. No liability shift. - `spa`: Mastercard card not enrolled in the SecureCode program. No liability shift. - `vbv_attempted`: Card not enrolled, but attempt to authenticate is recorded. Liability shift. - `vbv_failure`: For payment processor Barclays, Streamline, AIBMS, or FDC Germany, you receive this result if Visa’s directory service is not available. No liability shift.



62
63
64
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 62

def ecommerce_indicator
  @ecommerce_indicator
end

#effective_authentication_typeObject

This field describes the type of 3DS transaction flow that took place. It can be one of three possible flows; CH - Challenge FR - Frictionless FD - Frictionless with delegation, (challenge not generated by the issuer but by the scheme on behalf of the issuer).



71
72
73
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 71

def effective_authentication_type
  @effective_authentication_type
end

#idci_decisionObject

Decision on the Risk Assessment from Mastercard.



156
157
158
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 156

def idci_decision
  @idci_decision
end

#idci_reason_code1Object

ReasonCode from Mastercard



159
160
161
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 159

def idci_reason_code1
  @idci_reason_code1
end

#idci_reason_code2Object

ReasonCode from Mastercard



162
163
164
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 162

def idci_reason_code2
  @idci_reason_code2
end

#idci_scoreObject

Risk Assessment from Mastercard



153
154
155
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 153

def idci_score
  @idci_score
end

#indicatorObject

Indicator used to differentiate Internet transactions from other types. The authentication failed if this field is not returned. For Visa, if your payment processor is Streamline, Barclays, AIBMS, or FDC Germany, you receive the value vbv_failure instead of internet when eci is 07. The value of this field is passed automatically to the authorization service if you request the services together. This field contains one of these values: - ‘aesk`: American Express SafeKey authentication verified successfully. - `aesk_attempted`: Card not enrolled in American Express SafeKey, but the attempt to authenticate was recorded. - `dipb`: Discover ProtectBuy authentication verified successfully. - `dipb_attempted`: Card not enrolled in Discover ProtectBuy, but the attempt to authenticate was recorded. - `internet`: Authentication was not verified successfully. - `js`: J/Secure authentication verified successfully. - `js_attempted`: Card not enrolled in J/Secure, but the attempt to authenticate was recorded. - `moto`: Mail or telephone order. - `pb_attempted`: Card not enrolled in Diners Club ProtectBuy, but the attempt to authenticate was recorded. - `recurring`: Recurring transaction. - `spa`: Mastercard Identity Check authentication verified successfully. - `spa_failure`: Mastercard Identity Check failed authentication. - `vbv`: Visa Secure authentication verified successfully. - `vbv_attempted`: Card not enrolled in Visa Secure, but the attempt to authenticate was recorded. - `vbv_failure`: Visa Secure authentication unavailable.



135
136
137
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 135

def indicator
  @indicator
end

#interaction_counterObject

Indicates the number of authentication cycles attempted by the cardholder and is tracked by the Issuing Banks ACS.Example: if customer gets the challenge window and enter in their one time password and hit submit then that interaction counter should just be 1. When customer gets the challenge window and the bank asks if they want to have the one time password sent to their phone or their email and they have to choose before going to the next screen to enter in their one time password then this interaction count would be 2. One for the selection of how they want the one time password delivered and another with them actually entering in the one time password and hitting the submit button.



138
139
140
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 138

def interaction_counter
  @interaction_counter
end

#ivrObject

Returns the value of attribute ivr.



73
74
75
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 73

def ivr
  @ivr
end

#network_scoreObject

The global score calculated by the CB scoring platform and returned to merchants.



78
79
80
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 78

def network_score
  @network_score
end

#pareqObject

Payer authentication request (PAReq) message that you need to forward to the ACS. The value can be very large. The value is in base64.



81
82
83
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 81

def pareq
  @pareq
end

#pares_statusObject

Raw result of the authentication check. If you are configured for Asia, Middle East, and Africa Gateway Processing, you need to send the value of this field in your authorization request. This field can contain one of these values: - ‘A`: Proof of authentication attempt was generated. - `N`: Customer failed or canceled authentication. Transaction denied. - `U`: Authentication not completed regardless of the reason. - `Y`: Customer was successfully authenticated.



84
85
86
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 84

def pares_status
  @pares_status
end

#proof_xmlObject

Date and time of the enrollment check combined with the VEReq and VERes elements. If you ever need to show proof of enrollment checking, you may need to parse the string for the information required by the payment card company. The value can be very large. For cards issued in the U.S. or Canada, Visa may require this data for specific merchant category codes.For cards not issued in the U.S. or Canada, your bank may require this data as proof of enrollment checking for any payer authentication transaction that you re-present because of a chargeback.



87
88
89
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 87

def proof_xml
  @proof_xml
end

#proxy_panObject

Encrypted version of the card number used in the payer authentication request message.



90
91
92
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 90

def proxy_pan
  @proxy_pan
end

#sdk_transaction_idObject

SDK unique transaction identifier that is generated on each new transaction.



93
94
95
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 93

def sdk_transaction_id
  @sdk_transaction_id
end

#signed_pares_status_reasonObject

Provides additional information as to why the PAResStatus has a specific value.



96
97
98
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 96

def signed_pares_status_reason
  @signed_pares_status_reason
end

#specification_versionObject

This field contains the 3D Secure version that was used to process the transaction. For example: 2.2.0



99
100
101
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 99

def specification_version
  @specification_version
end

#step_up_urlObject

The fully qualified URL that the merchant uses to post a form to the cardholder in order to complete the Consumer Authentication transaction for the Cardinal Cruise API integration.



102
103
104
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 102

def step_up_url
  @step_up_url
end

#strong_authenticationObject

Returns the value of attribute strong_authentication.



75
76
77
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 75

def strong_authentication
  @strong_authentication
end

#three_ds_server_transaction_idObject

Unique transaction identifier assigned by the 3DS Server to identify a single transaction.



105
106
107
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 105

def three_ds_server_transaction_id
  @three_ds_server_transaction_id
end

#tokenObject

Returns the value of attribute token.



144
145
146
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 144

def token
  @token
end

#ucaf_authentication_dataObject

AAV is a unique identifier generated by the card-issuing bank for Mastercard Identity Check transactions after the customer is authenticated. The value is in base64. Include the data in the card authorization request.



108
109
110
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 108

def ucaf_authentication_data
  @ucaf_authentication_data
end

#ucaf_collection_indicatorObject

For enroll, Returned only for Mastercard transactions. Indicates that authentication is not required because the customer is not enrolled. Add the value of this field to the authorization field ucaf_collection_indicator. This field can contain these values: 0, 1. For validate, Numeric electronic commerce indicator (ECI) returned only for Mastercard Identity Check transactions. The field is absent when authentication fails. You must send this value to your payment processor in the request for card authorization. This field contain one of these values: - ‘0`: Authentication data not collected, and customer authentication was not completed. - `1`: Authentication data not collected because customer authentication was not completed. - `2`: Authentication data collected because customer completed authentication.



111
112
113
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 111

def ucaf_collection_indicator
  @ucaf_collection_indicator
end

#veres_enrolledObject

Result of the enrollment check. This field can contain one of these values: - ‘Y`: Card enrolled or can be enrolled; you must authenticate. Liability shift. - `N`: Card not enrolled; proceed with authorization. Liability shift. - `U`: Unable to authenticate regardless of the reason. No liability shift. Note This field only applies to the Asia, Middle East, and Africa Gateway. If you are configured for this processor, you must send the value of this field in your authorization request. The following value can be returned if you are using rules-based Payer Authentication: - `B`: Indicates that authentication was bypassed.



114
115
116
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 114

def veres_enrolled
  @veres_enrolled
end

#white_list_statusObject

Enables the communication of trusted beneficiary/whitelist status between the ACS, the DS and the 3DS Requestor. Possible Values: Y - 3DS Requestor is whitelisted by cardholder N - 3DS Requestor is not whitelisted by cardholder



141
142
143
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 141

def white_list_status
  @white_list_status
end

#white_list_status_sourceObject

This data element will be populated by the system setting Whitelist Status. Possible Values: 01 - 3DS/ Server/ 02 – DS/03 - ACS



117
118
119
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 117

def white_list_status_source
  @white_list_status_source
end

#xidObject

Transaction identifier generated by CyberSource for successful enrollment or validation checks. Use this value, which is in base64, to match an outgoing PAReq with an incoming PARes. CyberSource forwards the XID with the card authorization service to these payment processors in these cases: - Barclays - Streamline (when the ecommerceIndicator`=spa`)



120
121
122
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 120

def xid
  @xid
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 165

def self.attribute_map
  {
    :'access_token' => :'accessToken',
    :'acs_rendering_type' => :'acsRenderingType',
    :'acs_transaction_id' => :'acsTransactionId',
    :'acs_url' => :'acsUrl',
    :'authentication_path' => :'authenticationPath',
    :'authorization_payload' => :'authorizationPayload',
    :'authentication_transaction_id' => :'authenticationTransactionId',
    :'cardholder_message' => :'cardholderMessage',
    :'cavv' => :'cavv',
    :'cavv_algorithm' => :'cavvAlgorithm',
    :'challenge_cancel_code' => :'challengeCancelCode',
    :'challenge_required' => :'challengeRequired',
    :'decoupled_authentication_indicator' => :'decoupledAuthenticationIndicator',
    :'directory_server_error_code' => :'directoryServerErrorCode',
    :'directory_server_error_description' => :'directoryServerErrorDescription',
    :'ecommerce_indicator' => :'ecommerceIndicator',
    :'eci' => :'eci',
    :'eci_raw' => :'eciRaw',
    :'effective_authentication_type' => :'effectiveAuthenticationType',
    :'ivr' => :'ivr',
    :'strong_authentication' => :'strongAuthentication',
    :'network_score' => :'networkScore',
    :'pareq' => :'pareq',
    :'pares_status' => :'paresStatus',
    :'proof_xml' => :'proofXml',
    :'proxy_pan' => :'proxyPan',
    :'sdk_transaction_id' => :'sdkTransactionId',
    :'signed_pares_status_reason' => :'signedParesStatusReason',
    :'specification_version' => :'specificationVersion',
    :'step_up_url' => :'stepUpUrl',
    :'three_ds_server_transaction_id' => :'threeDSServerTransactionId',
    :'ucaf_authentication_data' => :'ucafAuthenticationData',
    :'ucaf_collection_indicator' => :'ucafCollectionIndicator',
    :'veres_enrolled' => :'veresEnrolled',
    :'white_list_status_source' => :'whiteListStatusSource',
    :'xid' => :'xid',
    :'directory_server_transaction_id' => :'directoryServerTransactionId',
    :'data_quality_indicator' => :'dataQualityIndicator',
    :'authentication_result' => :'authenticationResult',
    :'authentication_status_msg' => :'authenticationStatusMsg',
    :'indicator' => :'indicator',
    :'interaction_counter' => :'interactionCounter',
    :'white_list_status' => :'whiteListStatus',
    :'token' => :'token',
    :'acs_reference_number' => :'acsReferenceNumber',
    :'acs_operator_id' => :'acsOperatorID',
    :'idci_score' => :'idciScore',
    :'idci_decision' => :'idciDecision',
    :'idci_reason_code1' => :'idciReasonCode1',
    :'idci_reason_code2' => :'idciReasonCode2'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 221

def self.json_map
  {
    :'access_token' => :'access_token',
    :'acs_rendering_type' => :'acs_rendering_type',
    :'acs_transaction_id' => :'acs_transaction_id',
    :'acs_url' => :'acs_url',
    :'authentication_path' => :'authentication_path',
    :'authorization_payload' => :'authorization_payload',
    :'authentication_transaction_id' => :'authentication_transaction_id',
    :'cardholder_message' => :'cardholder_message',
    :'cavv' => :'cavv',
    :'cavv_algorithm' => :'cavv_algorithm',
    :'challenge_cancel_code' => :'challenge_cancel_code',
    :'challenge_required' => :'challenge_required',
    :'decoupled_authentication_indicator' => :'decoupled_authentication_indicator',
    :'directory_server_error_code' => :'directory_server_error_code',
    :'directory_server_error_description' => :'directory_server_error_description',
    :'ecommerce_indicator' => :'ecommerce_indicator',
    :'eci' => :'eci',
    :'eci_raw' => :'eci_raw',
    :'effective_authentication_type' => :'effective_authentication_type',
    :'ivr' => :'ivr',
    :'strong_authentication' => :'strong_authentication',
    :'network_score' => :'network_score',
    :'pareq' => :'pareq',
    :'pares_status' => :'pares_status',
    :'proof_xml' => :'proof_xml',
    :'proxy_pan' => :'proxy_pan',
    :'sdk_transaction_id' => :'sdk_transaction_id',
    :'signed_pares_status_reason' => :'signed_pares_status_reason',
    :'specification_version' => :'specification_version',
    :'step_up_url' => :'step_up_url',
    :'three_ds_server_transaction_id' => :'three_ds_server_transaction_id',
    :'ucaf_authentication_data' => :'ucaf_authentication_data',
    :'ucaf_collection_indicator' => :'ucaf_collection_indicator',
    :'veres_enrolled' => :'veres_enrolled',
    :'white_list_status_source' => :'white_list_status_source',
    :'xid' => :'xid',
    :'directory_server_transaction_id' => :'directory_server_transaction_id',
    :'data_quality_indicator' => :'data_quality_indicator',
    :'authentication_result' => :'authentication_result',
    :'authentication_status_msg' => :'authentication_status_msg',
    :'indicator' => :'indicator',
    :'interaction_counter' => :'interaction_counter',
    :'white_list_status' => :'white_list_status',
    :'token' => :'token',
    :'acs_reference_number' => :'acs_reference_number',
    :'acs_operator_id' => :'acs_operator_id',
    :'idci_score' => :'idci_score',
    :'idci_decision' => :'idci_decision',
    :'idci_reason_code1' => :'idci_reason_code1',
    :'idci_reason_code2' => :'idci_reason_code2'
  }
end

.swagger_typesObject

Attribute type mapping.



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 277

def self.swagger_types
  {
    :'access_token' => :'String',
    :'acs_rendering_type' => :'String',
    :'acs_transaction_id' => :'String',
    :'acs_url' => :'String',
    :'authentication_path' => :'String',
    :'authorization_payload' => :'String',
    :'authentication_transaction_id' => :'String',
    :'cardholder_message' => :'String',
    :'cavv' => :'String',
    :'cavv_algorithm' => :'String',
    :'challenge_cancel_code' => :'String',
    :'challenge_required' => :'String',
    :'decoupled_authentication_indicator' => :'String',
    :'directory_server_error_code' => :'String',
    :'directory_server_error_description' => :'String',
    :'ecommerce_indicator' => :'String',
    :'eci' => :'String',
    :'eci_raw' => :'String',
    :'effective_authentication_type' => :'String',
    :'ivr' => :'PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr',
    :'strong_authentication' => :'PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationStrongAuthentication',
    :'network_score' => :'String',
    :'pareq' => :'String',
    :'pares_status' => :'String',
    :'proof_xml' => :'String',
    :'proxy_pan' => :'String',
    :'sdk_transaction_id' => :'String',
    :'signed_pares_status_reason' => :'String',
    :'specification_version' => :'String',
    :'step_up_url' => :'String',
    :'three_ds_server_transaction_id' => :'String',
    :'ucaf_authentication_data' => :'String',
    :'ucaf_collection_indicator' => :'String',
    :'veres_enrolled' => :'String',
    :'white_list_status_source' => :'String',
    :'xid' => :'String',
    :'directory_server_transaction_id' => :'String',
    :'data_quality_indicator' => :'String',
    :'authentication_result' => :'String',
    :'authentication_status_msg' => :'String',
    :'indicator' => :'String',
    :'interaction_counter' => :'String',
    :'white_list_status' => :'String',
    :'token' => :'String',
    :'acs_reference_number' => :'String',
    :'acs_operator_id' => :'String',
    :'idci_score' => :'Integer',
    :'idci_decision' => :'String',
    :'idci_reason_code1' => :'String',
    :'idci_reason_code2' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 712

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_token == o.access_token &&
      acs_rendering_type == o.acs_rendering_type &&
      acs_transaction_id == o.acs_transaction_id &&
      acs_url == o.acs_url &&
      authentication_path == o.authentication_path &&
      authorization_payload == o.authorization_payload &&
      authentication_transaction_id == o.authentication_transaction_id &&
      cardholder_message == o.cardholder_message &&
      cavv == o.cavv &&
      cavv_algorithm == o.cavv_algorithm &&
      challenge_cancel_code == o.challenge_cancel_code &&
      challenge_required == o.challenge_required &&
      decoupled_authentication_indicator == o.decoupled_authentication_indicator &&
      directory_server_error_code == o.directory_server_error_code &&
      directory_server_error_description == o.directory_server_error_description &&
      ecommerce_indicator == o.ecommerce_indicator &&
      eci == o.eci &&
      eci_raw == o.eci_raw &&
      effective_authentication_type == o.effective_authentication_type &&
      ivr == o.ivr &&
      strong_authentication == o.strong_authentication &&
      network_score == o.network_score &&
      pareq == o.pareq &&
      pares_status == o.pares_status &&
      proof_xml == o.proof_xml &&
      proxy_pan == o.proxy_pan &&
      sdk_transaction_id == o.sdk_transaction_id &&
      signed_pares_status_reason == o.signed_pares_status_reason &&
      specification_version == o.specification_version &&
      step_up_url == o.step_up_url &&
      three_ds_server_transaction_id == o.three_ds_server_transaction_id &&
      ucaf_authentication_data == o.ucaf_authentication_data &&
      ucaf_collection_indicator == o.ucaf_collection_indicator &&
      veres_enrolled == o.veres_enrolled &&
      white_list_status_source == o.white_list_status_source &&
      xid == o.xid &&
      directory_server_transaction_id == o.directory_server_transaction_id &&
      data_quality_indicator == o.data_quality_indicator &&
      authentication_result == o.authentication_result &&
      authentication_status_msg == o.authentication_status_msg &&
      indicator == o.indicator &&
      interaction_counter == o.interaction_counter &&
      white_list_status == o.white_list_status &&
      token == o.token &&
      acs_reference_number == o.acs_reference_number &&
      acs_operator_id == o.acs_operator_id &&
      idci_score == o.idci_score &&
      idci_decision == o.idci_decision &&
      idci_reason_code1 == o.idci_reason_code1 &&
      idci_reason_code2 == o.idci_reason_code2
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 803

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



869
870
871
872
873
874
875
876
877
878
879
880
881
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 869

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 782

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


769
770
771
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 769

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



775
776
777
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 775

def hash
  [access_token, acs_rendering_type, acs_transaction_id, acs_url, authentication_path, authorization_payload, authentication_transaction_id, cardholder_message, cavv, cavv_algorithm, challenge_cancel_code, challenge_required, decoupled_authentication_indicator, directory_server_error_code, directory_server_error_description, ecommerce_indicator, eci, eci_raw, effective_authentication_type, ivr, strong_authentication, network_score, pareq, pares_status, proof_xml, proxy_pan, sdk_transaction_id, signed_pares_status_reason, specification_version, step_up_url, three_ds_server_transaction_id, ucaf_authentication_data, ucaf_collection_indicator, veres_enrolled, white_list_status_source, xid, directory_server_transaction_id, data_quality_indicator, authentication_result, authentication_status_msg, indicator, interaction_counter, white_list_status, token, acs_reference_number, acs_operator_id, idci_score, idci_decision, idci_reason_code1, idci_reason_code2].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



543
544
545
546
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 543

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



849
850
851
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 849

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



855
856
857
858
859
860
861
862
863
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 855

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



843
844
845
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 843

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



550
551
552
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_consumer_authentication_information.rb', line 550

def valid?
  true
end