Class: CyberSource::PtsV2PaymentsPost201ResponseOrderInformationAmountDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PtsV2PaymentsPost201ResponseOrderInformationAmountDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 114

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'totalAmount')
    self.total_amount = attributes[:'totalAmount']
  end

  if attributes.has_key?(:'authorizedAmount')
    self.authorized_amount = attributes[:'authorizedAmount']
  end

  if attributes.has_key?(:'cashbackAmount')
    self.cashback_amount = attributes[:'cashbackAmount']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'settlementAmount')
    self.settlement_amount = attributes[:'settlementAmount']
  end

  if attributes.has_key?(:'settlementCurrency')
    self.settlement_currency = attributes[:'settlementCurrency']
  end

  if attributes.has_key?(:'originalAmount')
    self.original_amount = attributes[:'originalAmount']
  end

  if attributes.has_key?(:'originalCurrency')
    self.original_currency = attributes[:'originalCurrency']
  end

  if attributes.has_key?(:'processorTransactionFee')
    self.processor_transaction_fee = attributes[:'processorTransactionFee']
  end

  if attributes.has_key?(:'exchangeRate')
    self.exchange_rate = attributes[:'exchangeRate']
  end

  if attributes.has_key?(:'foreignCurrency')
    self.foreign_currency = attributes[:'foreignCurrency']
  end

  if attributes.has_key?(:'foreignAmount')
    self.foreign_amount = attributes[:'foreignAmount']
  end

  if attributes.has_key?(:'discountAmount')
    self.discount_amount = attributes[:'discountAmount']
  end
end

Instance Attribute Details

#authorized_amountObject

Amount that was authorized. Returned by authorization service. #### PIN debit Amount of the purchase. Returned by PIN debit purchase.



20
21
22
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 20

def authorized_amount
  @authorized_amount
end

#cashback_amountObject

This field contains the purchase cashback amount expressed in the acquirer transaction currency. Use this field only for clearing with your acquirer.



23
24
25
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 23

def cashback_amount
  @cashback_amount
end

#currencyObject

Currency used for the order. Use the three-character [ISO Standard Currency Codes.](apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf) #### Used by Authorization Required field. **Authorization Reversal** For an authorization reversal (reversalInformation) or a capture (processingOptions.capture is set to true), you must use the same currency that you used in your payment authorization request. #### PIN Debit Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf). Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf). Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests. #### GPX This field is optional for reversing an authorization or credit. #### DCC for First Data Your local currency. #### Tax Calculation Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.



26
27
28
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 26

def currency
  @currency
end

#discount_amountObject

If coupons/vouchers are used in the transaction, the discount amount redeemed in the settlement currency will be returned. Otherwise, no return.



53
54
55
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 53

def discount_amount
  @discount_amount
end

#exchange_rateObject

The rate of conversion of the currency given in the request to CNY. The conversion happens at the time when Alipay’s trade order is created



44
45
46
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 44

def exchange_rate
  @exchange_rate
end

#foreign_amountObject

The transaction amount in CNY.



50
51
52
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 50

def foreign_amount
  @foreign_amount
end

#foreign_currencyObject

Currency code for the transaction performed in cross border currency.



47
48
49
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 47

def foreign_currency
  @foreign_currency
end

#original_amountObject

Amount in your original local pricing currency. This value cannot be negative. You can include a decimal point (.) in this field to denote the currency exponent, but you cannot include any other special characters. If needed, CyberSource truncates the amount to the correct number of decimal places.



35
36
37
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 35

def original_amount
  @original_amount
end

#original_currencyObject

Your local pricing currency code. For the possible values, see the [ISO Standard Currency Codes.](apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)



38
39
40
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 38

def original_currency
  @original_currency
end

#processor_transaction_feeObject

Amount up to N digit after the decimals separator as defined in ISO 4217 for the appropriate currency code.



41
42
43
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 41

def processor_transaction_fee
  @processor_transaction_fee
end

#settlement_amountObject

This is a multicurrency field. It contains the transaction amount (field 4), converted to the Currency used to bill the cardholder’s account. This field is returned for OCT transactions.



29
30
31
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 29

def settlement_amount
  @settlement_amount
end

#settlement_currencyObject

This is a multicurrency-only field. It contains a 3-digit numeric code that identifies the currency used by the issuer to bill the cardholder’s account. This field is returned for OCT transactions.



32
33
34
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 32

def settlement_currency
  @settlement_currency
end

#total_amountObject

Amount you requested for the payment or capture. This value is returned for partial authorizations. This field is also returned on incremental authorizations will contain the aggregated amount from the original authorizations and all the incremental authorizations.



17
18
19
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 17

def total_amount
  @total_amount
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 56

def self.attribute_map
  {
    :'total_amount' => :'totalAmount',
    :'authorized_amount' => :'authorizedAmount',
    :'cashback_amount' => :'cashbackAmount',
    :'currency' => :'currency',
    :'settlement_amount' => :'settlementAmount',
    :'settlement_currency' => :'settlementCurrency',
    :'original_amount' => :'originalAmount',
    :'original_currency' => :'originalCurrency',
    :'processor_transaction_fee' => :'processorTransactionFee',
    :'exchange_rate' => :'exchangeRate',
    :'foreign_currency' => :'foreignCurrency',
    :'foreign_amount' => :'foreignAmount',
    :'discount_amount' => :'discountAmount'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 75

def self.json_map
  {
    :'total_amount' => :'total_amount',
    :'authorized_amount' => :'authorized_amount',
    :'cashback_amount' => :'cashback_amount',
    :'currency' => :'currency',
    :'settlement_amount' => :'settlement_amount',
    :'settlement_currency' => :'settlement_currency',
    :'original_amount' => :'original_amount',
    :'original_currency' => :'original_currency',
    :'processor_transaction_fee' => :'processor_transaction_fee',
    :'exchange_rate' => :'exchange_rate',
    :'foreign_currency' => :'foreign_currency',
    :'foreign_amount' => :'foreign_amount',
    :'discount_amount' => :'discount_amount'
  }
end

.swagger_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 94

def self.swagger_types
  {
    :'total_amount' => :'String',
    :'authorized_amount' => :'String',
    :'cashback_amount' => :'String',
    :'currency' => :'String',
    :'settlement_amount' => :'String',
    :'settlement_currency' => :'String',
    :'original_amount' => :'String',
    :'original_currency' => :'String',
    :'processor_transaction_fee' => :'String',
    :'exchange_rate' => :'String',
    :'foreign_currency' => :'String',
    :'foreign_amount' => :'String',
    :'discount_amount' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 266

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      total_amount == o.total_amount &&
      authorized_amount == o.authorized_amount &&
      cashback_amount == o.cashback_amount &&
      currency == o.currency &&
      settlement_amount == o.settlement_amount &&
      settlement_currency == o.settlement_currency &&
      original_amount == o.original_amount &&
      original_currency == o.original_currency &&
      processor_transaction_fee == o.processor_transaction_fee &&
      exchange_rate == o.exchange_rate &&
      foreign_currency == o.foreign_currency &&
      foreign_amount == o.foreign_amount &&
      discount_amount == o.discount_amount
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 320

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 386

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 299

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 286

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



292
293
294
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 292

def hash
  [total_amount, authorized_amount, cashback_amount, currency, settlement_amount, settlement_currency, original_amount, original_currency, processor_transaction_fee, exchange_rate, foreign_currency, foreign_amount, discount_amount].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 175

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 366

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



372
373
374
375
376
377
378
379
380
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 372

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



360
361
362
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 360

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
# File 'lib/cybersource_rest_client/models/pts_v2_payments_post201_response_order_information_amount_details.rb', line 182

def valid?
  true
end