Class: CyberSource::PtsV2PayoutsPost201ResponseIssuerInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PtsV2PayoutsPost201ResponseIssuerInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 132

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'octDomesticParticipantIndicator')
    self.oct_domestic_participant_indicator = attributes[:'octDomesticParticipantIndicator']
  end

  if attributes.has_key?(:'octCrossBorderParticipantIndicator')
    self.oct_cross_border_participant_indicator = attributes[:'octCrossBorderParticipantIndicator']
  end

  if attributes.has_key?(:'octMoneyTransferDomesticIndicator')
    self.oct_money_transfer_domestic_indicator = attributes[:'octMoneyTransferDomesticIndicator']
  end

  if attributes.has_key?(:'octMoneyTransferCrossBorderIndicator')
    self.oct_money_transfer_cross_border_indicator = attributes[:'octMoneyTransferCrossBorderIndicator']
  end

  if attributes.has_key?(:'octMoneyTransferFastFundsDomesticIndicator')
    self.oct_money_transfer_fast_funds_domestic_indicator = attributes[:'octMoneyTransferFastFundsDomesticIndicator']
  end

  if attributes.has_key?(:'octMoneyTransferFastFundsCrossBorderIndicator')
    self.oct_money_transfer_fast_funds_cross_border_indicator = attributes[:'octMoneyTransferFastFundsCrossBorderIndicator']
  end

  if attributes.has_key?(:'octMoneyTransferMerchantCountryRestricted')
    self.oct_money_transfer_merchant_country_restricted = attributes[:'octMoneyTransferMerchantCountryRestricted']
  end

  if attributes.has_key?(:'octNonMoneyTransferDomesticIndicator')
    self.oct_non_money_transfer_domestic_indicator = attributes[:'octNonMoneyTransferDomesticIndicator']
  end

  if attributes.has_key?(:'octNonMoneyTransferCrossBorderIndicator')
    self.oct_non_money_transfer_cross_border_indicator = attributes[:'octNonMoneyTransferCrossBorderIndicator']
  end

  if attributes.has_key?(:'octNonMoneyTransferFastFundsDomesticIndicator')
    self.oct_non_money_transfer_fast_funds_domestic_indicator = attributes[:'octNonMoneyTransferFastFundsDomesticIndicator']
  end

  if attributes.has_key?(:'octNonMoneyTransferFastFundsCrossBorderIndicator')
    self.oct_non_money_transfer_fast_funds_cross_border_indicator = attributes[:'octNonMoneyTransferFastFundsCrossBorderIndicator']
  end

  if attributes.has_key?(:'octOnlineGamblingDomesticIndicator')
    self.oct_online_gambling_domestic_indicator = attributes[:'octOnlineGamblingDomesticIndicator']
  end

  if attributes.has_key?(:'octOnlineGamblingCrossBorderIndicator')
    self.oct_online_gambling_cross_border_indicator = attributes[:'octOnlineGamblingCrossBorderIndicator']
  end

  if attributes.has_key?(:'octOnlineGamblingFastFundsDomesticIndicator')
    self.oct_online_gambling_fast_funds_domestic_indicator = attributes[:'octOnlineGamblingFastFundsDomesticIndicator']
  end

  if attributes.has_key?(:'octOnlineGamblingFastFundsCrossBorderIndicator')
    self.oct_online_gambling_fast_funds_cross_border_indicator = attributes[:'octOnlineGamblingFastFundsCrossBorderIndicator']
  end

  if attributes.has_key?(:'serviceProcessingType')
    self.service_processing_type = attributes[:'serviceProcessingType']
  end
end

Instance Attribute Details

#oct_cross_border_participant_indicatorObject

Cross-border indicator for push funds (OCT). If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



20
21
22
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 20

def oct_cross_border_participant_indicator
  @oct_cross_border_participant_indicator
end

#oct_domestic_participant_indicatorObject

Domestic indicator for Push funds (OCT). If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



17
18
19
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 17

def oct_domestic_participant_indicator
  @oct_domestic_participant_indicator
end

#oct_money_transfer_cross_border_indicatorObject

Indicates whether cross-border money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



26
27
28
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 26

def oct_money_transfer_cross_border_indicator
  @oct_money_transfer_cross_border_indicator
end

#oct_money_transfer_domestic_indicatorObject

Indicates whether domestic money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



23
24
25
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 23

def oct_money_transfer_domestic_indicator
  @oct_money_transfer_domestic_indicator
end

#oct_money_transfer_fast_funds_cross_border_indicatorObject

Indicates whether cross-border money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



32
33
34
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 32

def oct_money_transfer_fast_funds_cross_border_indicator
  @oct_money_transfer_fast_funds_cross_border_indicator
end

#oct_money_transfer_fast_funds_domestic_indicatorObject

Indicates whether domestic money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



29
30
31
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 29

def oct_money_transfer_fast_funds_domestic_indicator
  @oct_money_transfer_fast_funds_domestic_indicator
end

#oct_money_transfer_merchant_country_restrictedObject

This field indicates if the recipient issuer can accept push funds (OCT) transactions from the merchant country. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



35
36
37
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 35

def oct_money_transfer_merchant_country_restricted
  @oct_money_transfer_merchant_country_restricted
end

#oct_non_money_transfer_cross_border_indicatorObject

Indicates whether cross-border non-money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



41
42
43
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 41

def oct_non_money_transfer_cross_border_indicator
  @oct_non_money_transfer_cross_border_indicator
end

#oct_non_money_transfer_domestic_indicatorObject

Indicates whether domestic non-money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



38
39
40
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 38

def oct_non_money_transfer_domestic_indicator
  @oct_non_money_transfer_domestic_indicator
end

#oct_non_money_transfer_fast_funds_cross_border_indicatorObject

Indicates whether cross-border non-money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



47
48
49
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 47

def oct_non_money_transfer_fast_funds_cross_border_indicator
  @oct_non_money_transfer_fast_funds_cross_border_indicator
end

#oct_non_money_transfer_fast_funds_domestic_indicatorObject

Indicates whether domestic non-money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



44
45
46
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 44

def oct_non_money_transfer_fast_funds_domestic_indicator
  @oct_non_money_transfer_fast_funds_domestic_indicator
end

#oct_online_gambling_cross_border_indicatorObject

Indicates whether cross-border gambling OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



53
54
55
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 53

def oct_online_gambling_cross_border_indicator
  @oct_online_gambling_cross_border_indicator
end

#oct_online_gambling_domestic_indicatorObject

Indicates whether domestic gambling OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



50
51
52
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 50

def oct_online_gambling_domestic_indicator
  @oct_online_gambling_domestic_indicator
end

#oct_online_gambling_fast_funds_cross_border_indicatorObject

Indicates whether cross-border gambling OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



59
60
61
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 59

def oct_online_gambling_fast_funds_cross_border_indicator
  @oct_online_gambling_fast_funds_cross_border_indicator
end

#oct_online_gambling_fast_funds_domestic_indicatorObject

Indicates whether domestic gambling OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.



56
57
58
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 56

def oct_online_gambling_fast_funds_domestic_indicator
  @oct_online_gambling_fast_funds_domestic_indicator
end

#service_processing_typeObject

This field contains values that identify the service type under which the transaction should be processed. The valid value for the Visa Alias Directory Service is A0 (Alias) and 00 (normal transaction).



62
63
64
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 62

def service_processing_type
  @service_processing_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 65

def self.attribute_map
  {
    :'oct_domestic_participant_indicator' => :'octDomesticParticipantIndicator',
    :'oct_cross_border_participant_indicator' => :'octCrossBorderParticipantIndicator',
    :'oct_money_transfer_domestic_indicator' => :'octMoneyTransferDomesticIndicator',
    :'oct_money_transfer_cross_border_indicator' => :'octMoneyTransferCrossBorderIndicator',
    :'oct_money_transfer_fast_funds_domestic_indicator' => :'octMoneyTransferFastFundsDomesticIndicator',
    :'oct_money_transfer_fast_funds_cross_border_indicator' => :'octMoneyTransferFastFundsCrossBorderIndicator',
    :'oct_money_transfer_merchant_country_restricted' => :'octMoneyTransferMerchantCountryRestricted',
    :'oct_non_money_transfer_domestic_indicator' => :'octNonMoneyTransferDomesticIndicator',
    :'oct_non_money_transfer_cross_border_indicator' => :'octNonMoneyTransferCrossBorderIndicator',
    :'oct_non_money_transfer_fast_funds_domestic_indicator' => :'octNonMoneyTransferFastFundsDomesticIndicator',
    :'oct_non_money_transfer_fast_funds_cross_border_indicator' => :'octNonMoneyTransferFastFundsCrossBorderIndicator',
    :'oct_online_gambling_domestic_indicator' => :'octOnlineGamblingDomesticIndicator',
    :'oct_online_gambling_cross_border_indicator' => :'octOnlineGamblingCrossBorderIndicator',
    :'oct_online_gambling_fast_funds_domestic_indicator' => :'octOnlineGamblingFastFundsDomesticIndicator',
    :'oct_online_gambling_fast_funds_cross_border_indicator' => :'octOnlineGamblingFastFundsCrossBorderIndicator',
    :'service_processing_type' => :'serviceProcessingType'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 87

def self.json_map
  {
    :'oct_domestic_participant_indicator' => :'oct_domestic_participant_indicator',
    :'oct_cross_border_participant_indicator' => :'oct_cross_border_participant_indicator',
    :'oct_money_transfer_domestic_indicator' => :'oct_money_transfer_domestic_indicator',
    :'oct_money_transfer_cross_border_indicator' => :'oct_money_transfer_cross_border_indicator',
    :'oct_money_transfer_fast_funds_domestic_indicator' => :'oct_money_transfer_fast_funds_domestic_indicator',
    :'oct_money_transfer_fast_funds_cross_border_indicator' => :'oct_money_transfer_fast_funds_cross_border_indicator',
    :'oct_money_transfer_merchant_country_restricted' => :'oct_money_transfer_merchant_country_restricted',
    :'oct_non_money_transfer_domestic_indicator' => :'oct_non_money_transfer_domestic_indicator',
    :'oct_non_money_transfer_cross_border_indicator' => :'oct_non_money_transfer_cross_border_indicator',
    :'oct_non_money_transfer_fast_funds_domestic_indicator' => :'oct_non_money_transfer_fast_funds_domestic_indicator',
    :'oct_non_money_transfer_fast_funds_cross_border_indicator' => :'oct_non_money_transfer_fast_funds_cross_border_indicator',
    :'oct_online_gambling_domestic_indicator' => :'oct_online_gambling_domestic_indicator',
    :'oct_online_gambling_cross_border_indicator' => :'oct_online_gambling_cross_border_indicator',
    :'oct_online_gambling_fast_funds_domestic_indicator' => :'oct_online_gambling_fast_funds_domestic_indicator',
    :'oct_online_gambling_fast_funds_cross_border_indicator' => :'oct_online_gambling_fast_funds_cross_border_indicator',
    :'service_processing_type' => :'service_processing_type'
  }
end

.swagger_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 109

def self.swagger_types
  {
    :'oct_domestic_participant_indicator' => :'BOOLEAN',
    :'oct_cross_border_participant_indicator' => :'BOOLEAN',
    :'oct_money_transfer_domestic_indicator' => :'BOOLEAN',
    :'oct_money_transfer_cross_border_indicator' => :'BOOLEAN',
    :'oct_money_transfer_fast_funds_domestic_indicator' => :'BOOLEAN',
    :'oct_money_transfer_fast_funds_cross_border_indicator' => :'BOOLEAN',
    :'oct_money_transfer_merchant_country_restricted' => :'BOOLEAN',
    :'oct_non_money_transfer_domestic_indicator' => :'BOOLEAN',
    :'oct_non_money_transfer_cross_border_indicator' => :'BOOLEAN',
    :'oct_non_money_transfer_fast_funds_domestic_indicator' => :'BOOLEAN',
    :'oct_non_money_transfer_fast_funds_cross_border_indicator' => :'BOOLEAN',
    :'oct_online_gambling_domestic_indicator' => :'BOOLEAN',
    :'oct_online_gambling_cross_border_indicator' => :'BOOLEAN',
    :'oct_online_gambling_fast_funds_domestic_indicator' => :'BOOLEAN',
    :'oct_online_gambling_fast_funds_cross_border_indicator' => :'BOOLEAN',
    :'service_processing_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      oct_domestic_participant_indicator == o.oct_domestic_participant_indicator &&
      oct_cross_border_participant_indicator == o.oct_cross_border_participant_indicator &&
      oct_money_transfer_domestic_indicator == o.oct_money_transfer_domestic_indicator &&
      oct_money_transfer_cross_border_indicator == o.oct_money_transfer_cross_border_indicator &&
      oct_money_transfer_fast_funds_domestic_indicator == o.oct_money_transfer_fast_funds_domestic_indicator &&
      oct_money_transfer_fast_funds_cross_border_indicator == o.oct_money_transfer_fast_funds_cross_border_indicator &&
      oct_money_transfer_merchant_country_restricted == o.oct_money_transfer_merchant_country_restricted &&
      oct_non_money_transfer_domestic_indicator == o.oct_non_money_transfer_domestic_indicator &&
      oct_non_money_transfer_cross_border_indicator == o.oct_non_money_transfer_cross_border_indicator &&
      oct_non_money_transfer_fast_funds_domestic_indicator == o.oct_non_money_transfer_fast_funds_domestic_indicator &&
      oct_non_money_transfer_fast_funds_cross_border_indicator == o.oct_non_money_transfer_fast_funds_cross_border_indicator &&
      oct_online_gambling_domestic_indicator == o.oct_online_gambling_domestic_indicator &&
      oct_online_gambling_cross_border_indicator == o.oct_online_gambling_cross_border_indicator &&
      oct_online_gambling_fast_funds_domestic_indicator == o.oct_online_gambling_fast_funds_domestic_indicator &&
      oct_online_gambling_fast_funds_cross_border_indicator == o.oct_online_gambling_fast_funds_cross_border_indicator &&
      service_processing_type == o.service_processing_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 281

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 347

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 260

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 247

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



253
254
255
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 253

def hash
  [oct_domestic_participant_indicator, oct_cross_border_participant_indicator, oct_money_transfer_domestic_indicator, oct_money_transfer_cross_border_indicator, oct_money_transfer_fast_funds_domestic_indicator, oct_money_transfer_fast_funds_cross_border_indicator, oct_money_transfer_merchant_country_restricted, oct_non_money_transfer_domestic_indicator, oct_non_money_transfer_cross_border_indicator, oct_non_money_transfer_fast_funds_domestic_indicator, oct_non_money_transfer_fast_funds_cross_border_indicator, oct_online_gambling_domestic_indicator, oct_online_gambling_cross_border_indicator, oct_online_gambling_fast_funds_domestic_indicator, oct_online_gambling_fast_funds_cross_border_indicator, service_processing_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 205

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 327

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



321
322
323
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 321

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_issuer_information.rb', line 212

def valid?
  true
end