Class: CyberSource::PtsV2PayoutsPost201ResponseProcessorInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PtsV2PayoutsPost201ResponseProcessorInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 91

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'approvalCode')
    self.approval_code = attributes[:'approvalCode']
  end

  if attributes.has_key?(:'responseCode')
    self.response_code = attributes[:'responseCode']
  end

  if attributes.has_key?(:'transactionId')
    self.transaction_id = attributes[:'transactionId']
  end

  if attributes.has_key?(:'systemTraceAuditNumber')
    self.system_trace_audit_number = attributes[:'systemTraceAuditNumber']
  end

  if attributes.has_key?(:'responseCodeSource')
    self.response_code_source = attributes[:'responseCodeSource']
  end

  if attributes.has_key?(:'merchantAdvice')
    self.merchant_advice = attributes[:'merchantAdvice']
  end

  if attributes.has_key?(:'avs')
    self.avs = attributes[:'avs']
  end

  if attributes.has_key?(:'customer')
    self.customer = attributes[:'customer']
  end

  if attributes.has_key?(:'electronicVerificationResults')
    self.electronic_verification_results = attributes[:'electronicVerificationResults']
  end

  if attributes.has_key?(:'cardVerification')
    self.card_verification = attributes[:'cardVerification']
  end
end

Instance Attribute Details

#approval_codeObject

Issuer-generated approval code for the transaction.



17
18
19
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 17

def approval_code
  @approval_code
end

#avsObject

Returns the value of attribute avs.



33
34
35
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 33

def avs
  @avs
end

#card_verificationObject

Returns the value of attribute card_verification.



39
40
41
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 39

def card_verification
  @card_verification
end

#customerObject

Returns the value of attribute customer.



35
36
37
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 35

def customer
  @customer
end

#electronic_verification_resultsObject

Returns the value of attribute electronic_verification_results.



37
38
39
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 37

def electronic_verification_results
  @electronic_verification_results
end

#merchant_adviceObject

Returns the value of attribute merchant_advice.



31
32
33
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 31

def merchant_advice
  @merchant_advice
end

#response_codeObject

Transaction status from the processor.



20
21
22
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 20

def response_code
  @response_code
end

#response_code_sourceObject

Used by Visa only and contains the response source/reason code that identifies the source of the response decision.



29
30
31
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 29

def response_code_source
  @response_code_source
end

#system_trace_audit_numberObject

This field is returned only for **American Express Direct** and **CyberSource through VisaNet**. Returned by authorization and incremental authorization services. #### American Express Direct System trace audit number (STAN). This value identifies the transaction and is useful when investigating a chargeback dispute. #### CyberSource through VisaNet System trace number that must be printed on the customer’s receipt.



26
27
28
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 26

def system_trace_audit_number
  @system_trace_audit_number
end

#transaction_idObject

Network transaction identifier (TID). This value can be used to identify a specific transaction when you are discussing the transaction with your processor.



23
24
25
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 23

def transaction_id
  @transaction_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 42

def self.attribute_map
  {
    :'approval_code' => :'approvalCode',
    :'response_code' => :'responseCode',
    :'transaction_id' => :'transactionId',
    :'system_trace_audit_number' => :'systemTraceAuditNumber',
    :'response_code_source' => :'responseCodeSource',
    :'merchant_advice' => :'merchantAdvice',
    :'avs' => :'avs',
    :'customer' => :'customer',
    :'electronic_verification_results' => :'electronicVerificationResults',
    :'card_verification' => :'cardVerification'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 58

def self.json_map
  {
    :'approval_code' => :'approval_code',
    :'response_code' => :'response_code',
    :'transaction_id' => :'transaction_id',
    :'system_trace_audit_number' => :'system_trace_audit_number',
    :'response_code_source' => :'response_code_source',
    :'merchant_advice' => :'merchant_advice',
    :'avs' => :'avs',
    :'customer' => :'customer',
    :'electronic_verification_results' => :'electronic_verification_results',
    :'card_verification' => :'card_verification'
  }
end

.swagger_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 74

def self.swagger_types
  {
    :'approval_code' => :'String',
    :'response_code' => :'String',
    :'transaction_id' => :'String',
    :'system_trace_audit_number' => :'String',
    :'response_code_source' => :'String',
    :'merchant_advice' => :'PtsV2PaymentsRefundPost201ResponseProcessorInformationMerchantAdvice',
    :'avs' => :'PtsV2PayoutsPost201ResponseProcessorInformationAvs',
    :'customer' => :'PtsV2PayoutsPost201ResponseProcessorInformationCustomer',
    :'electronic_verification_results' => :'PtsV2PayoutsPost201ResponseProcessorInformationElectronicVerificationResults',
    :'card_verification' => :'PtsV2PaymentsPost201ResponseProcessorInformationCardVerification'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      approval_code == o.approval_code &&
      response_code == o.response_code &&
      transaction_id == o.transaction_id &&
      system_trace_audit_number == o.system_trace_audit_number &&
      response_code_source == o.response_code_source &&
      merchant_advice == o.merchant_advice &&
      avs == o.avs &&
      customer == o.customer &&
      electronic_verification_results == o.electronic_verification_results &&
      card_verification == o.card_verification
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 234

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 300

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 213

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 200

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



206
207
208
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 206

def hash
  [approval_code, response_code, transaction_id, system_trace_audit_number, response_code_source, merchant_advice, avs, customer, electronic_verification_results, card_verification].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 280

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



274
275
276
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 274

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
# File 'lib/cybersource_rest_client/models/pts_v2_payouts_post201_response_processor_information.rb', line 147

def valid?
  true
end