Class: CyberSource::Ptsv1pullfundstransferSenderInformationPersonalIdentification

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Ptsv1pullfundstransferSenderInformationPersonalIdentification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'issuingCountry')
    self.issuing_country = attributes[:'issuingCountry']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'personalIdType')
    self.personal_id_type = attributes[:'personalIdType']
  end
end

Instance Attribute Details

#idObject

The ID number/value. Visa Direct(35 characters) This tag will contain an acquirer-populated id value associated with the API. If ‘senderInformation.personalIdentification.type`=`BTHD`, then the id format must be `YYYYMMDD`.



20
21
22
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 20

def id
  @id
end

#issuing_countryObject

Issuing country of the identification. The field format should be a 2 character ISO 3166-1 alpha-2 country code.



17
18
19
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 17

def issuing_country
  @issuing_country
end

#personal_id_typeObject

It denotes whether the tax ID is a business or individual tax ID. The valid values are: • ‘B` (Business) • `I` (Individual) Visa Direct This field is required when `senderInformation.personalIdentification.type` has the value of `TXIN` (Tax identification). A value for `senderInformation.personalInformation.id` is required when `senderInformation.personalIdentification.personalIdType` is present in a request.



26
27
28
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 26

def personal_id_type
  @personal_id_type
end

#typeObject

Visa Direct This tag will contain the type of sender identification. The valid values are: • ‘BTHD` (Date of birth) • `CUID` (Customer identification (unspecified)) • `NTID` (National identification) • `PASN` (Passport number) • `DRLN` (Driver license) • `TXIN` (Tax identification) • `CPNY` (Company registration number) • `PRXY` (Proxy identification) • `SSNB` (Social security number) • `ARNB` (Alien registration number) • `LAWE` (Law enforcement identification) • `MILI` (Military identification) • `TRVL` (Travel identification (non-passport)) • `EMAL` (Email) • `PHON` (Phone number)



23
24
25
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 23

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 29

def self.attribute_map
  {
    :'issuing_country' => :'issuingCountry',
    :'id' => :'id',
    :'type' => :'type',
    :'personal_id_type' => :'personalIdType'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



39
40
41
42
43
44
45
46
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 39

def self.json_map
  {
    :'issuing_country' => :'issuing_country',
    :'id' => :'id',
    :'type' => :'type',
    :'personal_id_type' => :'personal_id_type'
  }
end

.swagger_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 49

def self.swagger_types
  {
    :'issuing_country' => :'String',
    :'id' => :'String',
    :'type' => :'String',
    :'personal_id_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



149
150
151
152
153
154
155
156
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 149

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      issuing_country == o.issuing_country &&
      id == o.id &&
      type == o.type &&
      personal_id_type == o.personal_id_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 194

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 260

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 173

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 160

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



166
167
168
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 166

def hash
  [issuing_country, id, type, personal_id_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 85

def list_invalid_properties
  invalid_properties = Array.new
  #if !@issuing_country.nil? && @issuing_country !~ Regexp.new(/^(\\s{0,2}|.{2})$/)
    #invalid_properties.push('invalid value for "issuing_country", must conform to the pattern /^(\\s{0,2}|.{2})$/.')
  #end

  #if !@type.nil? && @type !~ Regexp.new(/^(\\s{0,4}|.{4})$/)
    #invalid_properties.push('invalid value for "type", must conform to the pattern /^(\\s{0,4}|.{4})$/.')
  #end

  #if !@personal_id_type.nil? && @personal_id_type !~ Regexp.new(/^(\\s{0,1}|.{1})$/)
    #invalid_properties.push('invalid value for "personal_id_type", must conform to the pattern /^(\\s{0,1}|.{1})$/.')
  #end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 240

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



234
235
236
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 234

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



104
105
106
107
108
109
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_sender_information_personal_identification.rb', line 104

def valid?
  #return false if !@issuing_country.nil? && @issuing_country !~ Regexp.new(/^(\\s{0,2}|.{2})$/)
  #return false if !@type.nil? && @type !~ Regexp.new(/^(\\s{0,4}|.{4})$/)
  #return false if !@personal_id_type.nil? && @personal_id_type !~ Regexp.new(/^(\\s{0,1}|.{1})$/)
  true
end