Class: CyberSource::Ptsv2paymentsAggregatorInformationSubMerchant

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Ptsv2paymentsAggregatorInformationSubMerchant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'cardAcceptorId')
    self.card_acceptor_id = attributes[:'cardAcceptorId']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'address1')
    self.address1 = attributes[:'address1']
  end

  if attributes.has_key?(:'locality')
    self.locality = attributes[:'locality']
  end

  if attributes.has_key?(:'administrativeArea')
    self.administrative_area = attributes[:'administrativeArea']
  end

  if attributes.has_key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.has_key?(:'postalCode')
    self.postal_code = attributes[:'postalCode']
  end

  if attributes.has_key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.has_key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.has_key?(:'phoneNumber')
    self.phone_number = attributes[:'phoneNumber']
  end

  if attributes.has_key?(:'merchantCategoryCode')
    self.merchant_category_code = attributes[:'merchantCategoryCode']
  end
end

Instance Attribute Details

#address1Object

First line of the sub-merchant’s street address. #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5. #### FDC Compass This value must consist of uppercase characters.



26
27
28
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 26

def address1
  @address1
end

#administrative_areaObject

Sub-merchant’s state or province. #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5. #### FDC Compass This value must consist of uppercase characters.



32
33
34
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 32

def administrative_area
  @administrative_area
end

#card_acceptor_idObject

Unique identifier assigned by the payment card company to the sub-merchant.



17
18
19
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 17

def card_acceptor_id
  @card_acceptor_id
end

#countryObject

Sub-merchant’s country. Use the [ISO Standard Country Codes](developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf). #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file. #### FDC Compass This value must consist of uppercase characters.



41
42
43
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 41

def country
  @country
end

#emailObject

Sub-merchant’s email address. **Maximum length for processors** - American Express Direct: 40 - CyberSource through VisaNet: 40 - FDC Compass: 40 - FDC Nashville Global: 19 #### CyberSource through VisaNet With American Express, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCRB - Position: 25-64 - Field: American Express Seller E-mail Address Note The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies.



44
45
46
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 44

def email
  @email
end

#idObject

The ID you assigned to your sub-merchant. CyberSource through VisaNet: For American Express transaction, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCRB - Position: 65-84 - Field: American Express Seller ID For Mastercard transactions, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR6 - Position: 117-131 - Field: Sub-Merchant ID FDC Compass: This value must consist of uppercase characters. American Express Direct: String (20) CyberSource through VisaNet with American Express: String (20) CyberSource through VisaNet with Visa,Mastercard and Discover: String (15) FDC Compass: String (20) FDC Nashville Global: String (14)



20
21
22
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 20

def id
  @id
end

#localityObject

Sub-merchant’s city. #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5. #### FDC Compass This value must consist of uppercase characters.



29
30
31
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 29

def locality
  @locality
end

#merchant_category_codeObject

Returns the value of attribute merchant_category_code.



49
50
51
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 49

def merchant_category_code
  @merchant_category_code
end

#nameObject

Sub-merchant’s business name. #### American Express Direct The maximum length of the sub-merchant name depends on the length of the aggregator name. The combined length for both values must not exceed 36 characters. #### CyberSource through VisaNet With American Express, the maximum length of the sub-merchant name depends on the length of the aggregator name. The combined length for both values must not exceed 36 characters. The value for this field does not map to the TC 33 capture file5. #### FDC Compass This value must consist of uppercase characters. #### FDC Nashville Global With Mastercard, the maximum length of the sub-merchant name depends on the length of the aggregator name: - If aggregator name length is 1 through 3, maximum sub-merchant name length is 21. - If aggregator name length is 4 through 7, maximum sub-merchant name length is 17. - If aggregator name length is 8 through 12, maximum sub-merchant name length is 12.



23
24
25
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 23

def name
  @name
end

#phone_numberObject

Sub-merchant’s telephone number. **Maximum length for procesors** - American Express Direct: 20 - CyberSource through VisaNet: 20 - FDC Compass: 13 - FDC Nashville Global: 10 #### CyberSource through VisaNet With American Express, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCRB - Position: 5-24 - Field: American Express Seller Telephone Number **FDC Compass**\ This value must consist of uppercase characters. Use one of these recommended formats:\ ‘NNN-NNN-NNNN`\ `NNN-AAAAAAA`



47
48
49
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 47

def phone_number
  @phone_number
end

#postal_codeObject

Partial postal code for the sub-merchant’s address. #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5. #### FDC Compass This value must consist of uppercase characters.



38
39
40
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 38

def postal_code
  @postal_code
end

#regionObject

Sub-merchant’s region. Example\ ‘NE` indicates that the sub-merchant is in the northeast region.



35
36
37
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 35

def region
  @region
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 52

def self.attribute_map
  {
    :'card_acceptor_id' => :'cardAcceptorId',
    :'id' => :'id',
    :'name' => :'name',
    :'address1' => :'address1',
    :'locality' => :'locality',
    :'administrative_area' => :'administrativeArea',
    :'region' => :'region',
    :'postal_code' => :'postalCode',
    :'country' => :'country',
    :'email' => :'email',
    :'phone_number' => :'phoneNumber',
    :'merchant_category_code' => :'merchantCategoryCode'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 70

def self.json_map
  {
    :'card_acceptor_id' => :'card_acceptor_id',
    :'id' => :'id',
    :'name' => :'name',
    :'address1' => :'address1',
    :'locality' => :'locality',
    :'administrative_area' => :'administrative_area',
    :'region' => :'region',
    :'postal_code' => :'postal_code',
    :'country' => :'country',
    :'email' => :'email',
    :'phone_number' => :'phone_number',
    :'merchant_category_code' => :'merchant_category_code'
  }
end

.swagger_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 88

def self.swagger_types
  {
    :'card_acceptor_id' => :'String',
    :'id' => :'String',
    :'name' => :'String',
    :'address1' => :'String',
    :'locality' => :'String',
    :'administrative_area' => :'String',
    :'region' => :'String',
    :'postal_code' => :'String',
    :'country' => :'String',
    :'email' => :'String',
    :'phone_number' => :'String',
    :'merchant_category_code' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      card_acceptor_id == o.card_acceptor_id &&
      id == o.id &&
      name == o.name &&
      address1 == o.address1 &&
      locality == o.locality &&
      administrative_area == o.administrative_area &&
      region == o.region &&
      postal_code == o.postal_code &&
      country == o.country &&
      email == o.email &&
      phone_number == o.phone_number &&
      merchant_category_code == o.merchant_category_code
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 296

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 362

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 275

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 262

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



268
269
270
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 268

def hash
  [card_acceptor_id, id, name, address1, locality, administrative_area, region, postal_code, country, email, phone_number, merchant_category_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 164

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 342

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 348

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



336
337
338
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 336

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
# File 'lib/cybersource_rest_client/models/ptsv2payments_aggregator_information_sub_merchant.rb', line 171

def valid?
  true
end