Class: CyberSource::Ptsv2paymentsOrderInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/ptsv2payments_order_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Ptsv2paymentsOrderInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 119

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'extensionDays')
    self.extension_days = attributes[:'extensionDays']
  end

  if attributes.has_key?(:'amountDetails')
    self.amount_details = attributes[:'amountDetails']
  end

  if attributes.has_key?(:'billTo')
    self.bill_to = attributes[:'billTo']
  end

  if attributes.has_key?(:'shipTo')
    self.ship_to = attributes[:'shipTo']
  end

  if attributes.has_key?(:'lineItems')
    if (value = attributes[:'lineItems']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.has_key?(:'invoiceDetails')
    self.invoice_details = attributes[:'invoiceDetails']
  end

  if attributes.has_key?(:'shippingDetails')
    self.shipping_details = attributes[:'shippingDetails']
  end

  if attributes.has_key?(:'digitalCurrency')
    self.digital_currency = attributes[:'digitalCurrency']
  end

  if attributes.has_key?(:'returnsAccepted')
    self.returns_accepted = attributes[:'returnsAccepted']
  end

  if attributes.has_key?(:'isCryptocurrencyPurchase')
    self.is_cryptocurrency_purchase = attributes[:'isCryptocurrencyPurchase']
  end

  if attributes.has_key?(:'cutoffDateTime')
    self.cutoff_date_time = attributes[:'cutoffDateTime']
  end

  if attributes.has_key?(:'preOrder')
    self.pre_order = attributes[:'preOrder']
  end

  if attributes.has_key?(:'preOrderDate')
    self.pre_order_date = attributes[:'preOrderDate']
  end

  if attributes.has_key?(:'reordered')
    self.reordered = attributes[:'reordered']
  end

  if attributes.has_key?(:'totalOffersCount')
    self.total_offers_count = attributes[:'totalOffersCount']
  end
end

Instance Attribute Details

#amount_detailsObject

Returns the value of attribute amount_details.



19
20
21
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 19

def amount_details
  @amount_details
end

#bill_toObject

Returns the value of attribute bill_to.



21
22
23
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 21

def bill_to
  @bill_to
end

#cutoff_date_timeObject

Starting date and time for an event or a journey that is independent of which transportation mechanism, in UTC. The cutoffDateTime will supersede travelInformation.transit.airline.legs[].departureDate and travelInformation.transit.airline.legs[].departureTime if these fields are supplied in the request. Format: YYYY-MM-DDThh:mm:ssZ. Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC.



40
41
42
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 40

def cutoff_date_time
  @cutoff_date_time
end

#digital_currencyObject

Returns the value of attribute digital_currency.



31
32
33
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 31

def digital_currency
  @digital_currency
end

#extension_daysObject

Request field for merchant to increase the AUTH expiry days for Klarna Advantage Plus. Applicable for Re-Authorization (AP_REAUTH) service.



17
18
19
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 17

def extension_days
  @extension_days
end

#invoice_detailsObject

Returns the value of attribute invoice_details.



27
28
29
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 27

def invoice_details
  @invoice_details
end

#is_cryptocurrency_purchaseObject

#### Visa Platform Connect : This API will contain the Flag that specifies whether the payment is for the purchase of cryptocurrency. Additional values to add : This API will contain the Flag that specifies whether the payment is for the purchase of cryptocurrency. valid values are - Y/y, true - N/n, false



37
38
39
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 37

def is_cryptocurrency_purchase
  @is_cryptocurrency_purchase
end

#line_itemsObject

Returns the value of attribute line_items.



25
26
27
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 25

def line_items
  @line_items
end

#pre_orderObject

Indicates whether cardholder is placing an order with a future availability or release date. This field can contain one of these values: - MERCHANDISE_AVAILABLE: Merchandise available - FUTURE_AVAILABILITY: Future availability



43
44
45
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 43

def pre_order
  @pre_order
end

#pre_order_dateObject

Expected date that a pre-ordered purchase will be available. Format: YYYYMMDD



46
47
48
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 46

def pre_order_date
  @pre_order_date
end

#reorderedObject

Indicates whether the cardholder is reordering previously purchased merchandise. This field can contain one of these values: - false: First time ordered - true: Reordered



49
50
51
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 49

def reordered
  @reordered
end

#returns_acceptedObject

This is only needed when you are requesting both payment and DM service at same time. Boolean that indicates whether returns are accepted for this order. This field can contain one of the following values: - true: Returns are accepted for this order. - false: Returns are not accepted for this order.



34
35
36
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 34

def returns_accepted
  @returns_accepted
end

#ship_toObject

Returns the value of attribute ship_to.



23
24
25
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 23

def ship_to
  @ship_to
end

#shipping_detailsObject

Returns the value of attribute shipping_details.



29
30
31
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 29

def shipping_details
  @shipping_details
end

#total_offers_countObject

Total number of articles/items in the order as a numeric decimal count. Possible values: 00 - 99



52
53
54
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 52

def total_offers_count
  @total_offers_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 55

def self.attribute_map
  {
    :'extension_days' => :'extensionDays',
    :'amount_details' => :'amountDetails',
    :'bill_to' => :'billTo',
    :'ship_to' => :'shipTo',
    :'line_items' => :'lineItems',
    :'invoice_details' => :'invoiceDetails',
    :'shipping_details' => :'shippingDetails',
    :'digital_currency' => :'digitalCurrency',
    :'returns_accepted' => :'returnsAccepted',
    :'is_cryptocurrency_purchase' => :'isCryptocurrencyPurchase',
    :'cutoff_date_time' => :'cutoffDateTime',
    :'pre_order' => :'preOrder',
    :'pre_order_date' => :'preOrderDate',
    :'reordered' => :'reordered',
    :'total_offers_count' => :'totalOffersCount'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 76

def self.json_map
  {
    :'extension_days' => :'extension_days',
    :'amount_details' => :'amount_details',
    :'bill_to' => :'bill_to',
    :'ship_to' => :'ship_to',
    :'line_items' => :'line_items',
    :'invoice_details' => :'invoice_details',
    :'shipping_details' => :'shipping_details',
    :'digital_currency' => :'digital_currency',
    :'returns_accepted' => :'returns_accepted',
    :'is_cryptocurrency_purchase' => :'is_cryptocurrency_purchase',
    :'cutoff_date_time' => :'cutoff_date_time',
    :'pre_order' => :'pre_order',
    :'pre_order_date' => :'pre_order_date',
    :'reordered' => :'reordered',
    :'total_offers_count' => :'total_offers_count'
  }
end

.swagger_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 97

def self.swagger_types
  {
    :'extension_days' => :'String',
    :'amount_details' => :'Ptsv2paymentsOrderInformationAmountDetails',
    :'bill_to' => :'Ptsv2paymentsOrderInformationBillTo',
    :'ship_to' => :'Ptsv2paymentsOrderInformationShipTo',
    :'line_items' => :'Array<Ptsv2paymentsOrderInformationLineItems>',
    :'invoice_details' => :'Ptsv2paymentsOrderInformationInvoiceDetails',
    :'shipping_details' => :'Ptsv2paymentsOrderInformationShippingDetails',
    :'digital_currency' => :'Ptsv2paymentsOrderInformationDigitalCurrency',
    :'returns_accepted' => :'BOOLEAN',
    :'is_cryptocurrency_purchase' => :'String',
    :'cutoff_date_time' => :'String',
    :'pre_order' => :'String',
    :'pre_order_date' => :'String',
    :'reordered' => :'BOOLEAN',
    :'total_offers_count' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 221

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      extension_days == o.extension_days &&
      amount_details == o.amount_details &&
      bill_to == o.bill_to &&
      ship_to == o.ship_to &&
      line_items == o.line_items &&
      invoice_details == o.invoice_details &&
      shipping_details == o.shipping_details &&
      digital_currency == o.digital_currency &&
      returns_accepted == o.returns_accepted &&
      is_cryptocurrency_purchase == o.is_cryptocurrency_purchase &&
      cutoff_date_time == o.cutoff_date_time &&
      pre_order == o.pre_order &&
      pre_order_date == o.pre_order_date &&
      reordered == o.reordered &&
      total_offers_count == o.total_offers_count
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 277

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 343

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 256

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 243

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



249
250
251
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 249

def hash
  [extension_days, amount_details, bill_to, ship_to, line_items, invoice_details, shipping_details, digital_currency, returns_accepted, is_cryptocurrency_purchase, cutoff_date_time, pre_order, pre_order_date, reordered, total_offers_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 190

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 323

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
332
333
334
335
336
337
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 329

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



317
318
319
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 317

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
# File 'lib/cybersource_rest_client/models/ptsv2payments_order_information.rb', line 197

def valid?
  true
end