Class: CyberSource::Ptsv2paymentsRecipientInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Ptsv2paymentsRecipientInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 156

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'accountId')
    self. = attributes[:'accountId']
  end

  if attributes.has_key?(:'accountType')
    self. = attributes[:'accountType']
  end

  if attributes.has_key?(:'firstName')
    self.first_name = attributes[:'firstName']
  end

  if attributes.has_key?(:'middleName')
    self.middle_name = attributes[:'middleName']
  end

  if attributes.has_key?(:'lastName')
    self.last_name = attributes[:'lastName']
  end

  if attributes.has_key?(:'address1')
    self.address1 = attributes[:'address1']
  end

  if attributes.has_key?(:'administrativeArea')
    self.administrative_area = attributes[:'administrativeArea']
  end

  if attributes.has_key?(:'postalCode')
    self.postal_code = attributes[:'postalCode']
  end

  if attributes.has_key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.has_key?(:'dateOfBirth')
    self.date_of_birth = attributes[:'dateOfBirth']
  end

  if attributes.has_key?(:'beneficiaryId')
    self.beneficiary_id = attributes[:'beneficiaryId']
  end

  if attributes.has_key?(:'beneficiaryName')
    self.beneficiary_name = attributes[:'beneficiaryName']
  end

  if attributes.has_key?(:'beneficiaryAddress')
    self.beneficiary_address = attributes[:'beneficiaryAddress']
  end

  if attributes.has_key?(:'aliasName')
    self.alias_name = attributes[:'aliasName']
  end

  if attributes.has_key?(:'nationality')
    self.nationality = attributes[:'nationality']
  end

  if attributes.has_key?(:'countryOfBirth')
    self.country_of_birth = attributes[:'countryOfBirth']
  end

  if attributes.has_key?(:'occupation')
    self.occupation = attributes[:'occupation']
  end

  if attributes.has_key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.has_key?(:'locality')
    self.locality = attributes[:'locality']
  end

  if attributes.has_key?(:'taxIdNumber')
    self.tax_id_number = attributes[:'taxIdNumber']
  end
end

Instance Attribute Details

#account_idObject

Identifier for the recipient’s account. This field is applicable for AFT transactions.



17
18
19
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 17

def 
  @account_id
end

#account_typeObject

Identifies the recipient’s account type. This field is applicable for AFT transactions. Valid values are: - ‘00` for Other - `01` for Routing Transit Number (RTN) + Bank Account Number (BAN) - `02` for International Bank Account Number (IBAN) - `03` for Card Account - `06` for Bank Account Number (BAN) + Bank Identification Code (BIC), also known as a SWIFT code



20
21
22
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 20

def 
  @account_type
end

#address1Object

The street address of the recipient This field is applicable for AFT and OCT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set are not supported and will be stripped before being sent to sent to the processor.



32
33
34
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 32

def address1
  @address1
end

#administrative_areaObject

The state or province of the recipient. This field is applicable for AFT transactions when the recipient country is US or CA. Else it is optional. Must be a two character value



35
36
37
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 35

def administrative_area
  @administrative_area
end

#alias_nameObject

Account owner alias name.



56
57
58
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 56

def alias_name
  @alias_name
end

#beneficiary_addressObject

Only for e-wallets: The ultimate beneficiary’s street address (street, zip code, city), excluding the country. Example: "Main street 1, 12345, Barcelona



53
54
55
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 53

def beneficiary_address
  @beneficiary_address
end

#beneficiary_idObject

Only for e-wallets: ID, username, hash or anything uniquely identifying the ultimate beneficiary.



47
48
49
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 47

def beneficiary_id
  @beneficiary_id
end

#beneficiary_nameObject

Only for e-wallets: The ultimate beneficiary’s full name.



50
51
52
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 50

def beneficiary_name
  @beneficiary_name
end

#countryObject

The country associated with the address of the recipient. This field is applicable for AFT and OCT transactions. Must be a two character ISO country code. For example, see [ISO Country Code](developer.cybersource.com/docs/cybs/en-us/country-codes/reference/all/na/country-codes/country-codes.html)



41
42
43
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 41

def country
  @country
end

#country_of_birthObject

Account Owner Country of Birth



62
63
64
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 62

def country_of_birth
  @country_of_birth
end

#date_of_birthObject

Recipient’s date of birth. Format: ‘YYYYMMDD`. This field is a `pass-through`, which means that CyberSource ensures that the value is eight numeric characters but otherwise does not verify the value or modify it in any way before sending it to the processor. If the field is not required for the transaction, CyberSource does not forward it to the processor.



44
45
46
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 44

def date_of_birth
  @date_of_birth
end

#emailObject

Account Owner email address



68
69
70
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 68

def email
  @email
end

#first_nameObject

First name of the recipient. This field is applicable for AFT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to sent to the processor.



23
24
25
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 23

def first_name
  @first_name
end

#last_nameObject

Last name of the recipient. This field is applicable for AFT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to sent to the processor.



29
30
31
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 29

def last_name
  @last_name
end

#localityObject

The city of the recipient. This field is applicable for AFT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set are not supported and will be stripped before being sent to sent to the processor.



71
72
73
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 71

def locality
  @locality
end

#middle_nameObject

Middle name of the recipient. This field is applicable for AFT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to sent to the processor.



26
27
28
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 26

def middle_name
  @middle_name
end

#nationalityObject

Account Owner Nationality



59
60
61
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 59

def nationality
  @nationality
end

#occupationObject

Account Owner Occupation



65
66
67
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 65

def occupation
  @occupation
end

#postal_codeObject

Partial postal code for the recipient’s address. For example, if the postal code is **NN5 7SG**, the value for this field should be the first part of the postal code: NN5. This field is a pass-through, which means that CyberSource does not verify the value or modify it in any way before sending it to the processor. If the field is not required for the transaction, CyberSource does not forward it to the processor.



38
39
40
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 38

def postal_code
  @postal_code
end

#tax_id_numberObject

CPF or CNPJ of the cash-in recipient. "Cadastro de Pessoas Físicas", which translates to the "Natural Persons Register." It is the individual taxpayer registry identification number in Brazil, similar to a Social Security Number (SSN) in the United States or a National Insurance Number in the UK.



74
75
76
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 74

def tax_id_number
  @tax_id_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 77

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'account_type' => :'accountType',
    :'first_name' => :'firstName',
    :'middle_name' => :'middleName',
    :'last_name' => :'lastName',
    :'address1' => :'address1',
    :'administrative_area' => :'administrativeArea',
    :'postal_code' => :'postalCode',
    :'country' => :'country',
    :'date_of_birth' => :'dateOfBirth',
    :'beneficiary_id' => :'beneficiaryId',
    :'beneficiary_name' => :'beneficiaryName',
    :'beneficiary_address' => :'beneficiaryAddress',
    :'alias_name' => :'aliasName',
    :'nationality' => :'nationality',
    :'country_of_birth' => :'countryOfBirth',
    :'occupation' => :'occupation',
    :'email' => :'email',
    :'locality' => :'locality',
    :'tax_id_number' => :'taxIdNumber'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 103

def self.json_map
  {
    :'account_id' => :'account_id',
    :'account_type' => :'account_type',
    :'first_name' => :'first_name',
    :'middle_name' => :'middle_name',
    :'last_name' => :'last_name',
    :'address1' => :'address1',
    :'administrative_area' => :'administrative_area',
    :'postal_code' => :'postal_code',
    :'country' => :'country',
    :'date_of_birth' => :'date_of_birth',
    :'beneficiary_id' => :'beneficiary_id',
    :'beneficiary_name' => :'beneficiary_name',
    :'beneficiary_address' => :'beneficiary_address',
    :'alias_name' => :'alias_name',
    :'nationality' => :'nationality',
    :'country_of_birth' => :'country_of_birth',
    :'occupation' => :'occupation',
    :'email' => :'email',
    :'locality' => :'locality',
    :'tax_id_number' => :'tax_id_number'
  }
end

.swagger_typesObject

Attribute type mapping.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 129

def self.swagger_types
  {
    :'account_id' => :'String',
    :'account_type' => :'String',
    :'first_name' => :'String',
    :'middle_name' => :'String',
    :'last_name' => :'String',
    :'address1' => :'String',
    :'administrative_area' => :'String',
    :'postal_code' => :'String',
    :'country' => :'String',
    :'date_of_birth' => :'String',
    :'beneficiary_id' => :'String',
    :'beneficiary_name' => :'String',
    :'beneficiary_address' => :'String',
    :'alias_name' => :'String',
    :'nationality' => :'String',
    :'country_of_birth' => :'String',
    :'occupation' => :'String',
    :'email' => :'String',
    :'locality' => :'String',
    :'tax_id_number' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 372

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      first_name == o.first_name &&
      middle_name == o.middle_name &&
      last_name == o.last_name &&
      address1 == o.address1 &&
      administrative_area == o.administrative_area &&
      postal_code == o.postal_code &&
      country == o.country &&
      date_of_birth == o.date_of_birth &&
      beneficiary_id == o.beneficiary_id &&
      beneficiary_name == o.beneficiary_name &&
      beneficiary_address == o.beneficiary_address &&
      alias_name == o.alias_name &&
      nationality == o.nationality &&
      country_of_birth == o.country_of_birth &&
      occupation == o.occupation &&
      email == o.email &&
      locality == o.locality &&
      tax_id_number == o.tax_id_number
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 433

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



499
500
501
502
503
504
505
506
507
508
509
510
511
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 499

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 412

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


399
400
401
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 399

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



405
406
407
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 405

def hash
  [, , first_name, middle_name, last_name, address1, administrative_area, postal_code, country, date_of_birth, beneficiary_id, beneficiary_name, beneficiary_address, alias_name, nationality, country_of_birth, occupation, email, locality, tax_id_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



245
246
247
248
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 245

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



479
480
481
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 479

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



485
486
487
488
489
490
491
492
493
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 485

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



473
474
475
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 473

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



252
253
254
# File 'lib/cybersource_rest_client/models/ptsv2payments_recipient_information.rb', line 252

def valid?
  true
end