Class: CyberSource::Ptsv2paymentsidcapturesProcessingInformation
- Inherits:
-
Object
- Object
- CyberSource::Ptsv2paymentsidcapturesProcessingInformation
- Defined in:
- lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb
Instance Attribute Summary collapse
-
#action_list ⇒ Object
Array of actions (one or more) to be included in the capture to invoke bundled services along with capture.
-
#authorization_options ⇒ Object
Returns the value of attribute authorization_options.
-
#capture_options ⇒ Object
Returns the value of attribute capture_options.
-
#digital_service_indicator ⇒ Object
Mastercard Digital Enablement Service (MDES) digital service indicators for force capture scenarios.
-
#industry_data_type ⇒ Object
Indicates that the transaction includes industry-specific data.
-
#issuer ⇒ Object
Returns the value of attribute issuer.
-
#japan_payment_options ⇒ Object
Returns the value of attribute japan_payment_options.
-
#link_id ⇒ Object
Value that links the current authorization request to the original authorization request.
-
#loan_options ⇒ Object
Returns the value of attribute loan_options.
-
#pay_by_points_indicator ⇒ Object
Flag that indicates if the transaction is pay by points transaction true: Transaction uses loyalty points false: Transaction does not use loyalty points Default: false.
-
#payment_solution ⇒ Object
Type of digital payment solution for the transaction.
-
#purchase_level ⇒ Object
Set this field to 3 to indicate that the request includes Level III data.
-
#reconciliation_id ⇒ Object
Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request.
-
#report_group ⇒ Object
Attribute that lets you define custom grouping for your processor reports.
-
#visa_checkout_id ⇒ Object
Identifier for the **Visa Checkout** order.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv2paymentsidcapturesProcessingInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv2paymentsidcapturesProcessingInformation
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 121 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'paymentSolution') self.payment_solution = attributes[:'paymentSolution'] end if attributes.has_key?(:'reconciliationId') self.reconciliation_id = attributes[:'reconciliationId'] end if attributes.has_key?(:'linkId') self.link_id = attributes[:'linkId'] end if attributes.has_key?(:'reportGroup') self.report_group = attributes[:'reportGroup'] end if attributes.has_key?(:'visaCheckoutId') self.visa_checkout_id = attributes[:'visaCheckoutId'] end if attributes.has_key?(:'purchaseLevel') self.purchase_level = attributes[:'purchaseLevel'] end if attributes.has_key?(:'industryDataType') self.industry_data_type = attributes[:'industryDataType'] end if attributes.has_key?(:'digitalServiceIndicator') self.digital_service_indicator = attributes[:'digitalServiceIndicator'] end if attributes.has_key?(:'issuer') self.issuer = attributes[:'issuer'] end if attributes.has_key?(:'authorizationOptions') self. = attributes[:'authorizationOptions'] end if attributes.has_key?(:'captureOptions') self. = attributes[:'captureOptions'] end if attributes.has_key?(:'loanOptions') self. = attributes[:'loanOptions'] end if attributes.has_key?(:'payByPointsIndicator') self.pay_by_points_indicator = attributes[:'payByPointsIndicator'] end if attributes.has_key?(:'actionList') if (value = attributes[:'actionList']).is_a?(Array) self.action_list = value end end if attributes.has_key?(:'japanPaymentOptions') self. = attributes[:'japanPaymentOptions'] end end |
Instance Attribute Details
#action_list ⇒ Object
Array of actions (one or more) to be included in the capture to invoke bundled services along with capture. Possible values : - ‘AP_CAPTURE`: Use this when Alternative Payment Capture service is requested.
52 53 54 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 52 def action_list @action_list end |
#authorization_options ⇒ Object
Returns the value of attribute authorization_options.
42 43 44 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 42 def @authorization_options end |
#capture_options ⇒ Object
Returns the value of attribute capture_options.
44 45 46 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 44 def @capture_options end |
#digital_service_indicator ⇒ Object
Mastercard Digital Enablement Service (MDES) digital service indicators for force capture scenarios. This field is used when the client is doing authorization with a different gateway and capture with CyberSource. This field is in ANS, EBCDIC format and flows in Field 34, DSID 04 Tag DF1F, mapped to Mastercard Data Element DE119, Sub-element 004. #### Used by **Capture Request** Request field for force capture support when auth is done with a different gateway.
38 39 40 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 38 def digital_service_indicator @digital_service_indicator end |
#industry_data_type ⇒ Object
Indicates that the transaction includes industry-specific data. Possible Values: - ‘airline` - `restaurant` - `lodging` - `auto_rental` - `transit` - `healthcare_medical` - `healthcare_transit` - `transit` #### Card Present, Airlines and Auto Rental You must set this field to `airline` in order for airline data to be sent to the processor. For example, if this field is not set to `airline` or is not included in the request, no airline data is sent to the processor. You must set this field to `restaurant` in order for restaurant data to be sent to the processor. When this field is not set to `restaurant` or is not included in the request, no restaurant data is sent to the processor. You must set this field to `auto_rental` in order for auto rental data to be sent to the processor. For example, if this field is not set to `auto_rental` or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on CyberSource through VisaNet.
35 36 37 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 35 def industry_data_type @industry_data_type end |
#issuer ⇒ Object
Returns the value of attribute issuer.
40 41 42 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 40 def issuer @issuer end |
#japan_payment_options ⇒ Object
Returns the value of attribute japan_payment_options.
54 55 56 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 54 def @japan_payment_options end |
#link_id ⇒ Object
Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request. This value is used for: - Partial authorizations - Split shipments
23 24 25 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 23 def link_id @link_id end |
#loan_options ⇒ Object
Returns the value of attribute loan_options.
46 47 48 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 46 def @loan_options end |
#pay_by_points_indicator ⇒ Object
Flag that indicates if the transaction is pay by points transaction true: Transaction uses loyalty points false: Transaction does not use loyalty points Default: false
49 50 51 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 49 def pay_by_points_indicator @pay_by_points_indicator end |
#payment_solution ⇒ Object
Type of digital payment solution for the transaction. Possible Values: - ‘visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the REST API.](developer.cybersource.com/content/dam/docs/cybs/en-us/apifields/reference/all/rest/api-fields.pdf) - `001`: Apple Pay. - `004`: Cybersource In-App Solution. - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. - `006`: Android Pay. - `007`: Chase Pay. - `008`: Samsung Pay. - `012`: Google Pay. - `013`: Cybersource P2PE Decryption - `014`: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token. - `015`: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token. - `027`: Click to Pay.
17 18 19 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 17 def payment_solution @payment_solution end |
#purchase_level ⇒ Object
Set this field to 3 to indicate that the request includes Level III data.
32 33 34 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 32 def purchase_level @purchase_level end |
#reconciliation_id ⇒ Object
Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22).
20 21 22 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 20 def reconciliation_id @reconciliation_id end |
#report_group ⇒ Object
Attribute that lets you define custom grouping for your processor reports. This field is supported only for **Worldpay VAP**.
26 27 28 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 26 def report_group @report_group end |
#visa_checkout_id ⇒ Object
Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.
29 30 31 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 29 def visa_checkout_id @visa_checkout_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 57 def self.attribute_map { :'payment_solution' => :'paymentSolution', :'reconciliation_id' => :'reconciliationId', :'link_id' => :'linkId', :'report_group' => :'reportGroup', :'visa_checkout_id' => :'visaCheckoutId', :'purchase_level' => :'purchaseLevel', :'industry_data_type' => :'industryDataType', :'digital_service_indicator' => :'digitalServiceIndicator', :'issuer' => :'issuer', :'authorization_options' => :'authorizationOptions', :'capture_options' => :'captureOptions', :'loan_options' => :'loanOptions', :'pay_by_points_indicator' => :'payByPointsIndicator', :'action_list' => :'actionList', :'japan_payment_options' => :'japanPaymentOptions' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 78 def self.json_map { :'payment_solution' => :'payment_solution', :'reconciliation_id' => :'reconciliation_id', :'link_id' => :'link_id', :'report_group' => :'report_group', :'visa_checkout_id' => :'visa_checkout_id', :'purchase_level' => :'purchase_level', :'industry_data_type' => :'industry_data_type', :'digital_service_indicator' => :'digital_service_indicator', :'issuer' => :'issuer', :'authorization_options' => :'authorization_options', :'capture_options' => :'capture_options', :'loan_options' => :'loan_options', :'pay_by_points_indicator' => :'pay_by_points_indicator', :'action_list' => :'action_list', :'japan_payment_options' => :'japan_payment_options' } end |
.swagger_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 99 def self.swagger_types { :'payment_solution' => :'String', :'reconciliation_id' => :'String', :'link_id' => :'String', :'report_group' => :'String', :'visa_checkout_id' => :'String', :'purchase_level' => :'String', :'industry_data_type' => :'String', :'digital_service_indicator' => :'String', :'issuer' => :'Ptsv2paymentsIssuerInformation', :'authorization_options' => :'Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions', :'capture_options' => :'Ptsv2paymentsidcapturesProcessingInformationCaptureOptions', :'loan_options' => :'Ptsv2paymentsProcessingInformationLoanOptions', :'pay_by_points_indicator' => :'BOOLEAN', :'action_list' => :'Array<String>', :'japan_payment_options' => :'Ptsv2paymentsidcapturesProcessingInformationJapanPaymentOptions' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 253 def ==(o) return true if self.equal?(o) self.class == o.class && payment_solution == o.payment_solution && reconciliation_id == o.reconciliation_id && link_id == o.link_id && report_group == o.report_group && visa_checkout_id == o.visa_checkout_id && purchase_level == o.purchase_level && industry_data_type == o.industry_data_type && digital_service_indicator == o.digital_service_indicator && issuer == o.issuer && == o. && == o. && == o. && pay_by_points_indicator == o.pay_by_points_indicator && action_list == o.action_list && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 309 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 375 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 288 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
275 276 277 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 275 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 281 def hash [payment_solution, reconciliation_id, link_id, report_group, visa_checkout_id, purchase_level, industry_data_type, digital_service_indicator, issuer, , , , pay_by_points_indicator, action_list, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
192 193 194 195 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 192 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
355 356 357 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 355 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
361 362 363 364 365 366 367 368 369 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 361 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
349 350 351 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 349 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_processing_information.rb', line 199 def valid? true end |