Class: CyberSource::Ptsv2paymentsidrefundsOrderInformation
- Inherits:
-
Object
- Object
- CyberSource::Ptsv2paymentsidrefundsOrderInformation
- Defined in:
- lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb
Instance Attribute Summary collapse
-
#amount_details ⇒ Object
Returns the value of attribute amount_details.
-
#bill_to ⇒ Object
Returns the value of attribute bill_to.
-
#digital_currency ⇒ Object
Returns the value of attribute digital_currency.
-
#invoice_details ⇒ Object
Returns the value of attribute invoice_details.
-
#line_items ⇒ Object
Returns the value of attribute line_items.
-
#ship_to ⇒ Object
Returns the value of attribute ship_to.
-
#shipping_details ⇒ Object
Returns the value of attribute shipping_details.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv2paymentsidrefundsOrderInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv2paymentsidrefundsOrderInformation
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'amountDetails') self.amount_details = attributes[:'amountDetails'] end if attributes.has_key?(:'billTo') self.bill_to = attributes[:'billTo'] end if attributes.has_key?(:'shipTo') self.ship_to = attributes[:'shipTo'] end if attributes.has_key?(:'lineItems') if (value = attributes[:'lineItems']).is_a?(Array) self.line_items = value end end if attributes.has_key?(:'invoiceDetails') self.invoice_details = attributes[:'invoiceDetails'] end if attributes.has_key?(:'shippingDetails') self.shipping_details = attributes[:'shippingDetails'] end if attributes.has_key?(:'digitalCurrency') self.digital_currency = attributes[:'digitalCurrency'] end end |
Instance Attribute Details
#amount_details ⇒ Object
Returns the value of attribute amount_details.
16 17 18 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 16 def amount_details @amount_details end |
#bill_to ⇒ Object
Returns the value of attribute bill_to.
18 19 20 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 18 def bill_to @bill_to end |
#digital_currency ⇒ Object
Returns the value of attribute digital_currency.
28 29 30 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 28 def digital_currency @digital_currency end |
#invoice_details ⇒ Object
Returns the value of attribute invoice_details.
24 25 26 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 24 def invoice_details @invoice_details end |
#line_items ⇒ Object
Returns the value of attribute line_items.
22 23 24 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 22 def line_items @line_items end |
#ship_to ⇒ Object
Returns the value of attribute ship_to.
20 21 22 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 20 def ship_to @ship_to end |
#shipping_details ⇒ Object
Returns the value of attribute shipping_details.
26 27 28 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 26 def shipping_details @shipping_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 31 def self.attribute_map { :'amount_details' => :'amountDetails', :'bill_to' => :'billTo', :'ship_to' => :'shipTo', :'line_items' => :'lineItems', :'invoice_details' => :'invoiceDetails', :'shipping_details' => :'shippingDetails', :'digital_currency' => :'digitalCurrency' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 44 def self.json_map { :'amount_details' => :'amount_details', :'bill_to' => :'bill_to', :'ship_to' => :'ship_to', :'line_items' => :'line_items', :'invoice_details' => :'invoice_details', :'shipping_details' => :'shipping_details', :'digital_currency' => :'digital_currency' } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 57 def self.swagger_types { :'amount_details' => :'Ptsv2paymentsidcapturesOrderInformationAmountDetails', :'bill_to' => :'Ptsv2paymentsidcapturesOrderInformationBillTo', :'ship_to' => :'Ptsv2paymentsidcapturesOrderInformationShipTo', :'line_items' => :'Array<Ptsv2paymentsidrefundsOrderInformationLineItems>', :'invoice_details' => :'Ptsv2paymentsidcapturesOrderInformationInvoiceDetails', :'shipping_details' => :'Ptsv2paymentsidrefundsOrderInformationShippingDetails', :'digital_currency' => :'Ptsv2paymentsOrderInformationDigitalCurrency' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 123 def ==(o) return true if self.equal?(o) self.class == o.class && amount_details == o.amount_details && bill_to == o.bill_to && ship_to == o.ship_to && line_items == o.line_items && invoice_details == o.invoice_details && shipping_details == o.shipping_details && digital_currency == o.digital_currency end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 171 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 237 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 150 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
137 138 139 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 137 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 143 def hash [amount_details, bill_to, ship_to, line_items, invoice_details, shipping_details, digital_currency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 110 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
217 218 219 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 217 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
211 212 213 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 211 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_order_information.rb', line 117 def valid? true end |