Class: CyberSource::Ptsv2paymentsidrefundsPaymentInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Ptsv2paymentsidrefundsPaymentInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'card')
    self.card = attributes[:'card']
  end

  if attributes.has_key?(:'bank')
    self.bank = attributes[:'bank']
  end

  if attributes.has_key?(:'tokenizedCard')
    self.tokenized_card = attributes[:'tokenizedCard']
  end

  if attributes.has_key?(:'fluidData')
    self.fluid_data = attributes[:'fluidData']
  end

  if attributes.has_key?(:'customer')
    self.customer = attributes[:'customer']
  end

  if attributes.has_key?(:'paymentInstrument')
    self.payment_instrument = attributes[:'paymentInstrument']
  end

  if attributes.has_key?(:'instrumentIdentifier')
    self.instrument_identifier = attributes[:'instrumentIdentifier']
  end

  if attributes.has_key?(:'shippingAddress')
    self.shipping_address = attributes[:'shippingAddress']
  end

  if attributes.has_key?(:'legacyToken')
    self.legacy_token = attributes[:'legacyToken']
  end

  if attributes.has_key?(:'paymentType')
    self.payment_type = attributes[:'paymentType']
  end

  if attributes.has_key?(:'eWallet')
    self.e_wallet = attributes[:'eWallet']
  end

  if attributes.has_key?(:'paymentAccountReference')
    self. = attributes[:'paymentAccountReference']
  end

  if attributes.has_key?(:'thirdPartyToken')
    self.third_party_token = attributes[:'thirdPartyToken']
  end

  if attributes.has_key?(:'initiationChannel')
    self.initiation_channel = attributes[:'initiationChannel']
  end
end

Instance Attribute Details

#bankObject

Returns the value of attribute bank.



18
19
20
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 18

def bank
  @bank
end

#cardObject

Returns the value of attribute card.



16
17
18
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 16

def card
  @card
end

#customerObject

Returns the value of attribute customer.



24
25
26
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 24

def customer
  @customer
end

#e_walletObject

Returns the value of attribute e_wallet.



36
37
38
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 36

def e_wallet
  @e_wallet
end

#fluid_dataObject

Returns the value of attribute fluid_data.



22
23
24
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 22

def fluid_data
  @fluid_data
end

#initiation_channelObject

Mastercard-defined code that indicates how the account information was obtained for credit authorization transactions. Possible values: - ‘00`: Card (default) - `01`: Mobile network operator (MNO) controlled removable secure element (SIM or UICC) personalized for use with a mobile phone or smartphone - `02`: Key fob - `03`: Watch - `04`: Mobile tag - `05`: Wristband - `06`: Mobile phone case or sleeve - `07`: Mobile phone or smartphone with fixed (nonremovable) secure element controlled by the MNO (for example, code division multiple access (CDMA)) - `08`: Removable secure element not controlled by the MNO (for example, memory card personalized for use with a mobile phone or smartphone) - `09`: Mobile phone or smartphone with a fixed (nonremovable) secure element not controlled by the MNO - `10`: MNO-controlled removable secure element (SIM or UICC) personalized for use with a tablet or e-book - `11`: Tablet or e-book with a fixed (nonremovable) secure element controlled by the MNO - `12`: Removable secure element not controlled by the MNO (for example, memory card personalized for use with a tablet or e-book) - `13`: Tablet or e-book with fixed (nonremovable) secure element not controlled by the MNO - `14` - `99`: Reserved for future use This field flows in ISO Field 104 DSID 65 Tag 04. This field is supported for Mastercard credit authorization transactions. #### Used by **Credit Authorization (Standalone)** Optional field.



43
44
45
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 43

def initiation_channel
  @initiation_channel
end

#instrument_identifierObject

Returns the value of attribute instrument_identifier.



28
29
30
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 28

def instrument_identifier
  @instrument_identifier
end

#legacy_tokenObject

Returns the value of attribute legacy_token.



32
33
34
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 32

def legacy_token
  @legacy_token
end

#payment_account_referenceObject

Returns the value of attribute payment_account_reference.



38
39
40
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 38

def 
  @payment_account_reference
end

#payment_instrumentObject

Returns the value of attribute payment_instrument.



26
27
28
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 26

def payment_instrument
  @payment_instrument
end

#payment_typeObject

Returns the value of attribute payment_type.



34
35
36
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 34

def payment_type
  @payment_type
end

#shipping_addressObject

Returns the value of attribute shipping_address.



30
31
32
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 30

def shipping_address
  @shipping_address
end

#third_party_tokenObject

Returns the value of attribute third_party_token.



40
41
42
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 40

def third_party_token
  @third_party_token
end

#tokenized_cardObject

Returns the value of attribute tokenized_card.



20
21
22
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 20

def tokenized_card
  @tokenized_card
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 46

def self.attribute_map
  {
    :'card' => :'card',
    :'bank' => :'bank',
    :'tokenized_card' => :'tokenizedCard',
    :'fluid_data' => :'fluidData',
    :'customer' => :'customer',
    :'payment_instrument' => :'paymentInstrument',
    :'instrument_identifier' => :'instrumentIdentifier',
    :'shipping_address' => :'shippingAddress',
    :'legacy_token' => :'legacyToken',
    :'payment_type' => :'paymentType',
    :'e_wallet' => :'eWallet',
    :'payment_account_reference' => :'paymentAccountReference',
    :'third_party_token' => :'thirdPartyToken',
    :'initiation_channel' => :'initiationChannel'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 66

def self.json_map
  {
    :'card' => :'card',
    :'bank' => :'bank',
    :'tokenized_card' => :'tokenized_card',
    :'fluid_data' => :'fluid_data',
    :'customer' => :'customer',
    :'payment_instrument' => :'payment_instrument',
    :'instrument_identifier' => :'instrument_identifier',
    :'shipping_address' => :'shipping_address',
    :'legacy_token' => :'legacy_token',
    :'payment_type' => :'payment_type',
    :'e_wallet' => :'e_wallet',
    :'payment_account_reference' => :'payment_account_reference',
    :'third_party_token' => :'third_party_token',
    :'initiation_channel' => :'initiation_channel'
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 86

def self.swagger_types
  {
    :'card' => :'Ptsv2paymentsidrefundsPaymentInformationCard',
    :'bank' => :'Ptsv2paymentsidrefundsPaymentInformationBank',
    :'tokenized_card' => :'Ptsv2paymentsPaymentInformationTokenizedCard',
    :'fluid_data' => :'Ptsv2paymentsPaymentInformationFluidData',
    :'customer' => :'Ptsv2paymentsPaymentInformationCustomer',
    :'payment_instrument' => :'Ptsv2paymentsPaymentInformationPaymentInstrument',
    :'instrument_identifier' => :'Ptsv2paymentsPaymentInformationInstrumentIdentifier',
    :'shipping_address' => :'Ptsv2paymentsPaymentInformationShippingAddress',
    :'legacy_token' => :'Ptsv2paymentsPaymentInformationLegacyToken',
    :'payment_type' => :'Ptsv2paymentsidrefundsPaymentInformationPaymentType',
    :'e_wallet' => :'Ptsv2paymentsidrefundsPaymentInformationEWallet',
    :'payment_account_reference' => :'Ptsv2paymentsPaymentInformationPaymentAccountReference',
    :'third_party_token' => :'Ptsv2paymentsPaymentInformationThirdPartyToken',
    :'initiation_channel' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      card == o.card &&
      bank == o.bank &&
      tokenized_card == o.tokenized_card &&
      fluid_data == o.fluid_data &&
      customer == o.customer &&
      payment_instrument == o.payment_instrument &&
      instrument_identifier == o.instrument_identifier &&
      shipping_address == o.shipping_address &&
      legacy_token == o.legacy_token &&
      payment_type == o.payment_type &&
      e_wallet == o.e_wallet &&
       == o. &&
      third_party_token == o.third_party_token &&
      initiation_channel == o.initiation_channel
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 246

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 312

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 225

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 212

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



218
219
220
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 218

def hash
  [card, bank, tokenized_card, fluid_data, customer, payment_instrument, instrument_identifier, shipping_address, legacy_token, payment_type, e_wallet, , third_party_token, initiation_channel].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 172

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 292

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



286
287
288
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 286

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_payment_information.rb', line 179

def valid?
  true
end