Class: CyberSource::Ptsv2paymentsidrefundsProcessingInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Ptsv2paymentsidrefundsProcessingInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 112

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'actionList')
    if (value = attributes[:'actionList']).is_a?(Array)
      self.action_list = value
    end
  end

  if attributes.has_key?(:'paymentSolution')
    self.payment_solution = attributes[:'paymentSolution']
  end

  if attributes.has_key?(:'reconciliationId')
    self.reconciliation_id = attributes[:'reconciliationId']
  end

  if attributes.has_key?(:'linkId')
    self.link_id = attributes[:'linkId']
  end

  if attributes.has_key?(:'reportGroup')
    self.report_group = attributes[:'reportGroup']
  end

  if attributes.has_key?(:'visaCheckoutId')
    self.visa_checkout_id = attributes[:'visaCheckoutId']
  end

  if attributes.has_key?(:'purchaseLevel')
    self.purchase_level = attributes[:'purchaseLevel']
  end

  if attributes.has_key?(:'recurringOptions')
    self.recurring_options = attributes[:'recurringOptions']
  end

  if attributes.has_key?(:'industryDataType')
    self.industry_data_type = attributes[:'industryDataType']
  end

  if attributes.has_key?(:'paymentType')
    self.payment_type = attributes[:'paymentType']
  end

  if attributes.has_key?(:'refundOptions')
    self.refund_options = attributes[:'refundOptions']
  end

  if attributes.has_key?(:'transactionTypeIndicator')
    self.transaction_type_indicator = attributes[:'transactionTypeIndicator']
  end

  if attributes.has_key?(:'merchantVerificationValue')
    self.merchant_verification_value = attributes[:'merchantVerificationValue']
  end
end

Instance Attribute Details

#action_listObject

Array of actions (one or more) to be included in the payment to invoke bundled services along with payment status. Possible values are one or more of follows: - ‘AP_REFUND`: Use this when Alternative Payment Refund service is requested.



17
18
19
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 17

def action_list
  @action_list
end

#industry_data_typeObject

Indicates that the transaction includes industry-specific data. Possible Values: - ‘airline` - `restaurant` - `lodging` - `auto_rental` - `transit` - `healthcare_medical` - `healthcare_transit` - `transit` #### Card Present, Airlines and Auto Rental You must set this field to `airline` in order for airline data to be sent to the processor. For example, if this field is not set to `airline` or is not included in the request, no airline data is sent to the processor. You must set this field to `restaurant` in order for restaurant data to be sent to the processor. When this field is not set to `restaurant` or is not included in the request, no restaurant data is sent to the processor. You must set this field to `auto_rental` in order for auto rental data to be sent to the processor. For example, if this field is not set to `auto_rental` or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on CyberSource through VisaNet.



40
41
42
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 40

def industry_data_type
  @industry_data_type
end

Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request. This value is used for: - Partial authorizations - Split shipments



26
27
28
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 26

def link_id
  @link_id
end

#merchant_verification_valueObject

The override value of the Merchant Verification Value (MVV) received by various card brands. MVV refers to the value assigned by the card brand/network to identify participation in select merchant programs. Sample value for Visa: ‘101010`



51
52
53
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 51

def merchant_verification_value
  @merchant_verification_value
end

#payment_solutionObject

Type of digital payment solution for the transaction. Possible Values: - ‘visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the REST API.](developer.cybersource.com/content/dam/docs/cybs/en-us/apifields/reference/all/rest/api-fields.pdf) - `001`: Apple Pay. - `004`: Cybersource In-App Solution. - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. - `006`: Android Pay. - `007`: Chase Pay. - `008`: Samsung Pay. - `012`: Google Pay. - `013`: Cybersource P2PE Decryption - `014`: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token. - `015`: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token. - `027`: Click to Pay.



20
21
22
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 20

def payment_solution
  @payment_solution
end

#payment_typeObject

Identifier for the payment type



43
44
45
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 43

def payment_type
  @payment_type
end

#purchase_levelObject

Set this field to 3 to indicate that the request includes Level III data.



35
36
37
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 35

def purchase_level
  @purchase_level
end

#reconciliation_idObject

Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22).



23
24
25
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 23

def reconciliation_id
  @reconciliation_id
end

#recurring_optionsObject

Returns the value of attribute recurring_options.



37
38
39
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 37

def recurring_options
  @recurring_options
end

#refund_optionsObject

Returns the value of attribute refund_options.



45
46
47
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 45

def refund_options
  @refund_options
end

#report_groupObject

Attribute that lets you define custom grouping for your processor reports. This field is supported only for **Worldpay VAP**.



29
30
31
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 29

def report_group
  @report_group
end

#transaction_type_indicatorObject

This field is used identify the type of payment transaction taking place. This field is applicable for MasterCard transactions only. Possible values: - 201- Mastercard Rebate - 202- rePower Load Value - 203- Gaming Re-pay - 204- General Person-to-Person - 205- General Transfer to Own Account - 206- Agent Cash Out - 207- Payment of Own Credit Card Bill - 208- Business Disbursement - 209- Government/Non-Profit Disbursement - 210- Rapid Merchant Settlement - 211- Cash in at ATM (Usage limited to specific countries) - 212- Cash in at Point of Sale (Usage limited to specific countries) - 213- General Business to Business Transfer - 214- Mastercard Merchant Presented QR - 215- Mastercard Merchant Presented QR Refund Payment - 216- Utility Payments (for Brazil domestic use only) - 217- Government Services (for Brazil domestic use only) - 218- Mobile phone top-ups (for Brazil domestic use only) - 219- Coupon booklet payments (for Brazil domestic use only) - 220- General Person-to-Person Transfer - 221- Person-to-Person Transfer to Card Account - 222- General Transfer to Own Account - 223- Agent Cash Out - 224- Payment of Own Credit Card Bill - 225- Business Disbursement - 226- Transfer to Own Staged Digital Wallet Account - 227- Transfer to Own Debit or Prepaid Account - 228- General Business-to-Business Transfer - 229- Installment-based repayment - 230- Mastercard ATM Cash Pick-Up Transaction - 231- Cryptocurrency - 232- High-risk Securities



48
49
50
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 48

def transaction_type_indicator
  @transaction_type_indicator
end

#visa_checkout_idObject

Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.



32
33
34
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 32

def visa_checkout_id
  @visa_checkout_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 54

def self.attribute_map
  {
    :'action_list' => :'actionList',
    :'payment_solution' => :'paymentSolution',
    :'reconciliation_id' => :'reconciliationId',
    :'link_id' => :'linkId',
    :'report_group' => :'reportGroup',
    :'visa_checkout_id' => :'visaCheckoutId',
    :'purchase_level' => :'purchaseLevel',
    :'recurring_options' => :'recurringOptions',
    :'industry_data_type' => :'industryDataType',
    :'payment_type' => :'paymentType',
    :'refund_options' => :'refundOptions',
    :'transaction_type_indicator' => :'transactionTypeIndicator',
    :'merchant_verification_value' => :'merchantVerificationValue'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 73

def self.json_map
  {
    :'action_list' => :'action_list',
    :'payment_solution' => :'payment_solution',
    :'reconciliation_id' => :'reconciliation_id',
    :'link_id' => :'link_id',
    :'report_group' => :'report_group',
    :'visa_checkout_id' => :'visa_checkout_id',
    :'purchase_level' => :'purchase_level',
    :'recurring_options' => :'recurring_options',
    :'industry_data_type' => :'industry_data_type',
    :'payment_type' => :'payment_type',
    :'refund_options' => :'refund_options',
    :'transaction_type_indicator' => :'transaction_type_indicator',
    :'merchant_verification_value' => :'merchant_verification_value'
  }
end

.swagger_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 92

def self.swagger_types
  {
    :'action_list' => :'Array<String>',
    :'payment_solution' => :'String',
    :'reconciliation_id' => :'String',
    :'link_id' => :'String',
    :'report_group' => :'String',
    :'visa_checkout_id' => :'String',
    :'purchase_level' => :'String',
    :'recurring_options' => :'Ptsv2paymentsidrefundsProcessingInformationRecurringOptions',
    :'industry_data_type' => :'String',
    :'payment_type' => :'String',
    :'refund_options' => :'Ptsv2paymentsidrefundsProcessingInformationRefundOptions',
    :'transaction_type_indicator' => :'String',
    :'merchant_verification_value' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action_list == o.action_list &&
      payment_solution == o.payment_solution &&
      reconciliation_id == o.reconciliation_id &&
      link_id == o.link_id &&
      report_group == o.report_group &&
      visa_checkout_id == o.visa_checkout_id &&
      purchase_level == o.purchase_level &&
      recurring_options == o.recurring_options &&
      industry_data_type == o.industry_data_type &&
      payment_type == o.payment_type &&
      refund_options == o.refund_options &&
      transaction_type_indicator == o.transaction_type_indicator &&
      merchant_verification_value == o.merchant_verification_value
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 296

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 362

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 275

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 262

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



268
269
270
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 268

def hash
  [action_list, payment_solution, reconciliation_id, link_id, report_group, visa_checkout_id, purchase_level, recurring_options, industry_data_type, payment_type, refund_options, transaction_type_indicator, merchant_verification_value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 175

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 342

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 348

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



336
337
338
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 336

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidrefunds_processing_information.rb', line 182

def valid?
  true
end