Class: CyberSource::Ptsv2payoutsfxratesOrderInformationAmountDetails
- Inherits:
-
Object
- Object
- CyberSource::Ptsv2payoutsfxratesOrderInformationAmountDetails
- Defined in:
- lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb
Instance Attribute Summary collapse
-
#destination_amount ⇒ Object
Amount in your destination's local pricing currency.
-
#destination_currency ⇒ Object
Your destination pricing currency code.
-
#markup_rate ⇒ Object
The markup between the offer exchange rate and wholesale rates, i.e.
-
#original_amount ⇒ Object
Amount in your original local pricing currency.
-
#original_currency ⇒ Object
Your local pricing currency code.
-
#settlement_currency ⇒ Object
The currency in which Visa or Mastercard settles with the acquirer/acquirer.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv2payoutsfxratesOrderInformationAmountDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv2payoutsfxratesOrderInformationAmountDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'markupRate') self.markup_rate = attributes[:'markupRate'] end if attributes.has_key?(:'settlementCurrency') self.settlement_currency = attributes[:'settlementCurrency'] end if attributes.has_key?(:'originalAmount') self.original_amount = attributes[:'originalAmount'] end if attributes.has_key?(:'originalCurrency') self.original_currency = attributes[:'originalCurrency'] end if attributes.has_key?(:'destinationAmount') self.destination_amount = attributes[:'destinationAmount'] end if attributes.has_key?(:'destinationCurrency') self.destination_currency = attributes[:'destinationCurrency'] end end |
Instance Attribute Details
#destination_amount ⇒ Object
Amount in your destination's local pricing currency. This value cannot be negative. You can include a decimal point (.) in this field to denote the currency exponent, but you cannot include any other special characters. If needed, CyberSource truncates the amount to the correct number of decimal places.
29 30 31 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 29 def destination_amount @destination_amount end |
#destination_currency ⇒ Object
Your destination pricing currency code. Use ISO 4217 3-Alpha Currency Codes.
32 33 34 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 32 def destination_currency @destination_currency end |
#markup_rate ⇒ Object
The markup between the offer exchange rate and wholesale rates, i.e. the mark up. Expressed as a percentage of 100, e.g. 3.75. If the markup value is not supplied in the API, and the Acquiring BIN is provided, the markup configured during onboarding will be picked up and applied to the transaction. To override any markup defaults set up on the account, always send a markup value of 0.00 to indicate 0% markup. Supported by Visa Direct.
17 18 19 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 17 def markup_rate @markup_rate end |
#original_amount ⇒ Object
Amount in your original local pricing currency. This value cannot be negative. You can include a decimal point (.) in this field to denote the currency exponent, but you cannot include any other special characters. If needed, CyberSource truncates the amount to the correct number of decimal places.
23 24 25 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 23 def original_amount @original_amount end |
#original_currency ⇒ Object
Your local pricing currency code. Use ISO 4217 3-Alpha Currency Codes.
26 27 28 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 26 def original_currency @original_currency end |
#settlement_currency ⇒ Object
The currency in which Visa or Mastercard settles with the acquirer/acquirer. Use ISO 4217 3-Alpha Currency Codes.
20 21 22 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 20 def settlement_currency @settlement_currency end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 35 def self.attribute_map { :'markup_rate' => :'markupRate', :'settlement_currency' => :'settlementCurrency', :'original_amount' => :'originalAmount', :'original_currency' => :'originalCurrency', :'destination_amount' => :'destinationAmount', :'destination_currency' => :'destinationCurrency' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 47 def self.json_map { :'markup_rate' => :'markup_rate', :'settlement_currency' => :'settlement_currency', :'original_amount' => :'original_amount', :'original_currency' => :'original_currency', :'destination_amount' => :'destination_amount', :'destination_currency' => :'destination_currency' } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 59 def self.swagger_types { :'markup_rate' => :'String', :'settlement_currency' => :'String', :'original_amount' => :'String', :'original_currency' => :'String', :'destination_amount' => :'String', :'destination_currency' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && markup_rate == o.markup_rate && settlement_currency == o.settlement_currency && original_amount == o.original_amount && original_currency == o.original_currency && destination_amount == o.destination_amount && destination_currency == o.destination_currency end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 219 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 285 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 198 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
185 186 187 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 185 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 191 def hash [markup_rate, settlement_currency, original_amount, original_currency, destination_amount, destination_currency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 105 def list_invalid_properties invalid_properties = Array.new if @original_currency.nil? invalid_properties.push('invalid value for "original_currency", original_currency cannot be nil.') end if @destination_currency.nil? invalid_properties.push('invalid value for "destination_currency", destination_currency cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
265 266 267 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 265 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 259 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 124 |
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_order_information_amount_details.rb', line 120 def valid? return false if @original_currency.nil? return false if @destination_currency.nil? true end |