Class: CyberSource::Ptsv2payoutsfxratesProcessingInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Ptsv2payoutsfxratesProcessingInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 59

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'transactionType')
    self.transaction_type = attributes[:'transactionType']
  end

  if attributes.has_key?(:'clearingSystem')
    self.clearing_system = attributes[:'clearingSystem']
  end

  if attributes.has_key?(:'transactionTypeIndicator')
    self.transaction_type_indicator = attributes[:'transactionTypeIndicator']
  end

  if attributes.has_key?(:'routing')
    self.routing = attributes[:'routing']
  end
end

Instance Attribute Details

#clearing_systemObject

System used for clearing. Values: - SINGLE - DUAL Supported for Mastercard Send.



20
21
22
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 20

def clearing_system
  @clearing_system
end

#routingObject

Returns the value of attribute routing.



25
26
27
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 25

def routing
  @routing
end

#transaction_typeObject

Indicate that the FX rate is for a push (OCT) or pull (AFT) transaction. If the field is not passed, it defaults to PUSH (OCT). Enum: PUSH, PULL Supported for Visa Direct.



17
18
19
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 17

def transaction_type
  @transaction_type
end

#transaction_type_indicatorObject

The Mastercard Transaction Type Indicator is an alphanumeric or numeric code that identifies the business purpose and transaction category for Mastercard‑routed payments. It is used by the Mastercard network to support correct processing, compliance controls, risk evaluation, and reporting. This field is treated as a pass‑through parameter. The indicator is forwarded as provided to downstream processors and the Mastercard network, where validation and interpretation occur. Supplying an incorrect or missing value may result in network declines, misclassification, or compliance issues with Mastercard. Example values: - C07 or 204 – General person‑to‑person - C55 or 208 – Business disbursement - C65 or 213 – Business‑to‑business transfer - P70 or 231 – Cryptocurrency Important: Clients are responsible for ensuring the value accurately reflects the transaction intent and complies with Mastercard network requirements.



23
24
25
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 23

def transaction_type_indicator
  @transaction_type_indicator
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 28

def self.attribute_map
  {
    :'transaction_type' => :'transactionType',
    :'clearing_system' => :'clearingSystem',
    :'transaction_type_indicator' => :'transactionTypeIndicator',
    :'routing' => :'routing'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



38
39
40
41
42
43
44
45
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 38

def self.json_map
  {
    :'transaction_type' => :'transaction_type',
    :'clearing_system' => :'clearing_system',
    :'transaction_type_indicator' => :'transaction_type_indicator',
    :'routing' => :'routing'
  }
end

.swagger_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 48

def self.swagger_types
  {
    :'transaction_type' => :'String',
    :'clearing_system' => :'String',
    :'transaction_type_indicator' => :'String',
    :'routing' => :'Ptsv2payoutsfxratesProcessingInformationRouting'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



115
116
117
118
119
120
121
122
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 115

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      transaction_type == o.transaction_type &&
      clearing_system == o.clearing_system &&
      transaction_type_indicator == o.transaction_type_indicator &&
      routing == o.routing
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 160

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 226

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 139

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


126
127
128
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 126

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



132
133
134
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 132

def hash
  [transaction_type, clearing_system, transaction_type_indicator, routing].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



84
85
86
87
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 84

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



206
207
208
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 206

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



200
201
202
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 200

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



91
92
93
# File 'lib/cybersource_rest_client/models/ptsv2payoutsfxrates_processing_information.rb', line 91

def valid?
  true
end