Class: CyberSource::PullFunds201ResponseProcessorInformation
- Inherits:
-
Object
- Object
- CyberSource::PullFunds201ResponseProcessorInformation
- Defined in:
- lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb
Instance Attribute Summary collapse
-
#approval_code ⇒ Object
Issuer-generated approval code for the transaction.
-
#avs ⇒ Object
Returns the value of attribute avs.
-
#card_verification ⇒ Object
Returns the value of attribute card_verification.
-
#consumer_authentication_response ⇒ Object
Returns the value of attribute consumer_authentication_response.
-
#customer ⇒ Object
Returns the value of attribute customer.
-
#electronic_verification_results ⇒ Object
Returns the value of attribute electronic_verification_results.
-
#response_code ⇒ Object
Transaction status from the processor.
-
#response_details ⇒ Object
This field might contain information about a decline.
-
#retrieval_reference_number ⇒ Object
This field contains a number that is used with other data elements as a key to identify and track all messages related to a given cardholder transaction; that is, to a given transaction set.
-
#system_trace_audit_number ⇒ Object
This field is returned by authorization and incremental authorization services.
-
#transaction_id ⇒ Object
Network transaction identifier (TID).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PullFunds201ResponseProcessorInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PullFunds201ResponseProcessorInformation
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'systemTraceAuditNumber') self.system_trace_audit_number = attributes[:'systemTraceAuditNumber'] end if attributes.has_key?(:'approvalCode') self.approval_code = attributes[:'approvalCode'] end if attributes.has_key?(:'responseCode') self.response_code = attributes[:'responseCode'] end if attributes.has_key?(:'transactionId') self.transaction_id = attributes[:'transactionId'] end if attributes.has_key?(:'consumerAuthenticationResponse') self.consumer_authentication_response = attributes[:'consumerAuthenticationResponse'] end if attributes.has_key?(:'retrievalReferenceNumber') self.retrieval_reference_number = attributes[:'retrievalReferenceNumber'] end if attributes.has_key?(:'avs') self.avs = attributes[:'avs'] end if attributes.has_key?(:'responseDetails') self.response_details = attributes[:'responseDetails'] end if attributes.has_key?(:'customer') self.customer = attributes[:'customer'] end if attributes.has_key?(:'electronicVerificationResults') self.electronic_verification_results = attributes[:'electronicVerificationResults'] end if attributes.has_key?(:'cardVerification') self.card_verification = attributes[:'cardVerification'] end end |
Instance Attribute Details
#approval_code ⇒ Object
Issuer-generated approval code for the transaction.
20 21 22 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 20 def approval_code @approval_code end |
#avs ⇒ Object
Returns the value of attribute avs.
33 34 35 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 33 def avs @avs end |
#card_verification ⇒ Object
Returns the value of attribute card_verification.
42 43 44 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 42 def card_verification @card_verification end |
#consumer_authentication_response ⇒ Object
Returns the value of attribute consumer_authentication_response.
28 29 30 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 28 def consumer_authentication_response @consumer_authentication_response end |
#customer ⇒ Object
Returns the value of attribute customer.
38 39 40 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 38 def customer @customer end |
#electronic_verification_results ⇒ Object
Returns the value of attribute electronic_verification_results.
40 41 42 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 40 def electronic_verification_results @electronic_verification_results end |
#response_code ⇒ Object
Transaction status from the processor.
23 24 25 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 23 def response_code @response_code end |
#response_details ⇒ Object
This field might contain information about a decline.
36 37 38 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 36 def response_details @response_details end |
#retrieval_reference_number ⇒ Object
This field contains a number that is used with other data elements as a key to identify and track all messages related to a given cardholder transaction; that is, to a given transaction set. Recommended format: ydddhhnnnnnn Positions 1-4: The yddd equivalent of the date, where y = 0-9 and ddd = 001 – 366. Positions 5-12: A unique identification number generated by the merchant or assigned by Cybersource.
31 32 33 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 31 def retrieval_reference_number @retrieval_reference_number end |
#system_trace_audit_number ⇒ Object
This field is returned by authorization and incremental authorization services. System trace number that must be printed on the customer’s receipt.
17 18 19 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 17 def system_trace_audit_number @system_trace_audit_number end |
#transaction_id ⇒ Object
Network transaction identifier (TID). This value can be used to identify a specific transaction when you are discussing the transaction with your processor.
26 27 28 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 26 def transaction_id @transaction_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 45 def self.attribute_map { :'system_trace_audit_number' => :'systemTraceAuditNumber', :'approval_code' => :'approvalCode', :'response_code' => :'responseCode', :'transaction_id' => :'transactionId', :'consumer_authentication_response' => :'consumerAuthenticationResponse', :'retrieval_reference_number' => :'retrievalReferenceNumber', :'avs' => :'avs', :'response_details' => :'responseDetails', :'customer' => :'customer', :'electronic_verification_results' => :'electronicVerificationResults', :'card_verification' => :'cardVerification' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 62 def self.json_map { :'system_trace_audit_number' => :'system_trace_audit_number', :'approval_code' => :'approval_code', :'response_code' => :'response_code', :'transaction_id' => :'transaction_id', :'consumer_authentication_response' => :'consumer_authentication_response', :'retrieval_reference_number' => :'retrieval_reference_number', :'avs' => :'avs', :'response_details' => :'response_details', :'customer' => :'customer', :'electronic_verification_results' => :'electronic_verification_results', :'card_verification' => :'card_verification' } end |
.swagger_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 79 def self.swagger_types { :'system_trace_audit_number' => :'String', :'approval_code' => :'String', :'response_code' => :'String', :'transaction_id' => :'String', :'consumer_authentication_response' => :'PullFunds201ResponseProcessorInformationConsumerAuthenticationResponse', :'retrieval_reference_number' => :'String', :'avs' => :'PtsV2PayoutsPost201ResponseProcessorInformationAvs', :'response_details' => :'String', :'customer' => :'PtsV2PayoutsPost201ResponseProcessorInformationCustomer', :'electronic_verification_results' => :'PtsV2PayoutsPost201ResponseProcessorInformationElectronicVerificationResults', :'card_verification' => :'PtsV2PaymentsPost201ResponseProcessorInformationCardVerification' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && system_trace_audit_number == o.system_trace_audit_number && approval_code == o.approval_code && response_code == o.response_code && transaction_id == o.transaction_id && consumer_authentication_response == o.consumer_authentication_response && retrieval_reference_number == o.retrieval_reference_number && avs == o.avs && response_details == o.response_details && customer == o.customer && electronic_verification_results == o.electronic_verification_results && card_verification == o.card_verification end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 251 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 317 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 230 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
217 218 219 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 217 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
223 224 225 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 223 def hash [system_trace_audit_number, approval_code, response_code, transaction_id, consumer_authentication_response, retrieval_reference_number, avs, response_details, customer, electronic_verification_results, card_verification].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 150 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
297 298 299 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 297 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
291 292 293 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 291 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 |
# File 'lib/cybersource_rest_client/models/pull_funds201_response_processor_information.rb', line 157 def valid? true end |