Class: CyberSource::PushFunds201ResponseIssuerInformation
- Inherits:
-
Object
- Object
- CyberSource::PushFunds201ResponseIssuerInformation
- Defined in:
- lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb
Instance Attribute Summary collapse
-
#oct_cross_border_participant_indicator ⇒ Object
Cross-border indicator for push funds (OCT).
-
#oct_domestic_participant_indicator ⇒ Object
Domestic indicator for Push funds (OCT).
-
#oct_money_transfer_cross_border_indicator ⇒ Object
Indicates whether cross-border money transfer OCTs (push funds) are allowed.
-
#oct_money_transfer_domestic_indicator ⇒ Object
Indicates whether domestic money transfer OCTs (push funds) are allowed.
-
#oct_money_transfer_fast_funds_cross_border_indicator ⇒ Object
Indicates whether cross-border money transfer OCTs (fast push funds) are allowed.
-
#oct_money_transfer_fast_funds_domestic_indicator ⇒ Object
Indicates whether domestic money transfer OCTs (fast push funds) are allowed.
-
#oct_money_transfer_merchant_country_restricted ⇒ Object
This field indicates if the recipient issuer can accept push funds (OCT) transactions from the merchant country.
-
#oct_non_money_transfer_cross_border_indicator ⇒ Object
Indicates whether cross-border non-money transfer OCTs (push funds) are allowed.
-
#oct_non_money_transfer_domestic_indicator ⇒ Object
Indicates whether domestic non-money transfer OCTs (push funds) are allowed.
-
#oct_non_money_transfer_fast_funds_cross_border_indicator ⇒ Object
Indicates whether cross-border non-money transfer OCTs (fast push funds) are allowed.
-
#oct_non_money_transfer_fast_funds_domestic_indicator ⇒ Object
Indicates whether domestic non-money transfer OCTs (fast push funds) are allowed.
-
#oct_online_gambling_cross_border_indicator ⇒ Object
Indicates whether cross-border gambling OCTs (push funds) are allowed.
-
#oct_online_gambling_domestic_indicator ⇒ Object
Indicates whether domestic gambling OCTs (push funds) are allowed.
-
#oct_online_gambling_fast_funds_cross_border_indicator ⇒ Object
Indicates whether cross-border gambling OCTs (fast push funds) are allowed.
-
#oct_online_gambling_fast_funds_domestic_indicator ⇒ Object
Indicates whether domestic gambling OCTs (fast push funds) are allowed.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PushFunds201ResponseIssuerInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PushFunds201ResponseIssuerInformation
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 126 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'octDomesticParticipantIndicator') self.oct_domestic_participant_indicator = attributes[:'octDomesticParticipantIndicator'] end if attributes.has_key?(:'octCrossBorderParticipantIndicator') self.oct_cross_border_participant_indicator = attributes[:'octCrossBorderParticipantIndicator'] end if attributes.has_key?(:'octMoneyTransferDomesticIndicator') self.oct_money_transfer_domestic_indicator = attributes[:'octMoneyTransferDomesticIndicator'] end if attributes.has_key?(:'octMoneyTransferCrossBorderIndicator') self.oct_money_transfer_cross_border_indicator = attributes[:'octMoneyTransferCrossBorderIndicator'] end if attributes.has_key?(:'octMoneyTransferFastFundsDomesticIndicator') self.oct_money_transfer_fast_funds_domestic_indicator = attributes[:'octMoneyTransferFastFundsDomesticIndicator'] end if attributes.has_key?(:'octMoneyTransferFastFundsCrossBorderIndicator') self.oct_money_transfer_fast_funds_cross_border_indicator = attributes[:'octMoneyTransferFastFundsCrossBorderIndicator'] end if attributes.has_key?(:'octMoneyTransferMerchantCountryRestricted') self.oct_money_transfer_merchant_country_restricted = attributes[:'octMoneyTransferMerchantCountryRestricted'] end if attributes.has_key?(:'octNonMoneyTransferDomesticIndicator') self.oct_non_money_transfer_domestic_indicator = attributes[:'octNonMoneyTransferDomesticIndicator'] end if attributes.has_key?(:'octNonMoneyTransferCrossBorderIndicator') self.oct_non_money_transfer_cross_border_indicator = attributes[:'octNonMoneyTransferCrossBorderIndicator'] end if attributes.has_key?(:'octNonMoneyTransferFastFundsDomesticIndicator') self.oct_non_money_transfer_fast_funds_domestic_indicator = attributes[:'octNonMoneyTransferFastFundsDomesticIndicator'] end if attributes.has_key?(:'octNonMoneyTransferFastFundsCrossBorderIndicator') self.oct_non_money_transfer_fast_funds_cross_border_indicator = attributes[:'octNonMoneyTransferFastFundsCrossBorderIndicator'] end if attributes.has_key?(:'octOnlineGamblingDomesticIndicator') self.oct_online_gambling_domestic_indicator = attributes[:'octOnlineGamblingDomesticIndicator'] end if attributes.has_key?(:'octOnlineGamblingCrossBorderIndicator') self.oct_online_gambling_cross_border_indicator = attributes[:'octOnlineGamblingCrossBorderIndicator'] end if attributes.has_key?(:'octOnlineGamblingFastFundsDomesticIndicator') self.oct_online_gambling_fast_funds_domestic_indicator = attributes[:'octOnlineGamblingFastFundsDomesticIndicator'] end if attributes.has_key?(:'octOnlineGamblingFastFundsCrossBorderIndicator') self.oct_online_gambling_fast_funds_cross_border_indicator = attributes[:'octOnlineGamblingFastFundsCrossBorderIndicator'] end end |
Instance Attribute Details
#oct_cross_border_participant_indicator ⇒ Object
Cross-border indicator for push funds (OCT). If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
20 21 22 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 20 def oct_cross_border_participant_indicator @oct_cross_border_participant_indicator end |
#oct_domestic_participant_indicator ⇒ Object
Domestic indicator for Push funds (OCT). If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
17 18 19 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 17 def oct_domestic_participant_indicator @oct_domestic_participant_indicator end |
#oct_money_transfer_cross_border_indicator ⇒ Object
Indicates whether cross-border money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
26 27 28 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 26 def oct_money_transfer_cross_border_indicator @oct_money_transfer_cross_border_indicator end |
#oct_money_transfer_domestic_indicator ⇒ Object
Indicates whether domestic money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
23 24 25 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 23 def oct_money_transfer_domestic_indicator @oct_money_transfer_domestic_indicator end |
#oct_money_transfer_fast_funds_cross_border_indicator ⇒ Object
Indicates whether cross-border money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
32 33 34 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 32 def oct_money_transfer_fast_funds_cross_border_indicator @oct_money_transfer_fast_funds_cross_border_indicator end |
#oct_money_transfer_fast_funds_domestic_indicator ⇒ Object
Indicates whether domestic money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
29 30 31 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 29 def oct_money_transfer_fast_funds_domestic_indicator @oct_money_transfer_fast_funds_domestic_indicator end |
#oct_money_transfer_merchant_country_restricted ⇒ Object
This field indicates if the recipient issuer can accept push funds (OCT) transactions from the merchant country. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
35 36 37 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 35 def oct_money_transfer_merchant_country_restricted @oct_money_transfer_merchant_country_restricted end |
#oct_non_money_transfer_cross_border_indicator ⇒ Object
Indicates whether cross-border non-money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
41 42 43 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 41 def oct_non_money_transfer_cross_border_indicator @oct_non_money_transfer_cross_border_indicator end |
#oct_non_money_transfer_domestic_indicator ⇒ Object
Indicates whether domestic non-money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
38 39 40 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 38 def oct_non_money_transfer_domestic_indicator @oct_non_money_transfer_domestic_indicator end |
#oct_non_money_transfer_fast_funds_cross_border_indicator ⇒ Object
Indicates whether cross-border non-money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
47 48 49 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 47 def oct_non_money_transfer_fast_funds_cross_border_indicator @oct_non_money_transfer_fast_funds_cross_border_indicator end |
#oct_non_money_transfer_fast_funds_domestic_indicator ⇒ Object
Indicates whether domestic non-money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
44 45 46 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 44 def oct_non_money_transfer_fast_funds_domestic_indicator @oct_non_money_transfer_fast_funds_domestic_indicator end |
#oct_online_gambling_cross_border_indicator ⇒ Object
Indicates whether cross-border gambling OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
53 54 55 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 53 def oct_online_gambling_cross_border_indicator @oct_online_gambling_cross_border_indicator end |
#oct_online_gambling_domestic_indicator ⇒ Object
Indicates whether domestic gambling OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
50 51 52 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 50 def oct_online_gambling_domestic_indicator @oct_online_gambling_domestic_indicator end |
#oct_online_gambling_fast_funds_cross_border_indicator ⇒ Object
Indicates whether cross-border gambling OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
59 60 61 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 59 def oct_online_gambling_fast_funds_cross_border_indicator @oct_online_gambling_fast_funds_cross_border_indicator end |
#oct_online_gambling_fast_funds_domestic_indicator ⇒ Object
Indicates whether domestic gambling OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
56 57 58 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 56 def oct_online_gambling_fast_funds_domestic_indicator @oct_online_gambling_fast_funds_domestic_indicator end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 62 def self.attribute_map { :'oct_domestic_participant_indicator' => :'octDomesticParticipantIndicator', :'oct_cross_border_participant_indicator' => :'octCrossBorderParticipantIndicator', :'oct_money_transfer_domestic_indicator' => :'octMoneyTransferDomesticIndicator', :'oct_money_transfer_cross_border_indicator' => :'octMoneyTransferCrossBorderIndicator', :'oct_money_transfer_fast_funds_domestic_indicator' => :'octMoneyTransferFastFundsDomesticIndicator', :'oct_money_transfer_fast_funds_cross_border_indicator' => :'octMoneyTransferFastFundsCrossBorderIndicator', :'oct_money_transfer_merchant_country_restricted' => :'octMoneyTransferMerchantCountryRestricted', :'oct_non_money_transfer_domestic_indicator' => :'octNonMoneyTransferDomesticIndicator', :'oct_non_money_transfer_cross_border_indicator' => :'octNonMoneyTransferCrossBorderIndicator', :'oct_non_money_transfer_fast_funds_domestic_indicator' => :'octNonMoneyTransferFastFundsDomesticIndicator', :'oct_non_money_transfer_fast_funds_cross_border_indicator' => :'octNonMoneyTransferFastFundsCrossBorderIndicator', :'oct_online_gambling_domestic_indicator' => :'octOnlineGamblingDomesticIndicator', :'oct_online_gambling_cross_border_indicator' => :'octOnlineGamblingCrossBorderIndicator', :'oct_online_gambling_fast_funds_domestic_indicator' => :'octOnlineGamblingFastFundsDomesticIndicator', :'oct_online_gambling_fast_funds_cross_border_indicator' => :'octOnlineGamblingFastFundsCrossBorderIndicator' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 83 def self.json_map { :'oct_domestic_participant_indicator' => :'oct_domestic_participant_indicator', :'oct_cross_border_participant_indicator' => :'oct_cross_border_participant_indicator', :'oct_money_transfer_domestic_indicator' => :'oct_money_transfer_domestic_indicator', :'oct_money_transfer_cross_border_indicator' => :'oct_money_transfer_cross_border_indicator', :'oct_money_transfer_fast_funds_domestic_indicator' => :'oct_money_transfer_fast_funds_domestic_indicator', :'oct_money_transfer_fast_funds_cross_border_indicator' => :'oct_money_transfer_fast_funds_cross_border_indicator', :'oct_money_transfer_merchant_country_restricted' => :'oct_money_transfer_merchant_country_restricted', :'oct_non_money_transfer_domestic_indicator' => :'oct_non_money_transfer_domestic_indicator', :'oct_non_money_transfer_cross_border_indicator' => :'oct_non_money_transfer_cross_border_indicator', :'oct_non_money_transfer_fast_funds_domestic_indicator' => :'oct_non_money_transfer_fast_funds_domestic_indicator', :'oct_non_money_transfer_fast_funds_cross_border_indicator' => :'oct_non_money_transfer_fast_funds_cross_border_indicator', :'oct_online_gambling_domestic_indicator' => :'oct_online_gambling_domestic_indicator', :'oct_online_gambling_cross_border_indicator' => :'oct_online_gambling_cross_border_indicator', :'oct_online_gambling_fast_funds_domestic_indicator' => :'oct_online_gambling_fast_funds_domestic_indicator', :'oct_online_gambling_fast_funds_cross_border_indicator' => :'oct_online_gambling_fast_funds_cross_border_indicator' } end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 104 def self.swagger_types { :'oct_domestic_participant_indicator' => :'BOOLEAN', :'oct_cross_border_participant_indicator' => :'BOOLEAN', :'oct_money_transfer_domestic_indicator' => :'BOOLEAN', :'oct_money_transfer_cross_border_indicator' => :'BOOLEAN', :'oct_money_transfer_fast_funds_domestic_indicator' => :'BOOLEAN', :'oct_money_transfer_fast_funds_cross_border_indicator' => :'BOOLEAN', :'oct_money_transfer_merchant_country_restricted' => :'BOOLEAN', :'oct_non_money_transfer_domestic_indicator' => :'BOOLEAN', :'oct_non_money_transfer_cross_border_indicator' => :'BOOLEAN', :'oct_non_money_transfer_fast_funds_domestic_indicator' => :'BOOLEAN', :'oct_non_money_transfer_fast_funds_cross_border_indicator' => :'BOOLEAN', :'oct_online_gambling_domestic_indicator' => :'BOOLEAN', :'oct_online_gambling_cross_border_indicator' => :'BOOLEAN', :'oct_online_gambling_fast_funds_domestic_indicator' => :'BOOLEAN', :'oct_online_gambling_fast_funds_cross_border_indicator' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && oct_domestic_participant_indicator == o.oct_domestic_participant_indicator && oct_cross_border_participant_indicator == o.oct_cross_border_participant_indicator && oct_money_transfer_domestic_indicator == o.oct_money_transfer_domestic_indicator && oct_money_transfer_cross_border_indicator == o.oct_money_transfer_cross_border_indicator && oct_money_transfer_fast_funds_domestic_indicator == o.oct_money_transfer_fast_funds_domestic_indicator && oct_money_transfer_fast_funds_cross_border_indicator == o.oct_money_transfer_fast_funds_cross_border_indicator && oct_money_transfer_merchant_country_restricted == o.oct_money_transfer_merchant_country_restricted && oct_non_money_transfer_domestic_indicator == o.oct_non_money_transfer_domestic_indicator && oct_non_money_transfer_cross_border_indicator == o.oct_non_money_transfer_cross_border_indicator && oct_non_money_transfer_fast_funds_domestic_indicator == o.oct_non_money_transfer_fast_funds_domestic_indicator && oct_non_money_transfer_fast_funds_cross_border_indicator == o.oct_non_money_transfer_fast_funds_cross_border_indicator && oct_online_gambling_domestic_indicator == o.oct_online_gambling_domestic_indicator && oct_online_gambling_cross_border_indicator == o.oct_online_gambling_cross_border_indicator && oct_online_gambling_fast_funds_domestic_indicator == o.oct_online_gambling_fast_funds_domestic_indicator && oct_online_gambling_fast_funds_cross_border_indicator == o.oct_online_gambling_fast_funds_cross_border_indicator end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 264 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 330 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 243 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
230 231 232 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 230 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 236 def hash [oct_domestic_participant_indicator, oct_cross_border_participant_indicator, oct_money_transfer_domestic_indicator, oct_money_transfer_cross_border_indicator, oct_money_transfer_fast_funds_domestic_indicator, oct_money_transfer_fast_funds_cross_border_indicator, oct_money_transfer_merchant_country_restricted, oct_non_money_transfer_domestic_indicator, oct_non_money_transfer_cross_border_indicator, oct_non_money_transfer_fast_funds_domestic_indicator, oct_non_money_transfer_fast_funds_cross_border_indicator, oct_online_gambling_domestic_indicator, oct_online_gambling_cross_border_indicator, oct_online_gambling_fast_funds_domestic_indicator, oct_online_gambling_fast_funds_cross_border_indicator].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 195 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
310 311 312 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 310 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 304 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_issuer_information.rb', line 202 def valid? true end |