Class: CyberSource::Tmsv2TokenizedCard

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Tmsv2TokenizedCard

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 153

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.has_key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'enrollmentId')
    self.enrollment_id = attributes[:'enrollmentId']
  end

  if attributes.has_key?(:'tokenReferenceId')
    self.token_reference_id = attributes[:'tokenReferenceId']
  end

  if attributes.has_key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.has_key?(:'expirationMonth')
    self.expiration_month = attributes[:'expirationMonth']
  end

  if attributes.has_key?(:'expirationYear')
    self.expiration_year = attributes[:'expirationYear']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.has_key?(:'cryptogram')
    self.cryptogram = attributes[:'cryptogram']
  end

  if attributes.has_key?(:'securityCode')
    self.security_code = attributes[:'securityCode']
  end

  if attributes.has_key?(:'eci')
    self.eci = attributes[:'eci']
  end

  if attributes.has_key?(:'requestorId')
    self.requestor_id = attributes[:'requestorId']
  end

  if attributes.has_key?(:'paymentAccountReference')
    self. = attributes[:'paymentAccountReference']
  end

  if attributes.has_key?(:'applicationTransactionCounter')
    self.application_transaction_counter = attributes[:'applicationTransactionCounter']
  end

  if attributes.has_key?(:'card')
    self.card = attributes[:'card']
  end

  if attributes.has_key?(:'verificationResults')
    self.verification_results = attributes[:'verificationResults']
  end

  if attributes.has_key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#application_transaction_counterObject

A sequence counter used as part of the input to the TAVV cryptogram and it is incremented for each cryptogram generation. This field is only returned for Visa network tokens.



65
66
67
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 65

def application_transaction_counter
  @application_transaction_counter
end

#cardObject

Returns the value of attribute card.



67
68
69
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 67

def card
  @card
end

#cryptogramObject

Value generated by the card association to be used alongside the network token for processing a payment. This field is returned by default for Visa and Mastercard network tokens. It can also be explicitly requested using paymentCredentialType: CRYPTOGRAM.



50
51
52
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 50

def cryptogram
  @cryptogram
end

#eciObject

Raw Electronic Commerce Indicator provided by the card association with the result of the cardholder authentication.



56
57
58
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 56

def eci
  @eci
end

#enrollment_idObject

Unique id to identify this PAN/ enrollment.



29
30
31
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 29

def enrollment_id
  @enrollment_id
end

#expiration_monthObject

Two-digit month in which the network token expires. Format: ‘MM`. Possible Values: `01` through `12`.



38
39
40
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 38

def expiration_month
  @expiration_month
end

#expiration_yearObject

Four-digit year in which the network token expires. Format: ‘YYYY`.



41
42
43
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 41

def expiration_year
  @expiration_year
end

#idObject

The Id of the Tokenized Card.



17
18
19
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 17

def id
  @id
end

#metadataObject

Returns the value of attribute metadata.



71
72
73
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 71

def 
  @metadata
end

#numberObject

The token requestor’s network token for the provided PAN and consumer Id, if available.



35
36
37
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 35

def number
  @number
end

#objectObject

The type. Possible Values: - tokenizedCard



20
21
22
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 20

def object
  @object
end

#payment_account_referenceObject

Payment account reference.



62
63
64
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 62

def 
  @payment_account_reference
end

#reasonObject

Indicates the reason why the network token provision request failed. Possible Values: - INVALID_REQUEST : The network token provision request contained invalid data. - CARD_VERIFICATION_FAILED : The network token provision request contained data that could not be verified. - CARD_NOT_ELIGIBLE : Card can currently not be used with issuer for tokenization. - CARD_NOT_ALLOWED : Card can currently not be used with card association for tokenization. - DECLINED : Card can currently not be used with issuer for tokenization. - SERVICE_UNAVAILABLE : The network token service was unavailable or timed out. - SYSTEM_ERROR : An unexpected error occurred with network token service, check configuration.



47
48
49
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 47

def reason
  @reason
end

#requestor_idObject

11-digit identifier that uniquely identifies the Token Requestor.



59
60
61
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 59

def requestor_id
  @requestor_id
end

#security_codeObject

Dynamic number generated by the card association to be used alongside the network token for processing a payment. - For American Express: Dynamic Card Secure Code (DCSC) returned by default. - For Visa: DTVV cryptogram when explicitly requested using paymentCredentialType: SECURITY_CODE. It can also be explicitly requested using paymentCredentialType: SECURITY_CODE.



53
54
55
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 53

def security_code
  @security_code
end

#sourceObject

Source of the card details. Possible Values: - ONFILE - TOKEN - ISSUER



23
24
25
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 23

def source
  @source
end

#stateObject

State of the network token or network token provision. Possible Values: - ACTIVE : Network token is active. - SUSPENDED : Network token is suspended. This state can change back to ACTIVE. - DELETED : This is a final state for a network token instance. - UNPROVISIONED : A previous network token.



26
27
28
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 26

def state
  @state
end

#token_reference_idObject

Unique ID for netwrok token.



32
33
34
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 32

def token_reference_id
  @token_reference_id
end

#typeObject

The type of card (Card Network). Possible Values: - visa - mastercard - americanexpress



44
45
46
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 44

def type
  @type
end

#verification_resultsObject

Returns the value of attribute verification_results.



69
70
71
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 69

def verification_results
  @verification_results
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 74

def self.attribute_map
  {
    :'id' => :'id',
    :'object' => :'object',
    :'source' => :'source',
    :'state' => :'state',
    :'enrollment_id' => :'enrollmentId',
    :'token_reference_id' => :'tokenReferenceId',
    :'number' => :'number',
    :'expiration_month' => :'expirationMonth',
    :'expiration_year' => :'expirationYear',
    :'type' => :'type',
    :'reason' => :'reason',
    :'cryptogram' => :'cryptogram',
    :'security_code' => :'securityCode',
    :'eci' => :'eci',
    :'requestor_id' => :'requestorId',
    :'payment_account_reference' => :'paymentAccountReference',
    :'application_transaction_counter' => :'applicationTransactionCounter',
    :'card' => :'card',
    :'verification_results' => :'verificationResults',
    :'metadata' => :'metadata'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 100

def self.json_map
  {
    :'id' => :'id',
    :'object' => :'object',
    :'source' => :'source',
    :'state' => :'state',
    :'enrollment_id' => :'enrollment_id',
    :'token_reference_id' => :'token_reference_id',
    :'number' => :'number',
    :'expiration_month' => :'expiration_month',
    :'expiration_year' => :'expiration_year',
    :'type' => :'type',
    :'reason' => :'reason',
    :'cryptogram' => :'cryptogram',
    :'security_code' => :'security_code',
    :'eci' => :'eci',
    :'requestor_id' => :'requestor_id',
    :'payment_account_reference' => :'payment_account_reference',
    :'application_transaction_counter' => :'application_transaction_counter',
    :'card' => :'card',
    :'verification_results' => :'verification_results',
    :'metadata' => :'metadata'
  }
end

.swagger_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 126

def self.swagger_types
  {
    :'id' => :'String',
    :'object' => :'String',
    :'source' => :'String',
    :'state' => :'String',
    :'enrollment_id' => :'String',
    :'token_reference_id' => :'String',
    :'number' => :'String',
    :'expiration_month' => :'String',
    :'expiration_year' => :'String',
    :'type' => :'String',
    :'reason' => :'String',
    :'cryptogram' => :'String',
    :'security_code' => :'String',
    :'eci' => :'String',
    :'requestor_id' => :'String',
    :'payment_account_reference' => :'String',
    :'application_transaction_counter' => :'String',
    :'card' => :'Tmsv2TokenizedCardCard',
    :'verification_results' => :'Tmsv2TokenizedCardVerificationResults',
    :'metadata' => :'Tmsv2TokenizedCardMetadata'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      object == o.object &&
      source == o.source &&
      state == o.state &&
      enrollment_id == o.enrollment_id &&
      token_reference_id == o.token_reference_id &&
      number == o.number &&
      expiration_month == o.expiration_month &&
      expiration_year == o.expiration_year &&
      type == o.type &&
      reason == o.reason &&
      cryptogram == o.cryptogram &&
      security_code == o.security_code &&
      eci == o.eci &&
      requestor_id == o.requestor_id &&
       == o. &&
      application_transaction_counter == o.application_transaction_counter &&
      card == o.card &&
      verification_results == o.verification_results &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 322

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 388

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 301

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


288
289
290
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 288

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



294
295
296
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 294

def hash
  [id, object, source, state, enrollment_id, token_reference_id, number, expiration_month, expiration_year, type, reason, cryptogram, security_code, eci, requestor_id, , application_transaction_counter, card, verification_results, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



242
243
244
245
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 242

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 368

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
377
378
379
380
381
382
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 374

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



362
363
364
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 362

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



249
250
251
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card.rb', line 249

def valid?
  true
end