Class: CyberSource::Tmsv2TokenizedCardMetadataIssuerCapabilities

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb

Overview

Flags indicating what authentication, binding, and trusted-beneficiary enrollment capabilities the issuer supports. Supported only for VTS Tokens.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Tmsv2TokenizedCardMetadataIssuerCapabilities

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 79

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'deviceBindingSupported')
    self.device_binding_supported = attributes[:'deviceBindingSupported']
  end

  if attributes.has_key?(:'cardholderVerificationSupported')
    self.cardholder_verification_supported = attributes[:'cardholderVerificationSupported']
  end

  if attributes.has_key?(:'trustedBeneficiaryEnrollmentSupported')
    self.trusted_beneficiary_enrollment_supported = attributes[:'trustedBeneficiaryEnrollmentSupported']
  end

  if attributes.has_key?(:'delegatedAuthenticationSupported')
    self.delegated_authentication_supported = attributes[:'delegatedAuthenticationSupported']
  end

  if attributes.has_key?(:'oboDeviceBindingSupported')
    self.obo_device_binding_supported = attributes[:'oboDeviceBindingSupported']
  end

  if attributes.has_key?(:'tokenLcmNotificationsSupported')
    self.token_lcm_notifications_supported = attributes[:'tokenLcmNotificationsSupported']
  end

  if attributes.has_key?(:'fpanLcmNotificationsSupported')
    self.fpan_lcm_notifications_supported = attributes[:'fpanLcmNotificationsSupported']
  end
end

Instance Attribute Details

#cardholder_verification_supportedObject

Indicates if the issuer participates in step-up authentication that requires cardholder verification.



21
22
23
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 21

def cardholder_verification_supported
  @cardholder_verification_supported
end

#delegated_authentication_supportedObject

Indicates if the issuer supports delegated authentication. e.g allowing approved thrird parties to perform authentication on behalf of the issuer.



27
28
29
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 27

def delegated_authentication_supported
  @delegated_authentication_supported
end

#device_binding_supportedObject

Indicates if the issuer supports device binding.



18
19
20
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 18

def device_binding_supported
  @device_binding_supported
end

#fpan_lcm_notifications_supportedObject

Indicates if the issuer supports receiving PAN lifecycle management notifications. e.g receiving updates on changes to the underlying card’s status or attributes.



36
37
38
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 36

def fpan_lcm_notifications_supported
  @fpan_lcm_notifications_supported
end

#obo_device_binding_supportedObject

Indicates if the issuer supports on-behalf-of device binding. e.g allowing approved third parties to perform device binding on behalf of the issuer.



30
31
32
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 30

def obo_device_binding_supported
  @obo_device_binding_supported
end

#token_lcm_notifications_supportedObject

Indicates if the issuer supports receiving token lifecycle management notifications. e.g receiving updates on changes to the token’s status or attributes.



33
34
35
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 33

def token_lcm_notifications_supported
  @token_lcm_notifications_supported
end

#trusted_beneficiary_enrollment_supportedObject

Indicates if the issuer supports trusted beneficiary enrollment. e.g allowing cardholders to designate trusted merchants or payment recipients that can be exempt from step-up authentication.



24
25
26
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 24

def trusted_beneficiary_enrollment_supported
  @trusted_beneficiary_enrollment_supported
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 39

def self.attribute_map
  {
    :'device_binding_supported' => :'deviceBindingSupported',
    :'cardholder_verification_supported' => :'cardholderVerificationSupported',
    :'trusted_beneficiary_enrollment_supported' => :'trustedBeneficiaryEnrollmentSupported',
    :'delegated_authentication_supported' => :'delegatedAuthenticationSupported',
    :'obo_device_binding_supported' => :'oboDeviceBindingSupported',
    :'token_lcm_notifications_supported' => :'tokenLcmNotificationsSupported',
    :'fpan_lcm_notifications_supported' => :'fpanLcmNotificationsSupported'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 52

def self.json_map
  {
    :'device_binding_supported' => :'device_binding_supported',
    :'cardholder_verification_supported' => :'cardholder_verification_supported',
    :'trusted_beneficiary_enrollment_supported' => :'trusted_beneficiary_enrollment_supported',
    :'delegated_authentication_supported' => :'delegated_authentication_supported',
    :'obo_device_binding_supported' => :'obo_device_binding_supported',
    :'token_lcm_notifications_supported' => :'token_lcm_notifications_supported',
    :'fpan_lcm_notifications_supported' => :'fpan_lcm_notifications_supported'
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 65

def self.swagger_types
  {
    :'device_binding_supported' => :'BOOLEAN',
    :'cardholder_verification_supported' => :'BOOLEAN',
    :'trusted_beneficiary_enrollment_supported' => :'BOOLEAN',
    :'delegated_authentication_supported' => :'BOOLEAN',
    :'obo_device_binding_supported' => :'BOOLEAN',
    :'token_lcm_notifications_supported' => :'BOOLEAN',
    :'fpan_lcm_notifications_supported' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



129
130
131
132
133
134
135
136
137
138
139
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 129

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      device_binding_supported == o.device_binding_supported &&
      cardholder_verification_supported == o.cardholder_verification_supported &&
      trusted_beneficiary_enrollment_supported == o.trusted_beneficiary_enrollment_supported &&
      delegated_authentication_supported == o.delegated_authentication_supported &&
      obo_device_binding_supported == o.obo_device_binding_supported &&
      token_lcm_notifications_supported == o.token_lcm_notifications_supported &&
      fpan_lcm_notifications_supported == o.fpan_lcm_notifications_supported
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 177

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 243

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 156

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


143
144
145
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 143

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



149
150
151
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 149

def hash
  [device_binding_supported, cardholder_verification_supported, trusted_beneficiary_enrollment_supported, delegated_authentication_supported, obo_device_binding_supported, token_lcm_notifications_supported, fpan_lcm_notifications_supported].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 116

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 223

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



217
218
219
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 217

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
# File 'lib/cybersource_rest_client/models/tmsv2_tokenized_card_metadata_issuer_capabilities.rb', line 123

def valid?
  true
end