Class: CyberSource::Ucv1sessionsData
- Inherits:
-
Object
- Object
- CyberSource::Ucv1sessionsData
- Defined in:
- lib/cybersource_rest_client/models/ucv1sessions_data.rb
Instance Attribute Summary collapse
-
#aggregator_information ⇒ Object
Returns the value of attribute aggregator_information.
-
#buyer_information ⇒ Object
Returns the value of attribute buyer_information.
-
#client_reference_information ⇒ Object
Returns the value of attribute client_reference_information.
-
#consumer_authentication_information ⇒ Object
Returns the value of attribute consumer_authentication_information.
-
#device_information ⇒ Object
Returns the value of attribute device_information.
-
#installment_information ⇒ Object
Returns the value of attribute installment_information.
-
#merchant_defined_information ⇒ Object
Returns the value of attribute merchant_defined_information.
-
#merchant_information ⇒ Object
Returns the value of attribute merchant_information.
-
#order_information ⇒ Object
Returns the value of attribute order_information.
-
#payment_information ⇒ Object
Returns the value of attribute payment_information.
-
#processing_information ⇒ Object
Returns the value of attribute processing_information.
-
#recipient_information ⇒ Object
Returns the value of attribute recipient_information.
-
#sender_information ⇒ Object
Returns the value of attribute sender_information.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ucv1sessionsData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ucv1sessionsData
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 101 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'aggregatorInformation') self.aggregator_information = attributes[:'aggregatorInformation'] end if attributes.has_key?(:'orderInformation') self.order_information = attributes[:'orderInformation'] end if attributes.has_key?(:'buyerInformation') self.buyer_information = attributes[:'buyerInformation'] end if attributes.has_key?(:'clientReferenceInformation') self.client_reference_information = attributes[:'clientReferenceInformation'] end if attributes.has_key?(:'consumerAuthenticationInformation') self.consumer_authentication_information = attributes[:'consumerAuthenticationInformation'] end if attributes.has_key?(:'merchantInformation') self.merchant_information = attributes[:'merchantInformation'] end if attributes.has_key?(:'processingInformation') self.processing_information = attributes[:'processingInformation'] end if attributes.has_key?(:'recipientInformation') self.recipient_information = attributes[:'recipientInformation'] end if attributes.has_key?(:'senderInformation') self.sender_information = attributes[:'senderInformation'] end if attributes.has_key?(:'deviceInformation') self.device_information = attributes[:'deviceInformation'] end if attributes.has_key?(:'paymentInformation') self.payment_information = attributes[:'paymentInformation'] end if attributes.has_key?(:'installmentInformation') self.installment_information = attributes[:'installmentInformation'] end if attributes.has_key?(:'merchantDefinedInformation') if (value = attributes[:'merchantDefinedInformation']).is_a?(Array) self.merchant_defined_information = value end end end |
Instance Attribute Details
#aggregator_information ⇒ Object
Returns the value of attribute aggregator_information.
16 17 18 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 16 def aggregator_information @aggregator_information end |
#buyer_information ⇒ Object
Returns the value of attribute buyer_information.
20 21 22 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 20 def buyer_information @buyer_information end |
#client_reference_information ⇒ Object
Returns the value of attribute client_reference_information.
22 23 24 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 22 def client_reference_information @client_reference_information end |
#consumer_authentication_information ⇒ Object
Returns the value of attribute consumer_authentication_information.
24 25 26 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 24 def consumer_authentication_information @consumer_authentication_information end |
#device_information ⇒ Object
Returns the value of attribute device_information.
34 35 36 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 34 def device_information @device_information end |
#installment_information ⇒ Object
Returns the value of attribute installment_information.
38 39 40 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 38 def installment_information @installment_information end |
#merchant_defined_information ⇒ Object
Returns the value of attribute merchant_defined_information.
40 41 42 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 40 def merchant_defined_information @merchant_defined_information end |
#merchant_information ⇒ Object
Returns the value of attribute merchant_information.
26 27 28 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 26 def merchant_information @merchant_information end |
#order_information ⇒ Object
Returns the value of attribute order_information.
18 19 20 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 18 def order_information @order_information end |
#payment_information ⇒ Object
Returns the value of attribute payment_information.
36 37 38 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 36 def payment_information @payment_information end |
#processing_information ⇒ Object
Returns the value of attribute processing_information.
28 29 30 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 28 def processing_information @processing_information end |
#recipient_information ⇒ Object
Returns the value of attribute recipient_information.
30 31 32 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 30 def recipient_information @recipient_information end |
#sender_information ⇒ Object
Returns the value of attribute sender_information.
32 33 34 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 32 def sender_information @sender_information end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 43 def self.attribute_map { :'aggregator_information' => :'aggregatorInformation', :'order_information' => :'orderInformation', :'buyer_information' => :'buyerInformation', :'client_reference_information' => :'clientReferenceInformation', :'consumer_authentication_information' => :'consumerAuthenticationInformation', :'merchant_information' => :'merchantInformation', :'processing_information' => :'processingInformation', :'recipient_information' => :'recipientInformation', :'sender_information' => :'senderInformation', :'device_information' => :'deviceInformation', :'payment_information' => :'paymentInformation', :'installment_information' => :'installmentInformation', :'merchant_defined_information' => :'merchantDefinedInformation' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 62 def self.json_map { :'aggregator_information' => :'aggregator_information', :'order_information' => :'order_information', :'buyer_information' => :'buyer_information', :'client_reference_information' => :'client_reference_information', :'consumer_authentication_information' => :'consumer_authentication_information', :'merchant_information' => :'merchant_information', :'processing_information' => :'processing_information', :'recipient_information' => :'recipient_information', :'sender_information' => :'sender_information', :'device_information' => :'device_information', :'payment_information' => :'payment_information', :'installment_information' => :'installment_information', :'merchant_defined_information' => :'merchant_defined_information' } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 81 def self.swagger_types { :'aggregator_information' => :'Ucv1sessionsDataAggregatorInformation', :'order_information' => :'Ucv1sessionsDataOrderInformation', :'buyer_information' => :'Ucv1sessionsDataBuyerInformation', :'client_reference_information' => :'Upv1capturecontextsDataClientReferenceInformation', :'consumer_authentication_information' => :'Ucv1sessionsDataConsumerAuthenticationInformation', :'merchant_information' => :'Ucv1sessionsDataMerchantInformation', :'processing_information' => :'Ucv1sessionsDataProcessingInformation', :'recipient_information' => :'Ucv1sessionsDataRecipientInformation', :'sender_information' => :'Ucv1sessionsDataSenderInformation', :'device_information' => :'Ucv1sessionsDataDeviceInformation', :'payment_information' => :'Ucv1sessionsDataPaymentInformation', :'installment_information' => :'Ucv1sessionsDataInstallmentInformation', :'merchant_defined_information' => :'Array<Ucv1sessionsDataMerchantDefinedInformation>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && aggregator_information == o.aggregator_information && order_information == o.order_information && buyer_information == o.buyer_information && client_reference_information == o.client_reference_information && consumer_authentication_information == o.consumer_authentication_information && merchant_information == o.merchant_information && processing_information == o.processing_information && recipient_information == o.recipient_information && sender_information == o.sender_information && device_information == o.device_information && payment_information == o.payment_information && installment_information == o.installment_information && merchant_defined_information == o.merchant_defined_information end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 231 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 297 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 203 def hash [aggregator_information, order_information, buyer_information, client_reference_information, consumer_authentication_information, merchant_information, processing_information, recipient_information, sender_information, device_information, payment_information, installment_information, merchant_defined_information].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 164 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
277 278 279 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 277 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
271 272 273 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 271 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data.rb', line 171 def valid? true end |