Class: CyberSource::Ucv1sessionsDataConsumerAuthenticationInformation
- Inherits:
-
Object
- Object
- CyberSource::Ucv1sessionsDataConsumerAuthenticationInformation
- Defined in:
- lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb
Instance Attribute Summary collapse
-
#acs_window_size ⇒ Object
The acs window size
Optional field: This field cannot be configured through the Merchant Experience screens in the Business Center, but if required should be provided on a per‑transaction basis in the uc/v1/sessions API request. -
#challenge_code ⇒ Object
The challenge code
Optional field: This field cannot be configured through the Merchant Experience screens in the Business Center, but if required should be provided on a per‑transaction basis in the uc/v1/sessions API request. -
#language_preference ⇒ Object
Preferred language to be used for cardholder authentication and challenge experiences (subject to issuer/ACS support).
-
#message_category ⇒ Object
The message category
Optional field: This field cannot be configured through the Merchant Experience screens in the Business Center, but if required should be provided on a per‑transaction basis in the uc/v1/sessions API request. -
#product_code ⇒ Object
Specifies the product code, which designates the type of transaction.
Specify one of the following values for this field: - AIR: Airline purchase Important Required for American Express SafeKey (U.S.).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ucv1sessionsDataConsumerAuthenticationInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ucv1sessionsDataConsumerAuthenticationInformation
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 66 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'challengeCode') self.challenge_code = attributes[:'challengeCode'] end if attributes.has_key?(:'messageCategory') self. = attributes[:'messageCategory'] end if attributes.has_key?(:'acsWindowSize') self.acs_window_size = attributes[:'acsWindowSize'] end if attributes.has_key?(:'productCode') self.product_code = attributes[:'productCode'] end if attributes.has_key?(:'languagePreference') self.language_preference = attributes[:'languagePreference'] end end |
Instance Attribute Details
#acs_window_size ⇒ Object
The acs window size
Optional field: This field cannot be configured through the Merchant Experience screens in the Business Center, but if required should be provided on a per‑transaction basis in the uc/v1/sessions API request.
23 24 25 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 23 def acs_window_size @acs_window_size end |
#challenge_code ⇒ Object
The challenge code
Optional field: This field cannot be configured through the Merchant Experience screens in the Business Center, but if required should be provided on a per‑transaction basis in the uc/v1/sessions API request.
17 18 19 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 17 def challenge_code @challenge_code end |
#language_preference ⇒ Object
Preferred language to be used for cardholder authentication and challenge experiences (subject to issuer/ACS support).
29 30 31 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 29 def language_preference @language_preference end |
#message_category ⇒ Object
The message category
Optional field: This field cannot be configured through the Merchant Experience screens in the Business Center, but if required should be provided on a per‑transaction basis in the uc/v1/sessions API request.
20 21 22 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 20 def @message_category end |
#product_code ⇒ Object
Specifies the product code, which designates the type of transaction.
Specify one of the following values for this field: - AIR: Airline purchase Important Required for American Express SafeKey (U.S.). - ACC: Accommodation Rental - ACF: Account funding - CHA: Check acceptance - DIG: Digital Goods - DSP: Cash Dispensing - GAS: Fuel - GEN: General Retail - LUX: Luxury Retail - PAL: Prepaid activation and load - PHY: Goods or services purchase - QCT: Quasi-cash transaction - REN: Car Rental - RES: Restaurant - SVC: Services - TBD: Other - TRA: Travel
Important Required for Visa Secure transactions in Brazil. Do not use this request field for any other types of transactions.
26 27 28 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 26 def product_code @product_code end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 32 def self.attribute_map { :'challenge_code' => :'challengeCode', :'message_category' => :'messageCategory', :'acs_window_size' => :'acsWindowSize', :'product_code' => :'productCode', :'language_preference' => :'languagePreference' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
43 44 45 46 47 48 49 50 51 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 43 def self.json_map { :'challenge_code' => :'challenge_code', :'message_category' => :'message_category', :'acs_window_size' => :'acs_window_size', :'product_code' => :'product_code', :'language_preference' => :'language_preference' } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 54 def self.swagger_types { :'challenge_code' => :'String', :'message_category' => :'String', :'acs_window_size' => :'String', :'product_code' => :'String', :'language_preference' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 132 def ==(o) return true if self.equal?(o) self.class == o.class && challenge_code == o.challenge_code && == o. && acs_window_size == o.acs_window_size && product_code == o.product_code && language_preference == o.language_preference end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 178 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 244 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
144 145 146 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 144 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 150 def hash [challenge_code, , acs_window_size, product_code, language_preference].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
95 96 97 98 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 95 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
224 225 226 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 224 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 218 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_consumer_authentication_information.rb', line 102 def valid? true end |