Class: CyberSource::Ucv1sessionsDataSenderInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Ucv1sessionsDataSenderInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'firstName')
    self.first_name = attributes[:'firstName']
  end

  if attributes.has_key?(:'middleName')
    self.middle_name = attributes[:'middleName']
  end

  if attributes.has_key?(:'lastName')
    self.last_name = attributes[:'lastName']
  end

  if attributes.has_key?(:'address1')
    self.address1 = attributes[:'address1']
  end

  if attributes.has_key?(:'locality')
    self.locality = attributes[:'locality']
  end

  if attributes.has_key?(:'administrativeArea')
    self.administrative_area = attributes[:'administrativeArea']
  end

  if attributes.has_key?(:'postalCode')
    self.postal_code = attributes[:'postalCode']
  end

  if attributes.has_key?(:'countryCode')
    self.country_code = attributes[:'countryCode']
  end

  if attributes.has_key?(:'phoneNumber')
    self.phone_number = attributes[:'phoneNumber']
  end

  if attributes.has_key?(:'dateOfBirth')
    self.date_of_birth = attributes[:'dateOfBirth']
  end

  if attributes.has_key?(:'accountType')
    self. = attributes[:'accountType']
  end

  if attributes.has_key?(:'account')
    self. = attributes[:'account']
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



49
50
51
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 49

def 
  @account
end

#account_typeObject

Identifies the sender’s account type. This field is applicable for AFT transactions. Valid values are: - ‘00` for Other - `01` for Routing Transit Number (RTN) + Bank Account Number (BAN) - `02` for International Bank Account Number (IBAN) - `03` for Card Account - `04` for Email - `05` for Phone Number - `06` for Bank Account Number (BAN) + Bank Identification Code (BIC), also known as a SWIFT code - `07` for Wallet ID - `08` for Social Network ID



47
48
49
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 47

def 
  @account_type
end

#address1Object

The street address of the sender. This field is applicable for AFT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set are not supported and will be stripped before being sent to sent to the processor.



26
27
28
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 26

def address1
  @address1
end

#administrative_areaObject

The state or province of the sender. This field is applicable for AFT transactions when the sender country is US or CA. Else it is optional. Must be a two character value



32
33
34
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 32

def administrative_area
  @administrative_area
end

#country_codeObject

The country associated with the address of the sender. This field is applicable for AFT transactions. Must be a two character ISO country code. For example, see [ISO Country Code](developer.cybersource.com/docs/cybs/en-us/country-codes/reference/all/na/country-codes/country-codes.html)



38
39
40
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 38

def country_code
  @country_code
end

#date_of_birthObject

Sender’s date of birth. Format: ‘YYYYMMDD`. This field is a `pass-through`, which means that CyberSource ensures that the value is eight numeric characters but otherwise does not verify the value or modify it in any way before sending it to the processor. If the field is not required for the transaction, CyberSource does not forward it to the processor.



44
45
46
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 44

def date_of_birth
  @date_of_birth
end

#first_nameObject

First name of the sender. This field is applicable for AFT and OCT transactions. Only alpha numeric values are supported.Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to the processor.



17
18
19
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 17

def first_name
  @first_name
end

#last_nameObject

Last name of the sender. This field is applicable for AFT and OCT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to sent to the processor.



23
24
25
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 23

def last_name
  @last_name
end

#localityObject

The city or locality of the sender. This field is applicable for AFT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set are not supported and will be stripped before being sent to sent to the processor.



29
30
31
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 29

def locality
  @locality
end

#middle_nameObject

Middle name of the sender. This field is applicable for AFT and OCT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to sent to the processor.



20
21
22
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 20

def middle_name
  @middle_name
end

#phone_numberObject

Sender phone number



41
42
43
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 41

def phone_number
  @phone_number
end

#postal_codeObject

Postal code of sender.



35
36
37
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 35

def postal_code
  @postal_code
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 52

def self.attribute_map
  {
    :'first_name' => :'firstName',
    :'middle_name' => :'middleName',
    :'last_name' => :'lastName',
    :'address1' => :'address1',
    :'locality' => :'locality',
    :'administrative_area' => :'administrativeArea',
    :'postal_code' => :'postalCode',
    :'country_code' => :'countryCode',
    :'phone_number' => :'phoneNumber',
    :'date_of_birth' => :'dateOfBirth',
    :'account_type' => :'accountType',
    :'account' => :'account'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 70

def self.json_map
  {
    :'first_name' => :'first_name',
    :'middle_name' => :'middle_name',
    :'last_name' => :'last_name',
    :'address1' => :'address1',
    :'locality' => :'locality',
    :'administrative_area' => :'administrative_area',
    :'postal_code' => :'postal_code',
    :'country_code' => :'country_code',
    :'phone_number' => :'phone_number',
    :'date_of_birth' => :'date_of_birth',
    :'account_type' => :'account_type',
    :'account' => :'account'
  }
end

.swagger_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 88

def self.swagger_types
  {
    :'first_name' => :'String',
    :'middle_name' => :'String',
    :'last_name' => :'String',
    :'address1' => :'String',
    :'locality' => :'String',
    :'administrative_area' => :'String',
    :'postal_code' => :'String',
    :'country_code' => :'String',
    :'phone_number' => :'String',
    :'date_of_birth' => :'String',
    :'account_type' => :'String',
    :'account' => :'Ucv1sessionsDataSenderInformationAccount'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      first_name == o.first_name &&
      middle_name == o.middle_name &&
      last_name == o.last_name &&
      address1 == o.address1 &&
      locality == o.locality &&
      administrative_area == o.administrative_area &&
      postal_code == o.postal_code &&
      country_code == o.country_code &&
      phone_number == o.phone_number &&
      date_of_birth == o.date_of_birth &&
       == o. &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 296

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 362

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 275

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 262

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



268
269
270
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 268

def hash
  [first_name, middle_name, last_name, address1, locality, administrative_area, postal_code, country_code, phone_number, date_of_birth, , ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 164

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 342

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 348

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



336
337
338
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 336

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_sender_information.rb', line 171

def valid?
  true
end