Class: CyberSource::UnifiedriskAcquirer

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb

Overview

Acquirer identification, credentials, and country information

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskAcquirer

Initializes the object



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 90

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key

  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'acquirerBin')
    self.acquirer_bin = attributes[:'acquirerBin']
  end

  if attributes.has_key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.has_key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.has_key?(:'merchantId')
    self.merchant_id = attributes[:'merchantId']
  end

  if attributes.has_key?(:'acquirerId')
    self.acquirer_id = attributes[:'acquirerId']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'merchantAccount')
    self. = attributes[:'merchantAccount']
  end

  if attributes.has_key?(:'declinedPhase')
    self.declined_phase = attributes[:'declinedPhase']
  end

  if attributes.has_key?(:'countrySource')
    self.country_source = attributes[:'countrySource']
  end
end

Instance Attribute Details

#acquirer_binObject

Acquirer bank ID number that corresponds to a certificate that Cybersource already has.This ID has this format. 4XXXXX for Visa and 5XXXXX for Mastercard.



18
19
20
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 18

def acquirer_bin
  @acquirer_bin
end

#acquirer_idObject

A unique identifier for the acquirer in a transaction. | A unique identifier for the acquirer in a transaction. This is only relevant if the originating event was a card transaction.



30
31
32
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 30

def acquirer_id
  @acquirer_id
end

#countryObject

Two-letter ISO 3166-1 country code for the acquirer. Used for jurisdiction, regulatory, and risk evaluation when acquirer country may differ from merchant country (including EEA scenarios).



21
22
23
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 21

def country
  @country
end

#country_sourceObject

The source system or database from which the acquirer's country code was derived or validated (e.g., BIN table, registration data)



41
42
43
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 41

def country_source
  @country_source
end

#declined_phaseObject

Indicates the phase or stage in the transaction processing flow at which the authorization was declined (e.g., ISSUER, ACQUIRER, NETWORK, MERCHANT)



38
39
40
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 38

def declined_phase
  @declined_phase
end

#merchant_accountObject

Returns the value of attribute merchant_account.



35
36
37
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 35

def 
  
end

#merchant_idObject

A unique identifier assigned to the merchant by the acquirer or payment processor



27
28
29
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 27

def merchant_id
  @merchant_id
end

#nameObject

Short name of the acquirer in acquirerId



33
34
35
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 33

def name
  @name
end

#passwordObject

Registered password for the Visa directory server.



24
25
26
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 24

def password
  @password
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 44

def self.attribute_map
  {
    :'acquirer_bin' => :'acquirerBin',
    :'country' => :'country',
    :'password' => :'password',
    :'merchant_id' => :'merchantId',
    :'acquirer_id' => :'acquirerId',
    :'name' => :'name',
    :'merchant_account' => :'merchantAccount',
    :'declined_phase' => :'declinedPhase',
    :'country_source' => :'countrySource'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 59

def self.json_map
  {
    :'acquirer_bin' => :'acquirer_bin',
    :'country' => :'country',
    :'password' => :'password',
    :'merchant_id' => :'merchant_id',
    :'acquirer_id' => :'acquirer_id',
    :'name' => :'name',
    :'merchant_account' => :'merchant_account',
    :'declined_phase' => :'declined_phase',
    :'country_source' => :'country_source'
  }
end

.swagger_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 74

def self.swagger_types
  {
    :'acquirer_bin' => :'String',
    :'country' => :'String',
    :'password' => :'String',
    :'merchant_id' => :'String',
    :'acquirer_id' => :'String',
    :'name' => :'String',
    :'merchant_account' => :'UnifiedriskAcquirerMerchantAccount',
    :'declined_phase' => :'String',
    :'country_source' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      acquirer_bin == o.acquirer_bin &&
      country == o.country &&
      password == o.password &&
      merchant_id == o.merchant_id &&
      acquirer_id == o.acquirer_id &&
      name == o.name &&
       == o. &&
      declined_phase == o.declined_phase &&
      country_source == o.country_source
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 222

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly

    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model

    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 288

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 201

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute

      # is documented as an array but the input is not

      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional

  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


188
189
190
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 188

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



194
195
196
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 194

def hash
  [acquirer_bin, country, password, merchant_id, acquirer_id, name, , declined_phase, country_source].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



135
136
137
138
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 135

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



268
269
270
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 268

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



262
263
264
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 262

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



142
143
144
# File 'lib/cybersource_rest_client/models/unifiedrisk_acquirer.rb', line 142

def valid?
  true
end