Class: CyberSource::UnifiedriskBrowser

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_browser.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskBrowser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 138

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'cookiesAccepted')
    self.cookies_accepted = attributes[:'cookiesAccepted']
  end

  if attributes.has_key?(:'fingerprintSessionId')
    self.fingerprint_session_id = attributes[:'fingerprintSessionId']
  end

  if attributes.has_key?(:'httpBrowserEmail')
    self.http_browser_email = attributes[:'httpBrowserEmail']
  end

  if attributes.has_key?(:'userAgent')
    self.user_agent = attributes[:'userAgent']
  end

  if attributes.has_key?(:'httpAcceptBrowserValue')
    self.http_accept_browser_value = attributes[:'httpAcceptBrowserValue']
  end

  if attributes.has_key?(:'httpAcceptContent')
    self.http_accept_content = attributes[:'httpAcceptContent']
  end

  if attributes.has_key?(:'httpBrowserLanguage')
    self.http_browser_language = attributes[:'httpBrowserLanguage']
  end

  if attributes.has_key?(:'httpBrowserJavaEnabled')
    self.http_browser_java_enabled = attributes[:'httpBrowserJavaEnabled']
  end

  if attributes.has_key?(:'httpBrowserJavaScriptEnabled')
    self.http_browser_java_script_enabled = attributes[:'httpBrowserJavaScriptEnabled']
  end

  if attributes.has_key?(:'httpBrowserColorDepth')
    self.http_browser_color_depth = attributes[:'httpBrowserColorDepth']
  end

  if attributes.has_key?(:'httpBrowserScreenHeight')
    self.http_browser_screen_height = attributes[:'httpBrowserScreenHeight']
  end

  if attributes.has_key?(:'httpBrowserScreenWidth')
    self.http_browser_screen_width = attributes[:'httpBrowserScreenWidth']
  end

  if attributes.has_key?(:'httpBrowserTimeDifference')
    self.http_browser_time_difference = attributes[:'httpBrowserTimeDifference']
  end

  if attributes.has_key?(:'userAgentBrowserValue')
    self.user_agent_browser_value = attributes[:'userAgentBrowserValue']
  end

  if attributes.has_key?(:'userId')
    self.user_id = attributes[:'userId']
  end

  if attributes.has_key?(:'httpAcceptLanguage')
    self.http_accept_language = attributes[:'httpAcceptLanguage']
  end

  if attributes.has_key?(:'httpBrowserTimeZone')
    self.http_browser_time_zone = attributes[:'httpBrowserTimeZone']
  end
end

Instance Attribute Details

#cookies_acceptedObject

Whether the customer's browser accepts cookies. This field can contain one of the following values: - yes: The customer's browser accepts cookies. - no: The customer's browser does not accept cookies.



17
18
19
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 17

def cookies_accepted
  @cookies_accepted
end

#fingerprint_session_idObject

Field that contains the session ID that you send to Decision Manager to obtain the device fingerprint information. The string can contain uppercase and lowercase letters, digits, hyphen (-), and underscore (_). However, do not use the same uppercase and lowercase letters to indicate different session IDs.The session ID must be unique for each merchant ID. You can use any string that you are already generating, such as an order number or web session ID.The session ID must be unique for each p



20
21
22
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 20

def fingerprint_session_id
  @fingerprint_session_id
end

#http_accept_browser_valueObject

Value of the Accept header sent by the customer's web browser. Note If the customer's browser provides a value, you must include it in your request.



29
30
31
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 29

def http_accept_browser_value
  @http_accept_browser_value
end

#http_accept_contentObject

The exact content of the HTTP accept header.



32
33
34
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 32

def http_accept_content
  @http_accept_content
end

#http_accept_languageObject

The HTTP Accept-Language header value from the browser indicating the user's preferred content languages, formatted per RFC 5646 (e.g., en-US,en;q=0.9,fr;q=0.8)



62
63
64
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 62

def http_accept_language
  @http_accept_language
end

#http_browser_color_depthObject

Value represents the bit depth of the color palette for displaying images, in bits per pixel. Example : 24, refer https://en.wikipedia.org/wiki/Color_depth for more details



44
45
46
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 44

def http_browser_color_depth
  @http_browser_color_depth
end

#http_browser_emailObject

Email address set in the customer's browser, which may differ from customer email.



23
24
25
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 23

def http_browser_email
  @http_browser_email
end

#http_browser_java_enabledObject

A Boolean value that represents the ability of the cardholder browser to execute Java. Value is returned from the navigator.javaEnabled property. Possible Values:True/False



38
39
40
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 38

def http_browser_java_enabled
  @http_browser_java_enabled
end

#http_browser_java_script_enabledObject

A Boolean value that represents the ability of the cardholder browser to execute JavaScript. Possible Values:True/False. Note: Merchants should be able to know the values from fingerprint details



41
42
43
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 41

def http_browser_java_script_enabled
  @http_browser_java_script_enabled
end

#http_browser_languageObject

Value represents the browser language as defined in IETF BCP47. Example:en-US, refer https://en.wikipedia.org/wiki/IETF_language_tag for more details.



35
36
37
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 35

def http_browser_language
  @http_browser_language
end

#http_browser_screen_heightObject

Total height of the Cardholder's scree in pixels, example: 864.



47
48
49
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 47

def http_browser_screen_height
  @http_browser_screen_height
end

#http_browser_screen_widthObject

Total width of the cardholder's screen in pixels. Example: 1536.



50
51
52
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 50

def http_browser_screen_width
  @http_browser_screen_width
end

#http_browser_time_differenceObject

Time difference between UTC time and the cardholder browser local time, in minutes, Example:300



53
54
55
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 53

def http_browser_time_difference
  @http_browser_time_difference
end

#http_browser_time_zoneObject

The timezone offset in minutes between UTC and the cardholder's browser local time (e.g., -300 for UTC-5). Used for temporal risk analysis and anomaly detection



65
66
67
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 65

def http_browser_time_zone
  @http_browser_time_zone
end

#user_agentObject

Customer's browser as identified from the HTTP header data. For example, Mozilla is the value that identifies the Netscape browser.



26
27
28
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 26

def user_agent
  @user_agent
end

#user_agent_browser_valueObject

Value of the User-Agent header sent by the customer's web browser. Note If the customer's browser provides a value, you must include it in your request.



56
57
58
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 56

def user_agent_browser_value
  @user_agent_browser_value
end

#user_idObject

Authenticated user identifier associated with the browser session, used for tracking user behaviour patterns and detecting account takeover attempts



59
60
61
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 59

def user_id
  @user_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 68

def self.attribute_map
  {
    :'cookies_accepted' => :'cookiesAccepted',
    :'fingerprint_session_id' => :'fingerprintSessionId',
    :'http_browser_email' => :'httpBrowserEmail',
    :'user_agent' => :'userAgent',
    :'http_accept_browser_value' => :'httpAcceptBrowserValue',
    :'http_accept_content' => :'httpAcceptContent',
    :'http_browser_language' => :'httpBrowserLanguage',
    :'http_browser_java_enabled' => :'httpBrowserJavaEnabled',
    :'http_browser_java_script_enabled' => :'httpBrowserJavaScriptEnabled',
    :'http_browser_color_depth' => :'httpBrowserColorDepth',
    :'http_browser_screen_height' => :'httpBrowserScreenHeight',
    :'http_browser_screen_width' => :'httpBrowserScreenWidth',
    :'http_browser_time_difference' => :'httpBrowserTimeDifference',
    :'user_agent_browser_value' => :'userAgentBrowserValue',
    :'user_id' => :'userId',
    :'http_accept_language' => :'httpAcceptLanguage',
    :'http_browser_time_zone' => :'httpBrowserTimeZone'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 91

def self.json_map
  {
    :'cookies_accepted' => :'cookies_accepted',
    :'fingerprint_session_id' => :'fingerprint_session_id',
    :'http_browser_email' => :'http_browser_email',
    :'user_agent' => :'user_agent',
    :'http_accept_browser_value' => :'http_accept_browser_value',
    :'http_accept_content' => :'http_accept_content',
    :'http_browser_language' => :'http_browser_language',
    :'http_browser_java_enabled' => :'http_browser_java_enabled',
    :'http_browser_java_script_enabled' => :'http_browser_java_script_enabled',
    :'http_browser_color_depth' => :'http_browser_color_depth',
    :'http_browser_screen_height' => :'http_browser_screen_height',
    :'http_browser_screen_width' => :'http_browser_screen_width',
    :'http_browser_time_difference' => :'http_browser_time_difference',
    :'user_agent_browser_value' => :'user_agent_browser_value',
    :'user_id' => :'user_id',
    :'http_accept_language' => :'http_accept_language',
    :'http_browser_time_zone' => :'http_browser_time_zone'
  }
end

.swagger_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 114

def self.swagger_types
  {
    :'cookies_accepted' => :'String',
    :'fingerprint_session_id' => :'String',
    :'http_browser_email' => :'String',
    :'user_agent' => :'String',
    :'http_accept_browser_value' => :'String',
    :'http_accept_content' => :'String',
    :'http_browser_language' => :'String',
    :'http_browser_java_enabled' => :'BOOLEAN',
    :'http_browser_java_script_enabled' => :'BOOLEAN',
    :'http_browser_color_depth' => :'String',
    :'http_browser_screen_height' => :'String',
    :'http_browser_screen_width' => :'String',
    :'http_browser_time_difference' => :'String',
    :'user_agent_browser_value' => :'String',
    :'user_id' => :'String',
    :'http_accept_language' => :'String',
    :'http_browser_time_zone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cookies_accepted == o.cookies_accepted &&
      fingerprint_session_id == o.fingerprint_session_id &&
      http_browser_email == o.http_browser_email &&
      user_agent == o.user_agent &&
      http_accept_browser_value == o.http_accept_browser_value &&
      http_accept_content == o.http_accept_content &&
      http_browser_language == o.http_browser_language &&
      http_browser_java_enabled == o.http_browser_java_enabled &&
      http_browser_java_script_enabled == o.http_browser_java_script_enabled &&
      http_browser_color_depth == o.http_browser_color_depth &&
      http_browser_screen_height == o.http_browser_screen_height &&
      http_browser_screen_width == o.http_browser_screen_width &&
      http_browser_time_difference == o.http_browser_time_difference &&
      user_agent_browser_value == o.user_agent_browser_value &&
      user_id == o.user_id &&
      http_accept_language == o.http_accept_language &&
      http_browser_time_zone == o.http_browser_time_zone
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 340

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 406

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 319

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


306
307
308
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 306

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



312
313
314
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 312

def hash
  [cookies_accepted, fingerprint_session_id, http_browser_email, user_agent, http_accept_browser_value, http_accept_content, http_browser_language, http_browser_java_enabled, http_browser_java_script_enabled, http_browser_color_depth, http_browser_screen_height, http_browser_screen_width, http_browser_time_difference, user_agent_browser_value, user_id, http_accept_language, http_browser_time_zone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



215
216
217
218
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 215

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 386

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



392
393
394
395
396
397
398
399
400
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 392

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



380
381
382
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 380

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
# File 'lib/cybersource_rest_client/models/unifiedrisk_browser.rb', line 222

def valid?
  true
end