Class: CyberSource::UnifiedriskDevice

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_device.rb

Overview

Device hardware, network information, location data, and point-of-sale context

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskDevice

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 300

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key

  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'ipAddress')
    self.ip_address = attributes[:'ipAddress']
  end

  if attributes.has_key?(:'hostName')
    self.host_name = attributes[:'hostName']
  end

  if attributes.has_key?(:'anonymizerInUseFlag')
    self.anonymizer_in_use_flag = attributes[:'anonymizerInUseFlag']
  end

  if attributes.has_key?(:'areaCode')
    self.area_code = attributes[:'areaCode']
  end

  if attributes.has_key?(:'browserType')
    self.browser_type = attributes[:'browserType']
  end

  if attributes.has_key?(:'browserVersion')
    self.browser_version = attributes[:'browserVersion']
  end

  if attributes.has_key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.has_key?(:'clientTimezone')
    self.client_timezone = attributes[:'clientTimezone']
  end

  if attributes.has_key?(:'continentCode')
    self.continent_code = attributes[:'continentCode']
  end

  if attributes.has_key?(:'cookieId')
    self.cookie_id = attributes[:'cookieId']
  end

  if attributes.has_key?(:'countryCode')
    self.country_code = attributes[:'countryCode']
  end

  if attributes.has_key?(:'countryName')
    self.country_name = attributes[:'countryName']
  end

  if attributes.has_key?(:'deviceFingerprint')
    self.device_fingerprint = attributes[:'deviceFingerprint']
  end

  if attributes.has_key?(:'deviceIMEI')
    self.device_imei = attributes[:'deviceIMEI']
  end

  if attributes.has_key?(:'deviceName')
    self.device_name = attributes[:'deviceName']
  end

  if attributes.has_key?(:'flashPlugin')
    self.flash_plugin = attributes[:'flashPlugin']
  end

  if attributes.has_key?(:'httpHeader')
    self.http_header = attributes[:'httpHeader']
  end

  if attributes.has_key?(:'metroCode')
    self.metro_code = attributes[:'metroCode']
  end

  if attributes.has_key?(:'mfaSession')
    self.mfa_session = attributes[:'mfaSession']
  end

  if attributes.has_key?(:'mimeTypesPresent')
    self.mime_types_present = attributes[:'mimeTypesPresent']
  end

  if attributes.has_key?(:'mobileNumberDeviceLink')
    self.mobile_number_device_link = attributes[:'mobileNumberDeviceLink']
  end

  if attributes.has_key?(:'networkCarrier')
    self.network_carrier = attributes[:'networkCarrier']
  end

  if attributes.has_key?(:'operatingSystem')
    self.operating_system = attributes[:'operatingSystem']
  end

  if attributes.has_key?(:'postalCode')
    self.postal_code = attributes[:'postalCode']
  end

  if attributes.has_key?(:'proxyDescription')
    self.proxy_description = attributes[:'proxyDescription']
  end

  if attributes.has_key?(:'proxyType')
    self.proxy_type = attributes[:'proxyType']
  end

  if attributes.has_key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.has_key?(:'screenResolution')
    self.screen_resolution = attributes[:'screenResolution']
  end

  if attributes.has_key?(:'sessionLatitude')
    self.session_latitude = attributes[:'sessionLatitude']
  end

  if attributes.has_key?(:'sessionLongitude')
    self.session_longitude = attributes[:'sessionLongitude']
  end

  if attributes.has_key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'userAgentString')
    self.user_agent_string = attributes[:'userAgentString']
  end

  if attributes.has_key?(:'deviceId')
    self.device_id = attributes[:'deviceId']
  end

  if attributes.has_key?(:'deviceFingerprintProvider')
    self.device_fingerprint_provider = attributes[:'deviceFingerprintProvider']
  end

  if attributes.has_key?(:'pointOfSale')
    self.point_of_sale = attributes[:'pointOfSale']
  end

  if attributes.has_key?(:'ipAddressV4')
    self.ip_address_v4 = attributes[:'ipAddressV4']
  end

  if attributes.has_key?(:'ipAddressV6')
    self.ip_address_v6 = attributes[:'ipAddressV6']
  end

  if attributes.has_key?(:'deviceFingerprintVendor')
    self.device_fingerprint_vendor = attributes[:'deviceFingerprintVendor']
  end

  if attributes.has_key?(:'deviceEntityId')
    self.device_entity_id = attributes[:'deviceEntityId']
  end

  if attributes.has_key?(:'referenceId')
    self.reference_id = attributes[:'referenceId']
  end

  if attributes.has_key?(:'encryptedDeviceData')
    self.encrypted_device_data = attributes[:'encryptedDeviceData']
  end

  if attributes.has_key?(:'deviceBindingStatus')
    self.device_binding_status = attributes[:'deviceBindingStatus']
  end

  if attributes.has_key?(:'deviceBindingStatusSource')
    self.device_binding_status_source = attributes[:'deviceBindingStatusSource']
  end
end

Instance Attribute Details

#anonymizer_in_use_flagObject

A flag indicating if the anonymizer was in use during the session. true if the anonymiser was in use, false otherwise.



24
25
26
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 24

def anonymizer_in_use_flag
  @anonymizer_in_use_flag
end

#area_codeObject

The device area code captured during the customer session



27
28
29
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 27

def area_code
  @area_code
end

#browser_typeObject

The device browser type captured during the customer session



30
31
32
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 30

def browser_type
  @browser_type
end

#browser_versionObject

The device browser version captured during the customer session



33
34
35
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 33

def browser_version
  @browser_version
end

#cityObject

The device city name captured during the customer session



36
37
38
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 36

def city
  @city
end

#client_timezoneObject

The clientTimeZone captured during the customer session



39
40
41
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 39

def client_timezone
  @client_timezone
end

#continent_codeObject

The device continent code captured during the customer session



42
43
44
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 42

def continent_code
  @continent_code
end

The cookie ID used during the customer session



45
46
47
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 45

def cookie_id
  @cookie_id
end

#country_codeObject

The device country code captured during the customer session



48
49
50
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 48

def country_code
  @country_code
end

#country_nameObject

The device country name captured during the customer session



51
52
53
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 51

def country_name
  @country_name
end

#device_binding_statusObject

Indicates whether the device is bound to a specific account or cardholder identity. Values such as BOUND, UNBOUND, or UNKNOWN reflect the trust level of the device association



143
144
145
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 143

def device_binding_status
  @device_binding_status
end

#device_binding_status_sourceObject

The source system or process that determined the device binding status (e.g., 3DS_SDK, ISSUER, DEVICE_INTELLIGENCE_PROVIDER)



146
147
148
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 146

def device_binding_status_source
  @device_binding_status_source
end

#device_entity_idObject

Unique entity identifier assigned to the device by the fingerprinting system, used to track device history and link sessions across transactions



134
135
136
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 134

def device_entity_id
  @device_entity_id
end

#device_fingerprintObject

The device fingerprint captured during the customer session by a third party. A device fingerprint is information collected about the software and hardware for the purpose of identification



54
55
56
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 54

def device_fingerprint
  @device_fingerprint
end

#device_fingerprint_providerObject

Vendor or provider providing device identification/fingerprinting services



120
121
122
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 120

def device_fingerprint_provider
  @device_fingerprint_provider
end

#device_fingerprint_vendorObject

Name of the third-party vendor providing device fingerprinting services for this transaction (e.g., ThreatMetrix, InAuth, Kount)



131
132
133
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 131

def device_fingerprint_vendor
  @device_fingerprint_vendor
end

#device_idObject

A unique identifier of the device performing the event, such as the laptop/mobile phone used to log into the online banking. | A unique identifier of the device performing the event, such as the mobil



117
118
119
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 117

def device_id
  @device_id
end

#device_imeiObject

The IMEI of the device used during the customer session. An IMEI identifies most types of mobile phone (GSM, WCDMA, iDEN), as well as some satellite phones.



57
58
59
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 57

def device_imei
  @device_imei
end

#device_nameObject

The device name given at point of registration



60
61
62
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 60

def device_name
  @device_name
end

#encrypted_device_dataObject

Encrypted payload containing device data collected by a 3DS SDK or device intelligence provider. The encryption protects sensitive device attributes during transmission



140
141
142
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 140

def encrypted_device_data
  @encrypted_device_data
end

#flash_pluginObject

The Flash Plugin captured during the customer session, if available.



63
64
65
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 63

def flash_plugin
  @flash_plugin
end

#host_nameObject

DNS resolved hostname from ipAddress.



21
22
23
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 21

def host_name
  @host_name
end

#http_headerObject

The HTTPHeader captured during the customer session



66
67
68
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 66

def http_header
  @http_header
end

#ip_addressObject

IPv4 or IPv6 address observed for the customer's device during the session.



18
19
20
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 18

def ip_address
  @ip_address
end

#ip_address_v4Object

IPv4 address of the customer's device captured during the session (e.g., 192.0.2.1). Used for geolocation, anonymizer detection, and IP-based risk signals



125
126
127
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 125

def ip_address_v4
  @ip_address_v4
end

#ip_address_v6Object

IPv6 address of the customer's device captured during the session (e.g., 2001:db8::1). Used for geolocation and risk analysis in IPv6-enabled environments



128
129
130
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 128

def ip_address_v6
  @ip_address_v6
end

#metro_codeObject

The device metropolitan code captured during the customer session



69
70
71
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 69

def metro_code
  @metro_code
end

#mfa_sessionObject

Whether multifactor authentication was used during the session



72
73
74
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 72

def mfa_session
  @mfa_session
end

#mime_types_presentObject

The Mime-Type(s) captured during the customer session



75
76
77
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 75

def mime_types_present
  @mime_types_present
end

A concatenated string of the mobile number and device ID to establish the link



78
79
80
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 78

def mobile_number_device_link
  @mobile_number_device_link
end

#network_carrierObject

The Network/carrier captured during the customer session



81
82
83
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 81

def network_carrier
  @network_carrier
end

#operating_systemObject

The device Operating System captured during the customer session



84
85
86
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 84

def operating_system
  @operating_system
end

#point_of_saleObject

Returns the value of attribute point_of_sale.



122
123
124
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 122

def point_of_sale
  @point_of_sale
end

#postal_codeObject

The postal code the device is registered to as captured during the customer session.



87
88
89
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 87

def postal_code
  @postal_code
end

#proxy_descriptionObject

The Proxy type description captured during the customer session



90
91
92
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 90

def proxy_description
  @proxy_description
end

#proxy_typeObject

The Proxy type captured during the customer session



93
94
95
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 93

def proxy_type
  @proxy_type
end

#reference_idObject

Session reference ID used to correlate the device fingerprinting session with the transaction. Must match the session ID submitted to the device fingerprinting script



137
138
139
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 137

def reference_id
  @reference_id
end

#regionObject

The device region code captured during the customer session



96
97
98
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 96

def region
  @region
end

#screen_resolutionObject

The screen resolution captured during the customer session



99
100
101
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 99

def screen_resolution
  @screen_resolution
end

#session_latitudeObject

Thelatitude captured during the customer session



102
103
104
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 102

def session_latitude
  @session_latitude
end

#session_longitudeObject

The longitude captured during the customer session



105
106
107
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 105

def session_longitude
  @session_longitude
end

#timestampObject

The timestamp captured during the customer session



108
109
110
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 108

def timestamp
  @timestamp
end

#typeObject

The Device Type captured during the customer session



111
112
113
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 111

def type
  @type
end

#user_agent_stringObject

The UserAgentString captured during the customer session



114
115
116
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 114

def user_agent_string
  @user_agent_string
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 149

def self.attribute_map
  {
    :'ip_address' => :'ipAddress',
    :'host_name' => :'hostName',
    :'anonymizer_in_use_flag' => :'anonymizerInUseFlag',
    :'area_code' => :'areaCode',
    :'browser_type' => :'browserType',
    :'browser_version' => :'browserVersion',
    :'city' => :'city',
    :'client_timezone' => :'clientTimezone',
    :'continent_code' => :'continentCode',
    :'cookie_id' => :'cookieId',
    :'country_code' => :'countryCode',
    :'country_name' => :'countryName',
    :'device_fingerprint' => :'deviceFingerprint',
    :'device_imei' => :'deviceIMEI',
    :'device_name' => :'deviceName',
    :'flash_plugin' => :'flashPlugin',
    :'http_header' => :'httpHeader',
    :'metro_code' => :'metroCode',
    :'mfa_session' => :'mfaSession',
    :'mime_types_present' => :'mimeTypesPresent',
    :'mobile_number_device_link' => :'mobileNumberDeviceLink',
    :'network_carrier' => :'networkCarrier',
    :'operating_system' => :'operatingSystem',
    :'postal_code' => :'postalCode',
    :'proxy_description' => :'proxyDescription',
    :'proxy_type' => :'proxyType',
    :'region' => :'region',
    :'screen_resolution' => :'screenResolution',
    :'session_latitude' => :'sessionLatitude',
    :'session_longitude' => :'sessionLongitude',
    :'timestamp' => :'timestamp',
    :'type' => :'type',
    :'user_agent_string' => :'userAgentString',
    :'device_id' => :'deviceId',
    :'device_fingerprint_provider' => :'deviceFingerprintProvider',
    :'point_of_sale' => :'pointOfSale',
    :'ip_address_v4' => :'ipAddressV4',
    :'ip_address_v6' => :'ipAddressV6',
    :'device_fingerprint_vendor' => :'deviceFingerprintVendor',
    :'device_entity_id' => :'deviceEntityId',
    :'reference_id' => :'referenceId',
    :'encrypted_device_data' => :'encryptedDeviceData',
    :'device_binding_status' => :'deviceBindingStatus',
    :'device_binding_status_source' => :'deviceBindingStatusSource'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 199

def self.json_map
  {
    :'ip_address' => :'ip_address',
    :'host_name' => :'host_name',
    :'anonymizer_in_use_flag' => :'anonymizer_in_use_flag',
    :'area_code' => :'area_code',
    :'browser_type' => :'browser_type',
    :'browser_version' => :'browser_version',
    :'city' => :'city',
    :'client_timezone' => :'client_timezone',
    :'continent_code' => :'continent_code',
    :'cookie_id' => :'cookie_id',
    :'country_code' => :'country_code',
    :'country_name' => :'country_name',
    :'device_fingerprint' => :'device_fingerprint',
    :'device_imei' => :'device_imei',
    :'device_name' => :'device_name',
    :'flash_plugin' => :'flash_plugin',
    :'http_header' => :'http_header',
    :'metro_code' => :'metro_code',
    :'mfa_session' => :'mfa_session',
    :'mime_types_present' => :'mime_types_present',
    :'mobile_number_device_link' => :'mobile_number_device_link',
    :'network_carrier' => :'network_carrier',
    :'operating_system' => :'operating_system',
    :'postal_code' => :'postal_code',
    :'proxy_description' => :'proxy_description',
    :'proxy_type' => :'proxy_type',
    :'region' => :'region',
    :'screen_resolution' => :'screen_resolution',
    :'session_latitude' => :'session_latitude',
    :'session_longitude' => :'session_longitude',
    :'timestamp' => :'timestamp',
    :'type' => :'type',
    :'user_agent_string' => :'user_agent_string',
    :'device_id' => :'device_id',
    :'device_fingerprint_provider' => :'device_fingerprint_provider',
    :'point_of_sale' => :'point_of_sale',
    :'ip_address_v4' => :'ip_address_v4',
    :'ip_address_v6' => :'ip_address_v6',
    :'device_fingerprint_vendor' => :'device_fingerprint_vendor',
    :'device_entity_id' => :'device_entity_id',
    :'reference_id' => :'reference_id',
    :'encrypted_device_data' => :'encrypted_device_data',
    :'device_binding_status' => :'device_binding_status',
    :'device_binding_status_source' => :'device_binding_status_source'
  }
end

.swagger_typesObject

Attribute type mapping.



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 249

def self.swagger_types
  {
    :'ip_address' => :'String',
    :'host_name' => :'String',
    :'anonymizer_in_use_flag' => :'BOOLEAN',
    :'area_code' => :'String',
    :'browser_type' => :'String',
    :'browser_version' => :'String',
    :'city' => :'String',
    :'client_timezone' => :'String',
    :'continent_code' => :'String',
    :'cookie_id' => :'String',
    :'country_code' => :'String',
    :'country_name' => :'String',
    :'device_fingerprint' => :'String',
    :'device_imei' => :'String',
    :'device_name' => :'String',
    :'flash_plugin' => :'String',
    :'http_header' => :'String',
    :'metro_code' => :'String',
    :'mfa_session' => :'BOOLEAN',
    :'mime_types_present' => :'String',
    :'mobile_number_device_link' => :'String',
    :'network_carrier' => :'String',
    :'operating_system' => :'String',
    :'postal_code' => :'String',
    :'proxy_description' => :'String',
    :'proxy_type' => :'String',
    :'region' => :'String',
    :'screen_resolution' => :'String',
    :'session_latitude' => :'Float',
    :'session_longitude' => :'Float',
    :'timestamp' => :'DateTime',
    :'type' => :'String',
    :'user_agent_string' => :'String',
    :'device_id' => :'String',
    :'device_fingerprint_provider' => :'String',
    :'point_of_sale' => :'UnifiedriskDevicePointOfSale',
    :'ip_address_v4' => :'String',
    :'ip_address_v6' => :'String',
    :'device_fingerprint_vendor' => :'String',
    :'device_entity_id' => :'String',
    :'reference_id' => :'String',
    :'encrypted_device_data' => :'String',
    :'device_binding_status' => :'String',
    :'device_binding_status_source' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 516

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ip_address == o.ip_address &&
      host_name == o.host_name &&
      anonymizer_in_use_flag == o.anonymizer_in_use_flag &&
      area_code == o.area_code &&
      browser_type == o.browser_type &&
      browser_version == o.browser_version &&
      city == o.city &&
      client_timezone == o.client_timezone &&
      continent_code == o.continent_code &&
      cookie_id == o.cookie_id &&
      country_code == o.country_code &&
      country_name == o.country_name &&
      device_fingerprint == o.device_fingerprint &&
      device_imei == o.device_imei &&
      device_name == o.device_name &&
      flash_plugin == o.flash_plugin &&
      http_header == o.http_header &&
      metro_code == o.metro_code &&
      mfa_session == o.mfa_session &&
      mime_types_present == o.mime_types_present &&
      mobile_number_device_link == o.mobile_number_device_link &&
      network_carrier == o.network_carrier &&
      operating_system == o.operating_system &&
      postal_code == o.postal_code &&
      proxy_description == o.proxy_description &&
      proxy_type == o.proxy_type &&
      region == o.region &&
      screen_resolution == o.screen_resolution &&
      session_latitude == o.session_latitude &&
      session_longitude == o.session_longitude &&
      timestamp == o.timestamp &&
      type == o.type &&
      user_agent_string == o.user_agent_string &&
      device_id == o.device_id &&
      device_fingerprint_provider == o.device_fingerprint_provider &&
      point_of_sale == o.point_of_sale &&
      ip_address_v4 == o.ip_address_v4 &&
      ip_address_v6 == o.ip_address_v6 &&
      device_fingerprint_vendor == o.device_fingerprint_vendor &&
      device_entity_id == o.device_entity_id &&
      reference_id == o.reference_id &&
      encrypted_device_data == o.encrypted_device_data &&
      device_binding_status == o.device_binding_status &&
      device_binding_status_source == o.device_binding_status_source
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 601

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly

    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model

    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



667
668
669
670
671
672
673
674
675
676
677
678
679
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 667

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 580

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute

      # is documented as an array but the input is not

      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional

  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


567
568
569
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 567

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



573
574
575
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 573

def hash
  [ip_address, host_name, anonymizer_in_use_flag, area_code, browser_type, browser_version, city, client_timezone, continent_code, cookie_id, country_code, country_name, device_fingerprint, device_imei, device_name, flash_plugin, http_header, metro_code, mfa_session, mime_types_present, mobile_number_device_link, network_carrier, operating_system, postal_code, proxy_description, proxy_type, region, screen_resolution, session_latitude, session_longitude, timestamp, type, user_agent_string, device_id, device_fingerprint_provider, point_of_sale, ip_address_v4, ip_address_v6, device_fingerprint_vendor, device_entity_id, reference_id, encrypted_device_data, device_binding_status, device_binding_status_source].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



485
486
487
488
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 485

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



647
648
649
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 647

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



653
654
655
656
657
658
659
660
661
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 653

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



641
642
643
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 641

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



492
493
494
# File 'lib/cybersource_rest_client/models/unifiedrisk_device.rb', line 492

def valid?
  true
end