Class: CyberSource::UnifiedriskMerchant

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_merchant.rb

Overview

Merchant identification, location, category code, and local currency

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskMerchant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 112

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'categoryCode')
    self.category_code = attributes[:'categoryCode']
  end

  if attributes.has_key?(:'merchantId')
    self.merchant_id = attributes[:'merchantId']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'merchantDescriptor')
    self.merchant_descriptor = attributes[:'merchantDescriptor']
  end

  if attributes.has_key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.has_key?(:'industryOfBusiness')
    self.industry_of_business = attributes[:'industryOfBusiness']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'tradingAddress')
    self.trading_address = attributes[:'tradingAddress']
  end

  if attributes.has_key?(:'referenceNumber')
    self.reference_number = attributes[:'referenceNumber']
  end

  if attributes.has_key?(:'merchantDefinedData')
    self.merchant_defined_data = attributes[:'merchantDefinedData']
  end

  if attributes.has_key?(:'merchantSellerId')
    self.merchant_seller_id = attributes[:'merchantSellerId']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



31
32
33
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 31

def address
  @address
end

#category_codeObject

Merchant category code (MCC) related to the type of services or goods the merchant provides for the transaction. It is strongly recommended that this conforms to an international standard such as ISO



18
19
20
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 18

def category_code
  @category_code
end

#currencyObject

Merchant's local currency (ISO 4217 3-letter code). Used for currency conversion calculations.



27
28
29
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 27

def currency
  @currency
end

#industry_of_businessObject

Industry sector or vertical the merchant operates in (e.g., RETAIL, HOSPITALITY, HEALTHCARE, FINANCIAL_SERVICES). Provides broader business context beyond the MCC



34
35
36
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 34

def industry_of_business
  @industry_of_business
end

#merchant_defined_dataObject

Free-form merchant-provided data for risk assessment, allowing supplementary information not captured by standard fields (e.g., loyalty tier, custom risk flags)



48
49
50
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 48

def merchant_defined_data
  @merchant_defined_data
end

#merchant_descriptorObject

Returns the value of attribute merchant_descriptor.



29
30
31
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 29

def merchant_descriptor
  @merchant_descriptor
end

#merchant_idObject

Identifier of the merchant in a transaction. This should be fully unique; two different merchants should not have the same merchantId. It is also essential that this merchantId is consistent over time



21
22
23
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 21

def merchant_id
  @merchant_id
end

#merchant_seller_idObject

Unique identifier assigned to this merchant as a seller within a marketplace or platform (e.g., Amazon Marketplace seller ID). Used to distinguish sub-merchants in aggregator models



51
52
53
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 51

def merchant_seller_id
  @merchant_seller_id
end

#nameObject

Name of the merchant in merchantId. This should include enough information to clearly identify the merchant, whenever possible.



24
25
26
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 24

def name
  @name
end

#reference_numberObject

An external or internal reference number associated with the merchant, used for cross-system reconciliation (e.g., CRM ID, acquirer reference, banking platform reference)



45
46
47
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 45

def reference_number
  @reference_number
end

#statusObject

Current operational status of the merchant account (e.g., ACTIVE, SUSPENDED, TERMINATED, PENDING_REVIEW). Drives eligibility checks during transaction processing



37
38
39
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 37

def status
  @status
end

#trading_addressObject

Returns the value of attribute trading_address.



42
43
44
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 42

def trading_address
  @trading_address
end

#typeObject

Classification of the merchant's business type (e.g., SOLE_TRADER, PARTNERSHIP, LIMITED_COMPANY, NON_PROFIT). Used for regulatory and underwriting purposes



40
41
42
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 40

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 54

def self.attribute_map
  {
    :'category_code' => :'categoryCode',
    :'merchant_id' => :'merchantId',
    :'name' => :'name',
    :'currency' => :'currency',
    :'merchant_descriptor' => :'merchantDescriptor',
    :'address' => :'address',
    :'industry_of_business' => :'industryOfBusiness',
    :'status' => :'status',
    :'type' => :'type',
    :'trading_address' => :'tradingAddress',
    :'reference_number' => :'referenceNumber',
    :'merchant_defined_data' => :'merchantDefinedData',
    :'merchant_seller_id' => :'merchantSellerId'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 73

def self.json_map
  {
    :'category_code' => :'category_code',
    :'merchant_id' => :'merchant_id',
    :'name' => :'name',
    :'currency' => :'currency',
    :'merchant_descriptor' => :'merchant_descriptor',
    :'address' => :'address',
    :'industry_of_business' => :'industry_of_business',
    :'status' => :'status',
    :'type' => :'type',
    :'trading_address' => :'trading_address',
    :'reference_number' => :'reference_number',
    :'merchant_defined_data' => :'merchant_defined_data',
    :'merchant_seller_id' => :'merchant_seller_id'
  }
end

.swagger_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 92

def self.swagger_types
  {
    :'category_code' => :'String',
    :'merchant_id' => :'String',
    :'name' => :'String',
    :'currency' => :'String',
    :'merchant_descriptor' => :'UnifiedriskMerchantMerchantDescriptor',
    :'address' => :'UnifiedriskMerchantAddress',
    :'industry_of_business' => :'String',
    :'status' => :'String',
    :'type' => :'String',
    :'trading_address' => :'UnifiedriskMerchantTradingAddress',
    :'reference_number' => :'String',
    :'merchant_defined_data' => :'String',
    :'merchant_seller_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      category_code == o.category_code &&
      merchant_id == o.merchant_id &&
      name == o.name &&
      currency == o.currency &&
      merchant_descriptor == o.merchant_descriptor &&
      address == o.address &&
      industry_of_business == o.industry_of_business &&
      status == o.status &&
      type == o.type &&
      trading_address == o.trading_address &&
      reference_number == o.reference_number &&
      merchant_defined_data == o.merchant_defined_data &&
      merchant_seller_id == o.merchant_seller_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 246

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 312

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 225

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 212

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



218
219
220
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 218

def hash
  [category_code, merchant_id, name, currency, merchant_descriptor, address, industry_of_business, status, type, trading_address, reference_number, merchant_defined_data, merchant_seller_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 173

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 292

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



286
287
288
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 286

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant.rb', line 180

def valid?
  true
end