Class: CyberSource::UnifiedriskMerchantTradingAddress

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb

Overview

The merchant's trading or operating address where business activities take place, which may differ from the registered legal address

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskMerchantTradingAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 103

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key

  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'addressLine1')
    self.address_line1 = attributes[:'addressLine1']
  end

  if attributes.has_key?(:'addressLine2')
    self.address_line2 = attributes[:'addressLine2']
  end

  if attributes.has_key?(:'addressLine3')
    self.address_line3 = attributes[:'addressLine3']
  end

  if attributes.has_key?(:'addressType')
    self.address_type = attributes[:'addressType']
  end

  if attributes.has_key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.has_key?(:'countrySubDivision')
    self.country_sub_division = attributes[:'countrySubDivision']
  end

  if attributes.has_key?(:'fullAddress')
    self.full_address = attributes[:'fullAddress']
  end

  if attributes.has_key?(:'latitude')
    self.latitude = attributes[:'latitude']
  end

  if attributes.has_key?(:'longitude')
    self.longitude = attributes[:'longitude']
  end

  if attributes.has_key?(:'postalCode')
    self.postal_code = attributes[:'postalCode']
  end

  if attributes.has_key?(:'locality')
    self.locality = attributes[:'locality']
  end
end

Instance Attribute Details

#address_line1Object

First line of the merchant's trading (physical store or operating) address, including street number and name



18
19
20
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 18

def address_line1
  @address_line1
end

#address_line2Object

Second line of the merchant's trading address for suite, unit, or floor details



21
22
23
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 21

def address_line2
  @address_line2
end

#address_line3Object

Third line of the merchant's trading address for additional location information



24
25
26
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 24

def address_line3
  @address_line3
end

#address_typeObject

Type of the trading address (e.g., TRADING, PHYSICAL, OPERATING) identifying its business use



27
28
29
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 27

def address_type
  @address_type
end

#countryObject

ISO 3166-1 alpha-3 country code for the merchant's trading address (e.g., GBR, USA, DEU)



30
31
32
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 30

def country
  @country
end

#country_sub_divisionObject

ISO 3166-2 subdivision code for the merchant's trading address state, province, or region (e.g., US-CA, GB-ENG)



33
34
35
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 33

def country_sub_division
  @country_sub_division
end

#full_addressObject

Complete concatenated trading address as a single string, including all lines, locality, postcode, and country



36
37
38
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 36

def full_address
  @full_address
end

#latitudeObject

Geographic latitude coordinate of the merchant's trading location in decimal degrees, used for proximity risk signals



39
40
41
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 39

def latitude
  @latitude
end

#localityObject

City or town of the merchant's trading address (e.g., London, New York, Berlin)



48
49
50
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 48

def locality
  @locality
end

#longitudeObject

Geographic longitude coordinate of the merchant's trading location in decimal degrees, used for proximity risk signals



42
43
44
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 42

def longitude
  @longitude
end

#postal_codeObject

Postal or ZIP code of the merchant's trading address (e.g., SW1A 1AA, 10001)



45
46
47
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 45

def postal_code
  @postal_code
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 51

def self.attribute_map
  {
    :'address_line1' => :'addressLine1',
    :'address_line2' => :'addressLine2',
    :'address_line3' => :'addressLine3',
    :'address_type' => :'addressType',
    :'country' => :'country',
    :'country_sub_division' => :'countrySubDivision',
    :'full_address' => :'fullAddress',
    :'latitude' => :'latitude',
    :'longitude' => :'longitude',
    :'postal_code' => :'postalCode',
    :'locality' => :'locality'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 68

def self.json_map
  {
    :'address_line1' => :'address_line1',
    :'address_line2' => :'address_line2',
    :'address_line3' => :'address_line3',
    :'address_type' => :'address_type',
    :'country' => :'country',
    :'country_sub_division' => :'country_sub_division',
    :'full_address' => :'full_address',
    :'latitude' => :'latitude',
    :'longitude' => :'longitude',
    :'postal_code' => :'postal_code',
    :'locality' => :'locality'
  }
end

.swagger_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 85

def self.swagger_types
  {
    :'address_line1' => :'String',
    :'address_line2' => :'String',
    :'address_line3' => :'String',
    :'address_type' => :'String',
    :'country' => :'String',
    :'country_sub_division' => :'String',
    :'full_address' => :'String',
    :'latitude' => :'String',
    :'longitude' => :'String',
    :'postal_code' => :'String',
    :'locality' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address_line1 == o.address_line1 &&
      address_line2 == o.address_line2 &&
      address_line3 == o.address_line3 &&
      address_type == o.address_type &&
      country == o.country &&
      country_sub_division == o.country_sub_division &&
      full_address == o.full_address &&
      latitude == o.latitude &&
      longitude == o.longitude &&
      postal_code == o.postal_code &&
      locality == o.locality
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 221

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly

    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model

    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 287

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 200

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute

      # is documented as an array but the input is not

      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional

  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 187

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



193
194
195
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 193

def hash
  [address_line1, address_line2, address_line3, address_type, country, country_sub_division, full_address, latitude, longitude, postal_code, locality].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 156

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 267

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 273

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



261
262
263
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 261

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
# File 'lib/cybersource_rest_client/models/unifiedrisk_merchant_trading_address.rb', line 163

def valid?
  true
end