Class: CyberSource::UnifiedriskOrder

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_order.rb

Overview

E-commerce order details including line items, billing/shipping addresses, and shipping preferences

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskOrder

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 76

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key

  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'totalItemsCount')
    self.total_items_count = attributes[:'totalItemsCount']
  end

  if attributes.has_key?(:'returnsAccepted')
    self.returns_accepted = attributes[:'returnsAccepted']
  end

  if attributes.has_key?(:'lineItems')
    if (value = attributes[:'lineItems']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.has_key?(:'shipping')
    self.shipping = attributes[:'shipping']
  end

  if attributes.has_key?(:'billing')
    self.billing = attributes[:'billing']
  end

  if attributes.has_key?(:'orderId')
    self.order_id = attributes[:'orderId']
  end

  if attributes.has_key?(:'orderDescription')
    self.order_description = attributes[:'orderDescription']
  end
end

Instance Attribute Details

#billingObject

Returns the value of attribute billing.



27
28
29
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 27

def billing
  @billing
end

#line_itemsObject

Returns the value of attribute line_items.



23
24
25
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 23

def line_items
  @line_items
end

#order_descriptionObject

Free-text description of the order contents or purpose, provided by the merchant for risk analysis and dispute management



33
34
35
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 33

def order_description
  @order_description
end

#order_idObject

Merchant-assigned unique identifier for this order, used for transaction correlation, dispute matching, and fraud monitoring



30
31
32
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 30

def order_id
  @order_id
end

#returns_acceptedObject

Indicates if returns are accepted



21
22
23
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 21

def returns_accepted
  @returns_accepted
end

#shippingObject

Returns the value of attribute shipping.



25
26
27
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 25

def shipping
  @shipping
end

#total_items_countObject

Total number of items in order



18
19
20
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 18

def total_items_count
  @total_items_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 36

def self.attribute_map
  {
    :'total_items_count' => :'totalItemsCount',
    :'returns_accepted' => :'returnsAccepted',
    :'line_items' => :'lineItems',
    :'shipping' => :'shipping',
    :'billing' => :'billing',
    :'order_id' => :'orderId',
    :'order_description' => :'orderDescription'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 49

def self.json_map
  {
    :'total_items_count' => :'total_items_count',
    :'returns_accepted' => :'returns_accepted',
    :'line_items' => :'line_items',
    :'shipping' => :'shipping',
    :'billing' => :'billing',
    :'order_id' => :'order_id',
    :'order_description' => :'order_description'
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 62

def self.swagger_types
  {
    :'total_items_count' => :'Integer',
    :'returns_accepted' => :'BOOLEAN',
    :'line_items' => :'Array<UnifiedriskOrderLineItems>',
    :'shipping' => :'UnifiedriskOrderShipping',
    :'billing' => :'UnifiedriskOrderBilling',
    :'order_id' => :'String',
    :'order_description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 128

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      total_items_count == o.total_items_count &&
      returns_accepted == o.returns_accepted &&
      line_items == o.line_items &&
      shipping == o.shipping &&
      billing == o.billing &&
      order_id == o.order_id &&
      order_description == o.order_description
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 176

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly

    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model

    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 242

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 155

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute

      # is documented as an array but the input is not

      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional

  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


142
143
144
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 142

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



148
149
150
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 148

def hash
  [total_items_count, returns_accepted, line_items, shipping, billing, order_id, order_description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 115

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 222

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



216
217
218
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 216

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



122
123
124
# File 'lib/cybersource_rest_client/models/unifiedrisk_order.rb', line 122

def valid?
  true
end