Class: CyberSource::UnifiedriskOrderShipping

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskOrderShipping

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 148

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key

  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'addressLine1')
    self.address_line1 = attributes[:'addressLine1']
  end

  if attributes.has_key?(:'addressLine2')
    self.address_line2 = attributes[:'addressLine2']
  end

  if attributes.has_key?(:'addressLine3')
    self.address_line3 = attributes[:'addressLine3']
  end

  if attributes.has_key?(:'administrativeArea')
    self.administrative_area = attributes[:'administrativeArea']
  end

  if attributes.has_key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.has_key?(:'destinationTypes')
    self.destination_types = attributes[:'destinationTypes']
  end

  if attributes.has_key?(:'locality')
    self.locality = attributes[:'locality']
  end

  if attributes.has_key?(:'firstName')
    self.first_name = attributes[:'firstName']
  end

  if attributes.has_key?(:'lastName')
    self.last_name = attributes[:'lastName']
  end

  if attributes.has_key?(:'middleName')
    self.middle_name = attributes[:'middleName']
  end

  if attributes.has_key?(:'phoneNumber')
    self.phone_number = attributes[:'phoneNumber']
  end

  if attributes.has_key?(:'postalCode')
    self.postal_code = attributes[:'postalCode']
  end

  if attributes.has_key?(:'destinationCode')
    self.destination_code = attributes[:'destinationCode']
  end

  if attributes.has_key?(:'deliveryType')
    self.delivery_type = attributes[:'deliveryType']
  end

  if attributes.has_key?(:'giftWrap')
    self.gift_wrap = attributes[:'giftWrap']
  end

  if attributes.has_key?(:'shippingMethod')
    self.shipping_method = attributes[:'shippingMethod']
  end

  if attributes.has_key?(:'store')
    self.store = attributes[:'store']
  end

  if attributes.has_key?(:'storeAddress')
    self.store_address = attributes[:'storeAddress']
  end

  if attributes.has_key?(:'email')
    self.email = attributes[:'email']
  end
end

Instance Attribute Details

#address_line1Object

First line of the shipping address.Required field for authorization if any shipping address information is included in the request; otherwise, optional.#### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder's location when shipTo objects are not present.



17
18
19
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 17

def address_line1
  @address_line1
end

#address_line2Object

Second line of the shipping address.Optional field.#### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder's location when shipTo objects are not present.



20
21
22
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 20

def address_line2
  @address_line2
end

#address_line3Object

Third line of the shipping address.#### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder's location when shipTo objects are not present.



23
24
25
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 23

def address_line3
  @address_line3
end

#administrative_areaObject

State or province of the shipping address. Use the State, Province, and Territory Codes for the United States and Canada (maximum length: 2) Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional. #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value



26
27
28
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 26

def administrative_area
  @administrative_area
end

#countryObject

Country of the shipping address. Use the two-character [ISO Standard Country Codes.]



29
30
31
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 29

def country
  @country
end

#delivery_typeObject

Delivery/fulfillment method Possible values: - shipToHome - storePickup - lockerPickup - curbside



56
57
58
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 56

def delivery_type
  @delivery_type
end

#destination_codeObject

Indicates destination chosen for the transaction. Possible values: - 01- Ship to cardholder billing address - 02- Ship to another verified address on file with merchant - 03- Ship to address that is different than billing address - 04- Ship to store (store address should be populated on request) - 05- Digital goods - 06- Travel and event tickets, not shipped - 07- Other



53
54
55
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 53

def destination_code
  @destination_code
end

#destination_typesObject

Shipping destination of item. Example: Commercial, Residential, Store



32
33
34
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 32

def destination_types
  @destination_types
end

#emailObject

Email address of the recipient or shipping contact for order confirmation, dispatch notifications, and delivery tracking



69
70
71
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 69

def email
  @email
end

#first_nameObject

First name of the recipient.#### Litle Maximum length: 25#### All other processors Maximum length: 60Optional field.



38
39
40
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 38

def first_name
  @first_name
end

#gift_wrapObject

Boolean that indicates whether the customer requested gift wrapping for this purchase. This field can contain one of the following values: - true: The customer requested gift wrapping. - false: The customer did not request gift wrapping.



59
60
61
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 59

def gift_wrap
  @gift_wrap
end

#last_nameObject

Last name of the recipient.#### Litle Maximum length: 25#### All other processors Maximum length: 60Optional field.



41
42
43
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 41

def last_name
  @last_name
end

#localityObject

City of the shipping address.Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.#### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. Billing address objects will be used to determine the cardholder's location when shipTo objects are not present.



35
36
37
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 35

def locality
  @locality
end

#middle_nameObject

Middle name of the recipient.#### Litle Maximum length: 25#### All other processors Maximum length: 60Optional field.



44
45
46
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 44

def middle_name
  @middle_name
end

#phone_numberObject

Phone number associated with the shipping address.



47
48
49
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 47

def phone_number
  @phone_number
end

#postal_codeObject

Postal code for the shipping address. The postal code must consist of 5 to 9 digits.Required field for authorization if any shipping address information is included in the request and shipping to the U.S. or Canada; otherwise, optional.When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits]Example 12345-6789When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][



50
51
52
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 50

def postal_code
  @postal_code
end

#shipping_methodObject

Shipping method for the product. Possible values: - lowcost: Lowest-cost service - sameday: Courier or same-day service - oneday: Next-day or overnight service - twoday: Two-day service



62
63
64
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 62

def shipping_method
  @shipping_method
end

#storeObject

Returns the value of attribute store.



64
65
66
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 64

def store
  @store
end

#store_addressObject

Returns the value of attribute store_address.



66
67
68
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 66

def store_address
  @store_address
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 72

def self.attribute_map
  {
    :'address_line1' => :'addressLine1',
    :'address_line2' => :'addressLine2',
    :'address_line3' => :'addressLine3',
    :'administrative_area' => :'administrativeArea',
    :'country' => :'country',
    :'destination_types' => :'destinationTypes',
    :'locality' => :'locality',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'middle_name' => :'middleName',
    :'phone_number' => :'phoneNumber',
    :'postal_code' => :'postalCode',
    :'destination_code' => :'destinationCode',
    :'delivery_type' => :'deliveryType',
    :'gift_wrap' => :'giftWrap',
    :'shipping_method' => :'shippingMethod',
    :'store' => :'store',
    :'store_address' => :'storeAddress',
    :'email' => :'email'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 97

def self.json_map
  {
    :'address_line1' => :'address_line1',
    :'address_line2' => :'address_line2',
    :'address_line3' => :'address_line3',
    :'administrative_area' => :'administrative_area',
    :'country' => :'country',
    :'destination_types' => :'destination_types',
    :'locality' => :'locality',
    :'first_name' => :'first_name',
    :'last_name' => :'last_name',
    :'middle_name' => :'middle_name',
    :'phone_number' => :'phone_number',
    :'postal_code' => :'postal_code',
    :'destination_code' => :'destination_code',
    :'delivery_type' => :'delivery_type',
    :'gift_wrap' => :'gift_wrap',
    :'shipping_method' => :'shipping_method',
    :'store' => :'store',
    :'store_address' => :'store_address',
    :'email' => :'email'
  }
end

.swagger_typesObject

Attribute type mapping.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 122

def self.swagger_types
  {
    :'address_line1' => :'String',
    :'address_line2' => :'String',
    :'address_line3' => :'String',
    :'administrative_area' => :'String',
    :'country' => :'String',
    :'destination_types' => :'String',
    :'locality' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'middle_name' => :'String',
    :'phone_number' => :'String',
    :'postal_code' => :'String',
    :'destination_code' => :'Integer',
    :'delivery_type' => :'String',
    :'gift_wrap' => :'BOOLEAN',
    :'shipping_method' => :'String',
    :'store' => :'UnifiedriskOrderShippingStore',
    :'store_address' => :'UnifiedriskOrderShippingStoreAddress',
    :'email' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 324

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address_line1 == o.address_line1 &&
      address_line2 == o.address_line2 &&
      address_line3 == o.address_line3 &&
      administrative_area == o.administrative_area &&
      country == o.country &&
      destination_types == o.destination_types &&
      locality == o.locality &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      middle_name == o.middle_name &&
      phone_number == o.phone_number &&
      postal_code == o.postal_code &&
      destination_code == o.destination_code &&
      delivery_type == o.delivery_type &&
      gift_wrap == o.gift_wrap &&
      shipping_method == o.shipping_method &&
      store == o.store &&
      store_address == o.store_address &&
      email == o.email
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 384

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly

    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model

    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 450

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 363

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute

      # is documented as an array but the input is not

      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional

  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


350
351
352
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 350

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



356
357
358
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 356

def hash
  [address_line1, address_line2, address_line3, administrative_area, country, destination_types, locality, first_name, last_name, middle_name, phone_number, postal_code, destination_code, delivery_type, gift_wrap, shipping_method, store, store_address, email].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



233
234
235
236
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 233

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 430

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
439
440
441
442
443
444
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 436

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



424
425
426
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 424

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



240
241
242
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_shipping.rb', line 240

def valid?
  true
end