Class: CyberSource::UnifiedriskPaymentCheck

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb

Overview

Container for check-specific payment details including MICR line data, deposit location, and split deposit information

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskPaymentCheck

Initializes the object



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 96

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key

  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'checkNumber')
    self.check_number = attributes[:'checkNumber']
  end

  if attributes.has_key?(:'depositSlipId')
    self.deposit_slip_id = attributes[:'depositSlipId']
  end

  if attributes.has_key?(:'depositLocation')
    self.deposit_location = attributes[:'depositLocation']
  end

  if attributes.has_key?(:'micrAccountNumber')
    self. = attributes[:'micrAccountNumber']
  end

  if attributes.has_key?(:'routingTransitNumber')
    self.routing_transit_number = attributes[:'routingTransitNumber']
  end

  if attributes.has_key?(:'splitDepositFlag')
    self.split_deposit_flag = attributes[:'splitDepositFlag']
  end

  if attributes.has_key?(:'splitAccountId1')
    self. = attributes[:'splitAccountId1']
  end

  if attributes.has_key?(:'splitAccountId2')
    self. = attributes[:'splitAccountId2']
  end

  if attributes.has_key?(:'splitAccountId3')
    self. = attributes[:'splitAccountId3']
  end

  if attributes.has_key?(:'splitAccountId4')
    self. = attributes[:'splitAccountId4']
  end
end

Instance Attribute Details

#check_numberObject

Serial number printed on the physical check, used for duplicate detection, check fraud prevention, and reconciliation



18
19
20
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 18

def check_number
  @check_number
end

#deposit_locationObject

Returns the value of attribute deposit_location.



23
24
25
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 23

def deposit_location
  @deposit_location
end

#deposit_slip_idObject

Unique identifier for the deposit slip associated with the check deposit, used for linking deposited checks to branch transactions



21
22
23
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 21

def deposit_slip_id
  @deposit_slip_id
end

#micr_account_numberObject

Account number encoded in the MICR (Magnetic Ink Character Recognition) line at the bottom of the check, used for automated account identification



26
27
28
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 26

def 
  
end

#routing_transit_numberObject

Bank routing and transit number (RTN) encoded in the MICR line of the check, identifying the financial institution on which the check is drawn



29
30
31
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 29

def routing_transit_number
  @routing_transit_number
end

#split_account_id1Object

First destination account ID in a split check deposit, used for tracking the allocation of funds across multiple accounts



35
36
37
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 35

def 
  
end

#split_account_id2Object

Second destination account ID in a split check deposit



38
39
40
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 38

def 
  
end

#split_account_id3Object

Third destination account ID in a split check deposit



41
42
43
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 41

def 
  
end

#split_account_id4Object

Fourth destination account ID in a split check deposit



44
45
46
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 44

def 
  
end

#split_deposit_flagObject

Indicates whether the check deposit has been split across multiple accounts. Split deposits may indicate structuring or kiting attempts



32
33
34
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 32

def split_deposit_flag
  @split_deposit_flag
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 47

def self.attribute_map
  {
    :'check_number' => :'checkNumber',
    :'deposit_slip_id' => :'depositSlipId',
    :'deposit_location' => :'depositLocation',
    :'micr_account_number' => :'micrAccountNumber',
    :'routing_transit_number' => :'routingTransitNumber',
    :'split_deposit_flag' => :'splitDepositFlag',
    :'split_account_id1' => :'splitAccountId1',
    :'split_account_id2' => :'splitAccountId2',
    :'split_account_id3' => :'splitAccountId3',
    :'split_account_id4' => :'splitAccountId4'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 63

def self.json_map
  {
    :'check_number' => :'check_number',
    :'deposit_slip_id' => :'deposit_slip_id',
    :'deposit_location' => :'deposit_location',
    :'micr_account_number' => :'micr_account_number',
    :'routing_transit_number' => :'routing_transit_number',
    :'split_deposit_flag' => :'split_deposit_flag',
    :'split_account_id1' => :'split_account_id1',
    :'split_account_id2' => :'split_account_id2',
    :'split_account_id3' => :'split_account_id3',
    :'split_account_id4' => :'split_account_id4'
  }
end

.swagger_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 79

def self.swagger_types
  {
    :'check_number' => :'String',
    :'deposit_slip_id' => :'String',
    :'deposit_location' => :'UnifiedriskPaymentCheckDepositLocation',
    :'micr_account_number' => :'String',
    :'routing_transit_number' => :'String',
    :'split_deposit_flag' => :'BOOLEAN',
    :'split_account_id1' => :'String',
    :'split_account_id2' => :'String',
    :'split_account_id3' => :'String',
    :'split_account_id4' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      check_number == o.check_number &&
      deposit_slip_id == o.deposit_slip_id &&
      deposit_location == o.deposit_location &&
       == o. &&
      routing_transit_number == o.routing_transit_number &&
      split_deposit_flag == o.split_deposit_flag &&
       == o. &&
       == o. &&
       == o. &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 209

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly

    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model

    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 275

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 188

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute

      # is documented as an array but the input is not

      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional

  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


175
176
177
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 175

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



181
182
183
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 181

def hash
  [check_number, deposit_slip_id, deposit_location, , routing_transit_number, split_deposit_flag, , , , ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



145
146
147
148
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 145

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



255
256
257
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 255

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



249
250
251
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 249

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



152
153
154
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_check.rb', line 152

def valid?
  true
end