Class: CyberSource::UnifiedriskPaymentCounterparty

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskPaymentCounterparty

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 94

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'accountId')
    self. = attributes[:'accountId']
  end

  if attributes.has_key?(:'accountFormat')
    self. = attributes[:'accountFormat']
  end

  if attributes.has_key?(:'branchId')
    self.branch_id = attributes[:'branchId']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'agentId')
    self.agent_id = attributes[:'agentId']
  end

  if attributes.has_key?(:'agentName')
    self.agent_name = attributes[:'agentName']
  end

  if attributes.has_key?(:'branchAddress')
    self.branch_address = attributes[:'branchAddress']
  end

  if attributes.has_key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.has_key?(:'creationTime')
    self.creation_time = attributes[:'creationTime']
  end
end

Instance Attribute Details

#account_formatObject

Counterparty account format



20
21
22
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 20

def 
  @account_format
end

#account_idObject

Counterparty account identifier



17
18
19
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 17

def 
  @account_id
end

#addressObject

Returns the value of attribute address.



39
40
41
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 39

def address
  @address
end

#agent_idObject

Unique identifier for the financial agent or correspondent bank through which the counterparty payment is being routed



32
33
34
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 32

def agent_id
  @agent_id
end

#agent_nameObject

Name of the financial agent or correspondent institution facilitating the payment to the counterparty



35
36
37
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 35

def agent_name
  @agent_name
end

#branch_addressObject

Returns the value of attribute branch_address.



37
38
39
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 37

def branch_address
  @branch_address
end

#branch_idObject

Counterparty branch identifier



23
24
25
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 23

def branch_id
  @branch_id
end

#creation_timeObject

Timestamp when the counterparty record was created in the system, expressed in ISO 8601 format. Used for new payee fraud detection



42
43
44
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 42

def creation_time
  @creation_time
end

#nameObject

Full legal name of the counterparty (individual or business) used for identity matching, beneficiary validation, and fraud screening



26
27
28
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 26

def name
  @name
end

#typeObject

Classification of the counterparty entity type (e.g., INDIVIDUAL, BUSINESS, FINANCIAL_INSTITUTION). Used for AML screening and beneficiary risk assessment



29
30
31
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 29

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 45

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'account_format' => :'accountFormat',
    :'branch_id' => :'branchId',
    :'name' => :'name',
    :'type' => :'type',
    :'agent_id' => :'agentId',
    :'agent_name' => :'agentName',
    :'branch_address' => :'branchAddress',
    :'address' => :'address',
    :'creation_time' => :'creationTime'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 61

def self.json_map
  {
    :'account_id' => :'account_id',
    :'account_format' => :'account_format',
    :'branch_id' => :'branch_id',
    :'name' => :'name',
    :'type' => :'type',
    :'agent_id' => :'agent_id',
    :'agent_name' => :'agent_name',
    :'branch_address' => :'branch_address',
    :'address' => :'address',
    :'creation_time' => :'creation_time'
  }
end

.swagger_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 77

def self.swagger_types
  {
    :'account_id' => :'String',
    :'account_format' => :'String',
    :'branch_id' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'agent_id' => :'String',
    :'agent_name' => :'String',
    :'branch_address' => :'UnifiedriskPaymentCounterpartyBranchAddress',
    :'address' => :'UnifiedriskPaymentCounterpartyAddress',
    :'creation_time' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 156

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      branch_id == o.branch_id &&
      name == o.name &&
      type == o.type &&
      agent_id == o.agent_id &&
      agent_name == o.agent_name &&
      branch_address == o.branch_address &&
      address == o.address &&
      creation_time == o.creation_time
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 207

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 273

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 186

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 173

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



179
180
181
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 179

def hash
  [, , branch_id, name, type, agent_id, agent_name, branch_address, address, creation_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 143

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 253

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



247
248
249
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 247

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
# File 'lib/cybersource_rest_client/models/unifiedrisk_payment_counterparty.rb', line 150

def valid?
  true
end