Class: CyberSource::UnifiedriskTerminalCapabilities
- Inherits:
-
Object
- Object
- CyberSource::UnifiedriskTerminalCapabilities
- Defined in:
- lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb
Instance Attribute Summary collapse
-
#card_reading ⇒ Object
Card reading capabilities of the terminal performing the transaction.
-
#card_writing ⇒ Object
Card writing or output capabilities of the terminal performing the transaction.
-
#cardholder_verification ⇒ Object
Cardholder verification capabilities performing the transaction at the point of service.
-
#online ⇒ Object
Capability of the terminal to go online OFLN OffLine Off-line only capable ONLN OnLine On-line only capable BOTH BothOnLineAndOffLine Both online and offline.
-
#pin_pad_inoperative ⇒ Object
If true then pin pad is inoperative.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UnifiedriskTerminalCapabilities
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UnifiedriskTerminalCapabilities
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 66 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'cardReading') self.card_reading = attributes[:'cardReading'] end if attributes.has_key?(:'cardWriting') self.card_writing = attributes[:'cardWriting'] end if attributes.has_key?(:'cardholderVerification') self.cardholder_verification = attributes[:'cardholderVerification'] end if attributes.has_key?(:'online') self.online = attributes[:'online'] end if attributes.has_key?(:'pinPadInoperative') self.pin_pad_inoperative = attributes[:'pinPadInoperative'] end end |
Instance Attribute Details
#card_reading ⇒ Object
Card reading capabilities of the terminal performing the transaction. ISO 8583:93 bit 22-2; ISO 8583:2003 bit 27-1 CDFL CardOnFile Card information are stored on a file ICPY ICCProximity ICC contactle
17 18 19 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 17 def card_reading @card_reading end |
#card_writing ⇒ Object
Card writing or output capabilities of the terminal performing the transaction. ISO 8583:93 bit 22-10, ISO 8583:2003 bit 27-8_9 ICPY ICCProximity ICC contactless proximity MGST MagneticStripe Magnetic
20 21 22 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 20 def card_writing @card_writing end |
#cardholder_verification ⇒ Object
Cardholder verification capabilities performing the transaction at the point of service. ISO 8583:93 bit 22-2, ISO 8583:2003-1 bit 27-2 APKI AccountDigitalSignature Account based digital signature NO
23 24 25 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 23 def cardholder_verification @cardholder_verification end |
#online ⇒ Object
Capability of the terminal to go online OFLN OffLine Off-line only capable ONLN OnLine On-line only capable BOTH BothOnLineAndOffLine Both online and offline
26 27 28 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 26 def online @online end |
#pin_pad_inoperative ⇒ Object
If true then pin pad is inoperative
29 30 31 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 29 def pin_pad_inoperative @pin_pad_inoperative end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 32 def self.attribute_map { :'card_reading' => :'cardReading', :'card_writing' => :'cardWriting', :'cardholder_verification' => :'cardholderVerification', :'online' => :'online', :'pin_pad_inoperative' => :'pinPadInoperative' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
43 44 45 46 47 48 49 50 51 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 43 def self.json_map { :'card_reading' => :'card_reading', :'card_writing' => :'card_writing', :'cardholder_verification' => :'cardholder_verification', :'online' => :'online', :'pin_pad_inoperative' => :'pin_pad_inoperative' } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 54 def self.swagger_types { :'card_reading' => :'String', :'card_writing' => :'String', :'cardholder_verification' => :'String', :'online' => :'String', :'pin_pad_inoperative' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 115 116 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 108 def ==(o) return true if self.equal?(o) self.class == o.class && card_reading == o.card_reading && card_writing == o.card_writing && cardholder_verification == o.cardholder_verification && online == o.online && pin_pad_inoperative == o.pin_pad_inoperative end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 154 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 220 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 133 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
120 121 122 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 120 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 126 def hash [card_reading, card_writing, cardholder_verification, online, pin_pad_inoperative].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
95 96 97 98 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 95 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
200 201 202 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 200 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
194 195 196 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 194 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_terminal_capabilities.rb', line 102 def valid? true end |