Class: CyberSource::UnifiedriskThirdPartyRisk

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskThirdPartyRisk

Initializes the object



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 311

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key

  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'authenticationFailedReason')
    self.authentication_failed_reason = attributes[:'authenticationFailedReason']
  end

  if attributes.has_key?(:'authenticationMethod')
    self.authentication_method = attributes[:'authenticationMethod']
  end

  if attributes.has_key?(:'authenticationServiceType')
    self.authentication_service_type = attributes[:'authenticationServiceType']
  end

  if attributes.has_key?(:'authenticationStatus')
    self.authentication_status = attributes[:'authenticationStatus']
  end

  if attributes.has_key?(:'browserAnomaly')
    self.browser_anomaly = attributes[:'browserAnomaly']
  end

  if attributes.has_key?(:'browserCrawlerIdentification')
    self.browser_crawler_identification = attributes[:'browserCrawlerIdentification']
  end

  if attributes.has_key?(:'browserHTTPInfo')
    self.browser_http_info = attributes[:'browserHTTPInfo']
  end

  if attributes.has_key?(:'browserHTTPInfoAnomaly')
    self.browser_http_info_anomaly = attributes[:'browserHTTPInfoAnomaly']
  end

  if attributes.has_key?(:'browserInfo')
    self.browser_info = attributes[:'browserInfo']
  end

  if attributes.has_key?(:'browserLanguage')
    self.browser_language = attributes[:'browserLanguage']
  end

  if attributes.has_key?(:'browserLanguageAnomaly')
    self.browser_language_anomaly = attributes[:'browserLanguageAnomaly']
  end

  if attributes.has_key?(:'browserStringMismatch')
    self.browser_string_mismatch = attributes[:'browserStringMismatch']
  end

  if attributes.has_key?(:'browserVersionId')
    self.browser_version_id = attributes[:'browserVersionId']
  end

  if attributes.has_key?(:'deviceFingerprint')
    self.device_fingerprint = attributes[:'deviceFingerprint']
  end

  if attributes.has_key?(:'deviceFingerprintFirstSeen')
    self.device_fingerprint_first_seen = attributes[:'deviceFingerprintFirstSeen']
  end

  if attributes.has_key?(:'deviceFingerprintResult')
    self.device_fingerprint_result = attributes[:'deviceFingerprintResult']
  end

  if attributes.has_key?(:'deviceFingerprintScore')
    self.device_fingerprint_score = attributes[:'deviceFingerprintScore']
  end

  if attributes.has_key?(:'deviceFirstSeenDate')
    self.device_first_seen_date = attributes[:'deviceFirstSeenDate']
  end

  if attributes.has_key?(:'deviceIdConfidence')
    self.device_id_confidence = attributes[:'deviceIdConfidence']
  end

  if attributes.has_key?(:'deviceMatchResult')
    self.device_match_result = attributes[:'deviceMatchResult']
  end

  if attributes.has_key?(:'deviceRootJailBreak')
    self.device_root_jail_break = attributes[:'deviceRootJailBreak']
  end

  if attributes.has_key?(:'deviceRootJailBreakReason')
    if (value = attributes[:'deviceRootJailBreakReason']).is_a?(Array)
      self.device_root_jail_break_reason = value
    end
  end

  if attributes.has_key?(:'deviceScore')
    self.device_score = attributes[:'deviceScore']
  end

  if attributes.has_key?(:'deviceScoreReason')
    self.device_score_reason = attributes[:'deviceScoreReason']
  end

  if attributes.has_key?(:'digitalId')
    self.digital_id = attributes[:'digitalId']
  end

  if attributes.has_key?(:'digitalIdConfidence')
    self.digital_id_confidence = attributes[:'digitalIdConfidence']
  end

  if attributes.has_key?(:'digitalIdTrustScoreRating')
    self.digital_id_trust_score_rating = attributes[:'digitalIdTrustScoreRating']
  end

  if attributes.has_key?(:'digitalIdTrustScoreReasonCode')
    self.digital_id_trust_score_reason_code = attributes[:'digitalIdTrustScoreReasonCode']
  end

  if attributes.has_key?(:'loginVerificationResult')
    self. = attributes[:'loginVerificationResult']
  end

  if attributes.has_key?(:'loginVerificationRulesHit')
    if (value = attributes[:'loginVerificationRulesHit']).is_a?(Array)
      self. = value
    end
  end

  if attributes.has_key?(:'loginVerificationScore')
    self. = attributes[:'loginVerificationScore']
  end

  if attributes.has_key?(:'nameVerificationResult')
    self.name_verification_result = attributes[:'nameVerificationResult']
  end

  if attributes.has_key?(:'nameVerificationRulesHit')
    if (value = attributes[:'nameVerificationRulesHit']).is_a?(Array)
      self.name_verification_rules_hit = value
    end
  end

  if attributes.has_key?(:'nameVerificationScore')
    self.name_verification_score = attributes[:'nameVerificationScore']
  end

  if attributes.has_key?(:'overallAssessment')
    self.overall_assessment = attributes[:'overallAssessment']
  end

  if attributes.has_key?(:'overallAssessmentReason')
    self.overall_assessment_reason = attributes[:'overallAssessmentReason']
  end

  if attributes.has_key?(:'phoneVerificationResult')
    self.phone_verification_result = attributes[:'phoneVerificationResult']
  end

  if attributes.has_key?(:'phoneVerificationScore')
    self.phone_verification_score = attributes[:'phoneVerificationScore']
  end

  if attributes.has_key?(:'profiledDeviceType')
    self.profiled_device_type = attributes[:'profiledDeviceType']
  end

  if attributes.has_key?(:'providerName')
    self.provider_name = attributes[:'providerName']
  end

  if attributes.has_key?(:'refNumber')
    self.ref_number = attributes[:'refNumber']
  end

  if attributes.has_key?(:'virtualDeviceIdentification')
    self.virtual_device_identification = attributes[:'virtualDeviceIdentification']
  end

  if attributes.has_key?(:'wifiAccuracy')
    self.wifi_accuracy = attributes[:'wifiAccuracy']
  end

  if attributes.has_key?(:'wifiLatitude')
    self.wifi_latitude = attributes[:'wifiLatitude']
  end

  if attributes.has_key?(:'wifiLongitude')
    self.wifi_longitude = attributes[:'wifiLongitude']
  end

  if attributes.has_key?(:'rawData')
    self.raw_data = attributes[:'rawData']
  end
end

Instance Attribute Details

#authentication_failed_reasonObject

If the user fails authentication, this displays the reason for failure, such as "user cancel" or "challenge response failed". Do not populate if there is no failed authentication.



17
18
19
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 17

def authentication_failed_reason
  @authentication_failed_reason
end

#authentication_methodObject

The authentication method used by the ThirdParty



20
21
22
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 20

def authentication_method
  @authentication_method
end

#authentication_service_typeObject

This field is only populated if the registration event is for an authentication service. It advises the authentication service being registered.



23
24
25
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 23

def authentication_service_type
  @authentication_service_type
end

#authentication_statusObject

Indicates the status of the authentication which may be: auth_success, auth_fail, auth_init, or auth_init_in_progress.



26
27
28
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 26

def authentication_status
  @authentication_status
end

#browser_anomalyObject

This attribute will be returned with a value of 'yes' if an anomaly is detected with the various browser attributes collected during profiling, including Flash, JavaScript and User Agent.



29
30
31
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 29

def browser_anomaly
  @browser_anomaly
end

#browser_crawler_identificationObject

The agent, parsed from the http user agent / "browser" string, which indicates the client may not be a real browser, e.g. crawler.



32
33
34
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 32

def browser_crawler_identification
  @browser_crawler_identification
end

#browser_http_infoObject

The user agent / browser string presented in the HTTP header.



35
36
37
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 35

def browser_http_info
  @browser_http_info
end

#browser_http_info_anomalyObject

Indicates as "Yes"if there is an anomaly in the browser string content.



38
39
40
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 38

def browser_http_info_anomaly
  @browser_http_info_anomaly
end

#browser_infoObject

The browser determined using a combination of Flash, JavaScript and User Agent. If browser detection was unsuccessful this will be set to "Unknown".



41
42
43
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 41

def browser_info
  @browser_info
end

#browser_languageObject

The code for the language that the browser is configured to accept which comes from the HTTP header.



44
45
46
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 44

def browser_language
  @browser_language
end

#browser_language_anomalyObject

Indicates as "Yes" if there is an anomaly between the browser language and flash plugin language. This happens when both appear, and none of the browser's preferred languages is the same as the flash



47
48
49
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 47

def browser_language_anomaly
  @browser_language_anomaly
end

#browser_string_mismatchObject

Indicates if there is a mismatch between the javascript user agent string and the HTTP user agent string.



50
51
52
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 50

def browser_string_mismatch
  @browser_string_mismatch
end

#browser_version_idObject

The version of the browser installed.



53
54
55
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 53

def browser_version_id
  @browser_version_id
end

#device_fingerprintObject

Device fingerprint as calculated the ThirdParty. A device fingerprint is information collected about the software and hardware for the purpose of identification.



56
57
58
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 56

def device_fingerprint
  @device_fingerprint
end

#device_fingerprint_first_seenObject

The date that this device was first encountered by ThirdParty



59
60
61
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 59

def device_fingerprint_first_seen
  @device_fingerprint_first_seen
end

#device_fingerprint_resultObject

"not found" indicates this is the first time ThirdParty has seen this device involved in a transaction; "success" indicates that ThirdParty has intelligence on this entity.



62
63
64
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 62

def device_fingerprint_result
  @device_fingerprint_result
end

#device_fingerprint_scoreObject

The risk score for this device as calculated by the ThirdParty



65
66
67
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 65

def device_fingerprint_score
  @device_fingerprint_score
end

#device_first_seen_dateObject

The date that this device was first encountered by ThirdParty, in yyyy-mm-dd format.



68
69
70
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 68

def device_first_seen_date
  @device_first_seen_date
end

#device_id_confidenceObject

A number between 0 and 1, representing the probability of the device being correctly identified.



71
72
73
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 71

def device_id_confidence
  @device_id_confidence
end

#device_match_resultObject

Indicates whether this device is a new device ("new"), whether it was encountered before ("success"), and if not enough attributes were gathered to create a device identity ("not enough attributes").



74
75
76
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 74

def device_match_result
  @device_match_result
end

#device_root_jail_breakObject

Detects whether a mobile device has Root privileges on Android, or a Jailbroken iOS device. This stores a numerical value that indicates the number of jailbreak/root elements on a device. 0 indicates



77
78
79
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 77

def device_root_jail_break
  @device_root_jail_break
end

#device_root_jail_break_reasonObject

An array of strings containing additional information that describes the element(s) on the device that triggered the Jailbreak or Root detection.



80
81
82
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 80

def device_root_jail_break_reason
  @device_root_jail_break_reason
end

#device_scoreObject

The risk score for this device as calculated by the ThirdParty.



83
84
85
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 83

def device_score
  @device_score
end

#device_score_reasonObject

Third party Risk score Reason Code (InAuth, biocatch…etc)



86
87
88
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 86

def device_score_reason
  @device_score_reason
end

#digital_idObject

A digital id assigned by the Thirdparty



89
90
91
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 89

def digital_id
  @digital_id
end

#digital_id_confidenceObject

The confidence score returned signifies the level of confidence that the event appears to be matching the behavior from the returned Digital ID.



92
93
94
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 92

def digital_id_confidence
  @digital_id_confidence
end

#digital_id_trust_score_ratingObject

Trust Score rating associated with the ThirdParty ID which may be one of the following: very_low, low, neutral, high, very_high



95
96
97
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 95

def digital_id_trust_score_rating
  @digital_id_trust_score_rating
end

#digital_id_trust_score_reason_codeObject

Reason codes describing the Trust Score rating (mutiple values). There may be up to 64 characters per entry and there may be an unlimited number of entries.



98
99
100
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 98

def digital_id_trust_score_reason_code
  @digital_id_trust_score_reason_code
end

#login_verification_resultObject

"not found" indicates this is the first time ThirdParty has seen this login (username) involved in a transaction; "success" indicates that ThirdParty has intelligence on this entity.



101
102
103
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 101

def 
  @login_verification_result
end

#login_verification_rules_hitObject

An array containing all of the Third Party rules that triggered for login (username) verification.



104
105
106
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 104

def 
  @login_verification_rules_hit
end

#login_verification_scoreObject

The risk score for the login (username) as calculated by the ThirdParty



107
108
109
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 107

def 
  @login_verification_score
end

#name_verification_resultObject

"not found" indicates this is the first time ThirdParty has seen this name involved in a transaction; "success" indicates that ThirdParty has intelligence on this entity.



110
111
112
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 110

def name_verification_result
  @name_verification_result
end

#name_verification_rules_hitObject

An array containing all of the Third Party rules that triggered for name verification.



113
114
115
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 113

def name_verification_rules_hit
  @name_verification_rules_hit
end

#name_verification_scoreObject

The risk score for the name as calculated by the ThirdParty



116
117
118
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 116

def name_verification_score
  @name_verification_score
end

#overall_assessmentObject

PASS, FAIL



119
120
121
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 119

def overall_assessment
  @overall_assessment
end

#overall_assessment_reasonObject

This is displayed indicating the reason for failure, such as "user cancel" or "challenge response failed".



122
123
124
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 122

def overall_assessment_reason
  @overall_assessment_reason
end

#phone_verification_resultObject

"not found" indicates this is the first time ThirdParty has seen this phone involved in a transaction; "success" indicates that ThirdParty has intelligence on this entity.



125
126
127
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 125

def phone_verification_result
  @phone_verification_result
end

#phone_verification_scoreObject

The risk score for the phone as calculated by the ThirdParty



128
129
130
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 128

def phone_verification_score
  @phone_verification_score
end

#profiled_device_typeObject

This indicates the type of device that was profiled, including mobile app, desktop app, or web browser on a desktop or mobile platform.



131
132
133
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 131

def profiled_device_type
  @profiled_device_type
end

#provider_nameObject

Name of the third party who's java script is used to capture and assess session, behaviour biometric use, etc



134
135
136
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 134

def provider_name
  @provider_name
end

#raw_dataObject

Returns the value of attribute raw_data.



151
152
153
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 151

def raw_data
  @raw_data
end

#ref_numberObject

Third party provider reference number assigned when the Third party assesses session risk and returns results to Customer



137
138
139
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 137

def ref_number
  @ref_number
end

#virtual_device_identificationObject

Detects whether a mobile device is running in an Emulator on Android, or a Simulator on iOS. This stores a numerical value that indicates the number of emulator/simulator elements on a device.



140
141
142
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 140

def virtual_device_identification
  @virtual_device_identification
end

#wifi_accuracyObject

The accuracy of the estimated location, in meters. This represents the radius of a circle around the given location.



143
144
145
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 143

def wifi_accuracy
  @wifi_accuracy
end

#wifi_latitudeObject

The Latitude of the WiFi connection based on BSSID.



146
147
148
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 146

def wifi_latitude
  @wifi_latitude
end

#wifi_longitudeObject

The Longitude of the WiFi connection based on BSSID.



149
150
151
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 149

def wifi_longitude
  @wifi_longitude
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 154

def self.attribute_map
  {
    :'authentication_failed_reason' => :'authenticationFailedReason',
    :'authentication_method' => :'authenticationMethod',
    :'authentication_service_type' => :'authenticationServiceType',
    :'authentication_status' => :'authenticationStatus',
    :'browser_anomaly' => :'browserAnomaly',
    :'browser_crawler_identification' => :'browserCrawlerIdentification',
    :'browser_http_info' => :'browserHTTPInfo',
    :'browser_http_info_anomaly' => :'browserHTTPInfoAnomaly',
    :'browser_info' => :'browserInfo',
    :'browser_language' => :'browserLanguage',
    :'browser_language_anomaly' => :'browserLanguageAnomaly',
    :'browser_string_mismatch' => :'browserStringMismatch',
    :'browser_version_id' => :'browserVersionId',
    :'device_fingerprint' => :'deviceFingerprint',
    :'device_fingerprint_first_seen' => :'deviceFingerprintFirstSeen',
    :'device_fingerprint_result' => :'deviceFingerprintResult',
    :'device_fingerprint_score' => :'deviceFingerprintScore',
    :'device_first_seen_date' => :'deviceFirstSeenDate',
    :'device_id_confidence' => :'deviceIdConfidence',
    :'device_match_result' => :'deviceMatchResult',
    :'device_root_jail_break' => :'deviceRootJailBreak',
    :'device_root_jail_break_reason' => :'deviceRootJailBreakReason',
    :'device_score' => :'deviceScore',
    :'device_score_reason' => :'deviceScoreReason',
    :'digital_id' => :'digitalId',
    :'digital_id_confidence' => :'digitalIdConfidence',
    :'digital_id_trust_score_rating' => :'digitalIdTrustScoreRating',
    :'digital_id_trust_score_reason_code' => :'digitalIdTrustScoreReasonCode',
    :'login_verification_result' => :'loginVerificationResult',
    :'login_verification_rules_hit' => :'loginVerificationRulesHit',
    :'login_verification_score' => :'loginVerificationScore',
    :'name_verification_result' => :'nameVerificationResult',
    :'name_verification_rules_hit' => :'nameVerificationRulesHit',
    :'name_verification_score' => :'nameVerificationScore',
    :'overall_assessment' => :'overallAssessment',
    :'overall_assessment_reason' => :'overallAssessmentReason',
    :'phone_verification_result' => :'phoneVerificationResult',
    :'phone_verification_score' => :'phoneVerificationScore',
    :'profiled_device_type' => :'profiledDeviceType',
    :'provider_name' => :'providerName',
    :'ref_number' => :'refNumber',
    :'virtual_device_identification' => :'virtualDeviceIdentification',
    :'wifi_accuracy' => :'wifiAccuracy',
    :'wifi_latitude' => :'wifiLatitude',
    :'wifi_longitude' => :'wifiLongitude',
    :'raw_data' => :'rawData'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 206

def self.json_map
  {
    :'authentication_failed_reason' => :'authentication_failed_reason',
    :'authentication_method' => :'authentication_method',
    :'authentication_service_type' => :'authentication_service_type',
    :'authentication_status' => :'authentication_status',
    :'browser_anomaly' => :'browser_anomaly',
    :'browser_crawler_identification' => :'browser_crawler_identification',
    :'browser_http_info' => :'browser_http_info',
    :'browser_http_info_anomaly' => :'browser_http_info_anomaly',
    :'browser_info' => :'browser_info',
    :'browser_language' => :'browser_language',
    :'browser_language_anomaly' => :'browser_language_anomaly',
    :'browser_string_mismatch' => :'browser_string_mismatch',
    :'browser_version_id' => :'browser_version_id',
    :'device_fingerprint' => :'device_fingerprint',
    :'device_fingerprint_first_seen' => :'device_fingerprint_first_seen',
    :'device_fingerprint_result' => :'device_fingerprint_result',
    :'device_fingerprint_score' => :'device_fingerprint_score',
    :'device_first_seen_date' => :'device_first_seen_date',
    :'device_id_confidence' => :'device_id_confidence',
    :'device_match_result' => :'device_match_result',
    :'device_root_jail_break' => :'device_root_jail_break',
    :'device_root_jail_break_reason' => :'device_root_jail_break_reason',
    :'device_score' => :'device_score',
    :'device_score_reason' => :'device_score_reason',
    :'digital_id' => :'digital_id',
    :'digital_id_confidence' => :'digital_id_confidence',
    :'digital_id_trust_score_rating' => :'digital_id_trust_score_rating',
    :'digital_id_trust_score_reason_code' => :'digital_id_trust_score_reason_code',
    :'login_verification_result' => :'login_verification_result',
    :'login_verification_rules_hit' => :'login_verification_rules_hit',
    :'login_verification_score' => :'login_verification_score',
    :'name_verification_result' => :'name_verification_result',
    :'name_verification_rules_hit' => :'name_verification_rules_hit',
    :'name_verification_score' => :'name_verification_score',
    :'overall_assessment' => :'overall_assessment',
    :'overall_assessment_reason' => :'overall_assessment_reason',
    :'phone_verification_result' => :'phone_verification_result',
    :'phone_verification_score' => :'phone_verification_score',
    :'profiled_device_type' => :'profiled_device_type',
    :'provider_name' => :'provider_name',
    :'ref_number' => :'ref_number',
    :'virtual_device_identification' => :'virtual_device_identification',
    :'wifi_accuracy' => :'wifi_accuracy',
    :'wifi_latitude' => :'wifi_latitude',
    :'wifi_longitude' => :'wifi_longitude',
    :'raw_data' => :'raw_data'
  }
end

.swagger_typesObject

Attribute type mapping.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 258

def self.swagger_types
  {
    :'authentication_failed_reason' => :'String',
    :'authentication_method' => :'String',
    :'authentication_service_type' => :'String',
    :'authentication_status' => :'String',
    :'browser_anomaly' => :'String',
    :'browser_crawler_identification' => :'String',
    :'browser_http_info' => :'String',
    :'browser_http_info_anomaly' => :'String',
    :'browser_info' => :'String',
    :'browser_language' => :'String',
    :'browser_language_anomaly' => :'String',
    :'browser_string_mismatch' => :'String',
    :'browser_version_id' => :'String',
    :'device_fingerprint' => :'String',
    :'device_fingerprint_first_seen' => :'Date',
    :'device_fingerprint_result' => :'String',
    :'device_fingerprint_score' => :'Float',
    :'device_first_seen_date' => :'Date',
    :'device_id_confidence' => :'Float',
    :'device_match_result' => :'String',
    :'device_root_jail_break' => :'Float',
    :'device_root_jail_break_reason' => :'Array<String>',
    :'device_score' => :'Float',
    :'device_score_reason' => :'String',
    :'digital_id' => :'String',
    :'digital_id_confidence' => :'Float',
    :'digital_id_trust_score_rating' => :'String',
    :'digital_id_trust_score_reason_code' => :'String',
    :'login_verification_result' => :'String',
    :'login_verification_rules_hit' => :'Array<String>',
    :'login_verification_score' => :'Float',
    :'name_verification_result' => :'String',
    :'name_verification_rules_hit' => :'Array<String>',
    :'name_verification_score' => :'Float',
    :'overall_assessment' => :'String',
    :'overall_assessment_reason' => :'String',
    :'phone_verification_result' => :'String',
    :'phone_verification_score' => :'Float',
    :'profiled_device_type' => :'String',
    :'provider_name' => :'String',
    :'ref_number' => :'String',
    :'virtual_device_identification' => :'Float',
    :'wifi_accuracy' => :'Float',
    :'wifi_latitude' => :'Float',
    :'wifi_longitude' => :'Float',
    :'raw_data' => :'UnifiedriskThirdPartyRiskRawData'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 541

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      authentication_failed_reason == o.authentication_failed_reason &&
      authentication_method == o.authentication_method &&
      authentication_service_type == o.authentication_service_type &&
      authentication_status == o.authentication_status &&
      browser_anomaly == o.browser_anomaly &&
      browser_crawler_identification == o.browser_crawler_identification &&
      browser_http_info == o.browser_http_info &&
      browser_http_info_anomaly == o.browser_http_info_anomaly &&
      browser_info == o.browser_info &&
      browser_language == o.browser_language &&
      browser_language_anomaly == o.browser_language_anomaly &&
      browser_string_mismatch == o.browser_string_mismatch &&
      browser_version_id == o.browser_version_id &&
      device_fingerprint == o.device_fingerprint &&
      device_fingerprint_first_seen == o.device_fingerprint_first_seen &&
      device_fingerprint_result == o.device_fingerprint_result &&
      device_fingerprint_score == o.device_fingerprint_score &&
      device_first_seen_date == o.device_first_seen_date &&
      device_id_confidence == o.device_id_confidence &&
      device_match_result == o.device_match_result &&
      device_root_jail_break == o.device_root_jail_break &&
      device_root_jail_break_reason == o.device_root_jail_break_reason &&
      device_score == o.device_score &&
      device_score_reason == o.device_score_reason &&
      digital_id == o.digital_id &&
      digital_id_confidence == o.digital_id_confidence &&
      digital_id_trust_score_rating == o.digital_id_trust_score_rating &&
      digital_id_trust_score_reason_code == o.digital_id_trust_score_reason_code &&
       == o. &&
       == o. &&
       == o. &&
      name_verification_result == o.name_verification_result &&
      name_verification_rules_hit == o.name_verification_rules_hit &&
      name_verification_score == o.name_verification_score &&
      overall_assessment == o.overall_assessment &&
      overall_assessment_reason == o.overall_assessment_reason &&
      phone_verification_result == o.phone_verification_result &&
      phone_verification_score == o.phone_verification_score &&
      profiled_device_type == o.profiled_device_type &&
      provider_name == o.provider_name &&
      ref_number == o.ref_number &&
      virtual_device_identification == o.virtual_device_identification &&
      wifi_accuracy == o.wifi_accuracy &&
      wifi_latitude == o.wifi_latitude &&
      wifi_longitude == o.wifi_longitude &&
      raw_data == o.raw_data
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 628

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly

    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model

    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



694
695
696
697
698
699
700
701
702
703
704
705
706
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 694

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 607

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute

      # is documented as an array but the input is not

      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional

  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


594
595
596
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 594

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



600
601
602
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 600

def hash
  [authentication_failed_reason, authentication_method, authentication_service_type, authentication_status, browser_anomaly, browser_crawler_identification, browser_http_info, browser_http_info_anomaly, browser_info, browser_language, browser_language_anomaly, browser_string_mismatch, browser_version_id, device_fingerprint, device_fingerprint_first_seen, device_fingerprint_result, device_fingerprint_score, device_first_seen_date, device_id_confidence, device_match_result, device_root_jail_break, device_root_jail_break_reason, device_score, device_score_reason, digital_id, digital_id_confidence, digital_id_trust_score_rating, digital_id_trust_score_reason_code, , , , name_verification_result, name_verification_rules_hit, name_verification_score, overall_assessment, overall_assessment_reason, phone_verification_result, phone_verification_score, profiled_device_type, provider_name, ref_number, virtual_device_identification, wifi_accuracy, wifi_latitude, wifi_longitude, raw_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



510
511
512
513
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 510

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



674
675
676
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 674

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



680
681
682
683
684
685
686
687
688
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 680

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



668
669
670
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 668

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



517
518
519
# File 'lib/cybersource_rest_client/models/unifiedrisk_third_party_risk.rb', line 517

def valid?
  true
end