Class: CyberSource::UnifiedriskTransactionRecurringDetails
- Inherits:
-
Object
- Object
- CyberSource::UnifiedriskTransactionRecurringDetails
- Defined in:
- lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb
Instance Attribute Summary collapse
-
#amount_type ⇒ Object
Amount type: FIXED, VARIABLE_WITH_MAX.
-
#end_date ⇒ Object
Date when recurring payments end.
-
#first_payment_date ⇒ Object
Date of the first payment in a recurring series, in ISO 8601 format (YYYY-MM-DD).
-
#frequency ⇒ Object
Days between recurring payments.
-
#maximum_amount ⇒ Object
Maximum amount for variable recurring payments.
-
#number_of_payments ⇒ Object
Total number of payments in recurring series.
-
#occurrence ⇒ Object
Recurring frequency code: DAILY, WEEKLY, MONTHLY, etc.
-
#original_purchase_date ⇒ Object
Date of original recurring purchase.
-
#reference_number ⇒ Object
Reference number for recurring payment.
-
#sequence_number ⇒ Object
Current sequence number in recurring series.
-
#type ⇒ Object
Recurring type: REGISTRATION, SUBSEQUENT, MODIFICATION, CANCELLATION.
-
#validation_indicator ⇒ Object
Indicates if recurring payment was validated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UnifiedriskTransactionRecurringDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UnifiedriskTransactionRecurringDetails
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'frequency') self.frequency = attributes[:'frequency'] end if attributes.has_key?(:'occurrence') self.occurrence = attributes[:'occurrence'] end if attributes.has_key?(:'endDate') self.end_date = attributes[:'endDate'] end if attributes.has_key?(:'numberOfPayments') self.number_of_payments = attributes[:'numberOfPayments'] end if attributes.has_key?(:'sequenceNumber') self.sequence_number = attributes[:'sequenceNumber'] end if attributes.has_key?(:'type') self.type = attributes[:'type'] end if attributes.has_key?(:'validationIndicator') self.validation_indicator = attributes[:'validationIndicator'] end if attributes.has_key?(:'amountType') self.amount_type = attributes[:'amountType'] end if attributes.has_key?(:'maximumAmount') self.maximum_amount = attributes[:'maximumAmount'] end if attributes.has_key?(:'originalPurchaseDate') self.original_purchase_date = attributes[:'originalPurchaseDate'] end if attributes.has_key?(:'referenceNumber') self.reference_number = attributes[:'referenceNumber'] end if attributes.has_key?(:'firstPaymentDate') self.first_payment_date = attributes[:'firstPaymentDate'] end end |
Instance Attribute Details
#amount_type ⇒ Object
Amount type: FIXED, VARIABLE_WITH_MAX
38 39 40 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 38 def amount_type @amount_type end |
#end_date ⇒ Object
Date when recurring payments end
23 24 25 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 23 def end_date @end_date end |
#first_payment_date ⇒ Object
Date of the first payment in a recurring series, in ISO 8601 format (YYYY-MM-DD). Used to establish the anchor date for recurring payment scheduling and risk assessment
50 51 52 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 50 def first_payment_date @first_payment_date end |
#frequency ⇒ Object
Days between recurring payments
17 18 19 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 17 def frequency @frequency end |
#maximum_amount ⇒ Object
Maximum amount for variable recurring payments
41 42 43 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 41 def maximum_amount @maximum_amount end |
#number_of_payments ⇒ Object
Total number of payments in recurring series
26 27 28 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 26 def number_of_payments @number_of_payments end |
#occurrence ⇒ Object
Recurring frequency code: DAILY, WEEKLY, MONTHLY, etc
20 21 22 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 20 def occurrence @occurrence end |
#original_purchase_date ⇒ Object
Date of original recurring purchase
44 45 46 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 44 def original_purchase_date @original_purchase_date end |
#reference_number ⇒ Object
Reference number for recurring payment
47 48 49 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 47 def reference_number @reference_number end |
#sequence_number ⇒ Object
Current sequence number in recurring series
29 30 31 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 29 def sequence_number @sequence_number end |
#type ⇒ Object
Recurring type: REGISTRATION, SUBSEQUENT, MODIFICATION, CANCELLATION
32 33 34 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 32 def type @type end |
#validation_indicator ⇒ Object
Indicates if recurring payment was validated
35 36 37 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 35 def validation_indicator @validation_indicator end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 53 def self.attribute_map { :'frequency' => :'frequency', :'occurrence' => :'occurrence', :'end_date' => :'endDate', :'number_of_payments' => :'numberOfPayments', :'sequence_number' => :'sequenceNumber', :'type' => :'type', :'validation_indicator' => :'validationIndicator', :'amount_type' => :'amountType', :'maximum_amount' => :'maximumAmount', :'original_purchase_date' => :'originalPurchaseDate', :'reference_number' => :'referenceNumber', :'first_payment_date' => :'firstPaymentDate' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 71 def self.json_map { :'frequency' => :'frequency', :'occurrence' => :'occurrence', :'end_date' => :'end_date', :'number_of_payments' => :'number_of_payments', :'sequence_number' => :'sequence_number', :'type' => :'type', :'validation_indicator' => :'validation_indicator', :'amount_type' => :'amount_type', :'maximum_amount' => :'maximum_amount', :'original_purchase_date' => :'original_purchase_date', :'reference_number' => :'reference_number', :'first_payment_date' => :'first_payment_date' } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 89 def self.swagger_types { :'frequency' => :'Integer', :'occurrence' => :'String', :'end_date' => :'Date', :'number_of_payments' => :'Integer', :'sequence_number' => :'Integer', :'type' => :'String', :'validation_indicator' => :'String', :'amount_type' => :'String', :'maximum_amount' => :'Float', :'original_purchase_date' => :'DateTime', :'reference_number' => :'String', :'first_payment_date' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && frequency == o.frequency && occurrence == o.occurrence && end_date == o.end_date && number_of_payments == o.number_of_payments && sequence_number == o.sequence_number && type == o.type && validation_indicator == o.validation_indicator && amount_type == o.amount_type && maximum_amount == o.maximum_amount && original_purchase_date == o.original_purchase_date && reference_number == o.reference_number && first_payment_date == o.first_payment_date end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 261 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 327 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 240 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 233 def hash [frequency, occurrence, end_date, number_of_payments, sequence_number, type, validation_indicator, amount_type, maximum_amount, original_purchase_date, reference_number, first_payment_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 165 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
307 308 309 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 307 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
301 302 303 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 301 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_transaction_recurring_details.rb', line 172 def valid? true end |