Class: CyberSource::UnifiedriskTravel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybersource_rest_client/models/unifiedrisk_travel.rb

Overview

Travel-specific information for airline/hotel transactions including routes, legs, and passenger details

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedriskTravel

Initializes the object



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 77

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'actualFinalDestination')
    self.actual_final_destination = attributes[:'actualFinalDestination']
  end

  if attributes.has_key?(:'completeRoute')
    self.complete_route = attributes[:'completeRoute']
  end

  if attributes.has_key?(:'departureTime')
    self.departure_time = attributes[:'departureTime']
  end

  if attributes.has_key?(:'journeyType')
    self.journey_type = attributes[:'journeyType']
  end

  if attributes.has_key?(:'numberOfPassengers')
    self.number_of_passengers = attributes[:'numberOfPassengers']
  end

  if attributes.has_key?(:'legs')
    self.legs = attributes[:'legs']
  end

  if attributes.has_key?(:'passengers')
    self.passengers = attributes[:'passengers']
  end
end

Instance Attribute Details

#actual_final_destinationObject

IATA Code for the actual final destination that the customer intends to travel to. It should be a destination on the completeRoute.



18
19
20
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 18

def actual_final_destination
  @actual_final_destination
end

#complete_routeObject

Concatenation of individual travel legs in the format ORIG1-DEST1, for example, SFO-JFK:JFK-LHR:LHR-CDG. For airport codes, see the IATA Airline and Airport Code Search. Note In your request, send either the complete route or the individual legs (_leg#_orig and _leg#_dest). If you send all the fields, the value of _complete_route takes precedence over that of the _leg# fields.



21
22
23
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 21

def complete_route
  @complete_route
end

#departure_timeObject

Departure date and time of the first leg of the trip. Use one of the following formats: - yyyy-MM-dd HH:mm z - yyyy-MM-dd hh:mm a z - yyyy-MM-dd hh:mma z HH = hour in 24-hour format hh = hou



24
25
26
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 24

def departure_time
  @departure_time
end

#journey_typeObject

Type of travel, for example one way or round trip.



27
28
29
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 27

def journey_type
  @journey_type
end

#legsObject

Returns the value of attribute legs.



32
33
34
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 32

def legs
  @legs
end

#number_of_passengersObject

Number of passengers for whom the ticket was issued. If you do not include this field in your request, CyberSource uses a default value of 1. Required for American Express SafeKey (U.S.) for travel-related requests.



30
31
32
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 30

def number_of_passengers
  @number_of_passengers
end

#passengersObject

Returns the value of attribute passengers.



34
35
36
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 34

def passengers
  @passengers
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 37

def self.attribute_map
  {
    :'actual_final_destination' => :'actualFinalDestination',
    :'complete_route' => :'completeRoute',
    :'departure_time' => :'departureTime',
    :'journey_type' => :'journeyType',
    :'number_of_passengers' => :'numberOfPassengers',
    :'legs' => :'legs',
    :'passengers' => :'passengers'
  }
end

.json_mapObject

Attribute mapping from JSON key to ruby-style variable name.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 50

def self.json_map
  {
    :'actual_final_destination' => :'actual_final_destination',
    :'complete_route' => :'complete_route',
    :'departure_time' => :'departure_time',
    :'journey_type' => :'journey_type',
    :'number_of_passengers' => :'number_of_passengers',
    :'legs' => :'legs',
    :'passengers' => :'passengers'
  }
end

.swagger_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 63

def self.swagger_types
  {
    :'actual_final_destination' => :'String',
    :'complete_route' => :'String',
    :'departure_time' => :'String',
    :'journey_type' => :'String',
    :'number_of_passengers' => :'Integer',
    :'legs' => :'Object',
    :'passengers' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



151
152
153
154
155
156
157
158
159
160
161
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      actual_final_destination == o.actual_final_destination &&
      complete_route == o.complete_route &&
      departure_time == o.departure_time &&
      journey_type == o.journey_type &&
      number_of_passengers == o.number_of_passengers &&
      legs == o.legs &&
      passengers == o.passengers
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 199

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CyberSource.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 265

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 178

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


165
166
167
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 165

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



171
172
173
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 171

def hash
  [actual_final_destination, complete_route, departure_time, journey_type, number_of_passengers, legs, passengers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



114
115
116
117
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 114

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



245
246
247
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 245

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



239
240
241
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 239

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



121
122
123
# File 'lib/cybersource_rest_client/models/unifiedrisk_travel.rb', line 121

def valid?
  true
end