Class: CyberSource::VisaProtectRiskInsightsApi
- Inherits:
-
Object
- Object
- CyberSource::VisaProtectRiskInsightsApi
- Defined in:
- lib/cybersource_rest_client/api/visa_protect_risk_insights_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default, config) ⇒ VisaProtectRiskInsightsApi
constructor
A new instance of VisaProtectRiskInsightsApi.
-
#submit_vpri(vpri_request, opts = {}) ⇒ UnifiedRiskPost201Response
Visa Protect Risk Insights VPRI delivers real-time, AI-driven risk scores and insights via a data-only API to enrich existing fraud strategies and improve decisioning.
-
#submit_vpri_with_http_info(vpri_request, opts = {}) ⇒ Array<(UnifiedRiskPost201Response, Fixnum, Hash)>
Visa Protect Risk Insights VPRI delivers real-time, AI-driven risk scores and insights via a data-only API to enrich existing fraud strategies and improve decisioning.
Constructor Details
#initialize(api_client = ApiClient.default, config) ⇒ VisaProtectRiskInsightsApi
Returns a new instance of VisaProtectRiskInsightsApi.
18 19 20 21 |
# File 'lib/cybersource_rest_client/api/visa_protect_risk_insights_api.rb', line 18 def initialize(api_client = ApiClient.default, config) @api_client = api_client @api_client.set_configuration(config) end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
16 17 18 |
# File 'lib/cybersource_rest_client/api/visa_protect_risk_insights_api.rb', line 16 def api_client @api_client end |
Instance Method Details
#submit_vpri(vpri_request, opts = {}) ⇒ UnifiedRiskPost201Response
Visa Protect Risk Insights VPRI delivers real-time, AI-driven risk scores and insights via a data-only API to enrich existing fraud strategies and improve decisioning. It integrates easily into existing workflows and provides immediate value by identifying legitimate behavior across Visa's global network—helping reduce false declines and increase acceptance.
29 30 31 32 |
# File 'lib/cybersource_rest_client/api/visa_protect_risk_insights_api.rb', line 29 def submit_vpri(vpri_request, opts = {}) data, status_code, headers = submit_vpri_with_http_info(vpri_request, opts) return data, status_code, headers end |
#submit_vpri_with_http_info(vpri_request, opts = {}) ⇒ Array<(UnifiedRiskPost201Response, Fixnum, Hash)>
Visa Protect Risk Insights VPRI delivers real-time, AI-driven risk scores and insights via a data-only API to enrich existing fraud strategies and improve decisioning. It integrates easily into existing workflows and provides immediate value by identifying legitimate behavior across Visa's global network—helping reduce false declines and increase acceptance.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cybersource_rest_client/api/visa_protect_risk_insights_api.rb', line 39 def submit_vpri_with_http_info(vpri_request, opts = {}) if @api_client.config.debugging begin raise @api_client.config.logger.debug 'Calling API: VisaProtectRiskInsightsApi.submit_vpri ...' rescue puts 'Cannot write to log' end end # verify the required parameter 'vpri_request' is set if @api_client.config.client_side_validation && vpri_request.nil? fail ArgumentError, "Missing the required parameter 'vpri_request' when calling VisaProtectRiskInsightsApi.submit_vpri" end # resource path local_var_path = 'unifiedrisk' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(vpri_request) sdk_tracker = SdkTracker.new post_body = sdk_tracker.insert_developer_id_tracker(post_body, 'VpriRequest', @api_client.config.host, @api_client.merchantconfig.defaultDeveloperId) inbound_mle_status = "mandatory" if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["submit_vpri","submit_vpri_with_http_info"]) begin post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body) rescue raise end end is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["submit_vpri","submit_vpri_with_http_info"]) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UnifiedRiskPost201Response', :isResponseMLEForApi => is_response_mle_for_api) if @api_client.config.debugging begin raise @api_client.config.logger.debug "API called: VisaProtectRiskInsightsApi#submit_vpri\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" rescue puts 'Cannot write to log' end end return data, status_code, headers end |