Class: CyberSource::Acpv1mppcredentialsChallenge
- Inherits:
-
Object
- Object
- CyberSource::Acpv1mppcredentialsChallenge
- Defined in:
- lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb
Overview
MPP challenge context received from the merchant’s 402 response.
Instance Attribute Summary collapse
-
#accepted_networks ⇒ Object
Card networks accepted by the merchant (e.g., [‘visa’, ‘mastercard’]).
-
#amount ⇒ Object
Amount in the smallest currency unit (e.g., ‘4999’ = $49.99).
-
#currency ⇒ Object
Three-letter ISO 4217 currency code, lowercase (e.g., ‘usd’).
-
#encryption_jwk ⇒ Object
Returns the value of attribute encryption_jwk.
-
#id ⇒ Object
Unique challenge identifier issued by the merchant server.
-
#merchant_id ⇒ Object
Merchant identifier (maps to ‘recipient’ in MPP spec request object).
-
#merchant_name ⇒ Object
Human-readable merchant name.
-
#realm ⇒ Object
Merchant realm (typically the API domain).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Acpv1mppcredentialsChallenge
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Acpv1mppcredentialsChallenge
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'realm') self.realm = attributes[:'realm'] end if attributes.has_key?(:'amount') self.amount = attributes[:'amount'] end if attributes.has_key?(:'currency') self.currency = attributes[:'currency'] end if attributes.has_key?(:'acceptedNetworks') if (value = attributes[:'acceptedNetworks']).is_a?(Array) self.accepted_networks = value end end if attributes.has_key?(:'merchantId') self.merchant_id = attributes[:'merchantId'] end if attributes.has_key?(:'merchantName') self.merchant_name = attributes[:'merchantName'] end if attributes.has_key?(:'encryption_jwk') self.encryption_jwk = attributes[:'encryption_jwk'] end end |
Instance Attribute Details
#accepted_networks ⇒ Object
Card networks accepted by the merchant (e.g., [‘visa’, ‘mastercard’]).
30 31 32 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 30 def accepted_networks @accepted_networks end |
#amount ⇒ Object
Amount in the smallest currency unit (e.g., ‘4999’ = $49.99).
24 25 26 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 24 def amount @amount end |
#currency ⇒ Object
Three-letter ISO 4217 currency code, lowercase (e.g., ‘usd’).
27 28 29 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 27 def currency @currency end |
#encryption_jwk ⇒ Object
Returns the value of attribute encryption_jwk.
38 39 40 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 38 def encryption_jwk @encryption_jwk end |
#id ⇒ Object
Unique challenge identifier issued by the merchant server.
18 19 20 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 18 def id @id end |
#merchant_id ⇒ Object
Merchant identifier (maps to ‘recipient’ in MPP spec request object).
33 34 35 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 33 def merchant_id @merchant_id end |
#merchant_name ⇒ Object
Human-readable merchant name.
36 37 38 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 36 def merchant_name @merchant_name end |
#realm ⇒ Object
Merchant realm (typically the API domain).
21 22 23 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 21 def realm @realm end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 41 def self.attribute_map { :'id' => :'id', :'realm' => :'realm', :'amount' => :'amount', :'currency' => :'currency', :'accepted_networks' => :'acceptedNetworks', :'merchant_id' => :'merchantId', :'merchant_name' => :'merchantName', :'encryption_jwk' => :'encryption_jwk' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 55 def self.json_map { :'id' => :'id', :'realm' => :'realm', :'amount' => :'amount', :'currency' => :'currency', :'accepted_networks' => :'accepted_networks', :'merchant_id' => :'merchant_id', :'merchant_name' => :'merchant_name', :'encryption_jwk' => :'encryption_jwk' } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 69 def self.swagger_types { :'id' => :'String', :'realm' => :'String', :'amount' => :'String', :'currency' => :'String', :'accepted_networks' => :'Array<String>', :'merchant_id' => :'String', :'merchant_name' => :'String', :'encryption_jwk' => :'Acpv1mppcredentialsChallengeEncryptionJwk' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && realm == o.realm && amount == o.amount && currency == o.currency && accepted_networks == o.accepted_networks && merchant_id == o.merchant_id && merchant_name == o.merchant_name && encryption_jwk == o.encryption_jwk end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 289 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 355 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 268 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 261 def hash [id, realm, amount, currency, accepted_networks, merchant_id, merchant_name, encryption_jwk].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 127 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @realm.nil? invalid_properties.push('invalid value for "realm", realm cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @accepted_networks.nil? invalid_properties.push('invalid value for "accepted_networks", accepted_networks cannot be nil.') end if @merchant_id.nil? invalid_properties.push('invalid value for "merchant_id", merchant_id cannot be nil.') end if @merchant_name.nil? invalid_properties.push('invalid value for "merchant_name", merchant_name cannot be nil.') end if @encryption_jwk.nil? invalid_properties.push('invalid value for "encryption_jwk", encryption_jwk cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
335 336 337 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 335 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
341 342 343 344 345 346 347 348 349 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 341 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
329 330 331 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 329 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/cybersource_rest_client/models/acpv1mppcredentials_challenge.rb', line 166 def valid? return false if @id.nil? return false if @realm.nil? return false if @amount.nil? return false if @currency.nil? return false if @accepted_networks.nil? return false if @merchant_id.nil? return false if @merchant_name.nil? return false if @encryption_jwk.nil? true end |