Class: CyberSource::GenerateUnifiedCheckoutV1CaptureContextRequest
- Inherits:
-
Object
- Object
- CyberSource::GenerateUnifiedCheckoutV1CaptureContextRequest
- Defined in:
- lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb
Instance Attribute Summary collapse
-
#allowed_card_networks ⇒ Object
The list of card networks you want to use for this Unified Checkout transaction.
-
#allowed_payment_types ⇒ Object
The payment types that are allowed for the merchant.
-
#appearance ⇒ Object
Returns the value of attribute appearance.
-
#button_type ⇒ Object
Changes the label on the payment button within Unified Checkout .
Possible values: - ADD_CARD - CARD_PAYMENT - CHECKOUT - CHECKOUT_AND_CONTINUE - DEBIT_CREDIT - DONATE - PAY - PAY_WITH_CARD - SAVE_CARD - SUBSCRIBE_WITH_CARD
The default value is CHECKOUT. -
#capture_mandate ⇒ Object
Returns the value of attribute capture_mandate.
-
#client_version ⇒ Object
This field is used to specify the Unified Checkout API version your integration should use.
-
#complete_mandate ⇒ Object
Returns the value of attribute complete_mandate.
-
#country ⇒ Object
Country the purchase is originating from (e.g. country of the merchant).
-
#data ⇒ Object
Returns the value of attribute data.
-
#locale ⇒ Object
Localization of the User experience conforming to the ISO 639 language standards and two-character ISO Standard Country Code.
Locale must be in the format: <ISO 639 language code>_<ISO 3166 region code> Please refer to list of [supported locales through Unified Checkout](developer.cybersource.com/docs/cybs/en-us/unified-checkout/developer/all/rest/unified-checkout/uc-appendix-languages.html)
Required field: This field cannot be configured through the Merchant Experience screens in the Business Center and must be provided on a per‑transaction basis in the uc/v1/sessions API request. -
#payment_configurations ⇒ Object
Returns the value of attribute payment_configurations.
-
#target_origins ⇒ Object
The [target origin](developer.mozilla.org/en-US/docs/Glossary/Origin) of the website on which you will be launching Unified Checkout is defined by the scheme (protocol), hostname (domain) and port number (if used).
-
#transient_token_response_options ⇒ Object
Returns the value of attribute transient_token_response_options.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GenerateUnifiedCheckoutV1CaptureContextRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GenerateUnifiedCheckoutV1CaptureContextRequest
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'clientVersion') self.client_version = attributes[:'clientVersion'] end if attributes.has_key?(:'targetOrigins') if (value = attributes[:'targetOrigins']).is_a?(Array) self.target_origins = value end end if attributes.has_key?(:'allowedCardNetworks') if (value = attributes[:'allowedCardNetworks']).is_a?(Array) self.allowed_card_networks = value end end if attributes.has_key?(:'allowedPaymentTypes') if (value = attributes[:'allowedPaymentTypes']).is_a?(Array) self.allowed_payment_types = value end end if attributes.has_key?(:'paymentConfigurations') self.payment_configurations = attributes[:'paymentConfigurations'] end if attributes.has_key?(:'appearance') self.appearance = attributes[:'appearance'] end if attributes.has_key?(:'country') self.country = attributes[:'country'] end if attributes.has_key?(:'locale') self.locale = attributes[:'locale'] end if attributes.has_key?(:'buttonType') self. = attributes[:'buttonType'] end if attributes.has_key?(:'captureMandate') self.capture_mandate = attributes[:'captureMandate'] end if attributes.has_key?(:'completeMandate') self.complete_mandate = attributes[:'completeMandate'] end if attributes.has_key?(:'transientTokenResponseOptions') self. = attributes[:'transientTokenResponseOptions'] end if attributes.has_key?(:'data') self.data = attributes[:'data'] end end |
Instance Attribute Details
#allowed_card_networks ⇒ Object
The list of card networks you want to use for this Unified Checkout transaction. Unified Checkout currently supports the following card networks: - VISA - MASTERCARD - AMEX - CARNET - CARTESBANCAIRES - CUP - DINERSCLUB - DISCOVER - EFTPOS - ELO - JAYWAN - JCB - JCREW - KCP - MADA - MAESTRO - MEEZA - PAYPAK - UATP
Optional field: This field can be configured through the Merchant Experience Screens in the Business Center. The configured value may be overridden on a per transaction basis in the uc/v1/sessions API request.
23 24 25 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 23 def allowed_card_networks @allowed_card_networks end |
#allowed_payment_types ⇒ Object
The payment types that are allowed for the merchant. Possible values when launching Unified Checkout: - APPLEPAY - CHECK - CLICKTOPAY - GOOGLEPAY - PANENTRY - PAZE - TMS_TOKEN
Unified Checkout supports the following Buy Now, Pay Later (BNPL) payment methods: - Cash App Afterpay (US): AFTERPAY - Clearpay (GB): AFTERPAY - Afterpay (CA, AU, NZ): AFTERPAY
Unified Checkout supports the following Online Bank Transfer payment methods: - Bancontact (BE): BANCONTACT - DragonPay (PH): DRAGONPAY - iDEAL (NL): IDEAL - Multibanco (PT): MULTIBANCO - MyBank (IT, BE, PT, ES): MYBANK - Przelewy24|P24 (PL): PRZELEWY24 - Tink Pay By Bank (GB): TINKPAYBYBANK
Unified Checkout supports the following Post-Pay Reference payment methods: - Konbini (JP): KONBINI
Unified Checkout supports the following wallet based payment methods: - PayPal v2: PAYPAL - Venmo: VENMO
Possible values when launching Click To Pay Drop-In UI: - CLICKTOPAY - PANENTRY
Important: - CLICKTOPAY only available for Visa, Mastercard and AMEX for saved cards. - Visa and Mastercard will look to tokenize using network tokenization for all Click to Pay requests. Click to Pay uses Click to Pay token requester IDs and not the merchant’s existing token requester. - Apple Pay, Google Pay, Check, and Paze can be used independently without requiring PAN entry in the allowedPaymentTypes field.
Optional field: This field can be configured through the Merchant Experience Screens in the Business Center. The configured value may be overridden on a per transaction basis in the uc/v1/sessions API request.
26 27 28 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 26 def allowed_payment_types @allowed_payment_types end |
#appearance ⇒ Object
Returns the value of attribute appearance.
30 31 32 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 30 def appearance @appearance end |
#button_type ⇒ Object
Changes the label on the payment button within Unified Checkout .
Possible values: - ADD_CARD - CARD_PAYMENT - CHECKOUT - CHECKOUT_AND_CONTINUE - DEBIT_CREDIT - DONATE - PAY - PAY_WITH_CARD - SAVE_CARD - SUBSCRIBE_WITH_CARD
The default value is CHECKOUT.
Optional field: This field can be configured through the Merchant Experience screens in the Business Center. The configured value may be overridden on a per‑transaction basis in the uc/v1/sessions API request.
39 40 41 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 39 def @button_type end |
#capture_mandate ⇒ Object
Returns the value of attribute capture_mandate.
41 42 43 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 41 def capture_mandate @capture_mandate end |
#client_version ⇒ Object
This field is used to specify the Unified Checkout API version your integration should use. The recommended approach is to omit this field from the uc/v1/sessions API request. When omitted, Unified Checkout automatically uses the latest available version, ensuring access to the most recent enhancements and updates without requiring integration changes. If included, the value must be provided in Major.Minor format (for example, 1.1 or 1.2).
Optional field: This field cannot be configured through the Merchant Experience screens in the Business Center but can be provided in the uc/v1/sessions API request.
17 18 19 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 17 def client_version @client_version end |
#complete_mandate ⇒ Object
Returns the value of attribute complete_mandate.
43 44 45 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 43 def complete_mandate @complete_mandate end |
#country ⇒ Object
Country the purchase is originating from (e.g. country of the merchant). Use the two-character ISO Standard
Country must be in the format: ISO 3166 country code
Required field: This field cannot be configured through the Merchant Experience screens in the Business Center and must be provided on a per‑transaction basis in the uc/v1/sessions API request.
33 34 35 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 33 def country @country end |
#data ⇒ Object
Returns the value of attribute data.
47 48 49 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 47 def data @data end |
#locale ⇒ Object
Localization of the User experience conforming to the ISO 639 language standards and two-character ISO Standard Country Code.
Locale must be in the format: <ISO 639 language code>_<ISO 3166 region code> Please refer to list of [supported locales through Unified Checkout](developer.cybersource.com/docs/cybs/en-us/unified-checkout/developer/all/rest/unified-checkout/uc-appendix-languages.html)
Required field: This field cannot be configured through the Merchant Experience screens in the Business Center and must be provided on a per‑transaction basis in the uc/v1/sessions API request.
36 37 38 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 36 def locale @locale end |
#payment_configurations ⇒ Object
Returns the value of attribute payment_configurations.
28 29 30 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 28 def payment_configurations @payment_configurations end |
#target_origins ⇒ Object
The [target origin](developer.mozilla.org/en-US/docs/Glossary/Origin) of the website on which you will be launching Unified Checkout is defined by the scheme (protocol), hostname (domain) and port number (if used). You must use hostname (unless you use localhost) Wildcards are NOT supported. Ensure that subdomains are included. Any valid top-level domain is supported (e.g. .com, .co.uk, .gov.br etc) Examples: - example.com - subdomain.example.com - example.com:8080<br><br> If you are embedding within multiple nested iframes you need to specify the origins of all the browser contexts used, for example: targetOrigins: [ "example.com", "basket.example.com", "ecom.example.com" ]
You can supply up to seven origins within the targetOrigins field for nested iframes. If the list of origins exceeds five ensure that you: - Compare the list of origins in the v1/sessions targetOrigins field against the location.ancestorOrigins of the browser. - Ensure that the count of origins and their content matches in both. If any origins are absent or mismatched, the system will prevent Unified Checkout from loading and display a client-side error message.
Required field: This field cannot be configured through the Merchant Experience Screens in the Business Center and must be provided on a per transaction basis via the uc/v1/sessions API request.
20 21 22 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 20 def target_origins @target_origins end |
#transient_token_response_options ⇒ Object
Returns the value of attribute transient_token_response_options.
45 46 47 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 45 def @transient_token_response_options end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 50 def self.attribute_map { :'client_version' => :'clientVersion', :'target_origins' => :'targetOrigins', :'allowed_card_networks' => :'allowedCardNetworks', :'allowed_payment_types' => :'allowedPaymentTypes', :'payment_configurations' => :'paymentConfigurations', :'appearance' => :'appearance', :'country' => :'country', :'locale' => :'locale', :'button_type' => :'buttonType', :'capture_mandate' => :'captureMandate', :'complete_mandate' => :'completeMandate', :'transient_token_response_options' => :'transientTokenResponseOptions', :'data' => :'data' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 69 def self.json_map { :'client_version' => :'client_version', :'target_origins' => :'target_origins', :'allowed_card_networks' => :'allowed_card_networks', :'allowed_payment_types' => :'allowed_payment_types', :'payment_configurations' => :'payment_configurations', :'appearance' => :'appearance', :'country' => :'country', :'locale' => :'locale', :'button_type' => :'button_type', :'capture_mandate' => :'capture_mandate', :'complete_mandate' => :'complete_mandate', :'transient_token_response_options' => :'transient_token_response_options', :'data' => :'data' } end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 88 def self.swagger_types { :'client_version' => :'String', :'target_origins' => :'Array<String>', :'allowed_card_networks' => :'Array<String>', :'allowed_payment_types' => :'Array<String>', :'payment_configurations' => :'Ucv1sessionsPaymentConfigurations', :'appearance' => :'Ucv1sessionsAppearance', :'country' => :'String', :'locale' => :'String', :'button_type' => :'String', :'capture_mandate' => :'Ucv1sessionsCaptureMandate', :'complete_mandate' => :'Ucv1sessionsCompleteMandate', :'transient_token_response_options' => :'Ucv1sessionsTransientTokenResponseOptions', :'data' => :'Ucv1sessionsData' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 200 def ==(o) return true if self.equal?(o) self.class == o.class && client_version == o.client_version && target_origins == o.target_origins && allowed_card_networks == o.allowed_card_networks && allowed_payment_types == o.allowed_payment_types && payment_configurations == o.payment_configurations && appearance == o.appearance && country == o.country && locale == o.locale && == o. && capture_mandate == o.capture_mandate && complete_mandate == o.complete_mandate && == o. && data == o.data end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 254 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 320 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 233 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 226 def hash [client_version, target_origins, allowed_card_networks, allowed_payment_types, payment_configurations, appearance, country, locale, , capture_mandate, complete_mandate, , data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 175 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
300 301 302 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 300 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
294 295 296 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 294 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
182 183 184 |
# File 'lib/cybersource_rest_client/models/generate_unified_checkout_v1_capture_context_request.rb', line 182 def valid? true end |