Class: CyberSource::GetSubscriptionsPaymentsResponseSubscriptionPayment
- Inherits:
-
Object
- Object
- CyberSource::GetSubscriptionsPaymentsResponseSubscriptionPayment
- Defined in:
- lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb
Instance Attribute Summary collapse
-
#billing_amount ⇒ Object
The amount billed for this payment.
-
#billing_cycle ⇒ Object
The billing cycle number.
-
#billing_end_date ⇒ Object
The end date of the billing cycle for this payment.
-
#billing_start_date ⇒ Object
The start date of the billing cycle for this payment.
-
#currency ⇒ Object
Currency used for the order.
-
#date ⇒ Object
The date and time of the payment processing.
-
#id ⇒ Object
Identifier assigned by Recurring Billing to uniquely reference this billing cycle’s payment, distinct from the Cybersource transactionID.
-
#modifiable ⇒ Object
Indicates if the payment is modifiable, meaning it can be skipped or restored.
-
#payment_number ⇒ Object
The sequential number of the payment in the subscription.
-
#payment_type ⇒ Object
The type of payment.
-
#setup_fee ⇒ Object
The setup fee associated with the payment.
-
#status ⇒ Object
The current status of the payment.
-
#surcharge_amount ⇒ Object
The surcharge amount, if any.
-
#surcharge_description ⇒ Object
The description for the surcharge.
-
#transaction_id ⇒ Object
An unique identification number generated by Cybersource to identify the submitted request.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetSubscriptionsPaymentsResponseSubscriptionPayment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GetSubscriptionsPaymentsResponseSubscriptionPayment
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 126 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'paymentType') self.payment_type = attributes[:'paymentType'] end if attributes.has_key?(:'transactionID') self.transaction_id = attributes[:'transactionID'] end if attributes.has_key?(:'date') self.date = attributes[:'date'] end if attributes.has_key?(:'currency') self.currency = attributes[:'currency'] end if attributes.has_key?(:'billingStartDate') self.billing_start_date = attributes[:'billingStartDate'] end if attributes.has_key?(:'billingEndDate') self.billing_end_date = attributes[:'billingEndDate'] end if attributes.has_key?(:'billingCycle') self.billing_cycle = attributes[:'billingCycle'] end if attributes.has_key?(:'paymentNumber') self.payment_number = attributes[:'paymentNumber'] end if attributes.has_key?(:'billingAmount') self.billing_amount = attributes[:'billingAmount'] end if attributes.has_key?(:'setupFee') self.setup_fee = attributes[:'setupFee'] end if attributes.has_key?(:'surchargeAmount') self.surcharge_amount = attributes[:'surchargeAmount'] end if attributes.has_key?(:'surchargeDescription') self.surcharge_description = attributes[:'surchargeDescription'] end if attributes.has_key?(:'modifiable') self.modifiable = attributes[:'modifiable'] end end |
Instance Attribute Details
#billing_amount ⇒ Object
The amount billed for this payment.
47 48 49 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 47 def billing_amount @billing_amount end |
#billing_cycle ⇒ Object
The billing cycle number.
41 42 43 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 41 def billing_cycle @billing_cycle end |
#billing_end_date ⇒ Object
The end date of the billing cycle for this payment.
38 39 40 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 38 def billing_end_date @billing_end_date end |
#billing_start_date ⇒ Object
The start date of the billing cycle for this payment.
35 36 37 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 35 def billing_start_date @billing_start_date end |
#currency ⇒ Object
Currency used for the order. Use the three-character [ISO Standard Currency Codes.](apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf) #### Used by Authorization Required field. **Authorization Reversal** For an authorization reversal (‘reversalInformation`) or a capture (`processingOptions.capture` is set to `true`), you must use the same currency that you used in your payment authorization request. #### PIN Debit Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf). Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf). Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests. #### GPX This field is optional for reversing an authorization or credit. #### DCC for First Data Your local currency. #### Tax Calculation Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.
32 33 34 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 32 def currency @currency end |
#date ⇒ Object
The date and time of the payment processing.
29 30 31 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 29 def date @date end |
#id ⇒ Object
Identifier assigned by Recurring Billing to uniquely reference this billing cycle’s payment, distinct from the Cybersource transactionID.
17 18 19 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 17 def id @id end |
#modifiable ⇒ Object
Indicates if the payment is modifiable, meaning it can be skipped or restored.
59 60 61 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 59 def modifiable @modifiable end |
#payment_number ⇒ Object
The sequential number of the payment in the subscription.
44 45 46 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 44 def payment_number @payment_number end |
#payment_type ⇒ Object
The type of payment. Possible values: - STANDARD - RETRY
23 24 25 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 23 def payment_type @payment_type end |
#setup_fee ⇒ Object
The setup fee associated with the payment.
50 51 52 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 50 def setup_fee @setup_fee end |
#status ⇒ Object
The current status of the payment. Possible values: - SCHEDULED - PAID - FAILED - SKIPPED - SCHEDULED_SKIPPED
20 21 22 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 20 def status @status end |
#surcharge_amount ⇒ Object
The surcharge amount, if any.
53 54 55 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 53 def surcharge_amount @surcharge_amount end |
#surcharge_description ⇒ Object
The description for the surcharge.
56 57 58 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 56 def surcharge_description @surcharge_description end |
#transaction_id ⇒ Object
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
26 27 28 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 26 def transaction_id @transaction_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 62 def self.attribute_map { :'id' => :'id', :'status' => :'status', :'payment_type' => :'paymentType', :'transaction_id' => :'transactionID', :'date' => :'date', :'currency' => :'currency', :'billing_start_date' => :'billingStartDate', :'billing_end_date' => :'billingEndDate', :'billing_cycle' => :'billingCycle', :'payment_number' => :'paymentNumber', :'billing_amount' => :'billingAmount', :'setup_fee' => :'setupFee', :'surcharge_amount' => :'surchargeAmount', :'surcharge_description' => :'surchargeDescription', :'modifiable' => :'modifiable' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 83 def self.json_map { :'id' => :'id', :'status' => :'status', :'payment_type' => :'payment_type', :'transaction_id' => :'transaction_id', :'date' => :'date', :'currency' => :'currency', :'billing_start_date' => :'billing_start_date', :'billing_end_date' => :'billing_end_date', :'billing_cycle' => :'billing_cycle', :'payment_number' => :'payment_number', :'billing_amount' => :'billing_amount', :'setup_fee' => :'setup_fee', :'surcharge_amount' => :'surcharge_amount', :'surcharge_description' => :'surcharge_description', :'modifiable' => :'modifiable' } end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 104 def self.swagger_types { :'id' => :'String', :'status' => :'String', :'payment_type' => :'String', :'transaction_id' => :'String', :'date' => :'DateTime', :'currency' => :'String', :'billing_start_date' => :'DateTime', :'billing_end_date' => :'DateTime', :'billing_cycle' => :'String', :'payment_number' => :'String', :'billing_amount' => :'String', :'setup_fee' => :'String', :'surcharge_amount' => :'String', :'surcharge_description' => :'String', :'modifiable' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && status == o.status && payment_type == o.payment_type && transaction_id == o.transaction_id && date == o.date && currency == o.currency && billing_start_date == o.billing_start_date && billing_end_date == o.billing_end_date && billing_cycle == o.billing_cycle && payment_number == o.payment_number && billing_amount == o.billing_amount && setup_fee == o.setup_fee && surcharge_amount == o.surcharge_amount && surcharge_description == o.surcharge_description && modifiable == o.modifiable end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 276 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 342 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 255 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 248 def hash [id, status, payment_type, transaction_id, date, currency, billing_start_date, billing_end_date, billing_cycle, payment_number, billing_amount, setup_fee, surcharge_amount, surcharge_description, modifiable].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 195 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
322 323 324 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 322 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
316 317 318 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 316 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 |
# File 'lib/cybersource_rest_client/models/get_subscriptions_payments_response_subscription_payment.rb', line 202 def valid? true end |