Class: CyberSource::InlineResponse2015ProcessorInformation
- Inherits:
-
Object
- Object
- CyberSource::InlineResponse2015ProcessorInformation
- Defined in:
- lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb
Instance Attribute Summary collapse
-
#approval_code ⇒ Object
Authorization code.
-
#card_verification ⇒ Object
Returns the value of attribute card_verification.
-
#consumer_authentication_response ⇒ Object
Returns the value of attribute consumer_authentication_response.
-
#fee_program_description ⇒ Object
Short text description of the Acquirer IRF (Interchange Reimbursement Fee) indicator.
-
#fee_program_id ⇒ Object
This field identifies the interchange fee program applicable to each financial transaction.
-
#network ⇒ Object
Network ID on which the transaction was performed.
-
#processing_date ⇒ Object
The date that transaction was processed.
-
#processor ⇒ Object
The name of the processor that was used to complete the transaction.
-
#reason_code_details ⇒ Object
The reason code description contains the reason explaining: - An acquirer-generated advice, reversal, cancellation, adjustment, chargeback (validation request or advice).
-
#reason_code_value ⇒ Object
A four digit number that correlates to reasonCodeDetails.
-
#reject_reason_code ⇒ Object
Reject reason code if the transaction was rejected by VisaNet.
-
#reject_reason_text ⇒ Object
This field contains reject reason text if the transaction was rejected by VisaNet and generic MasterCard Status reason.
-
#response_code ⇒ Object
Transaction status from the processor.
-
#response_details ⇒ Object
This field might contain information about a decline.
-
#response_details_original ⇒ Object
This field might contain the original information about a decline.
-
#retrieval_reference_number ⇒ Object
This field contains a number that is used with other data elements as a key to identify and track all messages related to a given cardholder transaction; that is, to a given transaction set.
-
#settlement_date_time ⇒ Object
The date and time that transaction was settled.
-
#status_code ⇒ Object
Specifies status of the transaction processing.
-
#system_trace_audit_number ⇒ Object
This field is returned by authorization and incremental authorization services.
-
#transaction_date_time ⇒ Object
The date and time that transaction was processed.
-
#transaction_id ⇒ Object
Network transaction identifier (TID).
-
#transaction_type ⇒ Object
Identifies the type of transaction originally sent.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InlineResponse2015ProcessorInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ InlineResponse2015ProcessorInformation
Initializes the object
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 166 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'rejectReasonCode') self.reject_reason_code = attributes[:'rejectReasonCode'] end if attributes.has_key?(:'rejectReasonText') self.reject_reason_text = attributes[:'rejectReasonText'] end if attributes.has_key?(:'approvalCode') self.approval_code = attributes[:'approvalCode'] end if attributes.has_key?(:'cardVerification') self.card_verification = attributes[:'cardVerification'] end if attributes.has_key?(:'consumerAuthenticationResponse') self.consumer_authentication_response = attributes[:'consumerAuthenticationResponse'] end if attributes.has_key?(:'feeProgramDescription') self.fee_program_description = attributes[:'feeProgramDescription'] end if attributes.has_key?(:'feeProgramId') self.fee_program_id = attributes[:'feeProgramId'] end if attributes.has_key?(:'network') self.network = attributes[:'network'] end if attributes.has_key?(:'processingDate') self.processing_date = attributes[:'processingDate'] end if attributes.has_key?(:'processor') self.processor = attributes[:'processor'] end if attributes.has_key?(:'reasonCodeDetails') self.reason_code_details = attributes[:'reasonCodeDetails'] end if attributes.has_key?(:'reasonCodeValue') self.reason_code_value = attributes[:'reasonCodeValue'] end if attributes.has_key?(:'responseCode') self.response_code = attributes[:'responseCode'] end if attributes.has_key?(:'responseDetails') self.response_details = attributes[:'responseDetails'] end if attributes.has_key?(:'responseDetailsOriginal') self.response_details_original = attributes[:'responseDetailsOriginal'] end if attributes.has_key?(:'retrievalReferenceNumber') self.retrieval_reference_number = attributes[:'retrievalReferenceNumber'] end if attributes.has_key?(:'settlementDateTime') self.settlement_date_time = attributes[:'settlementDateTime'] end if attributes.has_key?(:'statusCode') self.status_code = attributes[:'statusCode'] end if attributes.has_key?(:'systemTraceAuditNumber') self.system_trace_audit_number = attributes[:'systemTraceAuditNumber'] end if attributes.has_key?(:'transactionDateTime') self.transaction_date_time = attributes[:'transactionDateTime'] end if attributes.has_key?(:'transactionId') self.transaction_id = attributes[:'transactionId'] end if attributes.has_key?(:'transactionType') self.transaction_type = attributes[:'transactionType'] end end |
Instance Attribute Details
#approval_code ⇒ Object
Authorization code. Returned only when the processor returns this value.
23 24 25 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 23 def approval_code @approval_code end |
#card_verification ⇒ Object
Returns the value of attribute card_verification.
25 26 27 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 25 def card_verification @card_verification end |
#consumer_authentication_response ⇒ Object
Returns the value of attribute consumer_authentication_response.
27 28 29 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 27 def consumer_authentication_response @consumer_authentication_response end |
#fee_program_description ⇒ Object
Short text description of the Acquirer IRF (Interchange Reimbursement Fee) indicator.
30 31 32 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 30 def fee_program_description @fee_program_description end |
#fee_program_id ⇒ Object
This field identifies the interchange fee program applicable to each financial transaction. Fee-program indicator (FPI) values correspond to the fee descriptor and rate for each existing fee program. This field can be regarded as informational only in all authorization messages.
33 34 35 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 33 def fee_program_id @fee_program_id end |
#network ⇒ Object
Network ID on which the transaction was performed. Takes the format of 000x where x is a number.
36 37 38 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 36 def network @network end |
#processing_date ⇒ Object
The date that transaction was processed.
39 40 41 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 39 def processing_date @processing_date end |
#processor ⇒ Object
The name of the processor that was used to complete the transaction.
42 43 44 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 42 def processor @processor end |
#reason_code_details ⇒ Object
The reason code description contains the reason explaining: - An acquirer-generated advice, reversal, cancellation, adjustment, chargeback (validation request or advice). - An chargeback reversal, representment (validation request or advice).
45 46 47 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 45 def reason_code_details @reason_code_details end |
#reason_code_value ⇒ Object
A four digit number that correlates to reasonCodeDetails.
48 49 50 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 48 def reason_code_value @reason_code_value end |
#reject_reason_code ⇒ Object
Reject reason code if the transaction was rejected by VisaNet.
17 18 19 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 17 def reject_reason_code @reject_reason_code end |
#reject_reason_text ⇒ Object
This field contains reject reason text if the transaction was rejected by VisaNet and generic MasterCard Status reason.
20 21 22 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 20 def reject_reason_text @reject_reason_text end |
#response_code ⇒ Object
Transaction status from the processor.
51 52 53 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 51 def response_code @response_code end |
#response_details ⇒ Object
This field might contain information about a decline.
54 55 56 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 54 def response_details @response_details end |
#response_details_original ⇒ Object
This field might contain the original information about a decline.
57 58 59 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 57 def response_details_original @response_details_original end |
#retrieval_reference_number ⇒ Object
This field contains a number that is used with other data elements as a key to identify and track all messages related to a given cardholder transaction; that is, to a given transaction set. Recommended format: ydddhhnnnnnn Positions 1-4: The yddd equivalent of the date, where y = 0-9 and ddd = 001 – 366. Positions 5-12: A unique identification number generated by the merchant or assigned by CyberSource.
60 61 62 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 60 def retrieval_reference_number @retrieval_reference_number end |
#settlement_date_time ⇒ Object
The date and time that transaction was settled.
63 64 65 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 63 def settlement_date_time @settlement_date_time end |
#status_code ⇒ Object
Specifies status of the transaction processing.
66 67 68 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 66 def status_code @status_code end |
#system_trace_audit_number ⇒ Object
This field is returned by authorization and incremental authorization services. System trace number that must be printed on the customer's receipt.
69 70 71 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 69 def system_trace_audit_number @system_trace_audit_number end |
#transaction_date_time ⇒ Object
The date and time that transaction was processed.
72 73 74 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 72 def transaction_date_time @transaction_date_time end |
#transaction_id ⇒ Object
Network transaction identifier (TID). This value can be used to identify a specific transaction when you are discussing the transaction with your processor.
75 76 77 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 75 def transaction_id @transaction_id end |
#transaction_type ⇒ Object
Identifies the type of transaction originally sent.
78 79 80 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 78 def transaction_type @transaction_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 81 def self.attribute_map { :'reject_reason_code' => :'rejectReasonCode', :'reject_reason_text' => :'rejectReasonText', :'approval_code' => :'approvalCode', :'card_verification' => :'cardVerification', :'consumer_authentication_response' => :'consumerAuthenticationResponse', :'fee_program_description' => :'feeProgramDescription', :'fee_program_id' => :'feeProgramId', :'network' => :'network', :'processing_date' => :'processingDate', :'processor' => :'processor', :'reason_code_details' => :'reasonCodeDetails', :'reason_code_value' => :'reasonCodeValue', :'response_code' => :'responseCode', :'response_details' => :'responseDetails', :'response_details_original' => :'responseDetailsOriginal', :'retrieval_reference_number' => :'retrievalReferenceNumber', :'settlement_date_time' => :'settlementDateTime', :'status_code' => :'statusCode', :'system_trace_audit_number' => :'systemTraceAuditNumber', :'transaction_date_time' => :'transactionDateTime', :'transaction_id' => :'transactionId', :'transaction_type' => :'transactionType' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 109 def self.json_map { :'reject_reason_code' => :'reject_reason_code', :'reject_reason_text' => :'reject_reason_text', :'approval_code' => :'approval_code', :'card_verification' => :'card_verification', :'consumer_authentication_response' => :'consumer_authentication_response', :'fee_program_description' => :'fee_program_description', :'fee_program_id' => :'fee_program_id', :'network' => :'network', :'processing_date' => :'processing_date', :'processor' => :'processor', :'reason_code_details' => :'reason_code_details', :'reason_code_value' => :'reason_code_value', :'response_code' => :'response_code', :'response_details' => :'response_details', :'response_details_original' => :'response_details_original', :'retrieval_reference_number' => :'retrieval_reference_number', :'settlement_date_time' => :'settlement_date_time', :'status_code' => :'status_code', :'system_trace_audit_number' => :'system_trace_audit_number', :'transaction_date_time' => :'transaction_date_time', :'transaction_id' => :'transaction_id', :'transaction_type' => :'transaction_type' } end |
.swagger_types ⇒ Object
Attribute type mapping.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 137 def self.swagger_types { :'reject_reason_code' => :'String', :'reject_reason_text' => :'String', :'approval_code' => :'String', :'card_verification' => :'InlineResponse2015ProcessorInformationCardVerification', :'consumer_authentication_response' => :'ConsumerAuthenticationResponse', :'fee_program_description' => :'String', :'fee_program_id' => :'String', :'network' => :'String', :'processing_date' => :'String', :'processor' => :'String', :'reason_code_details' => :'String', :'reason_code_value' => :'String', :'response_code' => :'String', :'response_details' => :'String', :'response_details_original' => :'String', :'retrieval_reference_number' => :'String', :'settlement_date_time' => :'String', :'status_code' => :'String', :'system_trace_audit_number' => :'String', :'transaction_date_time' => :'String', :'transaction_id' => :'String', :'transaction_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 405 def ==(o) return true if self.equal?(o) self.class == o.class && reject_reason_code == o.reject_reason_code && reject_reason_text == o.reject_reason_text && approval_code == o.approval_code && card_verification == o.card_verification && consumer_authentication_response == o.consumer_authentication_response && fee_program_description == o.fee_program_description && fee_program_id == o.fee_program_id && network == o.network && processing_date == o.processing_date && processor == o.processor && reason_code_details == o.reason_code_details && reason_code_value == o.reason_code_value && response_code == o.response_code && response_details == o.response_details && response_details_original == o.response_details_original && retrieval_reference_number == o.retrieval_reference_number && settlement_date_time == o.settlement_date_time && status_code == o.status_code && system_trace_audit_number == o.system_trace_audit_number && transaction_date_time == o.transaction_date_time && transaction_id == o.transaction_id && transaction_type == o.transaction_type end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 468 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 534 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 447 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
434 435 436 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 434 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
440 441 442 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 440 def hash [reject_reason_code, reject_reason_text, approval_code, card_verification, consumer_authentication_response, fee_program_description, fee_program_id, network, processing_date, processor, reason_code_details, reason_code_value, response_code, response_details, response_details_original, retrieval_reference_number, settlement_date_time, status_code, system_trace_audit_number, transaction_date_time, transaction_id, transaction_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
263 264 265 266 267 268 269 270 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 263 def list_invalid_properties invalid_properties = Array.new if @transaction_id.nil? invalid_properties.push('invalid value for "transaction_id", transaction_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
514 515 516 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 514 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
520 521 522 523 524 525 526 527 528 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 520 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
508 509 510 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 508 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
274 275 276 277 |
# File 'lib/cybersource_rest_client/models/inline_response_201_5_processor_information.rb', line 274 def valid? return false if @transaction_id.nil? true end |