Class: CyberSource::Iplv2paymentlinksOrderInformationLineItems
- Inherits:
-
Object
- Object
- CyberSource::Iplv2paymentlinksOrderInformationLineItems
- Defined in:
- lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb
Overview
Line item from the order.
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
Discount amount applied to the item.
-
#discount_percent ⇒ Object
Discount rate applied to the item.
-
#product_description ⇒ Object
Brief description of item.
-
#product_name ⇒ Object
For an authorization or capture transaction (‘processingOptions.capture` is `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the other values that are related to shipping and/or handling.
-
#product_sku ⇒ Object
Product identifier code.
-
#quantity ⇒ Object
Number of units for this order.
-
#tax_amount ⇒ Object
Tax amount applied to the item.
-
#tax_rate ⇒ Object
Tax rate applied to the item.
-
#unit_price ⇒ Object
Per-item price of the product.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Iplv2paymentlinksOrderInformationLineItems
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Iplv2paymentlinksOrderInformationLineItems
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'productSku') self.product_sku = attributes[:'productSku'] end if attributes.has_key?(:'productName') self.product_name = attributes[:'productName'] end if attributes.has_key?(:'quantity') self.quantity = attributes[:'quantity'] end if attributes.has_key?(:'unitPrice') self.unit_price = attributes[:'unitPrice'] end if attributes.has_key?(:'productDescription') self.product_description = attributes[:'productDescription'] end if attributes.has_key?(:'discountAmount') self.discount_amount = attributes[:'discountAmount'] end if attributes.has_key?(:'discountPercent') self.discount_percent = attributes[:'discountPercent'] end if attributes.has_key?(:'taxAmount') self.tax_amount = attributes[:'taxAmount'] end if attributes.has_key?(:'taxRate') self.tax_rate = attributes[:'taxRate'] end end |
Instance Attribute Details
#discount_amount ⇒ Object
Discount amount applied to the item. Maximum of 2 decimal places. You may provide either discountAmount or discountPercent (not both). If both are present, their values must be consistent. Otherwise, a validation error will be returned.
33 34 35 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 33 def discount_amount @discount_amount end |
#discount_percent ⇒ Object
Discount rate applied to the item. Maximum of 3 decimal places. You may provide either discountAmount or discountPercent (not both). If both are present, their values must be consistent; otherwise, a validation error will be returned. Example: 5.25 (=5.25%)
36 37 38 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 36 def discount_percent @discount_percent end |
#product_description ⇒ Object
Brief description of item.
30 31 32 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 30 def product_description @product_description end |
#product_name ⇒ Object
For an authorization or capture transaction (‘processingOptions.capture` is `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the other values that are related to shipping and/or handling. #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes.
21 22 23 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 21 def product_name @product_name end |
#product_sku ⇒ Object
Product identifier code. Also known as the Stock Keeping Unit (SKU) code for the product. For an authorization or capture transaction (‘processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not set to default or one of the other values that are related to shipping and/or handling. #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. For an authorization or capture transaction (`processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the values related to shipping and/or handling.
18 19 20 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 18 def product_sku @product_sku end |
#quantity ⇒ Object
Number of units for this order. Must be a non-negative integer. The default is ‘1`. For an authorization or capture transaction (`processingOptions.capture` is set to `true` or `false`), this field is required when `orderInformation.lineItems[].productCode` is not `default` or one of the other values related to shipping and/or handling. #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes.
24 25 26 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 24 def quantity @quantity end |
#tax_amount ⇒ Object
Tax amount applied to the item. This value cannot be negative. Maximum of 2 decimal places. The tax amount and the offer amount must be in the same currency. The tax amount field is additive. If taxAmount is provided but taxRate is not, the taxRate will be calculated.
39 40 41 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 39 def tax_amount @tax_amount end |
#tax_rate ⇒ Object
Tax rate applied to the item. Valid range: 1.001% to 99.999%. Maximum of 3 decimal places. If a taxRate is provided but taxAmount is missing or incorrect, the taxAmount based on the given taxRate will be overwritten. Example: 21.00 (=21.00%)
42 43 44 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 42 def tax_rate @tax_rate end |
#unit_price ⇒ Object
Per-item price of the product. This value for this field cannot be negative. You must include either this field or the request-level field ‘orderInformation.amountDetails.totalAmount` in your request. You can include a decimal point (.), but you cannot include any other special characters. The value is truncated to the correct number of decimal places. #### DCC with a Third-Party Provider Set this field to the converted amount that was returned by the DCC provider. You must include either the 1st line item in the order and this field, or the request-level field `orderInformation.amountDetails.totalAmount` in your request. #### Tax Calculation Required field for U.S., Canadian, international and value added taxes. #### Zero Amount Authorizations If your processor supports zero amount authorizations, you can set this field to 0 for the authorization to check if the card is lost or stolen. #### Maximum Field Lengths For GPN and JCN Gateway: Decimal (10) All other processors: Decimal (15)
27 28 29 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 27 def unit_price @unit_price end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 45 def self.attribute_map { :'product_sku' => :'productSku', :'product_name' => :'productName', :'quantity' => :'quantity', :'unit_price' => :'unitPrice', :'product_description' => :'productDescription', :'discount_amount' => :'discountAmount', :'discount_percent' => :'discountPercent', :'tax_amount' => :'taxAmount', :'tax_rate' => :'taxRate' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 60 def self.json_map { :'product_sku' => :'product_sku', :'product_name' => :'product_name', :'quantity' => :'quantity', :'unit_price' => :'unit_price', :'product_description' => :'product_description', :'discount_amount' => :'discount_amount', :'discount_percent' => :'discount_percent', :'tax_amount' => :'tax_amount', :'tax_rate' => :'tax_rate' } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 75 def self.swagger_types { :'product_sku' => :'String', :'product_name' => :'String', :'quantity' => :'Integer', :'unit_price' => :'String', :'product_description' => :'String', :'discount_amount' => :'String', :'discount_percent' => :'String', :'tax_amount' => :'String', :'tax_rate' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && product_sku == o.product_sku && product_name == o.product_name && quantity == o.quantity && unit_price == o.unit_price && product_description == o.product_description && discount_amount == o.discount_amount && discount_percent == o.discount_percent && tax_amount == o.tax_amount && tax_rate == o.tax_rate end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 262 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 328 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 241 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
228 229 230 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 228 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 234 def hash [product_sku, product_name, quantity, unit_price, product_description, discount_amount, discount_percent, tax_amount, tax_rate].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
136 137 138 139 140 141 142 143 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 136 def list_invalid_properties invalid_properties = Array.new if @product_name.nil? invalid_properties.push('invalid value for "product_name", product_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
308 309 310 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 308 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
302 303 304 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 302 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
147 148 149 150 |
# File 'lib/cybersource_rest_client/models/iplv2paymentlinks_order_information_line_items.rb', line 147 def valid? return false if @product_name.nil? true end |