Class: CyberSource::OffersApi
- Inherits:
-
Object
- Object
- CyberSource::OffersApi
- Defined in:
- lib/cybersource_rest_client/api/offers_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_offer(content_type, x_requestid, v_c_merchant_id, v_c_correlation_id, v_c_organization_id, offer_request, opts = {}) ⇒ InlineResponse2019
Create an Offer Empower global transactions with transparency and choice.
-
#create_offer_with_http_info(content_type, x_requestid, v_c_merchant_id, v_c_correlation_id, v_c_organization_id, offer_request, opts = {}) ⇒ Array<(InlineResponse2019, Fixnum, Hash)>
Create an Offer Empower global transactions with transparency and choice.
-
#get_offer(content_type, x_requestid, v_c_merchant_id, v_c_correlation_id, v_c_organization_id, id, opts = {}) ⇒ InlineResponse20016
Retrieve an Offer Retrieves an offer record from the system.
-
#get_offer_with_http_info(content_type, x_requestid, v_c_merchant_id, v_c_correlation_id, v_c_organization_id, id, opts = {}) ⇒ Array<(InlineResponse20016, Fixnum, Hash)>
Retrieve an Offer Retrieves an offer record from the system.
-
#initialize(api_client = ApiClient.default, config) ⇒ OffersApi
constructor
A new instance of OffersApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
16 17 18 |
# File 'lib/cybersource_rest_client/api/offers_api.rb', line 16 def api_client @api_client end |
Instance Method Details
#create_offer(content_type, x_requestid, v_c_merchant_id, v_c_correlation_id, v_c_organization_id, offer_request, opts = {}) ⇒ InlineResponse2019
Create an Offer
Empower global transactions with transparency and choice. Our Dynamic Currency Conversion API lets merchants offer customers the option to pay in their home currency at checkout, delivering real-time exchange rates. <div style="display: flex; gap: 2rem;"> <div style="flex: 1;"> Key Benefits: - Enhanced Customer Experience: Provide clarity and convenience for international shoppers. - Real-Time Rates: Accurate currency conversion with all the data required for acquirers and their merchants to maintain compliance with card network rules. - Seamless Integration: Flexible API endpoints for rate lookup, authorization, and capture. - Regulatory Compliance: Provides the data required for acquirers and merchants to meet and maintain card scheme requirements for disclosure and consent.
Ideal for merchants and payment partners seeking to boost trust and conversion in cross-border commerce.
Key Features: - Rate Lookup: Retrieves the most up-to-date exchange rate for eligible cards before authorization. - Currency Choice: Enables the merchant to offer customers the option to select between the merchant's local currency and their card's billing currency. - Compliance: Ensures merchants have the data required to adhere to card network regulations; exchange rates, markups, etc. <div style="margin-top: 1.5rem;"> Supported Scenarios: - Dynamic Currency Conversion when cardholder's billing currency differs from merchant's pricing currency. - Merchant and acquirer must support the cardholder's billing currency.