Class: CyberSource::PaymentsProductsUnifiedCheckoutSubscriptionInformationFeatures
- Inherits:
-
Object
- Object
- CyberSource::PaymentsProductsUnifiedCheckoutSubscriptionInformationFeatures
- Defined in:
- lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb
Instance Attribute Summary collapse
-
#after_pay ⇒ Object
Returns the value of attribute after_pay.
-
#apple_pay ⇒ Object
Returns the value of attribute apple_pay.
-
#bancontact ⇒ Object
Returns the value of attribute bancontact.
-
#click_to_pay ⇒ Object
Returns the value of attribute click_to_pay.
-
#decision_manager ⇒ Object
Returns the value of attribute decision_manager.
-
#dragon_pay ⇒ Object
Returns the value of attribute dragon_pay.
-
#e_check ⇒ Object
Returns the value of attribute e_check.
-
#google_pay ⇒ Object
Returns the value of attribute google_pay.
-
#ideal ⇒ Object
Returns the value of attribute ideal.
-
#konbini ⇒ Object
Returns the value of attribute konbini.
-
#multibanco ⇒ Object
Returns the value of attribute multibanco.
-
#my_bank ⇒ Object
Returns the value of attribute my_bank.
-
#p24 ⇒ Object
Returns the value of attribute p24.
-
#pay_pal ⇒ Object
Returns the value of attribute pay_pal.
-
#payer_authentication ⇒ Object
Returns the value of attribute payer_authentication.
-
#paze_for_unified_checkout ⇒ Object
Returns the value of attribute paze_for_unified_checkout.
-
#portfolio_accessof_sensitive_data ⇒ Object
Returns the value of attribute portfolio_accessof_sensitive_data.
-
#tink_pay_by_bank ⇒ Object
Returns the value of attribute tink_pay_by_bank.
-
#token_management ⇒ Object
Returns the value of attribute token_management.
-
#unified_click_to_pay_sdk ⇒ Object
Returns the value of attribute unified_click_to_pay_sdk.
-
#venmo ⇒ Object
Returns the value of attribute venmo.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentsProductsUnifiedCheckoutSubscriptionInformationFeatures
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentsProductsUnifiedCheckoutSubscriptionInformationFeatures
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 141 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'pazeForUnifiedCheckout') self.paze_for_unified_checkout = attributes[:'pazeForUnifiedCheckout'] end if attributes.has_key?(:'tokenManagement') self.token_management = attributes[:'tokenManagement'] end if attributes.has_key?(:'payPal') self.pay_pal = attributes[:'payPal'] end if attributes.has_key?(:'venmo') self.venmo = attributes[:'venmo'] end if attributes.has_key?(:'applePay') self.apple_pay = attributes[:'applePay'] end if attributes.has_key?(:'googlePay') self.google_pay = attributes[:'googlePay'] end if attributes.has_key?(:'tinkPayByBank') self.tink_pay_by_bank = attributes[:'tinkPayByBank'] end if attributes.has_key?(:'eCheck') self.e_check = attributes[:'eCheck'] end if attributes.has_key?(:'p24') self.p24 = attributes[:'p24'] end if attributes.has_key?(:'myBank') self.my_bank = attributes[:'myBank'] end if attributes.has_key?(:'konbini') self.konbini = attributes[:'konbini'] end if attributes.has_key?(:'dragonPay') self.dragon_pay = attributes[:'dragonPay'] end if attributes.has_key?(:'decisionManager') self.decision_manager = attributes[:'decisionManager'] end if attributes.has_key?(:'payerAuthentication') self.payer_authentication = attributes[:'payerAuthentication'] end if attributes.has_key?(:'afterPay') self.after_pay = attributes[:'afterPay'] end if attributes.has_key?(:'ideal') self.ideal = attributes[:'ideal'] end if attributes.has_key?(:'multibanco') self.multibanco = attributes[:'multibanco'] end if attributes.has_key?(:'bancontact') self.bancontact = attributes[:'bancontact'] end if attributes.has_key?(:'clickToPay') self.click_to_pay = attributes[:'clickToPay'] end if attributes.has_key?(:'unifiedClickToPaySDK') self.unified_click_to_pay_sdk = attributes[:'unifiedClickToPaySDK'] end if attributes.has_key?(:'portfolioAccessofSensitiveData') self.portfolio_accessof_sensitive_data = attributes[:'portfolioAccessofSensitiveData'] end end |
Instance Attribute Details
#after_pay ⇒ Object
Returns the value of attribute after_pay.
44 45 46 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 44 def after_pay @after_pay end |
#apple_pay ⇒ Object
Returns the value of attribute apple_pay.
24 25 26 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 24 def apple_pay @apple_pay end |
#bancontact ⇒ Object
Returns the value of attribute bancontact.
50 51 52 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 50 def bancontact @bancontact end |
#click_to_pay ⇒ Object
Returns the value of attribute click_to_pay.
52 53 54 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 52 def click_to_pay @click_to_pay end |
#decision_manager ⇒ Object
Returns the value of attribute decision_manager.
40 41 42 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 40 def decision_manager @decision_manager end |
#dragon_pay ⇒ Object
Returns the value of attribute dragon_pay.
38 39 40 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 38 def dragon_pay @dragon_pay end |
#e_check ⇒ Object
Returns the value of attribute e_check.
30 31 32 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 30 def e_check @e_check end |
#google_pay ⇒ Object
Returns the value of attribute google_pay.
26 27 28 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 26 def google_pay @google_pay end |
#ideal ⇒ Object
Returns the value of attribute ideal.
46 47 48 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 46 def ideal @ideal end |
#konbini ⇒ Object
Returns the value of attribute konbini.
36 37 38 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 36 def konbini @konbini end |
#multibanco ⇒ Object
Returns the value of attribute multibanco.
48 49 50 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 48 def multibanco @multibanco end |
#my_bank ⇒ Object
Returns the value of attribute my_bank.
34 35 36 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 34 def my_bank @my_bank end |
#p24 ⇒ Object
Returns the value of attribute p24.
32 33 34 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 32 def p24 @p24 end |
#pay_pal ⇒ Object
Returns the value of attribute pay_pal.
20 21 22 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 20 def pay_pal @pay_pal end |
#payer_authentication ⇒ Object
Returns the value of attribute payer_authentication.
42 43 44 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 42 def payer_authentication @payer_authentication end |
#paze_for_unified_checkout ⇒ Object
Returns the value of attribute paze_for_unified_checkout.
16 17 18 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 16 def paze_for_unified_checkout @paze_for_unified_checkout end |
#portfolio_accessof_sensitive_data ⇒ Object
Returns the value of attribute portfolio_accessof_sensitive_data.
56 57 58 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 56 def portfolio_accessof_sensitive_data @portfolio_accessof_sensitive_data end |
#tink_pay_by_bank ⇒ Object
Returns the value of attribute tink_pay_by_bank.
28 29 30 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 28 def tink_pay_by_bank @tink_pay_by_bank end |
#token_management ⇒ Object
Returns the value of attribute token_management.
18 19 20 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 18 def token_management @token_management end |
#unified_click_to_pay_sdk ⇒ Object
Returns the value of attribute unified_click_to_pay_sdk.
54 55 56 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 54 def unified_click_to_pay_sdk @unified_click_to_pay_sdk end |
#venmo ⇒ Object
Returns the value of attribute venmo.
22 23 24 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 22 def venmo @venmo end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 59 def self.attribute_map { :'paze_for_unified_checkout' => :'pazeForUnifiedCheckout', :'token_management' => :'tokenManagement', :'pay_pal' => :'payPal', :'venmo' => :'venmo', :'apple_pay' => :'applePay', :'google_pay' => :'googlePay', :'tink_pay_by_bank' => :'tinkPayByBank', :'e_check' => :'eCheck', :'p24' => :'p24', :'my_bank' => :'myBank', :'konbini' => :'konbini', :'dragon_pay' => :'dragonPay', :'decision_manager' => :'decisionManager', :'payer_authentication' => :'payerAuthentication', :'after_pay' => :'afterPay', :'ideal' => :'ideal', :'multibanco' => :'multibanco', :'bancontact' => :'bancontact', :'click_to_pay' => :'clickToPay', :'unified_click_to_pay_sdk' => :'unifiedClickToPaySDK', :'portfolio_accessof_sensitive_data' => :'portfolioAccessofSensitiveData' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 86 def self.json_map { :'paze_for_unified_checkout' => :'paze_for_unified_checkout', :'token_management' => :'token_management', :'pay_pal' => :'pay_pal', :'venmo' => :'venmo', :'apple_pay' => :'apple_pay', :'google_pay' => :'google_pay', :'tink_pay_by_bank' => :'tink_pay_by_bank', :'e_check' => :'e_check', :'p24' => :'p24', :'my_bank' => :'my_bank', :'konbini' => :'konbini', :'dragon_pay' => :'dragon_pay', :'decision_manager' => :'decision_manager', :'payer_authentication' => :'payer_authentication', :'after_pay' => :'after_pay', :'ideal' => :'ideal', :'multibanco' => :'multibanco', :'bancontact' => :'bancontact', :'click_to_pay' => :'click_to_pay', :'unified_click_to_pay_sdk' => :'unified_click_to_pay_sdk', :'portfolio_accessof_sensitive_data' => :'portfolio_accessof_sensitive_data' } end |
.swagger_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 113 def self.swagger_types { :'paze_for_unified_checkout' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesPazeForUnifiedCheckout', :'token_management' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesTokenManagement', :'pay_pal' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesPayPal', :'venmo' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesVenmo', :'apple_pay' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesApplePay', :'google_pay' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesGooglePay', :'tink_pay_by_bank' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesTinkPayByBank', :'e_check' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesECheck', :'p24' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesP24', :'my_bank' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesMyBank', :'konbini' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesKonbini', :'dragon_pay' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesDragonPay', :'decision_manager' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesDecisionManager', :'payer_authentication' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesPayerAuthentication', :'after_pay' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesAfterPay', :'ideal' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesIdeal', :'multibanco' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesMultibanco', :'bancontact' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesBancontact', :'click_to_pay' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesClickToPay', :'unified_click_to_pay_sdk' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesUnifiedClickToPaySDK', :'portfolio_accessof_sensitive_data' => :'PaymentsProductsUnifiedCheckoutSubscriptionInformationFeaturesPortfolioAccessofSensitiveData' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 247 def ==(o) return true if self.equal?(o) self.class == o.class && paze_for_unified_checkout == o.paze_for_unified_checkout && token_management == o.token_management && pay_pal == o.pay_pal && venmo == o.venmo && apple_pay == o.apple_pay && google_pay == o.google_pay && tink_pay_by_bank == o.tink_pay_by_bank && e_check == o.e_check && p24 == o.p24 && my_bank == o.my_bank && konbini == o.konbini && dragon_pay == o.dragon_pay && decision_manager == o.decision_manager && payer_authentication == o.payer_authentication && after_pay == o.after_pay && ideal == o.ideal && multibanco == o.multibanco && bancontact == o.bancontact && click_to_pay == o.click_to_pay && unified_click_to_pay_sdk == o.unified_click_to_pay_sdk && portfolio_accessof_sensitive_data == o.portfolio_accessof_sensitive_data end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 309 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 375 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 288 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
275 276 277 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 275 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 281 def hash [paze_for_unified_checkout, token_management, pay_pal, venmo, apple_pay, google_pay, tink_pay_by_bank, e_check, p24, my_bank, konbini, dragon_pay, decision_manager, payer_authentication, after_pay, ideal, multibanco, bancontact, click_to_pay, unified_click_to_pay_sdk, portfolio_accessof_sensitive_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
234 235 236 237 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 234 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
355 356 357 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 355 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
361 362 363 364 365 366 367 368 369 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 361 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
349 350 351 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 349 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 |
# File 'lib/cybersource_rest_client/models/payments_products_unified_checkout_subscription_information_features.rb', line 241 def valid? true end |