Class: CyberSource::Ptsv1pullfundstransferProcessingInformation
- Inherits:
-
Object
- Object
- CyberSource::Ptsv1pullfundstransferProcessingInformation
- Defined in:
- lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb
Instance Attribute Summary collapse
-
#account_verification_code ⇒ Object
Account verification code will inform what Payment Account Verification should be performed.
-
#business_application_id ⇒ Object
Payouts transaction type.
-
#commerce_indicator ⇒ Object
Type of transaction.
-
#funding_options ⇒ Object
Returns the value of attribute funding_options.
-
#language_code ⇒ Object
Contains the ISO 639-2 defined language Code.
-
#payouts_options ⇒ Object
Returns the value of attribute payouts_options.
-
#purpose_of_payment ⇒ Object
Visa Direct Purpose of payment is required in certain markets to clearly identify the purpose of the payment based on the standard values defined for respective market.
-
#recurring_options ⇒ Object
Returns the value of attribute recurring_options.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv1pullfundstransferProcessingInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv1pullfundstransferProcessingInformation
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'commerceIndicator') self.commerce_indicator = attributes[:'commerceIndicator'] end if attributes.has_key?(:'fundingOptions') self. = attributes[:'fundingOptions'] end if attributes.has_key?(:'recurringOptions') self. = attributes[:'recurringOptions'] end if attributes.has_key?(:'businessApplicationId') self.business_application_id = attributes[:'businessApplicationId'] end if attributes.has_key?(:'purposeOfPayment') self.purpose_of_payment = attributes[:'purposeOfPayment'] end if attributes.has_key?(:'payoutsOptions') self. = attributes[:'payoutsOptions'] end if attributes.has_key?(:'languageCode') self.language_code = attributes[:'languageCode'] end if attributes.has_key?(:'accountVerificationCode') if (value = attributes[:'accountVerificationCode']).is_a?(Array) self.account_verification_code = value end end end |
Instance Attribute Details
#account_verification_code ⇒ Object
Account verification code will inform what Payment Account Verification should be performed. With this array of codes, a merchant can choose à la carte what verifications to run. This field is optional, and the default is 1 if it is not passed in. This means that a full validation of the fields will be performed. Valid verification codes: - ‘1` = Full Account Verification (Card Account, CVN, CAVV, TAVV, Address, Name, eMail, Phone, Identity) - `2` = Card Account Verification - `3` = Address Verification - `4` = Card Authentication Method (CAM) (Cryptogram) - `5` = Cardholder Authentication Verification (CAVV) - `6` = Cardholder Identity Verification - `7` = CVV2 Verification - `8` = eMail Verification - `9` = Name Verification - `10` = Phone Verification
35 36 37 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 35 def account_verification_code @account_verification_code end |
#business_application_id ⇒ Object
Payouts transaction type. Possible Values: - ‘AA` = Account to account - `PP` = Person to person - `TU` = Top-up for enhanced prepaid loads - `WT` = Wallet transfer - `BI` = Bank-Initiated - `FT` = Funds Transfer - `FD` = Funds Disbursement - `MP` = Merchant Payment - `PD` = Payroll Disbursement - `LA` = Liquid Assets
24 25 26 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 24 def business_application_id @business_application_id end |
#commerce_indicator ⇒ Object
Type of transaction. This field identifies the level of security used in an electronic commerce transaction over an open network (for example, the internet). Values for a Payouts transaction: ‘INTERNET`, `RECURRING`, `RECURRING_INTERNET`, `VBV_FAILURE`, `VBV_ATTEMPTED`, `VBV`, `SPA_FAILURE`, `SPA_ATTEMPTED`, `SPA` If no value is entered this field will set a default value = `INTERNET`.
17 18 19 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 17 def commerce_indicator @commerce_indicator end |
#funding_options ⇒ Object
Returns the value of attribute funding_options.
19 20 21 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 19 def @funding_options end |
#language_code ⇒ Object
Contains the ISO 639-2 defined language Code
32 33 34 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 32 def language_code @language_code end |
#payouts_options ⇒ Object
Returns the value of attribute payouts_options.
29 30 31 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 29 def @payouts_options end |
#purpose_of_payment ⇒ Object
Visa Direct Purpose of payment is required in certain markets to clearly identify the purpose of the payment based on the standard values defined for respective market.
27 28 29 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 27 def purpose_of_payment @purpose_of_payment end |
#recurring_options ⇒ Object
Returns the value of attribute recurring_options.
21 22 23 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 21 def @recurring_options end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 38 def self.attribute_map { :'commerce_indicator' => :'commerceIndicator', :'funding_options' => :'fundingOptions', :'recurring_options' => :'recurringOptions', :'business_application_id' => :'businessApplicationId', :'purpose_of_payment' => :'purposeOfPayment', :'payouts_options' => :'payoutsOptions', :'language_code' => :'languageCode', :'account_verification_code' => :'accountVerificationCode' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 52 def self.json_map { :'commerce_indicator' => :'commerce_indicator', :'funding_options' => :'funding_options', :'recurring_options' => :'recurring_options', :'business_application_id' => :'business_application_id', :'purpose_of_payment' => :'purpose_of_payment', :'payouts_options' => :'payouts_options', :'language_code' => :'language_code', :'account_verification_code' => :'account_verification_code' } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 66 def self.swagger_types { :'commerce_indicator' => :'String', :'funding_options' => :'Ptsv1pullfundstransferProcessingInformationFundingOptions', :'recurring_options' => :'Ptsv1pullfundstransferProcessingInformationRecurringOptions', :'business_application_id' => :'String', :'purpose_of_payment' => :'String', :'payouts_options' => :'Ptsv1pullfundstransferProcessingInformationPayoutsOptions', :'language_code' => :'String', :'account_verification_code' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && commerce_indicator == o.commerce_indicator && == o. && == o. && business_application_id == o.business_application_id && purpose_of_payment == o.purpose_of_payment && == o. && language_code == o.language_code && account_verification_code == o.account_verification_code end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 228 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 294 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 207 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 200 def hash [commerce_indicator, , , business_application_id, purpose_of_payment, , language_code, account_verification_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 124 def list_invalid_properties invalid_properties = Array.new if @business_application_id.nil? invalid_properties.push('invalid value for "business_application_id", business_application_id cannot be nil.') end #if @business_application_id !~ Regexp.new(/^(\\s{0,2}|.{2})$/) #invalid_properties.push('invalid value for "business_application_id", must conform to the pattern /^(\\s{0,2}|.{2})$/.') #end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
274 275 276 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 274 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
268 269 270 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 268 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
139 140 141 142 143 |
# File 'lib/cybersource_rest_client/models/ptsv1pullfundstransfer_processing_information.rb', line 139 def valid? return false if @business_application_id.nil? #return false if @business_application_id !~ Regexp.new(/^(\\s{0,2}|.{2})$/) true end |