Class: CyberSource::Ptsv1pushfundstransferProcessingInformation
- Inherits:
-
Object
- Object
- CyberSource::Ptsv1pushfundstransferProcessingInformation
- Defined in:
- lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb
Instance Attribute Summary collapse
-
#account_verification_code ⇒ Object
Account verification code will inform what Payment Account Verification should be performed.
-
#business_application_id ⇒ Object
Money Transfer (MT) - ‘AA`: Account to Account - `BI`: Bank-Initiated Money Transfer - `CD`: Cash Deposit - `FT`: Funds Transfer - `TU`: Prepaid Card Loan - `WT`: Wallet Transfer-Staged Digital Wallet (SDW) Transfer - `PP`: P2P Money Transfer Funds Disbursement (FD) - `BB`: Business-to-business Supplier Payments - `BP`: Non-Card Bill Pay - `CP`: Credit Card Bill Pay - `FD`: General Funds Disbursements - `GD`: Government Disbursements and Government Initiated Tax Refunds - `GP`: Gambling/Gaming Payouts (other than online gaming) - `LO`: Loyalty Payments - `MD`: Merchant Settlement - `MI`: Faster Refunds - `OG`: Online Gambling Payouts - `PD`: Payroll and Pension Disbursements - `RP`: Request-to-Pay Service.
-
#fee_program_id ⇒ Object
Fee Program Indicator.
-
#network_partner_id ⇒ Object
Merchant payment gateway ID that is assigned by Mastercard and is provided by the acquirer when a registered merchant payment gateway service provider is involved in the transaction.
-
#payouts_options ⇒ Object
Returns the value of attribute payouts_options.
-
#processing_code ⇒ Object
This field contains coding that identifies (1) the customer transaction type and (2) the customer account types affected by the transaction.
-
#purpose_of_payment ⇒ Object
This will send purpose of funds code for original credit transactions (OCTs).
-
#reconciliation_id ⇒ Object
Transaction’s reference number.
-
#sharing_group_code ⇒ Object
This U.S.-only field is optionally used by PIN Debit Gateway Service participants (merchants and acquirers) to specify the network access priority.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv1pushfundstransferProcessingInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv1pushfundstransferProcessingInformation
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 89 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'businessApplicationId') self.business_application_id = attributes[:'businessApplicationId'] end if attributes.has_key?(:'payoutsOptions') self. = attributes[:'payoutsOptions'] end if attributes.has_key?(:'feeProgramId') self.fee_program_id = attributes[:'feeProgramId'] end if attributes.has_key?(:'networkPartnerId') self.network_partner_id = attributes[:'networkPartnerId'] end if attributes.has_key?(:'processingCode') self.processing_code = attributes[:'processingCode'] end if attributes.has_key?(:'sharingGroupCode') self.sharing_group_code = attributes[:'sharingGroupCode'] end if attributes.has_key?(:'purposeOfPayment') self.purpose_of_payment = attributes[:'purposeOfPayment'] end if attributes.has_key?(:'reconciliationId') self.reconciliation_id = attributes[:'reconciliationId'] end if attributes.has_key?(:'accountVerificationCode') if (value = attributes[:'accountVerificationCode']).is_a?(Array) self.account_verification_code = value end end end |
Instance Attribute Details
#account_verification_code ⇒ Object
Account verification code will inform what Payment Account Verification should be performed. With this array of codes, a merchant can choose à la carte what verifications to run. This field is optional, and the default is 1 if it is not passed in. This means that a full validation of the fields will be performed. Valid verification codes: - ‘1` = Full Account Verification (Card Account, CVN, CAVV, TAVV, Address, Name, eMail, Phone, Identity) - `2` = Card Account Verification - `3` = Address Verification - `4` = Card Authentication Method (CAM) (Cryptogram) - `5` = Cardholder Authentication Verification (CAVV) - `6` = Cardholder Identity Verification - `7` = CVV2 Verification - `8` = eMail Verification - `9` = Name Verification - `10` = Phone Verification
40 41 42 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 40 def account_verification_code @account_verification_code end |
#business_application_id ⇒ Object
Money Transfer (MT) - ‘AA`: Account to Account - `BI`: Bank-Initiated Money Transfer - `CD`: Cash Deposit - `FT`: Funds Transfer - `TU`: Prepaid Card Loan - `WT`: Wallet Transfer-Staged Digital Wallet (SDW) Transfer - `PP`: P2P Money Transfer Funds Disbursement (FD) - `BB`: Business-to-business Supplier Payments - `BP`: Non-Card Bill Pay - `CP`: Credit Card Bill Pay - `FD`: General Funds Disbursements - `GD`: Government Disbursements and Government Initiated Tax Refunds - `GP`: Gambling/Gaming Payouts (other than online gaming) - `LO`: Loyalty Payments - `MD`: Merchant Settlement - `MI`: Faster Refunds - `OG`: Online Gambling Payouts - `PD`: Payroll and Pension Disbursements - `RP`: Request-to-Pay Service
17 18 19 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 17 def business_application_id @business_application_id end |
#fee_program_id ⇒ Object
Fee Program Indicator. This field identifies the interchange fee program applicable to each financial transaction. Fee program indicator (FPI) values correspond to the fee descriptor and rate for each existing fee program.
22 23 24 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 22 def fee_program_id @fee_program_id end |
#network_partner_id ⇒ Object
Merchant payment gateway ID that is assigned by Mastercard and is provided by the acquirer when a registered merchant payment gateway service provider is involved in the transaction. This field is supported for Visa Platform Connect, Chase Paymentech Salem.
25 26 27 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 25 def network_partner_id @network_partner_id end |
#payouts_options ⇒ Object
Returns the value of attribute payouts_options.
19 20 21 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 19 def @payouts_options end |
#processing_code ⇒ Object
This field contains coding that identifies (1) the customer transaction type and (2) the customer account types affected by the transaction. Default: 5402 (Original Credit Transaction) Contains codes that combined with some other fields such as the BAI (Business Application Id) identify some unique use cases. For Sales Tax rebates this field should be populated with the value 5120 (Value-added tax/Sales Tax) along with the businessApplicationId field set to the value ‘FD’ which indicates this push funds transfer is being conducted in order to facilitate a sales tax refund.
28 29 30 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 28 def processing_code @processing_code end |
#purpose_of_payment ⇒ Object
This will send purpose of funds code for original credit transactions (OCTs).
34 35 36 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 34 def purpose_of_payment @purpose_of_payment end |
#reconciliation_id ⇒ Object
Transaction’s reference number.
37 38 39 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 37 def reconciliation_id @reconciliation_id end |
#sharing_group_code ⇒ Object
This U.S.-only field is optionally used by PIN Debit Gateway Service participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for a network specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on issuer preference. If an preference exists for multiple specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on acquirer routing priorities. Valid Values: ACCEL_EXCHANGE_E CU24_C INTERLINK_G MAESTRO_8 NYCE_Y NYCE_F PULSE_S PULSE_L PULSE_H STAR_N STAR_W STAR_Z STAR_Q STAR_M VISA_V
31 32 33 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 31 def sharing_group_code @sharing_group_code end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 43 def self.attribute_map { :'business_application_id' => :'businessApplicationId', :'payouts_options' => :'payoutsOptions', :'fee_program_id' => :'feeProgramId', :'network_partner_id' => :'networkPartnerId', :'processing_code' => :'processingCode', :'sharing_group_code' => :'sharingGroupCode', :'purpose_of_payment' => :'purposeOfPayment', :'reconciliation_id' => :'reconciliationId', :'account_verification_code' => :'accountVerificationCode' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 58 def self.json_map { :'business_application_id' => :'business_application_id', :'payouts_options' => :'payouts_options', :'fee_program_id' => :'fee_program_id', :'network_partner_id' => :'network_partner_id', :'processing_code' => :'processing_code', :'sharing_group_code' => :'sharing_group_code', :'purpose_of_payment' => :'purpose_of_payment', :'reconciliation_id' => :'reconciliation_id', :'account_verification_code' => :'account_verification_code' } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 73 def self.swagger_types { :'business_application_id' => :'String', :'payouts_options' => :'Ptsv1pushfundstransferProcessingInformationPayoutsOptions', :'fee_program_id' => :'String', :'network_partner_id' => :'String', :'processing_code' => :'String', :'sharing_group_code' => :'String', :'purpose_of_payment' => :'String', :'reconciliation_id' => :'String', :'account_verification_code' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 218 def ==(o) return true if self.equal?(o) self.class == o.class && business_application_id == o.business_application_id && == o. && fee_program_id == o.fee_program_id && network_partner_id == o.network_partner_id && processing_code == o.processing_code && sharing_group_code == o.sharing_group_code && purpose_of_payment == o.purpose_of_payment && reconciliation_id == o.reconciliation_id && account_verification_code == o.account_verification_code end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 268 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 334 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 247 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 240 def hash [business_application_id, , fee_program_id, network_partner_id, processing_code, sharing_group_code, purpose_of_payment, reconciliation_id, account_verification_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 136 def list_invalid_properties invalid_properties = Array.new #if !@business_application_id.nil? && @business_application_id !~ Regexp.new(/^(\\s{0,2}|.{2})$/) #invalid_properties.push('invalid value for "business_application_id", must conform to the pattern /^(\\s{0,2}|.{2})$/.') #end #if !@fee_program_id.nil? && @fee_program_id !~ Regexp.new(/^(\\s{0,3}|[a-zA-Z0-9]{3})$/) #invalid_properties.push('invalid value for "fee_program_id", must conform to the pattern /^(\\s{0,3}|[a-zA-Z0-9]{3})$/.') #end #if !@processing_code.nil? && @processing_code !~ Regexp.new(/^(\\s{0,4}|\\d{4})$/) #invalid_properties.push('invalid value for "processing_code", must conform to the pattern /^(\\s{0,4}|\\d{4})$/.') #end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
314 315 316 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 314 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
308 309 310 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 308 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 159 160 |
# File 'lib/cybersource_rest_client/models/ptsv1pushfundstransfer_processing_information.rb', line 155 def valid? #return false if !@business_application_id.nil? && @business_application_id !~ Regexp.new(/^(\\s{0,2}|.{2})$/) #return false if !@fee_program_id.nil? && @fee_program_id !~ Regexp.new(/^(\\s{0,3}|[a-zA-Z0-9]{3})$/) #return false if !@processing_code.nil? && @processing_code !~ Regexp.new(/^(\\s{0,4}|\\d{4})$/) true end |