Class: CyberSource::Ptsv2paymentsSenderInformation
- Inherits:
-
Object
- Object
- CyberSource::Ptsv2paymentsSenderInformation
- Defined in:
- lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
Returns the value of attribute account.
-
#address1 ⇒ Object
The street address of the sender.
-
#administrative_area ⇒ Object
The state or province of the sender.
-
#alias_name ⇒ Object
Sender’s alias name.
-
#country_code ⇒ Object
The country associated with the address of the sender.
-
#first_name ⇒ Object
First name of the sender.
-
#last_name ⇒ Object
Last name of the sender.
-
#locality ⇒ Object
The city or locality of the sender.
-
#middle_name ⇒ Object
Middle name of the sender.
-
#postal_code ⇒ Object
Postal code of sender.
-
#reference_number ⇒ Object
This field is applicable for AFT transactions.
-
#tax_id_number ⇒ Object
CPF or CNPJ of the cash-in recipient.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv2paymentsSenderInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv2paymentsSenderInformation
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 107 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'firstName') self.first_name = attributes[:'firstName'] end if attributes.has_key?(:'middleName') self.middle_name = attributes[:'middleName'] end if attributes.has_key?(:'lastName') self.last_name = attributes[:'lastName'] end if attributes.has_key?(:'address1') self.address1 = attributes[:'address1'] end if attributes.has_key?(:'locality') self.locality = attributes[:'locality'] end if attributes.has_key?(:'administrativeArea') self.administrative_area = attributes[:'administrativeArea'] end if attributes.has_key?(:'countryCode') self.country_code = attributes[:'countryCode'] end if attributes.has_key?(:'aliasName') self.alias_name = attributes[:'aliasName'] end if attributes.has_key?(:'referenceNumber') self.reference_number = attributes[:'referenceNumber'] end if attributes.has_key?(:'account') self.account = attributes[:'account'] end if attributes.has_key?(:'postalCode') self.postal_code = attributes[:'postalCode'] end if attributes.has_key?(:'taxIdNumber') self.tax_id_number = attributes[:'taxIdNumber'] end end |
Instance Attribute Details
#account ⇒ Object
Returns the value of attribute account.
43 44 45 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 43 def account @account end |
#address1 ⇒ Object
The street address of the sender. This field is applicable for AFT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set are not supported and will be stripped before being sent to sent to the processor.
26 27 28 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 26 def address1 @address1 end |
#administrative_area ⇒ Object
The state or province of the sender. This field is applicable for AFT transactions when the sender country is US or CA. Else it is optional. Must be a two character value
32 33 34 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 32 def administrative_area @administrative_area end |
#alias_name ⇒ Object
Sender’s alias name.
38 39 40 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 38 def alias_name @alias_name end |
#country_code ⇒ Object
The country associated with the address of the sender. This field is applicable for AFT transactions. Must be a two character ISO country code. For example, see [ISO Country Code](developer.cybersource.com/docs/cybs/en-us/country-codes/reference/all/na/country-codes/country-codes.html)
35 36 37 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 35 def country_code @country_code end |
#first_name ⇒ Object
First name of the sender. This field is applicable for AFT and OCT transactions. Only alpha numeric values are supported.Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to the processor.
17 18 19 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 17 def first_name @first_name end |
#last_name ⇒ Object
Last name of the sender. This field is applicable for AFT and OCT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to sent to the processor.
23 24 25 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 23 def last_name @last_name end |
#locality ⇒ Object
The city or locality of the sender. This field is applicable for AFT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set are not supported and will be stripped before being sent to sent to the processor.
29 30 31 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 29 def locality @locality end |
#middle_name ⇒ Object
Middle name of the sender. This field is applicable for AFT and OCT transactions. Only alpha numeric values are supported. Special characters not in the standard ASCII character set, are not supported and will be stripped before being sent to sent to the processor.
20 21 22 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 20 def middle_name @middle_name end |
#postal_code ⇒ Object
Postal code of sender.
46 47 48 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 46 def postal_code @postal_code end |
#reference_number ⇒ Object
This field is applicable for AFT transactions. Contains a transaction reference number provided by the Merchant. Only alpha numeric values are supported.
41 42 43 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 41 def reference_number @reference_number end |
#tax_id_number ⇒ Object
CPF or CNPJ of the cash-in recipient. "Cadastro de Pessoas Físicas", which translates to the "Natural Persons Register." It is the individual taxpayer registry identification number in Brazil, similar to a Social Security Number (SSN) in the United States or a National Insurance Number in the UK.
49 50 51 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 49 def tax_id_number @tax_id_number end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 52 def self.attribute_map { :'first_name' => :'firstName', :'middle_name' => :'middleName', :'last_name' => :'lastName', :'address1' => :'address1', :'locality' => :'locality', :'administrative_area' => :'administrativeArea', :'country_code' => :'countryCode', :'alias_name' => :'aliasName', :'reference_number' => :'referenceNumber', :'account' => :'account', :'postal_code' => :'postalCode', :'tax_id_number' => :'taxIdNumber' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 70 def self.json_map { :'first_name' => :'first_name', :'middle_name' => :'middle_name', :'last_name' => :'last_name', :'address1' => :'address1', :'locality' => :'locality', :'administrative_area' => :'administrative_area', :'country_code' => :'country_code', :'alias_name' => :'alias_name', :'reference_number' => :'reference_number', :'account' => :'account', :'postal_code' => :'postal_code', :'tax_id_number' => :'tax_id_number' } end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 88 def self.swagger_types { :'first_name' => :'String', :'middle_name' => :'String', :'last_name' => :'String', :'address1' => :'String', :'locality' => :'String', :'administrative_area' => :'String', :'country_code' => :'String', :'alias_name' => :'String', :'reference_number' => :'String', :'account' => :'Ptsv2paymentsSenderInformationAccount', :'postal_code' => :'String', :'tax_id_number' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 237 def ==(o) return true if self.equal?(o) self.class == o.class && first_name == o.first_name && middle_name == o.middle_name && last_name == o.last_name && address1 == o.address1 && locality == o.locality && administrative_area == o.administrative_area && country_code == o.country_code && alias_name == o.alias_name && reference_number == o.reference_number && account == o.account && postal_code == o.postal_code && tax_id_number == o.tax_id_number end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 290 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 356 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 269 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
256 257 258 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 256 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 262 def hash [first_name, middle_name, last_name, address1, locality, administrative_area, country_code, alias_name, reference_number, account, postal_code, tax_id_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 164 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
336 337 338 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 336 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
342 343 344 345 346 347 348 349 350 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 342 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
330 331 332 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 330 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_sender_information.rb', line 171 def valid? true end |