Class: CyberSource::Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation
- Inherits:
-
Object
- Object
- CyberSource::Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation
- Defined in:
- lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb
Instance Attribute Summary collapse
-
#connected_ticket_number ⇒ Object
Number for the airline ticket to which the ancillary purchase is connected.
-
#credit_reason_indicator ⇒ Object
Reason for the credit.
-
#fee_description ⇒ Object
This field contains the fee description for the airline ancillary service provided.
-
#passenger_name ⇒ Object
Name of the passenger.
-
#service ⇒ Object
Returns the value of attribute service.
-
#ticket_number ⇒ Object
Ticket number, which consists of the carrier code, form, and serial number, without the check digit.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'ticketNumber') self.ticket_number = attributes[:'ticketNumber'] end if attributes.has_key?(:'passengerName') self.passenger_name = attributes[:'passengerName'] end if attributes.has_key?(:'connectedTicketNumber') self.connected_ticket_number = attributes[:'connectedTicketNumber'] end if attributes.has_key?(:'creditReasonIndicator') self.credit_reason_indicator = attributes[:'creditReasonIndicator'] end if attributes.has_key?(:'service') if (value = attributes[:'service']).is_a?(Array) self.service = value end end if attributes.has_key?(:'feeDescription') self.fee_description = attributes[:'feeDescription'] end end |
Instance Attribute Details
#connected_ticket_number ⇒ Object
Number for the airline ticket to which the ancillary purchase is connected. If this purchase has a connection or relationship to another purchase such as a baggage fee for a passenger transport ticket, this field must contain the ticket number for the other purchase. For a stand-alone purchase, the value for this field must be the same as the value for the ‘travelInformation.transit.airline.ancillaryInformation.ticketNumber` field. Important This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional request field for ancillary services.
23 24 25 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 23 def connected_ticket_number @connected_ticket_number end |
#credit_reason_indicator ⇒ Object
Reason for the credit. Possible values: - ‘A`: Cancellation of the ancillary passenger transport purchase. - `B`: Cancellation of the airline ticket and the passenger transport ancillary purchase. - `C`: Cancellation of the airline ticket. - `O`: Other. - `P`: Partial refund of the airline ticket. Format: English characters only. Optional field for ancillary services.
26 27 28 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 26 def credit_reason_indicator @credit_reason_indicator end |
#fee_description ⇒ Object
This field contains the fee description for the airline ancillary service provided. Format: Alphanumeric, 100 characters maximum. Optional field for ancillary services.
31 32 33 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 31 def fee_description @fee_description end |
#passenger_name ⇒ Object
Name of the passenger. If the passenger’s name is not available, this value is the cardholder’s name. If neither the passenger’s name nor the cardholder’s name is available, this value is a description of the ancillary purchase. Important This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional field for ancillary service.
20 21 22 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 20 def passenger_name @passenger_name end |
#service ⇒ Object
Returns the value of attribute service.
28 29 30 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 28 def service @service end |
#ticket_number ⇒ Object
Ticket number, which consists of the carrier code, form, and serial number, without the check digit. Important This field is required in the U.S. in order for you to qualify for either the custom payment service (CPS) or the electronic interchange reimbursement fee (EIRF) program. Format: English characters only. Optional field for ancillary services.
17 18 19 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 17 def ticket_number @ticket_number end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 34 def self.attribute_map { :'ticket_number' => :'ticketNumber', :'passenger_name' => :'passengerName', :'connected_ticket_number' => :'connectedTicketNumber', :'credit_reason_indicator' => :'creditReasonIndicator', :'service' => :'service', :'fee_description' => :'feeDescription' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 46 def self.json_map { :'ticket_number' => :'ticket_number', :'passenger_name' => :'passenger_name', :'connected_ticket_number' => :'connected_ticket_number', :'credit_reason_indicator' => :'credit_reason_indicator', :'service' => :'service', :'fee_description' => :'fee_description' } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 58 def self.swagger_types { :'ticket_number' => :'String', :'passenger_name' => :'String', :'connected_ticket_number' => :'String', :'credit_reason_indicator' => :'String', :'service' => :'Array<Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformationService>', :'fee_description' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && ticket_number == o.ticket_number && passenger_name == o.passenger_name && connected_ticket_number == o.connected_ticket_number && credit_reason_indicator == o.credit_reason_indicator && service == o.service && fee_description == o.fee_description end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 196 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 262 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 175 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
162 163 164 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 162 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 168 def hash [ticket_number, passenger_name, connected_ticket_number, credit_reason_indicator, service, fee_description].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 106 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
242 243 244 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 242 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
248 249 250 251 252 253 254 255 256 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 248 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
236 237 238 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 236 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 |
# File 'lib/cybersource_rest_client/models/ptsv2payments_travel_information_transit_airline_ancillary_information.rb', line 113 def valid? true end |