Class: CyberSource::Ptsv2paymentsidcapturesOrderInformationShippingDetails
- Inherits:
-
Object
- Object
- CyberSource::Ptsv2paymentsidcapturesOrderInformationShippingDetails
- Defined in:
- lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb
Overview
Contains shipping details information for Klarna Advantage Plus Capture transactions.
Instance Attribute Summary collapse
-
#estimated_delivery_date ⇒ Object
Estimated delivery date for the shipment provided by Merchant.
-
#ship_from_postal_code ⇒ Object
Postal code for the address from which the goods are shipped, which is used to establish nexus.
-
#shipping_carrier ⇒ Object
Name of the shipping carrier/company handling the delivery.
-
#shipping_method ⇒ Object
Shipping method for the product.
-
#tracking_number ⇒ Object
Shipment tracking number provided by the merchant.
-
#tracking_url ⇒ Object
URL where the customer can track their shipment.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv2paymentsidcapturesOrderInformationShippingDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv2paymentsidcapturesOrderInformationShippingDetails
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'shipFromPostalCode') self.ship_from_postal_code = attributes[:'shipFromPostalCode'] end if attributes.has_key?(:'trackingNumber') self.tracking_number = attributes[:'trackingNumber'] end if attributes.has_key?(:'trackingUrl') self.tracking_url = attributes[:'trackingUrl'] end if attributes.has_key?(:'shippingCarrier') self.shipping_carrier = attributes[:'shippingCarrier'] end if attributes.has_key?(:'estimatedDeliveryDate') self.estimated_delivery_date = attributes[:'estimatedDeliveryDate'] end if attributes.has_key?(:'shippingMethod') self.shipping_method = attributes[:'shippingMethod'] end end |
Instance Attribute Details
#estimated_delivery_date ⇒ Object
Estimated delivery date for the shipment provided by Merchant. Format: YYYYMMDD (e.g., 20251115 for November 15, 2025)
30 31 32 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 30 def estimated_delivery_date @estimated_delivery_date end |
#ship_from_postal_code ⇒ Object
Postal code for the address from which the goods are shipped, which is used to establish nexus. The default is the postal code associated with your CyberSource account. The postal code must consist of 5 to 9 digits. When the billing country is the U.S., the 9-digit postal code must follow this format: ‘[5 digits][4 digits]` Example 12345-6789 When the billing country is Canada, the 6-digit postal code must follow this format: `[alpha][alpha] [numeric][numeric]` Example A1B 2C3 This field is frequently used for Level II and Level III transactions.
18 19 20 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 18 def ship_from_postal_code @ship_from_postal_code end |
#shipping_carrier ⇒ Object
Name of the shipping carrier/company handling the delivery.
27 28 29 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 27 def shipping_carrier @shipping_carrier end |
#shipping_method ⇒ Object
Shipping method for the product. Possible values: - ‘lowcost`: Lowest-cost service - `sameday`: Courier or same-day service - `oneday`: Next-day or overnight service - `twoday`: Two-day service - `threeday`: Three-day service - `pickup`: Store pick-up - `other`: Other shipping method - `none`: No shipping method because product is a service or subscription Klarna Advantage Plus additional values: - `TO_DOOR`: Delivery to door - `TO_CURB`: Delivery to curb - `TO_MAILBOX`: Delivery to mailbox - `PICKUP_BOX`: Pickup from box - `PICKUP_POINT`: Pickup from point - `PICKUP_STORE`: Pickup from store - `PICKUP_WAREHOUSE`: Pickup from warehouse - `DIGITAL_EMAIL`: Digital delivery via email - `DIGITAL_DOWNLOAD`: Digital download - `DIGITAL_OTHER`: Other digital delivery - `PHYSICAL_OTHER`: Other physical delivery
33 34 35 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 33 def shipping_method @shipping_method end |
#tracking_number ⇒ Object
Shipment tracking number provided by the merchant. Used to track the shipment of goods to the customer.
21 22 23 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 21 def tracking_number @tracking_number end |
#tracking_url ⇒ Object
URL where the customer can track their shipment. Provides real-time tracking information for the delivery.
24 25 26 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 24 def tracking_url @tracking_url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 36 def self.attribute_map { :'ship_from_postal_code' => :'shipFromPostalCode', :'tracking_number' => :'trackingNumber', :'tracking_url' => :'trackingUrl', :'shipping_carrier' => :'shippingCarrier', :'estimated_delivery_date' => :'estimatedDeliveryDate', :'shipping_method' => :'shippingMethod' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 48 def self.json_map { :'ship_from_postal_code' => :'ship_from_postal_code', :'tracking_number' => :'tracking_number', :'tracking_url' => :'tracking_url', :'shipping_carrier' => :'shipping_carrier', :'estimated_delivery_date' => :'estimated_delivery_date', :'shipping_method' => :'shipping_method' } end |
.swagger_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 60 def self.swagger_types { :'ship_from_postal_code' => :'String', :'tracking_number' => :'String', :'tracking_url' => :'String', :'shipping_carrier' => :'String', :'estimated_delivery_date' => :'String', :'shipping_method' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && ship_from_postal_code == o.ship_from_postal_code && tracking_number == o.tracking_number && tracking_url == o.tracking_url && shipping_carrier == o.shipping_carrier && estimated_delivery_date == o.estimated_delivery_date && shipping_method == o.shipping_method end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 211 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 277 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 190 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 183 def hash [ship_from_postal_code, tracking_number, tracking_url, shipping_carrier, estimated_delivery_date, shipping_method].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 111 112 113 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 106 def list_invalid_properties invalid_properties = Array.new #if !@estimated_delivery_date.nil? && @estimated_delivery_date !~ Regexp.new(/^[0-9]{8}$/) #invalid_properties.push('invalid value for "estimated_delivery_date", must conform to the pattern /^[0-9]{8}$/.') #end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
257 258 259 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 257 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
263 264 265 266 267 268 269 270 271 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 263 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
251 252 253 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 251 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 |
# File 'lib/cybersource_rest_client/models/ptsv2paymentsidcaptures_order_information_shipping_details.rb', line 117 def valid? #return false if !@estimated_delivery_date.nil? && @estimated_delivery_date !~ Regexp.new(/^[0-9]{8}$/) true end |