Class: CyberSource::Ptsv2payoutsProcessingInformation
- Inherits:
-
Object
- Object
- CyberSource::Ptsv2payoutsProcessingInformation
- Defined in:
- lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb
Instance Attribute Summary collapse
-
#account_verification_code ⇒ Object
Account verification code will inform what Payment Account Verification should be performed.
-
#business_application_id ⇒ Object
Payouts transaction type.
-
#commerce_indicator ⇒ Object
Type of transaction.
-
#funding_options ⇒ Object
Returns the value of attribute funding_options.
-
#language_code ⇒ Object
Contains the ISO 639-2 defined language Code.
-
#network_routing_order ⇒ Object
This field is optionally used by Push Payments Gateway participants (merchants and acquirers) to get the attributes for specified networks only.
-
#payouts_options ⇒ Object
Returns the value of attribute payouts_options.
-
#purchase_options ⇒ Object
Returns the value of attribute purchase_options.
-
#purpose_of_payment ⇒ Object
This field is applicable for AFT and OCT transactions.
-
#reconciliation_id ⇒ Object
Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request.
-
#transaction_reason ⇒ Object
Transaction reason code.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ptsv2payoutsProcessingInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ptsv2payoutsProcessingInformation
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'businessApplicationId') self.business_application_id = attributes[:'businessApplicationId'] end if attributes.has_key?(:'networkRoutingOrder') self.network_routing_order = attributes[:'networkRoutingOrder'] end if attributes.has_key?(:'commerceIndicator') self.commerce_indicator = attributes[:'commerceIndicator'] end if attributes.has_key?(:'reconciliationId') self.reconciliation_id = attributes[:'reconciliationId'] end if attributes.has_key?(:'payoutsOptions') self. = attributes[:'payoutsOptions'] end if attributes.has_key?(:'transactionReason') self.transaction_reason = attributes[:'transactionReason'] end if attributes.has_key?(:'purposeOfPayment') self.purpose_of_payment = attributes[:'purposeOfPayment'] end if attributes.has_key?(:'fundingOptions') self. = attributes[:'fundingOptions'] end if attributes.has_key?(:'languageCode') self.language_code = attributes[:'languageCode'] end if attributes.has_key?(:'purchaseOptions') self. = attributes[:'purchaseOptions'] end if attributes.has_key?(:'accountVerificationCode') if (value = attributes[:'accountVerificationCode']).is_a?(Array) self.account_verification_code = value end end end |
Instance Attribute Details
#account_verification_code ⇒ Object
Account verification code will inform what Payment Account Verification should be performed. With this array of codes, a merchant can choose à la carte what verifications to run. This field is optional, and the default is 1 if it is not passed in. This means that a full validation of the fields will be performed. Valid verification codes: - ‘1` = Full Account Verification (Card Account, CVN, CAVV, TAVV, Address, Name, eMail, Phone, Identity) - `2` = Card Account Verification - `3` = Address Verification - `4` = Card Authentication Method (CAM) (Cryptogram) - `5` = Cardholder Authentication Verification (CAVV) - `6` = Cardholder Identity Verification - `7` = CVV2 Verification - `8` = eMail Verification - `9` = Name Verification - `10` = Phone Verification
44 45 46 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 44 def account_verification_code @account_verification_code end |
#business_application_id ⇒ Object
Payouts transaction type. Applicable Processors: FDC Compass, Paymentech, CtV Possible values: **Credit Card Bill Payment** - CP: credit card bill payment **Funds Disbursement** - FD: funds disbursement - GD: government disbursement - MD: merchant disbursement **Money Transfer** - AA: account to account. Sender and receiver are same person. - PP: person to person. Sender and receiver are different. **Prepaid Load** - TU: top up
17 18 19 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 17 def business_application_id @business_application_id end |
#commerce_indicator ⇒ Object
Type of transaction. Value for an OCT transaction: - ‘internet`
23 24 25 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 23 def commerce_indicator @commerce_indicator end |
#funding_options ⇒ Object
Returns the value of attribute funding_options.
36 37 38 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 36 def @funding_options end |
#language_code ⇒ Object
Contains the ISO 639-2 defined language Code
39 40 41 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 39 def language_code @language_code end |
#network_routing_order ⇒ Object
This field is optionally used by Push Payments Gateway participants (merchants and acquirers) to get the attributes for specified networks only. The networks specified in this field must be a subset of the information provided during program enrollment. Refer to Sharing Group Code/Network Routing Order. Note: Supported only in US for domestic transactions involving Push Payments Gateway Service. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the network routing order. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.
20 21 22 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 20 def network_routing_order @network_routing_order end |
#payouts_options ⇒ Object
Returns the value of attribute payouts_options.
28 29 30 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 28 def @payouts_options end |
#purchase_options ⇒ Object
Returns the value of attribute purchase_options.
41 42 43 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 41 def @purchase_options end |
#purpose_of_payment ⇒ Object
This field is applicable for AFT and OCT transactions. For list of supported values, please refer to Developer Guide.
34 35 36 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 34 def purpose_of_payment @purpose_of_payment end |
#reconciliation_id ⇒ Object
Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22).
26 27 28 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 26 def reconciliation_id @reconciliation_id end |
#transaction_reason ⇒ Object
Transaction reason code.
31 32 33 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 31 def transaction_reason @transaction_reason end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 47 def self.attribute_map { :'business_application_id' => :'businessApplicationId', :'network_routing_order' => :'networkRoutingOrder', :'commerce_indicator' => :'commerceIndicator', :'reconciliation_id' => :'reconciliationId', :'payouts_options' => :'payoutsOptions', :'transaction_reason' => :'transactionReason', :'purpose_of_payment' => :'purposeOfPayment', :'funding_options' => :'fundingOptions', :'language_code' => :'languageCode', :'purchase_options' => :'purchaseOptions', :'account_verification_code' => :'accountVerificationCode' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 64 def self.json_map { :'business_application_id' => :'business_application_id', :'network_routing_order' => :'network_routing_order', :'commerce_indicator' => :'commerce_indicator', :'reconciliation_id' => :'reconciliation_id', :'payouts_options' => :'payouts_options', :'transaction_reason' => :'transaction_reason', :'purpose_of_payment' => :'purpose_of_payment', :'funding_options' => :'funding_options', :'language_code' => :'language_code', :'purchase_options' => :'purchase_options', :'account_verification_code' => :'account_verification_code' } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 81 def self.swagger_types { :'business_application_id' => :'String', :'network_routing_order' => :'String', :'commerce_indicator' => :'String', :'reconciliation_id' => :'String', :'payouts_options' => :'Ptsv2payoutsProcessingInformationPayoutsOptions', :'transaction_reason' => :'String', :'purpose_of_payment' => :'String', :'funding_options' => :'Ptsv2payoutsProcessingInformationFundingOptions', :'language_code' => :'String', :'purchase_options' => :'Ptsv2payoutsProcessingInformationPurchaseOptions', :'account_verification_code' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 209 def ==(o) return true if self.equal?(o) self.class == o.class && business_application_id == o.business_application_id && network_routing_order == o.network_routing_order && commerce_indicator == o.commerce_indicator && reconciliation_id == o.reconciliation_id && == o. && transaction_reason == o.transaction_reason && purpose_of_payment == o.purpose_of_payment && == o. && language_code == o.language_code && == o. && account_verification_code == o.account_verification_code end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 261 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 327 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 240 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 233 def hash [business_application_id, network_routing_order, commerce_indicator, reconciliation_id, , transaction_reason, purpose_of_payment, , language_code, , account_verification_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 154 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
307 308 309 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 307 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
301 302 303 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 301 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 |
# File 'lib/cybersource_rest_client/models/ptsv2payouts_processing_information.rb', line 161 def valid? true end |