Class: CyberSource::PullFundsApi
- Inherits:
-
Object
- Object
- CyberSource::PullFundsApi
- Defined in:
- lib/cybersource_rest_client/api/pull_funds_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_pull_funds_refund(pull_funds_refund_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ PullFundsRefund201Response
Process a Pull Funds Refund Refund an Account Funding Transaction (AFT).
-
#create_pull_funds_refund_with_http_info(pull_funds_refund_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ Array<(PullFundsRefund201Response, Fixnum, Hash)>
Process a Pull Funds Refund Refund an Account Funding Transaction (AFT).
-
#create_pull_funds_reversal(pull_funds_reversal_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ PullFundsReversal201Response
Process a Pull Funds Reversal Reverse an Account Funding Transaction (AFT).
-
#create_pull_funds_reversal_with_http_info(pull_funds_reversal_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ Array<(PullFundsReversal201Response, Fixnum, Hash)>
Process a Pull Funds Reversal Reverse an Account Funding Transaction (AFT).
-
#create_pull_funds_transfer(pull_funds_request, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ PullFunds201Response
Process a Pull Funds Transfer Receive funds using an Account Funding Transaction (AFT).
-
#create_pull_funds_transfer_with_http_info(pull_funds_request, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ Array<(PullFunds201Response, Fixnum, Hash)>
Process a Pull Funds Transfer Receive funds using an Account Funding Transaction (AFT).
-
#initialize(api_client = ApiClient.default, config) ⇒ PullFundsApi
constructor
A new instance of PullFundsApi.
Constructor Details
#initialize(api_client = ApiClient.default, config) ⇒ PullFundsApi
Returns a new instance of PullFundsApi.
18 19 20 21 |
# File 'lib/cybersource_rest_client/api/pull_funds_api.rb', line 18 def initialize(api_client = ApiClient.default, config) @api_client = api_client @api_client.set_configuration(config) end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
16 17 18 |
# File 'lib/cybersource_rest_client/api/pull_funds_api.rb', line 16 def api_client @api_client end |
Instance Method Details
#create_pull_funds_refund(pull_funds_refund_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ PullFundsRefund201Response
Process a Pull Funds Refund Refund an Account Funding Transaction (AFT).
36 37 38 39 |
# File 'lib/cybersource_rest_client/api/pull_funds_api.rb', line 36 def create_pull_funds_refund(pull_funds_refund_request, id, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts = {}) data, status_code, headers = create_pull_funds_refund_with_http_info(pull_funds_refund_request, id, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts) return data, status_code, headers end |
#create_pull_funds_refund_with_http_info(pull_funds_refund_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ Array<(PullFundsRefund201Response, Fixnum, Hash)>
Process a Pull Funds Refund Refund an Account Funding Transaction (AFT).
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/cybersource_rest_client/api/pull_funds_api.rb', line 53 def create_pull_funds_refund_with_http_info(pull_funds_refund_request, id, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts = {}) if @api_client.config.debugging begin raise @api_client.config.logger.debug 'Calling API: PullFundsApi.create_pull_funds_refund ...' rescue puts 'Cannot write to log' end end # verify the required parameter 'pull_funds_refund_request' is set if @api_client.config.client_side_validation && pull_funds_refund_request.nil? fail ArgumentError, "Missing the required parameter 'pull_funds_refund_request' when calling PullFundsApi.create_pull_funds_refund" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling PullFundsApi.create_pull_funds_refund" end # verify the required parameter 'content_type' is set if @api_client.config.client_side_validation && content_type.nil? fail ArgumentError, "Missing the required parameter 'content_type' when calling PullFundsApi.create_pull_funds_refund" end # verify the required parameter 'x_requestid' is set if @api_client.config.client_side_validation && x_requestid.nil? fail ArgumentError, "Missing the required parameter 'x_requestid' when calling PullFundsApi.create_pull_funds_refund" end # verify the required parameter 'v_c_merchant_id' is set if @api_client.config.client_side_validation && v_c_merchant_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_merchant_id' when calling PullFundsApi.create_pull_funds_refund" end # verify the required parameter 'v_c_permissions' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'v_c_permissions' when calling PullFundsApi.create_pull_funds_refund" end # verify the required parameter 'v_c_correlation_id' is set if @api_client.config.client_side_validation && v_c_correlation_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_correlation_id' when calling PullFundsApi.create_pull_funds_refund" end # verify the required parameter 'v_c_organization_id' is set if @api_client.config.client_side_validation && v_c_organization_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_organization_id' when calling PullFundsApi.create_pull_funds_refund" end # resource path local_var_path = 'pts/v1/pull-funds-transfer/{id}/refund'.sub('{' + 'id' + '}', id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/hal+json;charset=utf-8']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8']) header_params[:'Content-Type'] = content_type header_params[:'x-requestid'] = x_requestid header_params[:'v-c-merchant-id'] = v_c_merchant_id header_params[:'v-c-permissions'] = header_params[:'v-c-correlation-id'] = v_c_correlation_id header_params[:'v-c-organization-id'] = v_c_organization_id # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(pull_funds_refund_request) sdk_tracker = SdkTracker.new post_body = sdk_tracker.insert_developer_id_tracker(post_body, 'PullFundsRefundRequest', @api_client.config.host, @api_client.merchantconfig.defaultDeveloperId) inbound_mle_status = "false" if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["create_pull_funds_refund","create_pull_funds_refund_with_http_info"]) begin post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body) rescue raise end end is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["create_pull_funds_refund","create_pull_funds_refund_with_http_info"]) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PullFundsRefund201Response', :isResponseMLEForApi => is_response_mle_for_api) if @api_client.config.debugging begin raise @api_client.config.logger.debug "API called: PullFundsApi#create_pull_funds_refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" rescue puts 'Cannot write to log' end end return data, status_code, headers end |
#create_pull_funds_reversal(pull_funds_reversal_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ PullFundsReversal201Response
Process a Pull Funds Reversal Reverse an Account Funding Transaction (AFT).
165 166 167 168 |
# File 'lib/cybersource_rest_client/api/pull_funds_api.rb', line 165 def create_pull_funds_reversal(pull_funds_reversal_request, id, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts = {}) data, status_code, headers = create_pull_funds_reversal_with_http_info(pull_funds_reversal_request, id, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts) return data, status_code, headers end |
#create_pull_funds_reversal_with_http_info(pull_funds_reversal_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ Array<(PullFundsReversal201Response, Fixnum, Hash)>
Process a Pull Funds Reversal Reverse an Account Funding Transaction (AFT).
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/cybersource_rest_client/api/pull_funds_api.rb', line 182 def create_pull_funds_reversal_with_http_info(pull_funds_reversal_request, id, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts = {}) if @api_client.config.debugging begin raise @api_client.config.logger.debug 'Calling API: PullFundsApi.create_pull_funds_reversal ...' rescue puts 'Cannot write to log' end end # verify the required parameter 'pull_funds_reversal_request' is set if @api_client.config.client_side_validation && pull_funds_reversal_request.nil? fail ArgumentError, "Missing the required parameter 'pull_funds_reversal_request' when calling PullFundsApi.create_pull_funds_reversal" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling PullFundsApi.create_pull_funds_reversal" end # verify the required parameter 'content_type' is set if @api_client.config.client_side_validation && content_type.nil? fail ArgumentError, "Missing the required parameter 'content_type' when calling PullFundsApi.create_pull_funds_reversal" end # verify the required parameter 'x_requestid' is set if @api_client.config.client_side_validation && x_requestid.nil? fail ArgumentError, "Missing the required parameter 'x_requestid' when calling PullFundsApi.create_pull_funds_reversal" end # verify the required parameter 'v_c_merchant_id' is set if @api_client.config.client_side_validation && v_c_merchant_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_merchant_id' when calling PullFundsApi.create_pull_funds_reversal" end # verify the required parameter 'v_c_permissions' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'v_c_permissions' when calling PullFundsApi.create_pull_funds_reversal" end # verify the required parameter 'v_c_correlation_id' is set if @api_client.config.client_side_validation && v_c_correlation_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_correlation_id' when calling PullFundsApi.create_pull_funds_reversal" end # verify the required parameter 'v_c_organization_id' is set if @api_client.config.client_side_validation && v_c_organization_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_organization_id' when calling PullFundsApi.create_pull_funds_reversal" end # resource path local_var_path = 'pts/v1/pull-funds-transfer/{id}/reversal'.sub('{' + 'id' + '}', id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/hal+json;charset=utf-8']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8']) header_params[:'Content-Type'] = content_type header_params[:'x-requestid'] = x_requestid header_params[:'v-c-merchant-id'] = v_c_merchant_id header_params[:'v-c-permissions'] = header_params[:'v-c-correlation-id'] = v_c_correlation_id header_params[:'v-c-organization-id'] = v_c_organization_id # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(pull_funds_reversal_request) sdk_tracker = SdkTracker.new post_body = sdk_tracker.insert_developer_id_tracker(post_body, 'PullFundsReversalRequest', @api_client.config.host, @api_client.merchantconfig.defaultDeveloperId) inbound_mle_status = "false" if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["create_pull_funds_reversal","create_pull_funds_reversal_with_http_info"]) begin post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body) rescue raise end end is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["create_pull_funds_reversal","create_pull_funds_reversal_with_http_info"]) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PullFundsReversal201Response', :isResponseMLEForApi => is_response_mle_for_api) if @api_client.config.debugging begin raise @api_client.config.logger.debug "API called: PullFundsApi#create_pull_funds_reversal\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" rescue puts 'Cannot write to log' end end return data, status_code, headers end |
#create_pull_funds_transfer(pull_funds_request, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ PullFunds201Response
Process a Pull Funds Transfer Receive funds using an Account Funding Transaction (AFT).
293 294 295 296 |
# File 'lib/cybersource_rest_client/api/pull_funds_api.rb', line 293 def create_pull_funds_transfer(pull_funds_request, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts = {}) data, status_code, headers = create_pull_funds_transfer_with_http_info(pull_funds_request, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts) return data, status_code, headers end |
#create_pull_funds_transfer_with_http_info(pull_funds_request, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id, opts = {}) ⇒ Array<(PullFunds201Response, Fixnum, Hash)>
Process a Pull Funds Transfer Receive funds using an Account Funding Transaction (AFT).
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/cybersource_rest_client/api/pull_funds_api.rb', line 309 def create_pull_funds_transfer_with_http_info(pull_funds_request, content_type, x_requestid, v_c_merchant_id, , v_c_correlation_id, v_c_organization_id, opts = {}) if @api_client.config.debugging begin raise @api_client.config.logger.debug 'Calling API: PullFundsApi.create_pull_funds_transfer ...' rescue puts 'Cannot write to log' end end # verify the required parameter 'pull_funds_request' is set if @api_client.config.client_side_validation && pull_funds_request.nil? fail ArgumentError, "Missing the required parameter 'pull_funds_request' when calling PullFundsApi.create_pull_funds_transfer" end # verify the required parameter 'content_type' is set if @api_client.config.client_side_validation && content_type.nil? fail ArgumentError, "Missing the required parameter 'content_type' when calling PullFundsApi.create_pull_funds_transfer" end # verify the required parameter 'x_requestid' is set if @api_client.config.client_side_validation && x_requestid.nil? fail ArgumentError, "Missing the required parameter 'x_requestid' when calling PullFundsApi.create_pull_funds_transfer" end # verify the required parameter 'v_c_merchant_id' is set if @api_client.config.client_side_validation && v_c_merchant_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_merchant_id' when calling PullFundsApi.create_pull_funds_transfer" end # verify the required parameter 'v_c_permissions' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'v_c_permissions' when calling PullFundsApi.create_pull_funds_transfer" end # verify the required parameter 'v_c_correlation_id' is set if @api_client.config.client_side_validation && v_c_correlation_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_correlation_id' when calling PullFundsApi.create_pull_funds_transfer" end # verify the required parameter 'v_c_organization_id' is set if @api_client.config.client_side_validation && v_c_organization_id.nil? fail ArgumentError, "Missing the required parameter 'v_c_organization_id' when calling PullFundsApi.create_pull_funds_transfer" end # resource path local_var_path = 'pts/v1/pull-funds-transfer' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/hal+json;charset=utf-8']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8']) header_params[:'Content-Type'] = content_type header_params[:'x-requestid'] = x_requestid header_params[:'v-c-merchant-id'] = v_c_merchant_id header_params[:'v-c-permissions'] = header_params[:'v-c-correlation-id'] = v_c_correlation_id header_params[:'v-c-organization-id'] = v_c_organization_id # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(pull_funds_request) sdk_tracker = SdkTracker.new post_body = sdk_tracker.insert_developer_id_tracker(post_body, 'PullFundsRequest', @api_client.config.host, @api_client.merchantconfig.defaultDeveloperId) inbound_mle_status = "false" if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["create_pull_funds_transfer","create_pull_funds_transfer_with_http_info"]) begin post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body) rescue raise end end is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["create_pull_funds_transfer","create_pull_funds_transfer_with_http_info"]) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PullFunds201Response', :isResponseMLEForApi => is_response_mle_for_api) if @api_client.config.debugging begin raise @api_client.config.logger.debug "API called: PullFundsApi#create_pull_funds_transfer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" rescue puts 'Cannot write to log' end end return data, status_code, headers end |