Class: CyberSource::PushFunds201Response
- Inherits:
-
Object
- Object
- CyberSource::PushFunds201Response
- Defined in:
- lib/cybersource_rest_client/models/push_funds201_response.rb
Instance Attribute Summary collapse
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#client_reference_information ⇒ Object
Returns the value of attribute client_reference_information.
-
#error_information ⇒ Object
Returns the value of attribute error_information.
-
#id ⇒ Object
A unique identification number to identify the submitted request.
-
#issuer_information ⇒ Object
Returns the value of attribute issuer_information.
-
#merchant_information ⇒ Object
Returns the value of attribute merchant_information.
-
#order_information ⇒ Object
Returns the value of attribute order_information.
-
#payment_information ⇒ Object
Returns the value of attribute payment_information.
-
#processing_information ⇒ Object
Returns the value of attribute processing_information.
-
#processor_information ⇒ Object
Returns the value of attribute processor_information.
-
#recipient_information ⇒ Object
Returns the value of attribute recipient_information.
-
#reconciliation_id ⇒ Object
Cybersource or merchant generated transaction reference number.
-
#status ⇒ Object
The status of the submitted transaction.
-
#submit_time_utc ⇒ Object
Time of request in UTC.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PushFunds201Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PushFunds201Response
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 110 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'submitTimeUtc') self.submit_time_utc = attributes[:'submitTimeUtc'] end if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'reconciliationId') self.reconciliation_id = attributes[:'reconciliationId'] end if attributes.has_key?(:'clientReferenceInformation') self.client_reference_information = attributes[:'clientReferenceInformation'] end if attributes.has_key?(:'recipientInformation') self.recipient_information = attributes[:'recipientInformation'] end if attributes.has_key?(:'merchantInformation') self.merchant_information = attributes[:'merchantInformation'] end if attributes.has_key?(:'errorInformation') self.error_information = attributes[:'errorInformation'] end if attributes.has_key?(:'processorInformation') self.processor_information = attributes[:'processorInformation'] end if attributes.has_key?(:'orderInformation') self.order_information = attributes[:'orderInformation'] end if attributes.has_key?(:'paymentInformation') self.payment_information = attributes[:'paymentInformation'] end if attributes.has_key?(:'processingInformation') self.processing_information = attributes[:'processingInformation'] end if attributes.has_key?(:'issuerInformation') self.issuer_information = attributes[:'issuerInformation'] end if attributes.has_key?(:'_links') self._links = attributes[:'_links'] end end |
Instance Attribute Details
#_links ⇒ Object
Returns the value of attribute _links.
46 47 48 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 46 def _links @_links end |
#client_reference_information ⇒ Object
Returns the value of attribute client_reference_information.
28 29 30 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 28 def client_reference_information @client_reference_information end |
#error_information ⇒ Object
Returns the value of attribute error_information.
34 35 36 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 34 def error_information @error_information end |
#id ⇒ Object
A unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.
17 18 19 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 17 def id @id end |
#issuer_information ⇒ Object
Returns the value of attribute issuer_information.
44 45 46 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 44 def issuer_information @issuer_information end |
#merchant_information ⇒ Object
Returns the value of attribute merchant_information.
32 33 34 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 32 def merchant_information @merchant_information end |
#order_information ⇒ Object
Returns the value of attribute order_information.
38 39 40 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 38 def order_information @order_information end |
#payment_information ⇒ Object
Returns the value of attribute payment_information.
40 41 42 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 40 def payment_information @payment_information end |
#processing_information ⇒ Object
Returns the value of attribute processing_information.
42 43 44 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 42 def processing_information @processing_information end |
#processor_information ⇒ Object
Returns the value of attribute processor_information.
36 37 38 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 36 def processor_information @processor_information end |
#recipient_information ⇒ Object
Returns the value of attribute recipient_information.
30 31 32 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 30 def recipient_information @recipient_information end |
#reconciliation_id ⇒ Object
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
26 27 28 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 26 def reconciliation_id @reconciliation_id end |
#status ⇒ Object
The status of the submitted transaction. Possible values: - AUTHORIZED - DECLINED - SERVER_ERROR - INVALID_REQUEST - PARTIAL_AUTHORIZED
23 24 25 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 23 def status @status end |
#submit_time_utc ⇒ Object
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC.
20 21 22 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 20 def submit_time_utc @submit_time_utc end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 49 def self.attribute_map { :'id' => :'id', :'submit_time_utc' => :'submitTimeUtc', :'status' => :'status', :'reconciliation_id' => :'reconciliationId', :'client_reference_information' => :'clientReferenceInformation', :'recipient_information' => :'recipientInformation', :'merchant_information' => :'merchantInformation', :'error_information' => :'errorInformation', :'processor_information' => :'processorInformation', :'order_information' => :'orderInformation', :'payment_information' => :'paymentInformation', :'processing_information' => :'processingInformation', :'issuer_information' => :'issuerInformation', :'_links' => :'_links' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 69 def self.json_map { :'id' => :'id', :'submit_time_utc' => :'submit_time_utc', :'status' => :'status', :'reconciliation_id' => :'reconciliation_id', :'client_reference_information' => :'client_reference_information', :'recipient_information' => :'recipient_information', :'merchant_information' => :'merchant_information', :'error_information' => :'error_information', :'processor_information' => :'processor_information', :'order_information' => :'order_information', :'payment_information' => :'payment_information', :'processing_information' => :'processing_information', :'issuer_information' => :'issuer_information', :'_links' => :'_links' } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 89 def self.swagger_types { :'id' => :'String', :'submit_time_utc' => :'String', :'status' => :'String', :'reconciliation_id' => :'String', :'client_reference_information' => :'PushFunds201ResponseClientReferenceInformation', :'recipient_information' => :'PushFunds201ResponseRecipientInformation', :'merchant_information' => :'PushFunds201ResponseMerchantInformation', :'error_information' => :'PushFunds201ResponseErrorInformation', :'processor_information' => :'PushFunds201ResponseProcessorInformation', :'order_information' => :'PushFunds201ResponseOrderInformation', :'payment_information' => :'PushFunds201ResponsePaymentInformation', :'processing_information' => :'PushFunds201ResponseProcessingInformation', :'issuer_information' => :'PushFunds201ResponseIssuerInformation', :'_links' => :'PushFunds201ResponseLinks' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && submit_time_utc == o.submit_time_utc && status == o.status && reconciliation_id == o.reconciliation_id && client_reference_information == o.client_reference_information && recipient_information == o.recipient_information && merchant_information == o.merchant_information && error_information == o.error_information && processor_information == o.processor_information && order_information == o.order_information && payment_information == o.payment_information && processing_information == o.processing_information && issuer_information == o.issuer_information && _links == o._links end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 267 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 333 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 246 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 239 def hash [id, submit_time_utc, status, reconciliation_id, client_reference_information, recipient_information, merchant_information, error_information, processor_information, order_information, payment_information, processing_information, issuer_information, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 175 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
313 314 315 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 313 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
319 320 321 322 323 324 325 326 327 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 319 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
307 308 309 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 307 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
182 183 184 |
# File 'lib/cybersource_rest_client/models/push_funds201_response.rb', line 182 def valid? true end |