Class: CyberSource::PushFunds201ResponseProcessorInformation
- Inherits:
-
Object
- Object
- CyberSource::PushFunds201ResponseProcessorInformation
- Defined in:
- lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb
Instance Attribute Summary collapse
-
#action_code ⇒ Object
The results of the transaction request Note: The VisaNet Response Code for the transaction.
-
#approval_code ⇒ Object
Issuer-generated approval code for the transaction.
-
#avs ⇒ Object
Returns the value of attribute avs.
-
#card_verification ⇒ Object
Returns the value of attribute card_verification.
-
#customer ⇒ Object
Returns the value of attribute customer.
-
#electronic_verification_results ⇒ Object
Returns the value of attribute electronic_verification_results.
-
#fee_program_indicator ⇒ Object
This field identifies the interchange fee program applicable to each financial transaction.
-
#merchant_advice ⇒ Object
Returns the value of attribute merchant_advice.
-
#name ⇒ Object
Name of the processor.
-
#response_code ⇒ Object
Transaction status from the processor.
-
#retrieval_reference_number ⇒ Object
This field contains a number that is used with other data elements as a key to identify and track all messages related to a given cardholder transaction; that is, to a given transaction set.
-
#routing ⇒ Object
Returns the value of attribute routing.
-
#settlement ⇒ Object
Returns the value of attribute settlement.
-
#system_trace_audit_number ⇒ Object
This field is returned by authorization and incremental authorization services.
-
#transaction_id ⇒ Object
Network transaction identifier (TID).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PushFunds201ResponseProcessorInformation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PushFunds201ResponseProcessorInformation
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 119 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'transactionId') self.transaction_id = attributes[:'transactionId'] end if attributes.has_key?(:'responseCode') self.response_code = attributes[:'responseCode'] end if attributes.has_key?(:'systemTraceAuditNumber') self.system_trace_audit_number = attributes[:'systemTraceAuditNumber'] end if attributes.has_key?(:'retrievalReferenceNumber') self.retrieval_reference_number = attributes[:'retrievalReferenceNumber'] end if attributes.has_key?(:'actionCode') self.action_code = attributes[:'actionCode'] end if attributes.has_key?(:'approvalCode') self.approval_code = attributes[:'approvalCode'] end if attributes.has_key?(:'feeProgramIndicator') self.fee_program_indicator = attributes[:'feeProgramIndicator'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'routing') self.routing = attributes[:'routing'] end if attributes.has_key?(:'settlement') self.settlement = attributes[:'settlement'] end if attributes.has_key?(:'merchantAdvice') self.merchant_advice = attributes[:'merchantAdvice'] end if attributes.has_key?(:'avs') self.avs = attributes[:'avs'] end if attributes.has_key?(:'customer') self.customer = attributes[:'customer'] end if attributes.has_key?(:'electronicVerificationResults') self.electronic_verification_results = attributes[:'electronicVerificationResults'] end if attributes.has_key?(:'cardVerification') self.card_verification = attributes[:'cardVerification'] end end |
Instance Attribute Details
#action_code ⇒ Object
The results of the transaction request Note: The VisaNet Response Code for the transaction
29 30 31 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 29 def action_code @action_code end |
#approval_code ⇒ Object
Issuer-generated approval code for the transaction.
32 33 34 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 32 def approval_code @approval_code end |
#avs ⇒ Object
Returns the value of attribute avs.
46 47 48 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 46 def avs @avs end |
#card_verification ⇒ Object
Returns the value of attribute card_verification.
52 53 54 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 52 def card_verification @card_verification end |
#customer ⇒ Object
Returns the value of attribute customer.
48 49 50 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 48 def customer @customer end |
#electronic_verification_results ⇒ Object
Returns the value of attribute electronic_verification_results.
50 51 52 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 50 def electronic_verification_results @electronic_verification_results end |
#fee_program_indicator ⇒ Object
This field identifies the interchange fee program applicable to each financial transaction. Fee program indicator (FPI) values correspond to the fee descriptor and rate for each existing fee program.
35 36 37 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 35 def fee_program_indicator @fee_program_indicator end |
#merchant_advice ⇒ Object
Returns the value of attribute merchant_advice.
44 45 46 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 44 def merchant_advice @merchant_advice end |
#name ⇒ Object
Name of the processor.
38 39 40 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 38 def name @name end |
#response_code ⇒ Object
Transaction status from the processor.
20 21 22 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 20 def response_code @response_code end |
#retrieval_reference_number ⇒ Object
This field contains a number that is used with other data elements as a key to identify and track all messages related to a given cardholder transaction; that is, to a given transaction set. Recommended format: ydddhhnnnnnn Positions 1-4: The yddd equivalent of the date, where y = 0-9 and ddd = 001 – 366. Positions 5-12: A unique identification number generated by the merchant or assigned by Cybersource.
26 27 28 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 26 def retrieval_reference_number @retrieval_reference_number end |
#routing ⇒ Object
Returns the value of attribute routing.
40 41 42 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 40 def routing @routing end |
#settlement ⇒ Object
Returns the value of attribute settlement.
42 43 44 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 42 def settlement @settlement end |
#system_trace_audit_number ⇒ Object
This field is returned by authorization and incremental authorization services. System trace number that must be printed on the customer’s receipt.
23 24 25 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 23 def system_trace_audit_number @system_trace_audit_number end |
#transaction_id ⇒ Object
Network transaction identifier (TID). This value can be used to identify a specific transaction when you are discussing the transaction with your processor.
17 18 19 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 17 def transaction_id @transaction_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 55 def self.attribute_map { :'transaction_id' => :'transactionId', :'response_code' => :'responseCode', :'system_trace_audit_number' => :'systemTraceAuditNumber', :'retrieval_reference_number' => :'retrievalReferenceNumber', :'action_code' => :'actionCode', :'approval_code' => :'approvalCode', :'fee_program_indicator' => :'feeProgramIndicator', :'name' => :'name', :'routing' => :'routing', :'settlement' => :'settlement', :'merchant_advice' => :'merchantAdvice', :'avs' => :'avs', :'customer' => :'customer', :'electronic_verification_results' => :'electronicVerificationResults', :'card_verification' => :'cardVerification' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 76 def self.json_map { :'transaction_id' => :'transaction_id', :'response_code' => :'response_code', :'system_trace_audit_number' => :'system_trace_audit_number', :'retrieval_reference_number' => :'retrieval_reference_number', :'action_code' => :'action_code', :'approval_code' => :'approval_code', :'fee_program_indicator' => :'fee_program_indicator', :'name' => :'name', :'routing' => :'routing', :'settlement' => :'settlement', :'merchant_advice' => :'merchant_advice', :'avs' => :'avs', :'customer' => :'customer', :'electronic_verification_results' => :'electronic_verification_results', :'card_verification' => :'card_verification' } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 97 def self.swagger_types { :'transaction_id' => :'Integer', :'response_code' => :'String', :'system_trace_audit_number' => :'String', :'retrieval_reference_number' => :'String', :'action_code' => :'String', :'approval_code' => :'String', :'fee_program_indicator' => :'String', :'name' => :'String', :'routing' => :'PushFunds201ResponseProcessorInformationRouting', :'settlement' => :'PushFunds201ResponseProcessorInformationSettlement', :'merchant_advice' => :'PushFunds201ResponseProcessorInformationMerchantAdvice', :'avs' => :'PtsV2PayoutsPost201ResponseProcessorInformationAvs', :'customer' => :'PtsV2PayoutsPost201ResponseProcessorInformationCustomer', :'electronic_verification_results' => :'PtsV2PayoutsPost201ResponseProcessorInformationElectronicVerificationResults', :'card_verification' => :'PtsV2PaymentsPost201ResponseProcessorInformationCardVerification' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 243 def ==(o) return true if self.equal?(o) self.class == o.class && transaction_id == o.transaction_id && response_code == o.response_code && system_trace_audit_number == o.system_trace_audit_number && retrieval_reference_number == o.retrieval_reference_number && action_code == o.action_code && approval_code == o.approval_code && fee_program_indicator == o.fee_program_indicator && name == o.name && routing == o.routing && settlement == o.settlement && merchant_advice == o.merchant_advice && avs == o.avs && customer == o.customer && electronic_verification_results == o.electronic_verification_results && card_verification == o.card_verification end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 299 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 365 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 278 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
265 266 267 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 265 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
271 272 273 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 271 def hash [transaction_id, response_code, system_trace_audit_number, retrieval_reference_number, action_code, approval_code, fee_program_indicator, name, routing, settlement, merchant_advice, avs, customer, electronic_verification_results, card_verification].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 188 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
345 346 347 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 345 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
351 352 353 354 355 356 357 358 359 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 351 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
339 340 341 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 339 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 |
# File 'lib/cybersource_rest_client/models/push_funds201_response_processor_information.rb', line 195 def valid? true end |