Class: CyberSource::TransientTokenDataV2Api
- Inherits:
-
Object
- Object
- CyberSource::TransientTokenDataV2Api
- Defined in:
- lib/cybersource_rest_client/api/transient_token_data_v2_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_payment_credentials_for_transient_token(payment_credentials_reference, opts = {}) ⇒ String
Get Payment Credentials Retrieve the Payment data captured by Unified Checkout.
-
#get_payment_credentials_for_transient_token_with_http_info(payment_credentials_reference, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Get Payment Credentials Retrieve the Payment data captured by Unified Checkout.
-
#get_transaction_for_transient_token(transient_token, opts = {}) ⇒ nil
Get Transient Token Data Retrieve the data captured by Unified Checkout.
-
#get_transaction_for_transient_token_jti(jti, opts = {}) ⇒ nil
Get Transient Token Data v2 Retrieve data captured through Unified Checkout.
-
#get_transaction_for_transient_token_jti_with_http_info(jti, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Get Transient Token Data v2 Retrieve data captured through Unified Checkout.
-
#get_transaction_for_transient_token_with_http_info(transient_token, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Get Transient Token Data Retrieve the data captured by Unified Checkout.
-
#initialize(api_client = ApiClient.default, config) ⇒ TransientTokenDataV2Api
constructor
A new instance of TransientTokenDataV2Api.
Constructor Details
#initialize(api_client = ApiClient.default, config) ⇒ TransientTokenDataV2Api
Returns a new instance of TransientTokenDataV2Api.
18 19 20 21 |
# File 'lib/cybersource_rest_client/api/transient_token_data_v2_api.rb', line 18 def initialize(api_client = ApiClient.default, config) @api_client = api_client @api_client.set_configuration(config) end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
16 17 18 |
# File 'lib/cybersource_rest_client/api/transient_token_data_v2_api.rb', line 16 def api_client @api_client end |
Instance Method Details
#get_payment_credentials_for_transient_token(payment_credentials_reference, opts = {}) ⇒ String
Get Payment Credentials Retrieve the Payment data captured by Unified Checkout. This API is used to retrieve the detailed data represented by the Transient Token. This API will return PCI payment data captured by the Unified Checkout platform.
29 30 31 32 |
# File 'lib/cybersource_rest_client/api/transient_token_data_v2_api.rb', line 29 def get_payment_credentials_for_transient_token(payment_credentials_reference, opts = {}) data, status_code, headers = get_payment_credentials_for_transient_token_with_http_info(payment_credentials_reference, opts) return data, status_code, headers end |
#get_payment_credentials_for_transient_token_with_http_info(payment_credentials_reference, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Get Payment Credentials Retrieve the Payment data captured by Unified Checkout. This API is used to retrieve the detailed data represented by the Transient Token. This API will return PCI payment data captured by the Unified Checkout platform.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/cybersource_rest_client/api/transient_token_data_v2_api.rb', line 39 def get_payment_credentials_for_transient_token_with_http_info(payment_credentials_reference, opts = {}) if @api_client.config.debugging begin raise @api_client.config.logger.debug 'Calling API: TransientTokenDataV2Api.get_payment_credentials_for_transient_token ...' rescue puts 'Cannot write to log' end end # verify the required parameter 'payment_credentials_reference' is set if @api_client.config.client_side_validation && payment_credentials_reference.nil? fail ArgumentError, "Missing the required parameter 'payment_credentials_reference' when calling TransientTokenDataV2Api.get_payment_credentials_for_transient_token" end # resource path local_var_path = 'flex/v2/payment-credentials/{paymentCredentialsReference}'.sub('{' + 'paymentCredentialsReference' + '}', payment_credentials_reference.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/jwt']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8']) # form parameters form_params = {} # http body (model) if 'GET' == 'POST' post_body = '{}' else post_body = nil end inbound_mle_status = "false" if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["get_payment_credentials_for_transient_token","get_payment_credentials_for_transient_token_with_http_info"]) begin post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body) rescue raise end end is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["get_payment_credentials_for_transient_token","get_payment_credentials_for_transient_token_with_http_info"]) auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String', :isResponseMLEForApi => is_response_mle_for_api) if @api_client.config.debugging begin raise @api_client.config.logger.debug "API called: TransientTokenDataV2Api#get_payment_credentials_for_transient_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" rescue puts 'Cannot write to log' end end return data, status_code, headers end |
#get_transaction_for_transient_token(transient_token, opts = {}) ⇒ nil
Get Transient Token Data Retrieve the data captured by Unified Checkout. This API is used to retrieve the detailed data represented by the Transient Token. This API will not return PCI payment data (PAN). Include the Request ID in the GET request to retrieve the transaction details.
112 113 114 115 |
# File 'lib/cybersource_rest_client/api/transient_token_data_v2_api.rb', line 112 def get_transaction_for_transient_token(transient_token, opts = {}) data, status_code, headers = get_transaction_for_transient_token_with_http_info(transient_token, opts) return data, status_code, headers end |
#get_transaction_for_transient_token_jti(jti, opts = {}) ⇒ nil
Get Transient Token Data v2 Retrieve data captured through Unified Checkout. This API retrieves the detailed information associated with a Transient Token by looking it up in TMS and using its ID (the jti claim from the /flex/v2/tokens JWT response). The response returns a decrypted version of the Transient Token; however, PCI-sensitive payment data (PAN) is never returned and is always masked.
Example jti value: 1D42LRF04LYTMO3I1G8JX6GO6S1PUFM2R4CQLU51267E0EOQ7X2169A99674E16E
194 195 196 197 |
# File 'lib/cybersource_rest_client/api/transient_token_data_v2_api.rb', line 194 def get_transaction_for_transient_token_jti(jti, opts = {}) data, status_code, headers = get_transaction_for_transient_token_jti_with_http_info(jti, opts) return data, status_code, headers end |
#get_transaction_for_transient_token_jti_with_http_info(jti, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Get Transient Token Data v2 Retrieve data captured through Unified Checkout. This API retrieves the detailed information associated with a Transient Token by looking it up in TMS and using its ID (the jti claim from the /flex/v2/tokens JWT response). The response returns a decrypted version of the Transient Token; however, PCI-sensitive payment data (PAN) is never returned and is always masked.<br><br> Example jti value: 1D42LRF04LYTMO3I1G8JX6GO6S1PUFM2R4CQLU51267E0EOQ7X2169A99674E16E
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/cybersource_rest_client/api/transient_token_data_v2_api.rb', line 204 def get_transaction_for_transient_token_jti_with_http_info(jti, opts = {}) if @api_client.config.debugging begin raise @api_client.config.logger.debug 'Calling API: TransientTokenDataV2Api.get_transaction_for_transient_token_jti ...' rescue puts 'Cannot write to log' end end # verify the required parameter 'jti' is set if @api_client.config.client_side_validation && jti.nil? fail ArgumentError, "Missing the required parameter 'jti' when calling TransientTokenDataV2Api.get_transaction_for_transient_token_jti" end # resource path local_var_path = 'flex/v2/payment-details/{jti}'.sub('{' + 'jti' + '}', jti.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8']) # form parameters form_params = {} # http body (model) if 'GET' == 'POST' post_body = '{}' else post_body = nil end inbound_mle_status = "false" if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["get_transaction_for_transient_token_jti","get_transaction_for_transient_token_jti_with_http_info"]) begin post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body) rescue raise end end is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["get_transaction_for_transient_token_jti","get_transaction_for_transient_token_jti_with_http_info"]) auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :isResponseMLEForApi => is_response_mle_for_api) if @api_client.config.debugging begin raise @api_client.config.logger.debug "API called: TransientTokenDataV2Api#get_transaction_for_transient_token_jti\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" rescue puts 'Cannot write to log' end end return data, status_code, headers end |
#get_transaction_for_transient_token_with_http_info(transient_token, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Get Transient Token Data Retrieve the data captured by Unified Checkout. This API is used to retrieve the detailed data represented by the Transient Token. This API will not return PCI payment data (PAN). Include the Request ID in the GET request to retrieve the transaction details.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/cybersource_rest_client/api/transient_token_data_v2_api.rb', line 122 def get_transaction_for_transient_token_with_http_info(transient_token, opts = {}) if @api_client.config.debugging begin raise @api_client.config.logger.debug 'Calling API: TransientTokenDataV2Api.get_transaction_for_transient_token ...' rescue puts 'Cannot write to log' end end # verify the required parameter 'transient_token' is set if @api_client.config.client_side_validation && transient_token.nil? fail ArgumentError, "Missing the required parameter 'transient_token' when calling TransientTokenDataV2Api.get_transaction_for_transient_token" end # resource path local_var_path = 'up/v1/payment-details/{transientToken}'.sub('{' + 'transientToken' + '}', transient_token.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json;charset=utf-8']) # form parameters form_params = {} # http body (model) if 'GET' == 'POST' post_body = '{}' else post_body = nil end inbound_mle_status = "false" if MLEUtility.check_is_mle_for_API(@api_client.merchantconfig, inbound_mle_status, ["get_transaction_for_transient_token","get_transaction_for_transient_token_with_http_info"]) begin post_body = MLEUtility.encrypt_request_payload(@api_client.merchantconfig, post_body) rescue raise end end is_response_mle_for_api = MLEUtility.check_is_response_mle_for_api(@api_client.merchantconfig, ["get_transaction_for_transient_token","get_transaction_for_transient_token_with_http_info"]) auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :isResponseMLEForApi => is_response_mle_for_api) if @api_client.config.debugging begin raise @api_client.config.logger.debug "API called: TransientTokenDataV2Api#get_transaction_for_transient_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" rescue puts 'Cannot write to log' end end return data, status_code, headers end |