Class: CyberSource::Ucv1sessionsDataOrderInformationLineItems
- Inherits:
-
Object
- Object
- CyberSource::Ucv1sessionsDataOrderInformationLineItems
- Defined in:
- lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb
Instance Attribute Summary collapse
-
#amount_includes_tax ⇒ Object
Indicates if amount includes tax.
-
#commodity_code ⇒ Object
Commodity code.
-
#discount_amount ⇒ Object
Discount amount applied.
-
#discount_applied ⇒ Object
Indicates if discount applied.
-
#discount_rate ⇒ Object
Discount rate applied.
-
#fulfillment_type ⇒ Object
Fulfillment type.
-
#gift ⇒ Object
Indicates if item is a gift.
-
#gift_card_currency ⇒ Object
Gift card currency.
-
#invoice_number ⇒ Object
Invoice number for the line item.
-
#passenger ⇒ Object
Returns the value of attribute passenger.
-
#product_code ⇒ Object
Code identifying the product.
-
#product_description ⇒ Object
Description of the product.
-
#product_name ⇒ Object
Name of the product.
-
#product_sku ⇒ Object
Stock Keeping Unit identifier.
-
#quantity ⇒ Object
Quantity of the product.
-
#reference_data_code ⇒ Object
Reference data code.
-
#reference_data_number ⇒ Object
Reference data number.
-
#shipping_country_code ⇒ Object
Country where item will be shipped.
-
#shipping_destination_types ⇒ Object
Shipping destination types.
-
#tax_amount ⇒ Object
Tax amount applied.
-
#tax_applied_after_discount ⇒ Object
Indicates if tax applied after discount.
-
#tax_details ⇒ Object
Returns the value of attribute tax_details.
-
#tax_rate ⇒ Object
The tax rate of an item.
-
#tax_status_indicator ⇒ Object
Tax status indicator.
-
#tax_type_code ⇒ Object
Tax type code.
-
#total_amount ⇒ Object
Total amount for the line item.
-
#type_of_supply ⇒ Object
Type of supply.
-
#unit_of_measure ⇒ Object
Unit of measure (e.g. EA, KG, LB).
-
#unit_price ⇒ Object
Price per unit.
-
#unit_tax_amount ⇒ Object
Unit tax amount.
-
#weight ⇒ Object
Weight of the product.
-
#weight_identifier ⇒ Object
Weight identifier.
-
#weight_unit ⇒ Object
Unit of weight of the product.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ucv1sessionsDataOrderInformationLineItems
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Ucv1sessionsDataOrderInformationLineItems
Initializes the object
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 232 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'productCode') self.product_code = attributes[:'productCode'] end if attributes.has_key?(:'productName') self.product_name = attributes[:'productName'] end if attributes.has_key?(:'productSku') self.product_sku = attributes[:'productSku'] end if attributes.has_key?(:'quantity') self.quantity = attributes[:'quantity'] end if attributes.has_key?(:'unitPrice') self.unit_price = attributes[:'unitPrice'] end if attributes.has_key?(:'unitOfMeasure') self.unit_of_measure = attributes[:'unitOfMeasure'] end if attributes.has_key?(:'totalAmount') self.total_amount = attributes[:'totalAmount'] end if attributes.has_key?(:'taxRate') self.tax_rate = attributes[:'taxRate'] end if attributes.has_key?(:'shippingCountryCode') self.shipping_country_code = attributes[:'shippingCountryCode'] end if attributes.has_key?(:'taxAmount') self.tax_amount = attributes[:'taxAmount'] end if attributes.has_key?(:'taxAppliedAfterDiscount') self.tax_applied_after_discount = attributes[:'taxAppliedAfterDiscount'] end if attributes.has_key?(:'taxStatusIndicator') self.tax_status_indicator = attributes[:'taxStatusIndicator'] end if attributes.has_key?(:'taxTypeCode') self.tax_type_code = attributes[:'taxTypeCode'] end if attributes.has_key?(:'amountIncludesTax') self.amount_includes_tax = attributes[:'amountIncludesTax'] end if attributes.has_key?(:'typeOfSupply') self.type_of_supply = attributes[:'typeOfSupply'] end if attributes.has_key?(:'commodityCode') self.commodity_code = attributes[:'commodityCode'] end if attributes.has_key?(:'discountAmount') self.discount_amount = attributes[:'discountAmount'] end if attributes.has_key?(:'discountApplied') self.discount_applied = attributes[:'discountApplied'] end if attributes.has_key?(:'discountRate') self.discount_rate = attributes[:'discountRate'] end if attributes.has_key?(:'invoiceNumber') self.invoice_number = attributes[:'invoiceNumber'] end if attributes.has_key?(:'taxDetails') self.tax_details = attributes[:'taxDetails'] end if attributes.has_key?(:'fulfillmentType') self.fulfillment_type = attributes[:'fulfillmentType'] end if attributes.has_key?(:'weight') self.weight = attributes[:'weight'] end if attributes.has_key?(:'weightIdentifier') self.weight_identifier = attributes[:'weightIdentifier'] end if attributes.has_key?(:'weightUnit') self.weight_unit = attributes[:'weightUnit'] end if attributes.has_key?(:'referenceDataCode') self.reference_data_code = attributes[:'referenceDataCode'] end if attributes.has_key?(:'referenceDataNumber') self.reference_data_number = attributes[:'referenceDataNumber'] end if attributes.has_key?(:'unitTaxAmount') self.unit_tax_amount = attributes[:'unitTaxAmount'] end if attributes.has_key?(:'productDescription') self.product_description = attributes[:'productDescription'] end if attributes.has_key?(:'giftCardCurrency') self.gift_card_currency = attributes[:'giftCardCurrency'] end if attributes.has_key?(:'shippingDestinationTypes') self.shipping_destination_types = attributes[:'shippingDestinationTypes'] end if attributes.has_key?(:'gift') self.gift = attributes[:'gift'] end if attributes.has_key?(:'passenger') self.passenger = attributes[:'passenger'] end end |
Instance Attribute Details
#amount_includes_tax ⇒ Object
Indicates if amount includes tax
56 57 58 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 56 def amount_includes_tax @amount_includes_tax end |
#commodity_code ⇒ Object
Commodity code
62 63 64 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 62 def commodity_code @commodity_code end |
#discount_amount ⇒ Object
Discount amount applied
65 66 67 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 65 def discount_amount @discount_amount end |
#discount_applied ⇒ Object
Indicates if discount applied
68 69 70 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 68 def discount_applied @discount_applied end |
#discount_rate ⇒ Object
Discount rate applied
71 72 73 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 71 def discount_rate @discount_rate end |
#fulfillment_type ⇒ Object
Fulfillment type
79 80 81 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 79 def fulfillment_type @fulfillment_type end |
#gift ⇒ Object
Indicates if item is a gift
109 110 111 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 109 def gift @gift end |
#gift_card_currency ⇒ Object
Gift card currency
103 104 105 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 103 def gift_card_currency @gift_card_currency end |
#invoice_number ⇒ Object
Invoice number for the line item
74 75 76 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 74 def invoice_number @invoice_number end |
#passenger ⇒ Object
Returns the value of attribute passenger.
111 112 113 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 111 def passenger @passenger end |
#product_code ⇒ Object
Code identifying the product.
17 18 19 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 17 def product_code @product_code end |
#product_description ⇒ Object
Description of the product
100 101 102 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 100 def product_description @product_description end |
#product_name ⇒ Object
Name of the product.
20 21 22 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 20 def product_name @product_name end |
#product_sku ⇒ Object
Stock Keeping Unit identifier
23 24 25 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 23 def product_sku @product_sku end |
#quantity ⇒ Object
Quantity of the product
26 27 28 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 26 def quantity @quantity end |
#reference_data_code ⇒ Object
Reference data code
91 92 93 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 91 def reference_data_code @reference_data_code end |
#reference_data_number ⇒ Object
Reference data number
94 95 96 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 94 def reference_data_number @reference_data_number end |
#shipping_country_code ⇒ Object
Country where item will be shipped
41 42 43 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 41 def shipping_country_code @shipping_country_code end |
#shipping_destination_types ⇒ Object
Shipping destination types
106 107 108 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 106 def shipping_destination_types @shipping_destination_types end |
#tax_amount ⇒ Object
Tax amount applied
44 45 46 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 44 def tax_amount @tax_amount end |
#tax_applied_after_discount ⇒ Object
Indicates if tax applied after discount
47 48 49 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 47 def tax_applied_after_discount @tax_applied_after_discount end |
#tax_details ⇒ Object
Returns the value of attribute tax_details.
76 77 78 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 76 def tax_details @tax_details end |
#tax_rate ⇒ Object
The tax rate of an item. Maximum of 2 decimal places. Valid range is 0 or 0.01 to 99.99.
38 39 40 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 38 def tax_rate @tax_rate end |
#tax_status_indicator ⇒ Object
Tax status indicator
50 51 52 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 50 def tax_status_indicator @tax_status_indicator end |
#tax_type_code ⇒ Object
Tax type code
53 54 55 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 53 def tax_type_code @tax_type_code end |
#total_amount ⇒ Object
Total amount for the line item
35 36 37 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 35 def total_amount @total_amount end |
#type_of_supply ⇒ Object
Type of supply
59 60 61 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 59 def type_of_supply @type_of_supply end |
#unit_of_measure ⇒ Object
Unit of measure (e.g. EA, KG, LB)
32 33 34 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 32 def unit_of_measure @unit_of_measure end |
#unit_price ⇒ Object
Price per unit
29 30 31 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 29 def unit_price @unit_price end |
#unit_tax_amount ⇒ Object
Unit tax amount
97 98 99 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 97 def unit_tax_amount @unit_tax_amount end |
#weight ⇒ Object
Weight of the product
82 83 84 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 82 def weight @weight end |
#weight_identifier ⇒ Object
Weight identifier
85 86 87 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 85 def weight_identifier @weight_identifier end |
#weight_unit ⇒ Object
Unit of weight of the product
88 89 90 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 88 def weight_unit @weight_unit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 114 def self.attribute_map { :'product_code' => :'productCode', :'product_name' => :'productName', :'product_sku' => :'productSku', :'quantity' => :'quantity', :'unit_price' => :'unitPrice', :'unit_of_measure' => :'unitOfMeasure', :'total_amount' => :'totalAmount', :'tax_rate' => :'taxRate', :'shipping_country_code' => :'shippingCountryCode', :'tax_amount' => :'taxAmount', :'tax_applied_after_discount' => :'taxAppliedAfterDiscount', :'tax_status_indicator' => :'taxStatusIndicator', :'tax_type_code' => :'taxTypeCode', :'amount_includes_tax' => :'amountIncludesTax', :'type_of_supply' => :'typeOfSupply', :'commodity_code' => :'commodityCode', :'discount_amount' => :'discountAmount', :'discount_applied' => :'discountApplied', :'discount_rate' => :'discountRate', :'invoice_number' => :'invoiceNumber', :'tax_details' => :'taxDetails', :'fulfillment_type' => :'fulfillmentType', :'weight' => :'weight', :'weight_identifier' => :'weightIdentifier', :'weight_unit' => :'weightUnit', :'reference_data_code' => :'referenceDataCode', :'reference_data_number' => :'referenceDataNumber', :'unit_tax_amount' => :'unitTaxAmount', :'product_description' => :'productDescription', :'gift_card_currency' => :'giftCardCurrency', :'shipping_destination_types' => :'shippingDestinationTypes', :'gift' => :'gift', :'passenger' => :'passenger' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 153 def self.json_map { :'product_code' => :'product_code', :'product_name' => :'product_name', :'product_sku' => :'product_sku', :'quantity' => :'quantity', :'unit_price' => :'unit_price', :'unit_of_measure' => :'unit_of_measure', :'total_amount' => :'total_amount', :'tax_rate' => :'tax_rate', :'shipping_country_code' => :'shipping_country_code', :'tax_amount' => :'tax_amount', :'tax_applied_after_discount' => :'tax_applied_after_discount', :'tax_status_indicator' => :'tax_status_indicator', :'tax_type_code' => :'tax_type_code', :'amount_includes_tax' => :'amount_includes_tax', :'type_of_supply' => :'type_of_supply', :'commodity_code' => :'commodity_code', :'discount_amount' => :'discount_amount', :'discount_applied' => :'discount_applied', :'discount_rate' => :'discount_rate', :'invoice_number' => :'invoice_number', :'tax_details' => :'tax_details', :'fulfillment_type' => :'fulfillment_type', :'weight' => :'weight', :'weight_identifier' => :'weight_identifier', :'weight_unit' => :'weight_unit', :'reference_data_code' => :'reference_data_code', :'reference_data_number' => :'reference_data_number', :'unit_tax_amount' => :'unit_tax_amount', :'product_description' => :'product_description', :'gift_card_currency' => :'gift_card_currency', :'shipping_destination_types' => :'shipping_destination_types', :'gift' => :'gift', :'passenger' => :'passenger' } end |
.swagger_types ⇒ Object
Attribute type mapping.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 192 def self.swagger_types { :'product_code' => :'String', :'product_name' => :'String', :'product_sku' => :'String', :'quantity' => :'Integer', :'unit_price' => :'String', :'unit_of_measure' => :'String', :'total_amount' => :'String', :'tax_rate' => :'String', :'shipping_country_code' => :'String', :'tax_amount' => :'String', :'tax_applied_after_discount' => :'String', :'tax_status_indicator' => :'String', :'tax_type_code' => :'String', :'amount_includes_tax' => :'BOOLEAN', :'type_of_supply' => :'String', :'commodity_code' => :'String', :'discount_amount' => :'String', :'discount_applied' => :'BOOLEAN', :'discount_rate' => :'String', :'invoice_number' => :'String', :'tax_details' => :'Upv1capturecontextsDataOrderInformationLineItemsTaxDetails', :'fulfillment_type' => :'String', :'weight' => :'String', :'weight_identifier' => :'String', :'weight_unit' => :'String', :'reference_data_code' => :'String', :'reference_data_number' => :'String', :'unit_tax_amount' => :'String', :'product_description' => :'String', :'gift_card_currency' => :'String', :'shipping_destination_types' => :'String', :'gift' => :'BOOLEAN', :'passenger' => :'Upv1capturecontextsDataOrderInformationLineItemsPassenger' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 548 def ==(o) return true if self.equal?(o) self.class == o.class && product_code == o.product_code && product_name == o.product_name && product_sku == o.product_sku && quantity == o.quantity && unit_price == o.unit_price && unit_of_measure == o.unit_of_measure && total_amount == o.total_amount && tax_rate == o.tax_rate && shipping_country_code == o.shipping_country_code && tax_amount == o.tax_amount && tax_applied_after_discount == o.tax_applied_after_discount && tax_status_indicator == o.tax_status_indicator && tax_type_code == o.tax_type_code && amount_includes_tax == o.amount_includes_tax && type_of_supply == o.type_of_supply && commodity_code == o.commodity_code && discount_amount == o.discount_amount && discount_applied == o.discount_applied && discount_rate == o.discount_rate && invoice_number == o.invoice_number && tax_details == o.tax_details && fulfillment_type == o.fulfillment_type && weight == o.weight && weight_identifier == o.weight_identifier && weight_unit == o.weight_unit && reference_data_code == o.reference_data_code && reference_data_number == o.reference_data_number && unit_tax_amount == o.unit_tax_amount && product_description == o.product_description && gift_card_currency == o.gift_card_currency && shipping_destination_types == o.shipping_destination_types && gift == o.gift && passenger == o.passenger end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 622 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
688 689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 688 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 601 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
588 589 590 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 588 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
594 595 596 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 594 def hash [product_code, product_name, product_sku, quantity, unit_price, unit_of_measure, total_amount, tax_rate, shipping_country_code, tax_amount, tax_applied_after_discount, tax_status_indicator, tax_type_code, amount_includes_tax, type_of_supply, commodity_code, discount_amount, discount_applied, discount_rate, invoice_number, tax_details, fulfillment_type, weight, weight_identifier, weight_unit, reference_data_code, reference_data_number, unit_tax_amount, product_description, gift_card_currency, shipping_destination_types, gift, passenger].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
373 374 375 376 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 373 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
668 669 670 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 668 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
674 675 676 677 678 679 680 681 682 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 674 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
662 663 664 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 662 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
380 381 382 |
# File 'lib/cybersource_rest_client/models/ucv1sessions_data_order_information_line_items.rb', line 380 def valid? true end |