Class: CyberSource::UnifiedriskCustomer
- Inherits:
-
Object
- Object
- CyberSource::UnifiedriskCustomer
- Defined in:
- lib/cybersource_rest_client/models/unifiedrisk_customer.rb
Overview
Customer identity, profile information, account history, and personal identification documents
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#agent_confidence_score ⇒ Object
Confidence score (0-1) for agent's alignment with customer preferences.
-
#agent_delegation_scope ⇒ Object
Scope of authority delegated to agent: discovery, purchase, or full Possible values: - discovery - purchase - full.
-
#agent_id ⇒ Object
Unique identifier for the AI agent acting on behalf of customer.
-
#agent_interaction_timestamp ⇒ Object
Timestamp of agent interaction with customer.
-
#agent_type ⇒ Object
Type of agent initiating transaction: HUMAN, AI_AGENT, or HYBRID Possible values: - HUMAN - AI_AGENT - HYBRID.
-
#business_name ⇒ Object
Name of business if customer is a business.
-
#customer_id ⇒ Object
A unique identifier for the customer.
-
#enrollment_date ⇒ Object
The date in which the customer signed up to use Mobile/online banking.
-
#flags ⇒ Object
Field to be used for specific customer flags that may determine treatment strategies.
-
#hashed_password ⇒ Object
The merchant's password that CyberSource hashes and stores as a hashed password.
-
#id ⇒ Object
The unique id of the customer.
-
#is_business ⇒ Object
Whether customer is a business entity.
-
#merchant_customer_id ⇒ Object
Your identifier for the customer.When a subscription or customer profile is being created, the maximum length for this field for most processors is 30.
-
#personal_identification ⇒ Object
Returns the value of attribute personal_identification.
-
#type ⇒ Object
The customer type.
-
#username ⇒ Object
Specifies the customer account user name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UnifiedriskCustomer
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UnifiedriskCustomer
Initializes the object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 137 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'merchantCustomerId') self.merchant_customer_id = attributes[:'merchantCustomerId'] end if attributes.has_key?(:'username') self.username = attributes[:'username'] end if attributes.has_key?(:'hashedPassword') self.hashed_password = attributes[:'hashedPassword'] end if attributes.has_key?(:'personalIdentification') self.personal_identification = attributes[:'personalIdentification'] end if attributes.has_key?(:'enrollmentDate') self.enrollment_date = attributes[:'enrollmentDate'] end if attributes.has_key?(:'flags') if (value = attributes[:'flags']).is_a?(Array) self.flags = value end end if attributes.has_key?(:'customerId') self.customer_id = attributes[:'customerId'] end if attributes.has_key?(:'type') self.type = attributes[:'type'] end if attributes.has_key?(:'agentType') self.agent_type = attributes[:'agentType'] end if attributes.has_key?(:'agentId') self.agent_id = attributes[:'agentId'] end if attributes.has_key?(:'agentConfidenceScore') self.agent_confidence_score = attributes[:'agentConfidenceScore'] end if attributes.has_key?(:'agentDelegationScope') self.agent_delegation_scope = attributes[:'agentDelegationScope'] end if attributes.has_key?(:'agentInteractionTimestamp') self. = attributes[:'agentInteractionTimestamp'] end if attributes.has_key?(:'isBusiness') self.is_business = attributes[:'isBusiness'] end if attributes.has_key?(:'businessName') self.business_name = attributes[:'businessName'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'address') self.address = attributes[:'address'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
64 65 66 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 64 def address @address end |
#agent_confidence_score ⇒ Object
Confidence score (0-1) for agent's alignment with customer preferences
47 48 49 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 47 def agent_confidence_score @agent_confidence_score end |
#agent_delegation_scope ⇒ Object
Scope of authority delegated to agent: discovery, purchase, or full Possible values: - discovery - purchase - full
50 51 52 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 50 def agent_delegation_scope @agent_delegation_scope end |
#agent_id ⇒ Object
Unique identifier for the AI agent acting on behalf of customer
44 45 46 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 44 def agent_id @agent_id end |
#agent_interaction_timestamp ⇒ Object
Timestamp of agent interaction with customer
53 54 55 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 53 def end |
#agent_type ⇒ Object
Type of agent initiating transaction: HUMAN, AI_AGENT, or HYBRID Possible values: - HUMAN - AI_AGENT - HYBRID
41 42 43 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 41 def agent_type @agent_type end |
#business_name ⇒ Object
Name of business if customer is a business
59 60 61 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 59 def business_name @business_name end |
#customer_id ⇒ Object
A unique identifier for the customer. | A unique identifier for the customer. This field should be considered mandatory for the payments solution, but not otherwise.
35 36 37 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 35 def customer_id @customer_id end |
#enrollment_date ⇒ Object
The date in which the customer signed up to use Mobile/online banking
29 30 31 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 29 def enrollment_date @enrollment_date end |
#flags ⇒ Object
Field to be used for specific customer flags that may determine treatment strategies. This is an array that can include free text values. For retail customers this may be a vulnerability or a VIP mar
32 33 34 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 32 def flags @flags end |
#hashed_password ⇒ Object
The merchant's password that CyberSource hashes and stores as a hashed password.
24 25 26 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 24 def hashed_password @hashed_password end |
#id ⇒ Object
The unique id of the customer
62 63 64 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 62 def id @id end |
#is_business ⇒ Object
Whether customer is a business entity
56 57 58 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 56 def is_business @is_business end |
#merchant_customer_id ⇒ Object
Your identifier for the customer.When a subscription or customer profile is being created, the maximum length for this field for most processors is 30. Otherwise, the maximum length is 100.#### Comercio Latino For recurring payments in Mexico, the value is the customer's contract number. Note Before you request the authorization, you must inform the issuer of the customer contract numbers that will be used for recurring transactions.#### Worldpay VAP For a follow-on credit with Worldpay VA
18 19 20 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 18 def merchant_customer_id @merchant_customer_id end |
#personal_identification ⇒ Object
Returns the value of attribute personal_identification.
26 27 28 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 26 def personal_identification @personal_identification end |
#type ⇒ Object
The customer type. If the identifier in customerId represents an individual, set this attribute to "Retail", if it represents a business, set this attribute to "Business".
38 39 40 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 38 def type @type end |
#username ⇒ Object
Specifies the customer account user name.
21 22 23 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 21 def username @username end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 67 def self.attribute_map { :'merchant_customer_id' => :'merchantCustomerId', :'username' => :'username', :'hashed_password' => :'hashedPassword', :'personal_identification' => :'personalIdentification', :'enrollment_date' => :'enrollmentDate', :'flags' => :'flags', :'customer_id' => :'customerId', :'type' => :'type', :'agent_type' => :'agentType', :'agent_id' => :'agentId', :'agent_confidence_score' => :'agentConfidenceScore', :'agent_delegation_scope' => :'agentDelegationScope', :'agent_interaction_timestamp' => :'agentInteractionTimestamp', :'is_business' => :'isBusiness', :'business_name' => :'businessName', :'id' => :'id', :'address' => :'address' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 90 def self.json_map { :'merchant_customer_id' => :'merchant_customer_id', :'username' => :'username', :'hashed_password' => :'hashed_password', :'personal_identification' => :'personal_identification', :'enrollment_date' => :'enrollment_date', :'flags' => :'flags', :'customer_id' => :'customer_id', :'type' => :'type', :'agent_type' => :'agent_type', :'agent_id' => :'agent_id', :'agent_confidence_score' => :'agent_confidence_score', :'agent_delegation_scope' => :'agent_delegation_scope', :'agent_interaction_timestamp' => :'agent_interaction_timestamp', :'is_business' => :'is_business', :'business_name' => :'business_name', :'id' => :'id', :'address' => :'address' } end |
.swagger_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 113 def self.swagger_types { :'merchant_customer_id' => :'String', :'username' => :'String', :'hashed_password' => :'String', :'personal_identification' => :'UnifiedriskCustomerPersonalIdentification', :'enrollment_date' => :'Date', :'flags' => :'Array<String>', :'customer_id' => :'String', :'type' => :'String', :'agent_type' => :'String', :'agent_id' => :'String', :'agent_confidence_score' => :'Float', :'agent_delegation_scope' => :'String', :'agent_interaction_timestamp' => :'DateTime', :'is_business' => :'BOOLEAN', :'business_name' => :'String', :'id' => :'String', :'address' => :'UnifiedriskCustomerAddress' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && merchant_customer_id == o.merchant_customer_id && username == o.username && hashed_password == o.hashed_password && personal_identification == o.personal_identification && enrollment_date == o.enrollment_date && flags == o.flags && customer_id == o.customer_id && type == o.type && agent_type == o.agent_type && agent_id == o.agent_id && agent_confidence_score == o.agent_confidence_score && agent_delegation_scope == o.agent_delegation_scope && == o. && is_business == o.is_business && business_name == o.business_name && id == o.id && address == o.address end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 323 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 389 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 302 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
289 290 291 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 289 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
295 296 297 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 295 def hash [merchant_customer_id, username, hashed_password, personal_identification, enrollment_date, flags, customer_id, type, agent_type, agent_id, agent_confidence_score, agent_delegation_scope, , is_business, business_name, id, address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
216 217 218 219 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 216 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
369 370 371 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 369 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
375 376 377 378 379 380 381 382 383 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 375 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
363 364 365 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 363 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_customer.rb', line 223 def valid? true end |