Class: CyberSource::UnifiedriskOrderBilling
- Inherits:
-
Object
- Object
- CyberSource::UnifiedriskOrderBilling
- Defined in:
- lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb
Instance Attribute Summary collapse
-
#address_line1 ⇒ Object
Payment card billing street address as it appears on the credit card issuer's records.
-
#address_line2 ⇒ Object
Used for additional address information.
-
#address_line3 ⇒ Object
Third line of the billing address for additional information such as building name, estate, or care-of address.
-
#administrative_area ⇒ Object
State or province of the billing address.
-
#country ⇒ Object
Payment card billing country.
-
#email ⇒ Object
Customer's email address, including the full domain name.
-
#first_name ⇒ Object
Customer's first name.
-
#last_name ⇒ Object
Customer's last name.
-
#locality ⇒ Object
Payment card billing city.
-
#phone_number ⇒ Object
Customer's phone number.It is recommended that you include the country code when the order is from outside the U.S.
-
#postal_code ⇒ Object
Postal code for the billing address.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UnifiedriskOrderBilling
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UnifiedriskOrderBilling
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'addressLine1') self.address_line1 = attributes[:'addressLine1'] end if attributes.has_key?(:'addressLine2') self.address_line2 = attributes[:'addressLine2'] end if attributes.has_key?(:'administrativeArea') self.administrative_area = attributes[:'administrativeArea'] end if attributes.has_key?(:'country') self.country = attributes[:'country'] end if attributes.has_key?(:'locality') self.locality = attributes[:'locality'] end if attributes.has_key?(:'firstName') self.first_name = attributes[:'firstName'] end if attributes.has_key?(:'lastName') self.last_name = attributes[:'lastName'] end if attributes.has_key?(:'phoneNumber') self.phone_number = attributes[:'phoneNumber'] end if attributes.has_key?(:'email') self.email = attributes[:'email'] end if attributes.has_key?(:'postalCode') self.postal_code = attributes[:'postalCode'] end if attributes.has_key?(:'addressLine3') self.address_line3 = attributes[:'addressLine3'] end end |
Instance Attribute Details
#address_line1 ⇒ Object
Payment card billing street address as it appears on the credit card issuer's records.
17 18 19 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 17 def address_line1 @address_line1 end |
#address_line2 ⇒ Object
Used for additional address information. For example: Attention: Accounts Payable Optional field. This value is used for AVS.
20 21 22 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 20 def address_line2 @address_line2 end |
#address_line3 ⇒ Object
Third line of the billing address for additional information such as building name, estate, or care-of address
47 48 49 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 47 def address_line3 @address_line3 end |
#administrative_area ⇒ Object
State or province of the billing address. Use the State, Province, and Territory Codes for the United States and Canada.For Payouts: This field may be sent only for FDC Compass.##### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctl
23 24 25 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 23 def administrative_area @administrative_area end |
#country ⇒ Object
Payment card billing country. Use the two-character ISO Standard Country Codes
26 27 28 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 26 def country @country end |
#email ⇒ Object
Customer's email address, including the full domain name.
41 42 43 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 41 def email @email end |
#first_name ⇒ Object
Customer's first name. This name must be the same as the name on the card.
32 33 34 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 32 def first_name @first_name end |
#last_name ⇒ Object
Customer's last name. This name must be the same as the name on the card.
35 36 37 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 35 def last_name @last_name end |
#locality ⇒ Object
Payment card billing city.
29 30 31 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 29 def locality @locality end |
#phone_number ⇒ Object
Customer's phone number.It is recommended that you include the country code when the order is from outside the U.S.
38 39 40 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 38 def phone_number @phone_number end |
#postal_code ⇒ Object
Postal code for the billing address. The postal code must consist of 5 to 9 digits.When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits]
44 45 46 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 44 def postal_code @postal_code end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 50 def self.attribute_map { :'address_line1' => :'addressLine1', :'address_line2' => :'addressLine2', :'administrative_area' => :'administrativeArea', :'country' => :'country', :'locality' => :'locality', :'first_name' => :'firstName', :'last_name' => :'lastName', :'phone_number' => :'phoneNumber', :'email' => :'email', :'postal_code' => :'postalCode', :'address_line3' => :'addressLine3' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 67 def self.json_map { :'address_line1' => :'address_line1', :'address_line2' => :'address_line2', :'administrative_area' => :'administrative_area', :'country' => :'country', :'locality' => :'locality', :'first_name' => :'first_name', :'last_name' => :'last_name', :'phone_number' => :'phone_number', :'email' => :'email', :'postal_code' => :'postal_code', :'address_line3' => :'address_line3' } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 84 def self.swagger_types { :'address_line1' => :'String', :'address_line2' => :'String', :'administrative_area' => :'String', :'country' => :'String', :'locality' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'phone_number' => :'String', :'email' => :'String', :'postal_code' => :'String', :'address_line3' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && address_line1 == o.address_line1 && address_line2 == o.address_line2 && administrative_area == o.administrative_area && country == o.country && locality == o.locality && first_name == o.first_name && last_name == o.last_name && phone_number == o.phone_number && email == o.email && postal_code == o.postal_code && address_line3 == o.address_line3 end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 280 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 346 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
246 247 248 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 246 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 252 def hash [address_line1, address_line2, administrative_area, country, locality, first_name, last_name, phone_number, email, postal_code, address_line3].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 155 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
326 327 328 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 326 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
332 333 334 335 336 337 338 339 340 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 332 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
320 321 322 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 320 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_order_billing.rb', line 162 def valid? true end |