Class: CyberSource::UnifiedriskRiskAssessmentBuyerHistoryCustomerAccount
- Inherits:
-
Object
- Object
- CyberSource::UnifiedriskRiskAssessmentBuyerHistoryCustomerAccount
- Defined in:
- lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb
Instance Attribute Summary collapse
-
#alertnate_authentication ⇒ Object
Returns the value of attribute alertnate_authentication.
-
#create_date ⇒ Object
Date the cardholder opened the account.
-
#creation_history ⇒ Object
The values from the enum can be: - GUEST - NEW_ACCOUNT - EXISTING_ACCOUNT.
-
#last_change_date ⇒ Object
Date the cardholder's account was last changed.
-
#modification_history ⇒ Object
This field is applicable only in case of EXISTING_ACCOUNT in creationHistory.
-
#password_change_date ⇒ Object
Date the cardholder last changed or reset password on account.
-
#password_history ⇒ Object
This only applies for EXISTING_ACCOUNT in creationHistory.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UnifiedriskRiskAssessmentBuyerHistoryCustomerAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UnifiedriskRiskAssessmentBuyerHistoryCustomerAccount
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 77 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'lastChangeDate') self.last_change_date = attributes[:'lastChangeDate'] end if attributes.has_key?(:'creationHistory') self.creation_history = attributes[:'creationHistory'] end if attributes.has_key?(:'modificationHistory') self.modification_history = attributes[:'modificationHistory'] end if attributes.has_key?(:'passwordHistory') self.password_history = attributes[:'passwordHistory'] end if attributes.has_key?(:'createDate') self.create_date = attributes[:'createDate'] end if attributes.has_key?(:'passwordChangeDate') self.password_change_date = attributes[:'passwordChangeDate'] end if attributes.has_key?(:'alertnateAuthentication') self.alertnate_authentication = attributes[:'alertnateAuthentication'] end end |
Instance Attribute Details
#alertnate_authentication ⇒ Object
Returns the value of attribute alertnate_authentication.
34 35 36 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 34 def alertnate_authentication @alertnate_authentication end |
#create_date ⇒ Object
Date the cardholder opened the account. Recommended for Discover ProtectBuy. This only applies for EXISTING_ACCOUNT in creationHistory.
29 30 31 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 29 def create_date @create_date end |
#creation_history ⇒ Object
The values from the enum can be: - GUEST - NEW_ACCOUNT - EXISTING_ACCOUNT
20 21 22 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 20 def creation_history @creation_history end |
#last_change_date ⇒ Object
Date the cardholder's account was last changed. This includes changes to the billing or shipping address, new payment accounts or new users added. Recommended for Discover ProtectBuy.
17 18 19 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 17 def last_change_date @last_change_date end |
#modification_history ⇒ Object
This field is applicable only in case of EXISTING_ACCOUNT in creationHistory. Possible values: - ACCOUNT_UPDATED_NOW - ACCOUNT_UPDATED_PAST
23 24 25 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 23 def modification_history @modification_history end |
#password_change_date ⇒ Object
Date the cardholder last changed or reset password on account. Recommended for Discover ProtectBuy. This only applies for PASSWORD_CHANGED_PAST in passwordHistory.
32 33 34 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 32 def password_change_date @password_change_date end |
#password_history ⇒ Object
This only applies for EXISTING_ACCOUNT in creationHistory. The values from the enum can be: - PASSWORD_CHANGED_NOW - PASSWORD_CHANGED_PAST - PASSWORD_NEVER_CHANGED
26 27 28 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 26 def password_history @password_history end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 37 def self.attribute_map { :'last_change_date' => :'lastChangeDate', :'creation_history' => :'creationHistory', :'modification_history' => :'modificationHistory', :'password_history' => :'passwordHistory', :'create_date' => :'createDate', :'password_change_date' => :'passwordChangeDate', :'alertnate_authentication' => :'alertnateAuthentication' } end |
.json_map ⇒ Object
Attribute mapping from JSON key to ruby-style variable name.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 50 def self.json_map { :'last_change_date' => :'last_change_date', :'creation_history' => :'creation_history', :'modification_history' => :'modification_history', :'password_history' => :'password_history', :'create_date' => :'create_date', :'password_change_date' => :'password_change_date', :'alertnate_authentication' => :'alertnate_authentication' } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 63 def self.swagger_types { :'last_change_date' => :'String', :'creation_history' => :'String', :'modification_history' => :'String', :'password_history' => :'String', :'create_date' => :'String', :'password_change_date' => :'String', :'alertnate_authentication' => :'UnifiedriskRiskAssessmentBuyerHistoryCustomerAccountAlertnateAuthentication' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && last_change_date == o.last_change_date && creation_history == o.creation_history && modification_history == o.modification_history && password_history == o.password_history && create_date == o.create_date && password_change_date == o.password_change_date && alertnate_authentication == o.alertnate_authentication end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 193 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CyberSource.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 259 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 172 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{self.class.json_map[key]}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{self.class.json_map[key]}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 165 def hash [last_change_date, creation_history, modification_history, password_history, create_date, password_change_date, alertnate_authentication].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 114 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
239 240 241 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 239 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
233 234 235 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 233 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 |
# File 'lib/cybersource_rest_client/models/unifiedrisk_risk_assessment_buyer_history_customer_account.rb', line 121 def valid? true end |